(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     15202,        567]*)
(*NotebookOutlinePosition[     15931,        592]*)
(*  CellTagsIndexPosition[     15887,        588]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Part ",
    FontWeight->"Bold"],
  StyleBox["1. Quantum Isotropic Rotator",
    FontWeight->"Bold"],
  "\n1.1. Two-Dimensional Isotropic Quantum Rotator"
}], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
1.1.2. Radial Equation of the Two-Dimensional Quantum Rotator:
General Solutions, Radial Wave Functions  and Energy Levels\
\>", "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["1. Radial equation of the two-dimensional quantum rotator", "Section"],

Cell[TextData[{
  "Consider radial equation (",
  StyleBox["RadDifEqnQntOsc",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  ") of the two-dimensional quantum rotator for ",
  Cell[BoxData[
      RowBox[{"|", 
        StyleBox["r",
          FontWeight->"Bold",
          FontSlant->"Italic"], 
        StyleBox["|",
          FontWeight->"Bold",
          FontSlant->"Plain"], 
        RowBox[{
          StyleBox["<",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["r0",
            FontWeight->"Bold",
            FontSlant->"Italic"]}]}]]],
  ": "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"RadDifEqnQntOsc", "=", 
      RowBox[{
        RowBox[{\(D[R[r], {r, 2}]\), "+", \(\((1/r)\)*D[R[r], r]\), "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"2", "*", 
                SubscriptBox["m", 
                  StyleBox["0",
                    "TI"]], "*", \(En/\[HBar]^2\)}], ")"}], "*", \(R[r]\)}], 
          "-", \(\((m\_azm\%2/r^2)\)*R[r]\)}], "\[Equal]", "0"}]}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(\(2\ En\ R[r]\ m\_0\)\/\[HBar]\^2\), 
        "-", \(\(R[r]\ m\_azm\%2\)\/r\^2\), "+", 
        FractionBox[
          RowBox[{
            SuperscriptBox["R", "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}], "r"], "+", 
        RowBox[{
          SuperscriptBox["R", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}], "==", 
      "0"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  Cell[BoxData[
      \(m\_0\)],
    FontSlant->"Italic"],
  " is mass of oscillating particle, ",
  Cell[BoxData[
      \(\(\(m\_azm\)\(\ \)\)\)],
    FontSlant->"Italic"],
  " is azimuth quantum number, ",
  Cell[BoxData[
      \(En\)],
    FontSlant->"Italic"],
  "  is total energy of oscillator,  ",
  Cell[BoxData[
      \(R[r]\)],
    FontSlant->"Italic"],
  " is radial part of wave function of rotator."
}], "Text"],

Cell["Use extra denotations:", "Text"],

Cell[BoxData[
    \(k = \@\(2\ \(m\_0\) En\)\/\[HBar]\)], "NumberedEquation",
  TextAlignment->Center],

Cell["and we will have", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RadDifEqnQntOsc1 = 
      Simplify[ReplaceAll[
          RadDifEqnQntOsc, {En \[Rule] \(k\^2\ \[HBar]\^2\)\/\(2\ \
m\_0\)}]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(R[r]\ \((k\^2 - m\_azm\%2\/r\^2)\)\), "+", 
        FractionBox[
          RowBox[{
            SuperscriptBox["R", "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}], "r"], "+", 
        RowBox[{
          SuperscriptBox["R", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}], "==", 
      "0"}]], "Output"]
}, Open  ]],

Cell["\<\
These transformation give dimensionless form of the radial equation.
We will seek solution of radial equation using the substitution:\
\>", "Text"],

Cell[BoxData[
    \(R[r] = \@r\ v[r]\)], "NumberedEquation",
  TextAlignment->Center],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[r] = \ \@r\ v[r]\), "\[IndentingNewLine]", 
    \(RadDifEqnQntOsc2 = 
      Simplify[\(-\(\(R[r]\ m\_azm\%2\)\/r\^2\)\) + k\^2\ R[r] + 
            D[R[r], r]\/r + D[R[r], {r, 2}]] \[Equal] 0\)}], "Input"],

Cell[BoxData[
    \(\@r\ v[r]\)], "Output"],

Cell[BoxData[
    RowBox[{
      FractionBox[
        RowBox[{\(\((1 + 4\ k\^2\ r\^2 - 4\ m\_azm\%2)\)\ v[r]\), "+", 
          RowBox[{"4", " ", "r", " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"2", " ", 
                  RowBox[{
                    SuperscriptBox["v", "\[Prime]",
                      MultilineFunction->None], "[", "r", "]"}]}], "+", 
                RowBox[{"r", " ", 
                  RowBox[{
                    SuperscriptBox["v", "\[Prime]\[Prime]",
                      MultilineFunction->None], "[", "r", "]"}]}]}], 
              ")"}]}]}], \(4\ r\^\(3/2\)\)], "==", "0"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "and will solve with \"",
  StyleBox["DSolve",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  "\" tool:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DSolve[RadDifEqnQntOsc2, v[r], r]\)], "Input"],

Cell[BoxData[
    \({{v[
            r] \[Rule] \(BesselJ[m\_azm, k\ r]\ C[1]\)\/\@r + \
\(BesselY[m\_azm, k\ r]\ C[2]\)\/\@r}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "General solution for ",
  Cell[BoxData[
      \(v[r]\)],
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "is superposition of two independent fundamental solutions:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(v1[r] = \ C[1] BesselJ[m\_azm, k\ r]\/\@r\), "\[IndentingNewLine]", 
    \(v2[r] = C[2]\ BesselY[m\_azm, k\ r]\/\@r\)}], "Input",
  TextAlignment->Center],

Cell[BoxData[
    \(\(BesselJ[m\_azm, k\ r]\ C[1]\)\/\@r\)], "Output"],

Cell[BoxData[
    \(\(BesselY[m\_azm, k\ r]\ C[2]\)\/\@r\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "where BesselJ is the Bessel function of the first kind ",
  Cell[BoxData[
      \(TraditionalForm\`\(J\_n\)(z)\)], "InlineFormula"],
  " and BesselY is the Bessel function of the second kind ",
  Cell[BoxData[
      \(TraditionalForm\`\(Y\_n\)(z)\)], "InlineFormula"],
  " and ",
  Cell[BoxData[
      \(\:0421[1]\)],
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  " and  ",
  Cell[BoxData[
      \(\:0421[2]\)],
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  " are constants.\nAs a result we have solution of the radial equation in \
the form:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(R[r] = Simplify[\ \@r\ \((v2[r] + v1[r])\)]\)], "Input"],

Cell[BoxData[
    \(BesselJ[m\_azm, k\ r]\ C[1] + BesselY[m\_azm, k\ r]\ C[2]\)], "Output"]
}, Open  ]],

Cell["or as superposition of two components:", "Text"],

Cell[BoxData[
    \(R[r] = R2[r] + R1[r]\)], "NumberedEquation",
  TextAlignment->Center],

Cell["where", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R1[r] = \ C[1]\ BesselJ[m\_azm, k\ r]\), "\[IndentingNewLine]", 
    \(R2[r] = \ C[2]\ BesselY[m\_azm, k\ r]\)}], "Input"],

Cell[BoxData[
    \(BesselJ[m\_azm, k\ r]\ C[1]\)], "Output"],

Cell[BoxData[
    \(BesselY[m\_azm, k\ r]\ C[2]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Now we analyze behavior of functions  ",
  Cell[BoxData[
      \(R1[r]\)],
    FontSlant->"Italic"],
  " and  ",
  Cell[BoxData[
      \(R2[r]\)],
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "near zero.\nTake Taylor series of the radial functions ",
  " ",
  Cell[BoxData[
      \(R1[r]\)],
    FontSlant->"Italic"],
  " and  ",
  Cell[BoxData[
      \(R2[r]\)],
    FontSlant->"Italic"],
  "near zero:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R2Taylor1[r] = 
      Simplify[Series[
          BesselJ[m\_azm, k\ r]\ , {r, \ 0, \ 1}]]\), "\[IndentingNewLine]", 
    \(R1Taylor2[r] = 
      Simplify[Series[BesselY[m\_azm, k\ r], {r, \ 0, \ 1}]]\)}], "Input"],

Cell[BoxData[
    RowBox[{\(r\^m\_azm\), " ", 
      RowBox[{"(", 
        InterpretationBox[
          RowBox[{\(\(2\^\(-m\_azm\)\ k\^m\_azm\)\/Gamma[1 + m\_azm]\), "+", 
            InterpretationBox[\(O[r]\^1\),
              SeriesData[ r, 0, {}, 0, 1, 1]]}],
          SeriesData[ r, 0, {
            Times[ 
              Power[ 2, 
                Times[ -1, 
                  Subscript[ m, azm]]], 
              Power[ k, 
                Subscript[ m, azm]], 
              Power[ 
                Gamma[ 
                  Plus[ 1, 
                    Subscript[ m, azm]]], -1]]}, 0, 1, 1]], ")"}]}]], "Output"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(r\^\(-m\_azm\)\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            
            RowBox[{\(-\(\(2\^m\_azm\ k\^\(-m\_azm\)\ Csc[\[Pi]\ \
m\_azm]\)\/Gamma[1 - m\_azm]\)\), "+", 
              InterpretationBox[\(O[r]\^1\),
                SeriesData[ r, 0, {}, 0, 1, 1]]}],
            SeriesData[ r, 0, {
              Times[ -1, 
                Power[ 2, 
                  Subscript[ m, azm]], 
                Power[ k, 
                  Times[ -1, 
                    Subscript[ m, azm]]], 
                Csc[ 
                  Times[ Pi, 
                    Subscript[ m, azm]]], 
                Power[ 
                  Gamma[ 
                    Plus[ 1, 
                      Times[ -1, 
                        Subscript[ m, azm]]]], -1]]}, 0, 1, 1]], ")"}]}], "+",
       
      RowBox[{\(r\^m\_azm\), " ", 
        RowBox[{"(", 
          InterpretationBox[
            
            RowBox[{\(\(2\^\(-m\_azm\)\ k\^m\_azm\ Cot[\[Pi]\ \
m\_azm]\)\/Gamma[1 + m\_azm]\), "+", 
              InterpretationBox[\(O[r]\^1\),
                SeriesData[ r, 0, {}, 0, 1, 1]]}],
            SeriesData[ r, 0, {
              Times[ 
                Power[ 2, 
                  Times[ -1, 
                    Subscript[ m, azm]]], 
                Power[ k, 
                  Subscript[ m, azm]], 
                Cot[ 
                  Times[ Pi, 
                    Subscript[ m, azm]]], 
                Power[ 
                  Gamma[ 
                    Plus[ 1, 
                      Subscript[ m, azm]]], -1]]}, 0, 1, 1]], 
          ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(R2[r]\)],
    FontSlant->"Italic"],
  " is divergent function near zero and ",
  " ",
  Cell[BoxData[
      \(R1[r]\)],
    FontSlant->"Italic"],
  " tends to zero.\nFiniteness of the wave function results us to condition:"
}], "Text"],

Cell[BoxData[
    \(C[2] = 0\)], "NumberedEquation",
  TextAlignment->Center],

Cell["\<\
Therefore radial wave function is:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(R[r] = C[1]\ BesselJ[m\_azm, k\ r]\)], "Input"],

Cell[BoxData[
    \(BesselJ[m\_azm, k\ r]\ C[1]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2. Condition for energy levels of the two-dimensional quantum rotator\
\>", "Section"],

Cell["\<\
Proper radial functions of the two-dimensional quantum rotator have to \
satisfy to boundary condition:\
\>", "Text"],

Cell[BoxData[
    \(R[r\_0] = 0\)], "NumberedEquation",
  TextAlignment->Center],

Cell["or", "Text"],

Cell[BoxData[
    \(BesselJ[m\_azm, k\ r0] = 0\)], "NumberedEquation",
  TextAlignment->Center],

Cell[TextData[{
  "Bessel function with certain value of ",
  Cell[BoxData[
      StyleBox[\(m\_azm\),
        FontSlant->"Italic"]],
    TextAlignment->Center],
  " has infinite number of zeros."
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "Therefor we will have infinite number of values ",
  Cell[BoxData[
      StyleBox[\(k\_\(n\_rad, m\_azm\)\),
        FontSlant->"Italic"]],
    TextAlignment->Center],
  " satisfying to ",
  "condition:"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    RowBox[{
      RowBox[{"BesselJ", "[", 
        RowBox[{\(m\_azm\), ",", 
          RowBox[{
            StyleBox[\(k\_\(n\_rad, m\_azm\)\),
              FontSlant->"Italic"], " ", "r0"}]}], "]"}], "=", 
      "0"}]], "NumberedEquation",
  TextAlignment->Center],

Cell["Thus we will have infinite number energy levels:", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"En", "=", 
      RowBox[{\(\[HBar]\^2\/\(2\ m\_0\)\), " ", 
        SuperscriptBox[
          StyleBox[\(k\_\(n\_rad, m\_azm\)\),
            FontSlant->"Italic"], "2"]}]}]], "Input",
  TextAlignment->Center],

Cell[BoxData[
    \(\(\[HBar]\^2\ k\_\(n\_rad, m\_azm\)\%2\)\/\(2\ m\_0\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(n\_r\)],
    FontSlant->"Italic"],
  " is the radial quantum number:"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(n\_rad = \ 1, 2, 3, 4.  .. \)], "NumberedEquation",
  TextAlignment->Center],

Cell[TextData[{
  "Radial quantum number  ",
  Cell[BoxData[
      \(n\_r\)],
    FontSlant->"Italic"],
  " defines number of ",
  "zeros",
  " of the ",
  "Bessel function ",
  Cell[BoxData[
      StyleBox[\(BesselJ[m\_azm, k\_\(n\_rad, m\_azm\)\ r0]\),
        FontSlant->"Italic"]],
    TextAlignment->Center],
  "."
}], "Text"]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1016, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.25,
StyleDefinitions -> "Classroom1.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 246, 8, 93, "Subtitle"],
Cell[2519, 82, 202, 5, 124, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2746, 91, 76, 0, 85, "Section"],
Cell[2825, 93, 654, 23, 57, "Text"],

Cell[CellGroupData[{
Cell[3504, 120, 440, 10, 88, "Input"],
Cell[3947, 132, 438, 11, 89, "Output"]
}, Open  ]],
Cell[4400, 146, 440, 17, 80, "Text"],
Cell[4843, 165, 38, 0, 56, "Text"],
Cell[4884, 167, 102, 2, 75, "NumberedEquation"],
Cell[4989, 171, 32, 0, 56, "Text"],

Cell[CellGroupData[{
Cell[5046, 175, 157, 4, 91, "Input"],
Cell[5206, 181, 394, 10, 96, "Output"]
}, Open  ]],
Cell[5615, 194, 157, 3, 92, "Text"],
Cell[5775, 199, 85, 2, 56, "NumberedEquation"],

Cell[CellGroupData[{
Cell[5885, 205, 228, 4, 124, "Input"],
Cell[6116, 211, 43, 1, 69, "Output"],
Cell[6162, 214, 653, 15, 89, "Output"]
}, Open  ]],
Cell[6830, 232, 187, 7, 57, "Text"],

Cell[CellGroupData[{
Cell[7042, 243, 66, 1, 63, "Input"],
Cell[7111, 246, 141, 3, 95, "Output"]
}, Open  ]],
Cell[7267, 252, 218, 8, 56, "Text"],

Cell[CellGroupData[{
Cell[7510, 264, 175, 3, 159, "Input"],
Cell[7688, 269, 70, 1, 95, "Output"],
Cell[7761, 272, 70, 1, 95, "Output"]
}, Open  ]],
Cell[7846, 276, 622, 21, 116, "Text"],

Cell[CellGroupData[{
Cell[8493, 301, 76, 1, 71, "Input"],
Cell[8572, 304, 91, 1, 63, "Output"]
}, Open  ]],
Cell[8678, 308, 54, 0, 56, "Text"],
Cell[8735, 310, 89, 2, 53, "NumberedEquation"],
Cell[8827, 314, 68, 2, 56, "Text"],

Cell[CellGroupData[{
Cell[8920, 320, 143, 2, 88, "Input"],
Cell[9066, 324, 61, 1, 63, "Output"],
Cell[9130, 327, 61, 1, 63, "Output"]
}, Open  ]],
Cell[9206, 331, 460, 21, 92, "Text"],

Cell[CellGroupData[{
Cell[9691, 356, 234, 5, 88, "Input"],
Cell[9928, 363, 624, 17, 89, "Output"],
Cell[10555, 382, 1642, 48, 89, "Output"]
}, Open  ]],
Cell[12212, 433, 282, 11, 92, "Text"],
Cell[12497, 446, 77, 2, 53, "NumberedEquation"],
Cell[12577, 450, 58, 2, 56, "Text"],

Cell[CellGroupData[{
Cell[12660, 456, 67, 1, 63, "Input"],
Cell[12730, 459, 61, 1, 63, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[12840, 466, 96, 2, 85, "Section"],
Cell[12939, 470, 127, 3, 56, "Text"],
Cell[13069, 475, 80, 2, 53, "NumberedEquation"],
Cell[13152, 479, 18, 0, 56, "Text"],
Cell[13173, 481, 95, 2, 53, "NumberedEquation"],
Cell[13271, 485, 255, 9, 56, "Text"],
Cell[13529, 496, 281, 10, 56, "Text"],
Cell[13813, 508, 281, 8, 54, "NumberedEquation"],
Cell[14097, 518, 111, 2, 56, "Text"],

Cell[CellGroupData[{
Cell[14233, 524, 235, 6, 91, "Input"],
Cell[14471, 532, 87, 1, 95, "Output"]
}, Open  ]],
Cell[14573, 536, 180, 8, 56, "Text"],
Cell[14756, 546, 96, 2, 53, "NumberedEquation"],
Cell[14855, 550, 331, 14, 56, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

