(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     13406,        416]*)
(*NotebookOutlinePosition[     14135,        441]*)
(*  CellTagsIndexPosition[     14091,        437]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Part ",
    FontWeight->"Bold"],
  StyleBox["1. Quantum Isotropic Rotator",
    FontWeight->"Bold"],
  "\n1.1. Two-Dimensional Isotropic Quantum Rotator"
}], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell["1.1.3. Energy levels of the two-dimensional quantum rotator", \
"Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
1. Zeros of the Bessel functions and energy levels of the two-dimensional \
quantum rotator\
\>", "Section"],

Cell[TextData[{
  "We will use \"",
  StyleBox["NumericalMath`BesselZeros`",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  "\" to find energy levels of the ",
  "two",
  "-dimensional quantum rotator."
}], "Text"],

Cell[BoxData[
    \(<< NumericalMath`BesselZeros`\)], "Input"],

Cell["\<\
We consider states of the two-dimensional quantum rotator defining by quantum \
numbers:\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(n\_rad = \ 1, 2, 3, 4\)],
    TextAlignment->Center],
  ",\n ",
  Cell[BoxData[
      \(m\_azm = 0, \ 1, 2, 3\)],
    TextAlignment->Center],
  "."
}], "NumberedEquation"],

Cell["Determine energy levels by the formulas:", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    RowBox[{\(En[n\_rad, m\_azm, r\_0]\), "=", 
      RowBox[{\(\[HBar]\^2\/\(2\ m\_0\)\), " ", 
        SuperscriptBox[
          StyleBox[\(k\_\(n\_rad, m\_azm\)\),
            FontSlant->"Italic"], "2"]}]}]], "NumberedEquation",
  TextAlignment->Center],

Cell["and calculate energy levels for given quantum numbers:", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell[TextData[{
  "1) ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\(BesselJZeros[m\_azm, {1, 1}];\)\), "\[IndentingNewLine]", 
    \(\(BesselJZeros[m\_azm, {2, 2}];\)\), "\[IndentingNewLine]", 
    \(\(BesselJZeros[m\_azm, {3, 3}];\)\), "\[IndentingNewLine]", 
    \(\(BesselJZeros[m\_azm, {4, 4}];\)\), "\[IndentingNewLine]", 
    \(\(k\_\(1, 0\) = 
        BesselJZeros[m\_azm, {1, 1}]\/r\_0;\)\), "\[IndentingNewLine]", 
    \(\(k\_\(2, 0\) = 
        BesselJZeros[m\_azm, {2, 2}]\/r\_0;\)\), "\[IndentingNewLine]", 
    \(\(k\_\(3, 0\) = 
        BesselJZeros[m\_azm, {3, 3}]\/r\_0;\)\), "\[IndentingNewLine]", 
    \(\(\(k\_\(4, 0\) = 
        BesselJZeros[m\_azm, {4, 4}]\/r\_0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(En[1, 0, 
        r\_0] = \[HBar]\^2\/\(2\ m\_0\)\ \((BesselJZeros[m\_azm, {1, \
1}]\/r\_0)\)\^2\), "\[IndentingNewLine]", 
    \(En[2, 0, 
        r\_0] = \[HBar]\^2\/\(2\ m\_0\)\ \((BesselJZeros[m\_azm, {2, \
2}]\/r\_0)\)\^2\), "\[IndentingNewLine]", 
    \(En[3, 0, 
        r\_0] = \[HBar]\^2\/\(2\ m\_0\)\ \((BesselJZeros[m\_azm, {3, \
3}]\/r\_0)\)\^2\), "\[IndentingNewLine]", 
    \(En[4, 0, 
        r\_0] = \[HBar]\^2\/\(2\ m\_0\)\ \((BesselJZeros[m\_azm, {4, \
4}]\/r\_0)\)\^2\)}], "Input"],

Cell[BoxData[
    \({\(2.8915929814733294`\ \[HBar]\^2\)\/\(m\_0\ r\_0\%2\)}\)], "Output"],

Cell[BoxData[
    \({\(15.235631171831038`\ \[HBar]\^2\)\/\(m\_0\ r\_0\%2\)}\)], "Output"],

Cell[BoxData[
    \({\(37.44350339710187`\ \[HBar]\^2\)\/\(m\_0\ r\_0\%2\)}\)], "Output"],

Cell[BoxData[
    \({\(69.5201422137344`\ \[HBar]\^2\)\/\(m\_0\ r\_0\%2\)}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "2) ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\(BesselJZeros[m\_azm, {1, 1}];\)\), "\[IndentingNewLine]", 
    \(\(BesselJZeros[m\_azm, {2, 2}];\)\), "\[IndentingNewLine]", 
    \(\(BesselJZeros[m\_azm, {3, 3}];\)\), "\[IndentingNewLine]", 
    \(\(BesselJZeros[m\_azm, {4, 4}];\)\), "\[IndentingNewLine]", 
    \(\(k\_\(1, 1\) = 
        BesselJZeros[m\_azm, {1, 1}]\/r\_0;\)\), "\[IndentingNewLine]", 
    \(\(k\_\(2, 1\) = 
        BesselJZeros[m\_azm, {2, 2}]\/r\_0;\)\), "\[IndentingNewLine]", 
    \(\(k\_\(3, 1\) = 
        BesselJZeros[m\_azm, {3, 3}]\/r\_0;\)\), "\[IndentingNewLine]", 
    \(\(\(k\_\(4, 1\) = 
        BesselJZeros[m\_azm, {4, 4}]\/r\_0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(En[1, 1, 
        r\_0] = \[HBar]\^2\/\(2\ m\_0\)\ \((BesselJZeros[m\_azm, {1, \
1}]\/r\_0)\)\^2\), "\[IndentingNewLine]", 
    \(En[2, 1, 
        r\_0] = \[HBar]\^2\/\(2\ m\_0\)\ \((BesselJZeros[m\_azm, {2, \
2}]\/r\_0)\)\^2\), "\[IndentingNewLine]", 
    \(En[3, 1, 
        r\_0] = \[HBar]\^2\/\(2\ m\_0\)\ \((BesselJZeros[m\_azm, {3, \
3}]\/r\_0)\)\^2\), "\[IndentingNewLine]", 
    \(En[4, 1, 
        r\_0] = \[HBar]\^2\/\(2\ m\_0\)\ \((BesselJZeros[m\_azm, {4, \
4}]\/r\_0)\)\^2\)}], "Input"],

Cell[BoxData[
    \({\(7.340985321061948`\ \[HBar]\^2\)\/\(m\_0\ r\_0\%2\)}\)], "Output"],

Cell[BoxData[
    \({\(24.609228160847277`\ \[HBar]\^2\)\/\(m\_0\ r\_0\%2\)}\)], "Output"],

Cell[BoxData[
    \({\(51.7497269485213`\ \[HBar]\^2\)\/\(m\_0\ r\_0\%2\)}\)], "Output"],

Cell[BoxData[
    \({\(88.76038340721897`\ \[HBar]\^2\)\/\(m\_0\ r\_0\%2\)}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "3) ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(m\_azm = 2;\)\), "\[IndentingNewLine]", 
    \(\(BesselJZeros[m\_azm, {1, 1}];\)\), "\[IndentingNewLine]", 
    \(\(BesselJZeros[m\_azm, {2, 2}];\)\), "\[IndentingNewLine]", 
    \(\(BesselJZeros[m\_azm, {3, 3}];\)\), "\[IndentingNewLine]", 
    \(\(BesselJZeros[m\_azm, {4, 4}];\)\), "\[IndentingNewLine]", 
    \(\(k\_\(1, 2\) = 
        BesselJZeros[m\_azm, {1, 1}]\/r\_0;\)\), "\[IndentingNewLine]", 
    \(\(k\_\(2, 2\) = 
        BesselJZeros[m\_azm, {2, 2}]\/r\_0;\)\), "\[IndentingNewLine]", 
    \(\(k\_\(3, 2\) = 
        BesselJZeros[m\_azm, {3, 3}]\/r\_0;\)\), "\[IndentingNewLine]", 
    \(\(\(k\_\(4, 2\) = 
        BesselJZeros[m\_azm, {4, 4}]\/r\_0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(En[1, 2, 
        r\_0] = \[HBar]\^2\/\(2\ m\_0\)\ \((BesselJZeros[m\_azm, {1, \
1}]\/r\_0)\)\^2\), "\[IndentingNewLine]", 
    \(En[2, 2, 
        r\_0] = \[HBar]\^2\/\(2\ m\_0\)\ \((BesselJZeros[m\_azm, {2, \
2}]\/r\_0)\)\^2\), "\[IndentingNewLine]", 
    \(En[3, 2, 
        r\_0] = \[HBar]\^2\/\(2\ m\_0\)\ \((BesselJZeros[m\_azm, {3, \
3}]\/r\_0)\)\^2\), "\[IndentingNewLine]", 
    \(En[4, 2, 
        r\_0] = \[HBar]\^2\/\(2\ m\_0\)\ \((BesselJZeros[m\_azm, {4, \
4}]\/r\_0)\)\^2\)}], "Input"],

Cell[BoxData[
    \({\(13.187308213581696`\ \[HBar]\^2\)\/\(m\_0\ r\_0\%2\)}\)], "Output"],

Cell[BoxData[
    \({\(35.42499946203892`\ \[HBar]\^2\)\/\(m\_0\ r\_0\%2\)}\)], "Output"],

Cell[BoxData[
    \({\(67.51035443359612`\ \[HBar]\^2\)\/\(m\_0\ r\_0\%2\)}\)], "Output"],

Cell[BoxData[
    \({\(109.4600945730517`\ \[HBar]\^2\)\/\(m\_0\ r\_0\%2\)}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "4) ",
  Cell[BoxData[
      \(m\_azm = 3\)]]
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(m\_azm = 3;\)\), "\[IndentingNewLine]", 
    \(\(BesselJZeros[m\_azm, {1, 1}];\)\), "\[IndentingNewLine]", 
    \(\(BesselJZeros[m\_azm, {2, 2}];\)\), "\[IndentingNewLine]", 
    \(\(BesselJZeros[m\_azm, {3, 3}];\)\), "\[IndentingNewLine]", 
    \(\(BesselJZeros[m\_azm, {4, 4}];\)\), "\[IndentingNewLine]", 
    \(\(k\_\(1, 3\) = 
        BesselJZeros[m\_azm, {1, 1}]\/r\_0;\)\), "\[IndentingNewLine]", 
    \(\(k\_\(2, 3\) = 
        BesselJZeros[m\_azm, {2, 2}]\/r\_0;\)\), "\[IndentingNewLine]", 
    \(\(k\_\(3, 3\) = 
        BesselJZeros[m\_azm, {3, 3}]\/r\_0;\)\), "\[IndentingNewLine]", 
    \(\(\(k\_\(4, 3\) = 
        BesselJZeros[m\_azm, {4, 4}]\/r\_0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(En[1, 3, 
        r\_0] = \[HBar]\^2\/\(2\ m\_0\)\ \((BesselJZeros[m\_azm, {1, \
1}]\/r\_0)\)\^2\), "\[IndentingNewLine]", 
    \(En[2, 3, 
        r\_0] = \[HBar]\^2\/\(2\ m\_0\)\ \((BesselJZeros[m\_azm, {2, \
2}]\/r\_0)\)\^2\), "\[IndentingNewLine]", 
    \(En[3, 3, 
        r\_0] = \[HBar]\^2\/\(2\ m\_0\)\ \((BesselJZeros[m\_azm, {3, \
3}]\/r\_0)\)\^2\), "\[IndentingNewLine]", 
    \(En[4, 3, 
        r\_0] = \[HBar]\^2\/\(2\ m\_0\)\ \((BesselJZeros[m\_azm, {4, \
4}]\/r\_0)\)\^2\)}], "Input"],

Cell[BoxData[
    \({\(20.353232909193416`\ \[HBar]\^2\)\/\(m\_0\ r\_0\%2\)}\)], "Output"],

Cell[BoxData[
    \({\(47.63878627365585`\ \[HBar]\^2\)\/\(m\_0\ r\_0\%2\)}\)], "Output"],

Cell[BoxData[
    \({\(84.6977249134818`\ \[HBar]\^2\)\/\(m\_0\ r\_0\%2\)}\)], "Output"],

Cell[BoxData[
    \({\(131.60042712766744`\ \[HBar]\^2\)\/\(m\_0\ r\_0\%2\)}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2. Calculated energy levels of the two-dimensional quantum rotator\
\>", "Section"],

Cell["\<\
Thus energy levels of the two-dimensional quantum rotator for given quantum \
numbers are:\
\>", "Text"],

Cell[BoxData[{
    \(\(En[1, 0, 
          r\_0] = \(2.8915929814733294`\ \[HBar]\^2\)\/\(m\_0\ \
r\_0\%2\);\)\), "\[IndentingNewLine]", 
    \(\(En[2, 0, 
          r\_0] = \(15.235631171831038`\ \[HBar]\^2\)\/\(m\_0\ \
r\_0\%2\);\)\), "\[IndentingNewLine]", 
    \(\(En[3, 0, 
          r\_0] = \(37.44350339710187`\ \[HBar]\^2\)\/\(m\_0\ r\_0\%2\);\)\), \
"\[IndentingNewLine]", 
    \(\(\(En[4, 0, 
          r\_0] = \(69.5201422137344`\ \[HBar]\^2\)\/\(m\_0\ r\_0\%2\);\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(En[1, 1, 
          r\_0] = \(7.340985321061948`\ \[HBar]\^2\)\/\(m\_0\ r\_0\%2\);\)\), \
"\[IndentingNewLine]", 
    \(\(En[2, 1, 
          r\_0] = \(24.609228160847277`\ \[HBar]\^2\)\/\(m\_0\ \
r\_0\%2\);\)\), "\[IndentingNewLine]", 
    \(\(En[3, 1, 
          r\_0] = \(51.7497269485213`\ \[HBar]\^2\)\/\(m\_0\ r\_0\%2\);\)\), \
"\[IndentingNewLine]", 
    \(\(\(En[4, 1, 
          r\_0] = \(88.76038340721897`\ \[HBar]\^2\)\/\(m\_0\ r\_0\%2\);\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(En[1, 2, 
          r\_0] = \(13.187308213581696`\ \[HBar]\^2\)\/\(m\_0\ \
r\_0\%2\);\)\), "\[IndentingNewLine]", 
    \(\(En[2, 2, 
          r\_0] = \(35.42499946203892`\ \[HBar]\^2\)\/\(m\_0\ r\_0\%2\);\)\), \
"\[IndentingNewLine]", 
    \(\(En[3, 2, 
          r\_0] = \(67.51035443359612`\ \[HBar]\^2\)\/\(m\_0\ r\_0\%2\);\)\), \
"\[IndentingNewLine]", 
    \(\(\(En[4, 2, 
          r\_0] = \(109.4600945730517`\ \[HBar]\^2\)\/\(m\_0\ r\_0\%2\);\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(En[1, 3, 
          r\_0] = \(20.353232909193416`\ \[HBar]\^2\)\/\(m\_0\ \
r\_0\%2\);\)\), "\[IndentingNewLine]", 
    \(\(En[2, 3, 
          r\_0] = \(47.63878627365585`\ \[HBar]\^2\)\/\(m\_0\ r\_0\%2\);\)\), \
"\[IndentingNewLine]", 
    \(\(En[3, 3, 
          r\_0] = \(84.6977249134818`\ \[HBar]\^2\)\/\(m\_0\ r\_0\%2\);\)\), \
"\[IndentingNewLine]", 
    \(\(En[4, 3, 
          r\_0] = \(131.60042712766744`\ \[HBar]\^2\)\/\(m\_0\ \
r\_0\%2\);\)\)}], "Input"],

Cell["", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1016, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.25,
StyleDefinitions -> "Classroom1.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 246, 8, 93, "Subtitle"],
Cell[2519, 82, 133, 3, 97, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2677, 89, 118, 3, 85, "Section"],
Cell[2798, 94, 267, 9, 57, "Text"],
Cell[3068, 105, 62, 1, 63, "Input"],
Cell[3133, 108, 112, 3, 56, "Text"],
Cell[3248, 113, 211, 9, 74, "NumberedEquation"],
Cell[3462, 124, 103, 2, 56, "Text"],
Cell[3568, 128, 270, 6, 74, "NumberedEquation"],
Cell[3841, 136, 117, 2, 56, "Text"],

Cell[CellGroupData[{
Cell[3983, 142, 81, 4, 89, "Subsection"],

Cell[CellGroupData[{
Cell[4089, 150, 1254, 26, 641, "Input"],
Cell[5346, 178, 90, 1, 93, "Output"],
Cell[5439, 181, 90, 1, 93, "Output"],
Cell[5532, 184, 89, 1, 93, "Output"],
Cell[5624, 187, 88, 1, 93, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5761, 194, 81, 4, 89, "Subsection"],

Cell[CellGroupData[{
Cell[5867, 202, 1254, 26, 641, "Input"],
Cell[7124, 230, 89, 1, 93, "Output"],
Cell[7216, 233, 90, 1, 93, "Output"],
Cell[7309, 236, 88, 1, 93, "Output"],
Cell[7400, 239, 89, 1, 93, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7538, 246, 81, 4, 89, "Subsection"],

Cell[CellGroupData[{
Cell[7644, 254, 1254, 26, 641, "Input"],
Cell[8901, 282, 90, 1, 93, "Output"],
Cell[8994, 285, 89, 1, 93, "Output"],
Cell[9086, 288, 89, 1, 93, "Output"],
Cell[9178, 291, 89, 1, 93, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9316, 298, 81, 4, 89, "Subsection"],

Cell[CellGroupData[{
Cell[9422, 306, 1254, 26, 641, "Input"],
Cell[10679, 334, 90, 1, 93, "Output"],
Cell[10772, 337, 89, 1, 93, "Output"],
Cell[10864, 340, 88, 1, 93, "Output"],
Cell[10955, 343, 90, 1, 93, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[11106, 351, 93, 2, 85, "Section"],
Cell[11202, 355, 114, 3, 56, "Text"],
Cell[11319, 360, 2052, 51, 1098, "Input"],
Cell[13374, 413, 16, 0, 56, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

