(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     33380,        987]*)
(*NotebookOutlinePosition[     34109,       1012]*)
(*  CellTagsIndexPosition[     34065,       1008]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Part ",
    FontWeight->"Bold"],
  StyleBox["1. Quantum Isotropic Rotator",
    FontWeight->"Bold"],
  "\n1.1. Two-Dimensional Isotropic Quantum Rotator"
}], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
1.1.4. Calculation Radial functions of the Two-Dimensional Quantum Rotator\
\>", "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
1. Zeros of the Bessel functions and calculation radial functions of the \
two-dimensional quantum rotator\
\>", "Section"],

Cell[TextData[{
  "We will use \"",
  StyleBox["NumericalMath`BesselZeros`",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  "\" to calculate radial functions of the ",
  "two",
  "-dimensional quantum rotator."
}], "Text"],

Cell[BoxData[
    \(<< NumericalMath`BesselZeros`\)], "Input"],

Cell["\<\
We consider states of he two-dimensional quantum rotator defining by quantum \
numbers:\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(n\_rad = \ 1, 2, 3, 4\)],
    TextAlignment->Center],
  ",\n ",
  Cell[BoxData[
      \(m\_azm = 0, \ 1, 2, 3\)],
    TextAlignment->Center],
  "."
}], "NumberedEquation"],

Cell[TextData[{
  "Determine parameter ",
  Cell[BoxData[
      \(TraditionalForm\`k\_\(n\_rad, m\_azm\)\)]],
  " and ",
  "radial functions",
  " by the formulas:"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{\(k\_\(n\_rad, m\_azm\) = 
      BesselJZeros[m\_azm, {1, 1}]\/r\_0\), "\[IndentingNewLine]", 
    RowBox[{\(R[n\_rad, m\_azm, r\_0]\), "=", 
      RowBox[{\(C[1]\), " ", 
        RowBox[{"BesselJ", "[", 
          RowBox[{\(m\_azm\), ",", 
            RowBox[{
              StyleBox[\(k\_\(n\_rad, m\_azm\)\),
                FontSlant->"Italic"], " ", "r"}]}], 
          "]"}]}]}]}], "NumberedEquation",
  TextAlignment->Center],

Cell["and calculate its for given quantum numbers:", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell[TextData[{
  "1) ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(m\_azm = 0;\), "\[IndentingNewLine]", \(BesselJZeros[
        m\_azm, {1, 1}];\), "\[IndentingNewLine]", \(BesselJZeros[
        m\_azm, {2, 2}];\), "\[IndentingNewLine]", \(BesselJZeros[
        m\_azm, {3, 3}];\), "\[IndentingNewLine]", \(BesselJZeros[
        m\_azm, {4, 4}];\), "\[IndentingNewLine]", \(k\_\(1, 0\) = 
        BesselJZeros[m\_azm, {1, 1}]\/r\_0;\), "\[IndentingNewLine]", \
\(k\_\(2, 0\) = 
        BesselJZeros[m\_azm, {2, 2}]\/r\_0;\), "\[IndentingNewLine]", \
\(k\_\(3, 0\) = BesselJZeros[m\_azm, {3, 3}]\/r\_0;\), "\[IndentingNewLine]", 
  
    RowBox[{\(k\_\(4, 0\) = BesselJZeros[m\_azm, {4, 4}]\/r\_0;\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{\(R[1, 0, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[1, 0]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(m\_azm\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[m\_azm, {1, 1}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}], "\[IndentingNewLine]", 
    RowBox[{\(R[2, 0, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[2, 0]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(m\_azm\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[m\_azm, {2, 2}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}], "\[IndentingNewLine]", 
    RowBox[{\(R[3, 0, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[3, 0]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(m\_azm\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[m\_azm, {3, 3}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}], "\[IndentingNewLine]", 
    RowBox[{\(R[4, 0, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[4, 0]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(m\_azm\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[m\_azm, {4, 4}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}]}], "Input"],

Cell[BoxData[
    \({BesselJ[0, \(2.4048255576957467`\ r\)\/r\_0]\ C[1, 0]}\)], "Output"],

Cell[BoxData[
    \({BesselJ[0, \(5.52007811028631`\ r\)\/r\_0]\ C[2, 0]}\)], "Output"],

Cell[BoxData[
    \({BesselJ[0, \(8.653727913113732`\ r\)\/r\_0]\ C[3, 0]}\)], "Output"],

Cell[BoxData[
    \({BesselJ[0, \(11.791534439057065`\ r\)\/r\_0]\ C[4, 0]}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "2) ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(m\_azm = 1;\), "\[IndentingNewLine]", \(BesselJZeros[
        m\_azm, {1, 1}];\), "\[IndentingNewLine]", \(BesselJZeros[
        m\_azm, {2, 2}];\), "\[IndentingNewLine]", \(BesselJZeros[
        m\_azm, {3, 3}];\), "\[IndentingNewLine]", \(BesselJZeros[
        m\_azm, {4, 4}];\), "\[IndentingNewLine]", \(k\_\(1, 1\) = 
        BesselJZeros[m\_azm, {1, 1}]\/r\_0;\), "\[IndentingNewLine]", \
\(k\_\(2, 1\) = 
        BesselJZeros[m\_azm, {2, 2}]\/r\_0;\), "\[IndentingNewLine]", \
\(k\_\(3, 1\) = BesselJZeros[m\_azm, {3, 3}]\/r\_0;\), "\[IndentingNewLine]", 
  
    RowBox[{\(k\_\(4, 1\) = BesselJZeros[m\_azm, {4, 4}]\/r\_0;\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{\(R[1, 1, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[1, 1]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(m\_azm\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[m\_azm, {1, 1}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}], "\[IndentingNewLine]", 
    RowBox[{\(R[2, 1, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[2, 1]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(m\_azm\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[m\_azm, {2, 2}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}], "\[IndentingNewLine]", 
    RowBox[{\(R[3, 1, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[3, 1]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(m\_azm\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[m\_azm, {3, 3}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}], "\[IndentingNewLine]", 
    RowBox[{\(R[4, 1, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[4, 1]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(m\_azm\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[m\_azm, {4, 4}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}]}], "Input"],

Cell[BoxData[
    \({BesselJ[1, \(3.8317059702075125`\ r\)\/r\_0]\ C[1, 1]}\)], "Output"],

Cell[BoxData[
    \({BesselJ[1, \(7.015586669815615`\ r\)\/r\_0]\ C[2, 1]}\)], "Output"],

Cell[BoxData[
    \({BesselJ[1, \(10.173468135156398`\ r\)\/r\_0]\ C[3, 1]}\)], "Output"],

Cell[BoxData[
    \({BesselJ[1, \(13.323691936337989`\ r\)\/r\_0]\ C[4, 1]}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "3) ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(m\_azm = 2;\), "\[IndentingNewLine]", \(BesselJZeros[
        m\_azm, {1, 1}];\), "\[IndentingNewLine]", \(BesselJZeros[
        m\_azm, {2, 2}];\), "\[IndentingNewLine]", \(BesselJZeros[
        m\_azm, {3, 3}];\), "\[IndentingNewLine]", \(BesselJZeros[
        m\_azm, {4, 4}];\), "\[IndentingNewLine]", \(k\_\(1, 2\) = 
        BesselJZeros[m\_azm, {1, 1}]\/r\_0;\), "\[IndentingNewLine]", \
\(k\_\(2, 2\) = 
        BesselJZeros[m\_azm, {2, 2}]\/r\_0;\), "\[IndentingNewLine]", \
\(k\_\(3, 2\) = BesselJZeros[m\_azm, {3, 3}]\/r\_0;\), "\[IndentingNewLine]", 
  
    RowBox[{\(k\_\(4, 2\) = BesselJZeros[m\_azm, {4, 4}]\/r\_0;\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{\(R[1, 2, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[1, 2]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(m\_azm\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[m\_azm, {1, 1}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}], "\[IndentingNewLine]", 
    RowBox[{\(R[2, 2, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[2, 2]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(m\_azm\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[m\_azm, {2, 2}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}], "\[IndentingNewLine]", 
    RowBox[{\(R[3, 2, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[3, 2]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(m\_azm\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[m\_azm, {3, 3}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}], "\[IndentingNewLine]", 
    RowBox[{\(R[4, 2, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[4, 2]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(m\_azm\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[m\_azm, {4, 4}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}]}], "Input"],

Cell[BoxData[
    \({BesselJ[2, \(5.135622301840683`\ r\)\/r\_0]\ C[1, 2]}\)], "Output"],

Cell[BoxData[
    \({BesselJ[2, \(8.417244140695804`\ r\)\/r\_0]\ C[2, 2]}\)], "Output"],

Cell[BoxData[
    \({BesselJ[2, \(11.619841172201633`\ r\)\/r\_0]\ C[3, 2]}\)], "Output"],

Cell[BoxData[
    \({BesselJ[2, \(14.795951782366128`\ r\)\/r\_0]\ C[4, 2]}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "4) ",
  Cell[BoxData[
      \(m\_azm = 3\)]]
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(m\_azm = 3;\), "\[IndentingNewLine]", \(BesselJZeros[
        m\_azm, {1, 1}];\), "\[IndentingNewLine]", \(BesselJZeros[
        m\_azm, {2, 2}];\), "\[IndentingNewLine]", \(BesselJZeros[
        m\_azm, {3, 3}];\), "\[IndentingNewLine]", \(BesselJZeros[
        m\_azm, {4, 4}];\), "\[IndentingNewLine]", \(k\_\(1, 3\) = 
        BesselJZeros[m\_azm, {1, 1}]\/r\_0;\), "\[IndentingNewLine]", \
\(k\_\(2, 3\) = 
        BesselJZeros[m\_azm, {2, 2}]\/r\_0;\), "\[IndentingNewLine]", \
\(k\_\(3, 3\) = BesselJZeros[m\_azm, {3, 3}]\/r\_0;\), "\[IndentingNewLine]", 
  
    RowBox[{\(k\_\(4, 3\) = BesselJZeros[m\_azm, {4, 4}]\/r\_0;\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{\(R[1, 3, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[1, 3]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(m\_azm\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[m\_azm, {1, 1}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}], "\[IndentingNewLine]", 
    RowBox[{\(R[2, 3, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[2, 3]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(m\_azm\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[m\_azm, {2, 2}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}], "\[IndentingNewLine]", 
    RowBox[{\(R[3, 3, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[3, 3]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(m\_azm\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[m\_azm, {3, 3}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}], "\[IndentingNewLine]", 
    RowBox[{\(R[4, 3, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[4, 3]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(m\_azm\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[m\_azm, {4, 4}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}]}], "Input"],

Cell[BoxData[
    \({BesselJ[3, \(6.3801618959386`\ r\)\/r\_0]\ C[1, 3]}\)], "Output"],

Cell[BoxData[
    \({BesselJ[3, \(9.761023130149406`\ r\)\/r\_0]\ C[2, 3]}\)], "Output"],

Cell[BoxData[
    \({BesselJ[3, \(13.015200721731633`\ r\)\/r\_0]\ C[3, 3]}\)], "Output"],

Cell[BoxData[
    \({BesselJ[3, \(16.223466160328837`\ r\)\/r\_0]\ C[4, 3]}\)], "Output"]
}, Open  ]],

Cell["Thus radial functions for given quantum numbers are:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{\(R[1, 0, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[1, 0]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{"0", ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[0, {1, 1}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}], "\[IndentingNewLine]", 
    RowBox[{\(R[2, 0, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[2, 0]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{"0", ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[0, {2, 2}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}], "\[IndentingNewLine]", 
    RowBox[{\(R[3, 0, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[3, 0]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{"0", ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[0, {3, 3}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(R[4, 0, r\_0]\), "=", 
        RowBox[{"FullSimplify", "[", 
          RowBox[{\(C[4, 0]\), " ", 
            RowBox[{"BesselJ", "[", 
              RowBox[{"0", ",", 
                RowBox[{
                  StyleBox[\(BesselJZeros[0, {4, 4}]\/r\_0\),
                    FontSlant->"Italic"], " ", "r"}]}], "]"}]}], "]"}]}], 
      "\[IndentingNewLine]", "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{\(R[1, 1, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[1, 1]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{"1", ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[1, {1, 1}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}], "\[IndentingNewLine]", 
    RowBox[{\(R[2, 1, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[2, 1]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{"1", ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[1, {2, 2}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}], "\[IndentingNewLine]", 
    RowBox[{\(R[3, 1, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[3, 1]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{"1", ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[1, {3, 3}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(R[4, 1, r\_0]\), "=", 
        RowBox[{"FullSimplify", "[", 
          RowBox[{\(C[4, 1]\), " ", 
            RowBox[{"BesselJ", "[", 
              RowBox[{"1", ",", 
                RowBox[{
                  StyleBox[\(BesselJZeros[1, {4, 4}]\/r\_0\),
                    FontSlant->"Italic"], " ", "r"}]}], "]"}]}], "]"}]}], 
      "\[IndentingNewLine]", "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{\(R[1, 2, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[1, 2]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{"2", ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[2, {1, 1}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}], "\[IndentingNewLine]", 
    RowBox[{\(R[2, 2, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[2, 2]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{"2", ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[2, {2, 2}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}], "\[IndentingNewLine]", 
    RowBox[{\(R[3, 2, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[3, 2]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{"2", ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[2, {3, 3}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(R[4, 2, r\_0]\), "=", 
        RowBox[{"FullSimplify", "[", 
          RowBox[{\(C[4, 2]\), " ", 
            RowBox[{"BesselJ", "[", 
              RowBox[{"2", ",", 
                RowBox[{
                  StyleBox[\(BesselJZeros[2, {4, 4}]\/r\_0\),
                    FontSlant->"Italic"], " ", "r"}]}], "]"}]}], "]"}]}], 
      "\[IndentingNewLine]", "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{\(R[1, 3, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[1, 3]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{"3", ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[3, {1, 1}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}], "\[IndentingNewLine]", 
    RowBox[{\(R[2, 3, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[2, 3]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{"3", ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[3, {2, 2}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}], "\[IndentingNewLine]", 
    RowBox[{\(R[3, 3, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[3, 3]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{"3", ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[3, {3, 3}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}], "\[IndentingNewLine]", 
    RowBox[{\(R[4, 3, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[4, 3]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{"3", ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[3, {4, 4}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}]}], "Input"],

Cell[BoxData[
    \({BesselJ[0, \(2.4048255576957467`\ r\)\/r\_0]\ C[1, 0]}\)], "Output"],

Cell[BoxData[
    \({BesselJ[0, \(5.52007811028631`\ r\)\/r\_0]\ C[2, 0]}\)], "Output"],

Cell[BoxData[
    \({BesselJ[0, \(8.653727913113732`\ r\)\/r\_0]\ C[3, 0]}\)], "Output"],

Cell[BoxData[
    \({BesselJ[0, \(11.791534439057065`\ r\)\/r\_0]\ C[4, 0]}\)], "Output"],

Cell[BoxData[
    \({BesselJ[1, \(3.8317059702075125`\ r\)\/r\_0]\ C[1, 1]}\)], "Output"],

Cell[BoxData[
    \({BesselJ[1, \(7.015586669815615`\ r\)\/r\_0]\ C[2, 1]}\)], "Output"],

Cell[BoxData[
    \({BesselJ[1, \(10.173468135156398`\ r\)\/r\_0]\ C[3, 1]}\)], "Output"],

Cell[BoxData[
    \({BesselJ[1, \(13.323691936337989`\ r\)\/r\_0]\ C[4, 1]}\)], "Output"],

Cell[BoxData[
    \({BesselJ[2, \(5.135622301840683`\ r\)\/r\_0]\ C[1, 2]}\)], "Output"],

Cell[BoxData[
    \({BesselJ[2, \(8.417244140695804`\ r\)\/r\_0]\ C[2, 2]}\)], "Output"],

Cell[BoxData[
    \({BesselJ[2, \(11.619841172201633`\ r\)\/r\_0]\ C[3, 2]}\)], "Output"],

Cell[BoxData[
    \({BesselJ[2, \(14.795951782366128`\ r\)\/r\_0]\ C[4, 2]}\)], "Output"],

Cell[BoxData[
    \({BesselJ[3, \(6.3801618959386`\ r\)\/r\_0]\ C[1, 3]}\)], "Output"],

Cell[BoxData[
    \({BesselJ[3, \(9.761023130149406`\ r\)\/r\_0]\ C[2, 3]}\)], "Output"],

Cell[BoxData[
    \({BesselJ[3, \(13.015200721731633`\ r\)\/r\_0]\ C[3, 3]}\)], "Output"],

Cell[BoxData[
    \({BesselJ[3, \(16.223466160328837`\ r\)\/r\_0]\ C[4, 3]}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2. General formula for radial functions of the two-dimensional quantum \
rotator\
\>", "Section"],

Cell["We can calculate radial functions by the general formula:", "Text"],

Cell[BoxData[
    RowBox[{\(R[n\_rad, m\_azm, r\_0]\), "=", 
      RowBox[{\(C[n\_rad, m\_azm]\), " ", 
        RowBox[{"BesselJ", "[", 
          RowBox[{\(m\_azm\), ",", 
            RowBox[{
              StyleBox[\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\/r\_0\),
                FontSlant->"Italic"], " ", "r"}]}], 
          "]"}]}]}]], "NumberedEquation"],

Cell["\<\
and calculate individual radial functions for given quantum numbers:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell[TextData[{
  "1) ",
  Cell[BoxData[
      \(n\_rad = 1\)]]
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 1;\), "\[IndentingNewLine]", \(m\_azm = 
        0;\), "\[IndentingNewLine]", 
    RowBox[{\(R[n\_rad, m\_azm, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[n\_rad, m\_azm]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(m\_azm\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}]}], "Input"],

Cell[BoxData[
    \({BesselJ[0, \(2.4048255576957467`\ r\)\/r\_0]\ C[1, 0]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 1;\), "\n", \(m\_azm = 1;\), "\n", 
    RowBox[{\(R[n\_rad, m\_azm, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[n\_rad, m\_azm]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(m\_azm\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}]}], "Input"],

Cell[BoxData[
    \({BesselJ[1, \(3.8317059702075125`\ r\)\/r\_0]\ C[1, 1]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 1;\), "\n", \(m\_azm = 2;\), "\n", 
    RowBox[{\(R[n\_rad, m\_azm, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[n\_rad, m\_azm]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(m\_azm\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}]}], "Input"],

Cell[BoxData[
    \({BesselJ[2, \(5.135622301840683`\ r\)\/r\_0]\ C[1, 2]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 1;\), "\n", \(m\_azm = 3;\), "\n", 
    RowBox[{\(R[n\_rad, m\_azm, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[n\_rad, m\_azm]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(m\_azm\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}]}], "Input"],

Cell[BoxData[
    \({BesselJ[3, \(6.3801618959386`\ r\)\/r\_0]\ C[1, 3]}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "2) ",
  Cell[BoxData[
      \(n\_rad = 2\)]]
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 2;\), "\[IndentingNewLine]", \(m\_azm = 
        0;\), "\[IndentingNewLine]", 
    RowBox[{\(R[n\_rad, m\_azm, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[n\_rad, m\_azm]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(m\_azm\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}]}], "Input"],

Cell[BoxData[
    \({BesselJ[0, \(5.52007811028631`\ r\)\/r\_0]\ C[2, 0]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 2;\), "\n", \(m\_azm = 1;\), "\n", 
    RowBox[{\(R[n\_rad, m\_azm, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[n\_rad, m\_azm]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(m\_azm\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}]}], "Input"],

Cell[BoxData[
    \({BesselJ[1, \(7.015586669815615`\ r\)\/r\_0]\ C[2, 1]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 2;\), "\n", \(m\_azm = 2;\), "\n", 
    RowBox[{\(R[n\_rad, m\_azm, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[n\_rad, m\_azm]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(m\_azm\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}]}], "Input"],

Cell[BoxData[
    \({BesselJ[2, \(8.417244140695804`\ r\)\/r\_0]\ C[2, 2]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 2;\), "\n", \(m\_azm = 3;\), "\n", 
    RowBox[{\(R[n\_rad, m\_azm, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[n\_rad, m\_azm]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(m\_azm\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}]}], "Input"],

Cell[BoxData[
    \({BesselJ[3, \(9.761023130149406`\ r\)\/r\_0]\ C[2, 3]}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "3) ",
  Cell[BoxData[
      \(n\_rad = 3\)]]
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 3;\), "\[IndentingNewLine]", \(m\_azm = 
        0;\), "\[IndentingNewLine]", 
    RowBox[{\(R[n\_rad, m\_azm, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[n\_rad, m\_azm]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(m\_azm\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}]}], "Input"],

Cell[BoxData[
    \({BesselJ[0, \(8.653727913113732`\ r\)\/r\_0]\ C[3, 0]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 3;\), "\n", \(m\_azm = 1;\), "\n", 
    RowBox[{\(R[n\_rad, m\_azm, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[n\_rad, m\_azm]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(m\_azm\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}]}], "Input"],

Cell[BoxData[
    \({BesselJ[1, \(10.173468135156398`\ r\)\/r\_0]\ C[3, 1]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 3;\), "\n", \(m\_azm = 2;\), "\n", 
    RowBox[{\(R[n\_rad, m\_azm, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[n\_rad, m\_azm]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(m\_azm\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}]}], "Input"],

Cell[BoxData[
    \({BesselJ[2, \(11.619841172201633`\ r\)\/r\_0]\ C[3, 2]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 3;\), "\n", \(m\_azm = 3;\), "\n", 
    RowBox[{\(R[n\_rad, m\_azm, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[n\_rad, m\_azm]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(m\_azm\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}]}], "Input"],

Cell[BoxData[
    \({BesselJ[3, \(13.015200721731633`\ r\)\/r\_0]\ C[3, 3]}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "4) ",
  Cell[BoxData[
      \(n\_rad = 4\)]]
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 4;\), "\[IndentingNewLine]", \(m\_azm = 
        0;\), "\[IndentingNewLine]", 
    RowBox[{\(R[n\_rad, m\_azm, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[n\_rad, m\_azm]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(m\_azm\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}]}], "Input"],

Cell[BoxData[
    \({BesselJ[0, \(11.791534439057065`\ r\)\/r\_0]\ C[4, 0]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 4;\), "\n", \(m\_azm = 1;\), "\n", 
    RowBox[{\(R[n\_rad, m\_azm, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[n\_rad, m\_azm]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(m\_azm\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}]}], "Input"],

Cell[BoxData[
    \({BesselJ[1, \(13.323691936337989`\ r\)\/r\_0]\ C[4, 1]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 4;\), "\n", \(m\_azm = 2;\), "\n", 
    RowBox[{\(R[n\_rad, m\_azm, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[n\_rad, m\_azm]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(m\_azm\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}]}], "Input"],

Cell[BoxData[
    \({BesselJ[2, \(14.795951782366128`\ r\)\/r\_0]\ C[4, 2]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 4;\), "\n", \(m\_azm = 3;\), "\n", 
    RowBox[{\(R[n\_rad, m\_azm, r\_0]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(C[n\_rad, m\_azm]\), " ", 
          RowBox[{"BesselJ", "[", 
            RowBox[{\(m\_azm\), ",", 
              RowBox[{
                StyleBox[\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\/r\_0\),
                  FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
        "]"}]}]}], "Input"],

Cell[BoxData[
    \({BesselJ[3, \(16.223466160328837`\ r\)\/r\_0]\ C[4, 3]}\)], "Output"]
}, Open  ]],

Cell["", "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1016, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.25,
StyleDefinitions -> "Classroom1.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 246, 8, 93, "Subtitle"],
Cell[2519, 82, 154, 4, 97, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2698, 90, 133, 3, 119, "Section"],
Cell[2834, 95, 275, 9, 57, "Text"],
Cell[3112, 106, 62, 1, 63, "Input"],
Cell[3177, 109, 111, 3, 56, "Text"],
Cell[3291, 114, 211, 9, 74, "NumberedEquation"],
Cell[3505, 125, 223, 9, 57, "Text"],
Cell[3731, 136, 446, 10, 99, "NumberedEquation"],
Cell[4180, 148, 107, 2, 56, "Text"],

Cell[CellGroupData[{
Cell[4312, 154, 81, 4, 89, "Subsection"],

Cell[CellGroupData[{
Cell[4418, 162, 2187, 47, 625, "Input"],
Cell[6608, 211, 89, 1, 88, "Output"],
Cell[6700, 214, 87, 1, 88, "Output"],
Cell[6790, 217, 88, 1, 88, "Output"],
Cell[6881, 220, 89, 1, 88, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7019, 227, 81, 4, 89, "Subsection"],

Cell[CellGroupData[{
Cell[7125, 235, 2187, 47, 625, "Input"],
Cell[9315, 284, 89, 1, 88, "Output"],
Cell[9407, 287, 88, 1, 88, "Output"],
Cell[9498, 290, 89, 1, 88, "Output"],
Cell[9590, 293, 89, 1, 88, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9728, 300, 81, 4, 89, "Subsection"],

Cell[CellGroupData[{
Cell[9834, 308, 2187, 47, 625, "Input"],
Cell[12024, 357, 88, 1, 88, "Output"],
Cell[12115, 360, 88, 1, 88, "Output"],
Cell[12206, 363, 89, 1, 88, "Output"],
Cell[12298, 366, 89, 1, 88, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[12436, 373, 81, 4, 89, "Subsection"],

Cell[CellGroupData[{
Cell[12542, 381, 2187, 47, 625, "Input"],
Cell[14732, 430, 86, 1, 88, "Output"],
Cell[14821, 433, 88, 1, 88, "Output"],
Cell[14912, 436, 89, 1, 88, "Output"],
Cell[15004, 439, 89, 1, 88, "Output"]
}, Open  ]],
Cell[15108, 443, 68, 0, 56, "Text"],

Cell[CellGroupData[{
Cell[15201, 447, 6018, 147, 1063, "Input"],
Cell[21222, 596, 89, 1, 88, "Output"],
Cell[21314, 599, 87, 1, 88, "Output"],
Cell[21404, 602, 88, 1, 88, "Output"],
Cell[21495, 605, 89, 1, 88, "Output"],
Cell[21587, 608, 89, 1, 88, "Output"],
Cell[21679, 611, 88, 1, 88, "Output"],
Cell[21770, 614, 89, 1, 88, "Output"],
Cell[21862, 617, 89, 1, 88, "Output"],
Cell[21954, 620, 88, 1, 88, "Output"],
Cell[22045, 623, 88, 1, 88, "Output"],
Cell[22136, 626, 89, 1, 88, "Output"],
Cell[22228, 629, 89, 1, 88, "Output"],
Cell[22320, 632, 86, 1, 88, "Output"],
Cell[22409, 635, 88, 1, 88, "Output"],
Cell[22500, 638, 89, 1, 88, "Output"],
Cell[22592, 641, 89, 1, 88, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[22742, 649, 107, 3, 85, "Section"],
Cell[22852, 654, 73, 0, 56, "Text"],
Cell[22928, 656, 361, 8, 71, "NumberedEquation"],
Cell[23292, 666, 139, 4, 56, "Text"],

Cell[CellGroupData[{
Cell[23456, 674, 81, 4, 89, "Subsection"],

Cell[CellGroupData[{
Cell[23562, 682, 494, 10, 165, "Input"],
Cell[24059, 694, 89, 1, 88, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24185, 700, 451, 9, 165, "Input"],
Cell[24639, 711, 89, 1, 88, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24765, 717, 451, 9, 165, "Input"],
Cell[25219, 728, 88, 1, 88, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25344, 734, 451, 9, 165, "Input"],
Cell[25798, 745, 86, 1, 88, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[25933, 752, 81, 4, 89, "Subsection"],

Cell[CellGroupData[{
Cell[26039, 760, 494, 10, 165, "Input"],
Cell[26536, 772, 87, 1, 88, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26660, 778, 451, 9, 165, "Input"],
Cell[27114, 789, 88, 1, 88, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27239, 795, 451, 9, 165, "Input"],
Cell[27693, 806, 88, 1, 88, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27818, 812, 451, 9, 165, "Input"],
Cell[28272, 823, 88, 1, 88, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[28409, 830, 81, 4, 89, "Subsection"],

Cell[CellGroupData[{
Cell[28515, 838, 494, 10, 165, "Input"],
Cell[29012, 850, 88, 1, 88, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29137, 856, 451, 9, 165, "Input"],
Cell[29591, 867, 89, 1, 88, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29717, 873, 451, 9, 165, "Input"],
Cell[30171, 884, 89, 1, 88, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30297, 890, 451, 9, 165, "Input"],
Cell[30751, 901, 89, 1, 88, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[30889, 908, 81, 4, 89, "Subsection"],

Cell[CellGroupData[{
Cell[30995, 916, 494, 10, 165, "Input"],
Cell[31492, 928, 89, 1, 88, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31618, 934, 451, 9, 165, "Input"],
Cell[32072, 945, 89, 1, 88, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32198, 951, 451, 9, 165, "Input"],
Cell[32652, 962, 89, 1, 88, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32778, 968, 451, 9, 165, "Input"],
Cell[33232, 979, 89, 1, 88, "Output"]
}, Open  ]],
Cell[33336, 983, 16, 0, 56, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

