(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     44807,       1569]*)
(*NotebookOutlinePosition[     45536,       1594]*)
(*  CellTagsIndexPosition[     45492,       1590]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Part ",
    FontWeight->"Bold"],
  StyleBox["1. Quantum Isotropic Rotator",
    FontWeight->"Bold"],
  "\n1.1. Two-Dimensional Isotropic Quantum Rotator"
}], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
1.1.5. Radial probability density and normalization of the radial wave \
functions of Two-Dimensional Quantum Rotator\
\>", "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
1. Radial probability density of the two-dimensional quantum rotator\
\>", "Section"],

Cell[TextData[{
  "We will use \"",
  StyleBox["NumericalMath`BesselZeros`",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  "\"."
}], "Text"],

Cell[BoxData[
    \(<< NumericalMath`BesselZeros`\)], "Input"],

Cell["\<\
Consider radial wave function of the two-dimensional quantum rotator:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(R[n\_rad, m\_azm, r0, r]\), "=", 
      RowBox[{\(C[n\_rad, m\_azm]\), " ", 
        RowBox[{"BesselJ", "[", 
          RowBox[{\(m\_azm\), ",", 
            RowBox[{
              StyleBox[\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\/r0\),
                FontSlant->"Italic"], " ", "r"}]}], "]"}]}]}]], "Input"],

Cell[BoxData[
    \(BesselJ[m\_azm, \(r\ BesselJZeros[m\_azm, {n\_rad, n\_rad}]\)\/r0]\ C[
        n\_rad, m\_azm]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(C[n\_rad, m\_azm]\)],
    FontSlant->"Italic"],
  "are constants."
}], "Text"],

Cell["\<\
Define radial probability density of the two-dimensional quantum rotator:\
\>", "Text"],

Cell[BoxData[
    \(RR[n\_rad, m\_azm, 
        r\_0] = \(\(|\)\(R[n\_rad, m\_azm, 
          r\_0]\)\( | \^2\)\(\ \)\(r\)\)\)], "NumberedEquation",
  TextAlignment->Center],

Cell[TextData[{
  "As ",
  Cell[BoxData[
      \(R[n\_rad, m\_azm, r0, r]\)],
    FontSlant->"Italic"],
  "is real ",
  "function we have"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell[BoxData[
    \(RR[n\_rad, m\_azm, r0, r] = 
      FullSimplify[R[n\_rad, m\_azm, r0, r]\^2\ r]\)], "Input"],

Cell[BoxData[
    \(r\ BesselJ[m\_azm, \(r\ BesselJZeros[m\_azm, {n\_rad, \
n\_rad}]\)\/r0]\^2\ C[n\_rad, m\_azm]\^2\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2. Dimensionless form of the radial wave functions of the two-dimensional \
quantum rotator\
\>", "Section"],

Cell[TextData[{
  "Transform  radial wave function of ",
  "the two-dimensional quantum rotator",
  " to the dimensionless form using new dimensionless variable \[Rho] and \
constant ",
  Cell[BoxData[
      \(C[n\_rad, m\_azm, \[Lambda]]\)],
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[BoxData[
    \(r = \(\[Rho]\ r0\)\/BesselJZeros[m\_azm, {n\_rad, n\_rad}], \[Rho] = \
\(r\ BesselJZeros[m\_azm, {n\_rad, n\_rad}]\)\/r0\)], "NumberedEquation"],

Cell[CellGroupData[{

Cell[BoxData[
    \(R[n\_rad, m\_azm, r0, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, m\_azm, r0, 
          r], {r \[Rule] \(\[Rho]\ r0\)\/BesselJZeros[m\_azm, {n\_rad, \
n\_rad}]}]\)], "Input"],

Cell[BoxData[
    \(BesselJ[m\_azm, \[Rho]]\ C[n\_rad, m\_azm]\)], "Output"]
}, Open  ]],

Cell["\<\
Transform  radial probability density of the two-dimensional quantum rotator \
to the dimensionless form too:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RR[n\_rad, m\_azm, r0, \[Rho]] = 
      FullSimplify[
        ReplaceAll[
          RR[n\_rad, m\_azm, r0, 
            r], {r \[Rule] \(\[Rho]\ r0\)\/BesselJZeros[m\_azm, {n\_rad, \
n\_rad}]}]]\)], "Input"],

Cell[BoxData[
    \(\(r0\ \[Rho]\ BesselJ[m\_azm, \[Rho]]\^2\ C[n\_rad, \
m\_azm]\^2\)\/BesselJZeros[m\_azm, {n\_rad, n\_rad}]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
3. Normalization procedure for the radial wave functions of the \
two-dimensional quantum rotator\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Consider normalization procedure for radial wave functions. This implies the \
integral condition:\
\>", "Text"],

Cell[BoxData[
    \(\[Integral]\_0\%\[Infinity] RR[n\_rad, m\_azm, \[Lambda], 
            r] \[DifferentialD]r = 1\)], "NumberedEquation"],

Cell["or for dimensionless radial functions:", "Text"],

Cell[BoxData[
    \(\(r0\/BesselJZeros[
              m\_azm, {n\_rad, 
                n\_rad}]\) \(\[Integral]\_0\%\(BesselJZeros[m\_azm, {n\_rad, \
n\_rad}]\)RR[n\_rad, m\_azm, r0, \[Rho]] \[DifferentialD]\[Rho]\) = 
      1\)], "NumberedEquation"],

Cell["\<\
Normalize radial wave functions for different values of quantum numbers:\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(n\_rad\),
            FontSlant->"Italic"], "=", "1"}], ",", "2", ",", "3", ",", 
        "4"}]]],
  ",\n",
  Cell[BoxData[
      \(m\_azm = 0, 1, 2, 3\)]]
}], "NumberedEquation"],

Cell[TextData[{
  "We will obtain values for constants ",
  Cell[BoxData[
      \(C[n\_rad, m\_azm]\)],
    FontSlant->"Italic"],
  " and normalized radial wave functions ",
  Cell[BoxData[
      \(R\_Nrm[0, 0, r]\)],
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  "1). ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 0"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 1;\), "\[IndentingNewLine]", \(m\_azm = 
        0;\), "\[IndentingNewLine]", 
    RowBox[{"FullSimplify", "[", " ", 
      RowBox[{"BesselJ", "[", 
        RowBox[{\(m\_azm\), ",", 
          RowBox[{
            StyleBox[\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\/r0\),
              FontSlant->"Italic"], " ", "r"}]}], "]"}], 
      "]"}], "\[IndentingNewLine]", \(NormRot = \
\[Integral]\_0\%\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\)\(\(r0\^2\ \[Rho]\ \
BesselJ[m\_azm, \[Rho]]\^2\ C[n\_rad, m\_azm]\^2\)\/BesselJZeros[m\_azm, \
{n\_rad, n\_rad}]\^2\) \[DifferentialD]\[Rho]\)}], "Input"],

Cell[BoxData[
    \({BesselJ[0, \(2.4048255576957467`\ r\)\/r0]}\)], "Output"],

Cell[BoxData[
    \({{0.13475706197096138`\ r0\^2\ C[1, 0]\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[0.13475706197096138`\ r0\^2\ C[1, 0]\^2 \[Equal] 1, 
      C[1, 0]]\)], "Input"],

Cell[BoxData[
    \({{C[1, 0] \[Rule] \(-\(2.724107444910865`\/r0\)\)}, {C[1, 0] \[Rule] 
          2.724107444910865`\/r0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(R\_Nrm[1, 0, r0, r] = 
      2.724107444910865`\/r0\ BesselJ[
          0, \(2.4048255576957467`\ r\)\/r0]\)], "Input"],

Cell[BoxData[
    \(\(2.724107444910865`\ BesselJ[0, \(2.4048255576957467`\ \
r\)\/r0]\)\/r0\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "2) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 1"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 1;\), "\[IndentingNewLine]", \(m\_azm = 
        1;\), "\[IndentingNewLine]", 
    RowBox[{"FullSimplify", "[", " ", 
      RowBox[{"BesselJ", "[", 
        RowBox[{\(m\_azm\), ",", 
          RowBox[{
            StyleBox[\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\/r0\),
              FontSlant->"Italic"], " ", "r"}]}], "]"}], 
      "]"}], "\[IndentingNewLine]", \(NormRot = \
\[Integral]\_0\%\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\)\(\(r0\^2\ \[Rho]\ \
BesselJ[m\_azm, \[Rho]]\^2\ C[n\_rad, m\_azm]\^2\)\/BesselJZeros[m\_azm, \
{n\_rad, n\_rad}]\^2\) \[DifferentialD]\[Rho]\)}], "Input"],

Cell[BoxData[
    \({BesselJ[1, \(3.8317059702075125`\ r\)\/r0]}\)], "Output"],

Cell[BoxData[
    \({{0.08110756541334281`\ r0\^2\ C[1, 1]\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[0.08110756541334281`\ r0\^2\ C[1, 1]\^2 \[Equal] 1, 
      C[1, 1]]\)], "Input"],

Cell[BoxData[
    \({{C[1, 1] \[Rule] \(-\(3.511311163594863`\/r0\)\)}, {C[1, 1] \[Rule] 
          3.511311163594863`\/r0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(R\_Nrm[1, 1, r0, r] = 
      3.511311163594863`\/r0\ BesselJ[
          1, \(3.8317059702075125`\ r\)\/r0]\)], "Input"],

Cell[BoxData[
    \(\(3.511311163594863`\ BesselJ[1, \(3.8317059702075125`\ \
r\)\/r0]\)\/r0\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "3) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 2"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 1;\), "\[IndentingNewLine]", \(m\_azm = 
        2;\), "\[IndentingNewLine]", 
    RowBox[{"FullSimplify", "[", " ", 
      RowBox[{"BesselJ", "[", 
        RowBox[{\(m\_azm\), ",", 
          RowBox[{
            StyleBox[\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\/r0\),
              FontSlant->"Italic"], " ", "r"}]}], "]"}], 
      "]"}], "\[IndentingNewLine]", \(NormRot = \
\[Integral]\_0\%\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\)\(\(r0\^2\ \[Rho]\ \
BesselJ[m\_azm, \[Rho]]\^2\ C[n\_rad, m\_azm]\^2\)\/BesselJZeros[m\_azm, \
{n\_rad, n\_rad}]\^2\) \[DifferentialD]\[Rho]\)}], "Input"],

Cell[BoxData[
    \({BesselJ[2, \(5.135622301840683`\ r\)\/r0]}\)], "Output"],

Cell[BoxData[
    \({{0.05768742740874397`\ r0\^2\ C[1, 2]\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[0.05768742740874397`\ r0\^2\ C[1, 2]\^2 \[Equal] 1, 
      C[1, 2]]\)], "Input"],

Cell[BoxData[
    \({{C[1, 2] \[Rule] \(-\(4.163508101524556`\/r0\)\)}, {C[1, 2] \[Rule] 
          4.163508101524556`\/r0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(R\_Nrm[1, 2, r0, r] = 
      4.163508101524556`\/r0\ BesselJ[
          2, \(5.135622301840683`\ r\)\/r0]\)], "Input"],

Cell[BoxData[
    \(\(4.163508101524556`\ BesselJ[2, \(5.135622301840683`\ \
r\)\/r0]\)\/r0\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "4) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 1;\), "\[IndentingNewLine]", \(m\_azm = 
        3;\), "\[IndentingNewLine]", 
    RowBox[{"FullSimplify", "[", " ", 
      RowBox[{"BesselJ", "[", 
        RowBox[{\(m\_azm\), ",", 
          RowBox[{
            StyleBox[\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\/r0\),
              FontSlant->"Italic"], " ", "r"}]}], "]"}], 
      "]"}], "\[IndentingNewLine]", \(NormRot = \
\[Integral]\_0\%\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\)\(\(r0\^2\ \[Rho]\ \
BesselJ[m\_azm, \[Rho]]\^2\ C[n\_rad, m\_azm]\^2\)\/BesselJZeros[m\_azm, \
{n\_rad, n\_rad}]\^2\) \[DifferentialD]\[Rho]\)}], "Input"],

Cell[BoxData[
    \({BesselJ[3, \(6.3801618959386`\ r\)\/r0]}\)], "Output"],

Cell[BoxData[
    \({{0.04448348887810606`\ r0\^2\ C[1, 3]\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[0.04448348887810606`\ r0\^2\ C[1, 3]\^2 \[Equal] 1, 
      C[1, 3]]\)], "Input"],

Cell[BoxData[
    \({{C[1, 3] \[Rule] \(-\(4.741334316925816`\/r0\)\)}, {C[1, 3] \[Rule] 
          4.741334316925816`\/r0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(R\_Nrm[1, 3, r0, r] = 
      4.741334316925816`\/r0\ BesselJ[
          3, \(6.3801618959386`\ r\)\/r0]\)], "Input"],

Cell[BoxData[
    \(\(4.741334316925816`\ BesselJ[3, \(6.3801618959386`\ r\)\/r0]\)\/r0\)], \
"Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "5) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 2, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 0"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 2;\), "\[IndentingNewLine]", \(m\_azm = 
        0;\), "\[IndentingNewLine]", 
    RowBox[{"FullSimplify", "[", " ", 
      RowBox[{"BesselJ", "[", 
        RowBox[{\(m\_azm\), ",", 
          RowBox[{
            StyleBox[\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\/r0\),
              FontSlant->"Italic"], " ", "r"}]}], "]"}], 
      "]"}], "\[IndentingNewLine]", \(NormRot = \
\[Integral]\_0\%\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\)\(\(r0\^2\ \[Rho]\ \
BesselJ[m\_azm, \[Rho]]\^2\ C[n\_rad, m\_azm]\^2\)\/BesselJZeros[m\_azm, \
{n\_rad, n\_rad}]\^2\) \[DifferentialD]\[Rho]\)}], "Input"],

Cell[BoxData[
    \({BesselJ[0, \(5.52007811028631`\ r\)\/r0]}\)], "Output"],

Cell[BoxData[
    \({{0.057890069291101874`\ r0\^2\ C[2, 0]\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[0.057890069291101874`\ r0\^2\ C[2, 0]\^2 \[Equal] 1, 
      C[2, 0]]\)], "Input"],

Cell[BoxData[
    \({{C[2, 0] \[Rule] \(-\(4.15621461613164`\/r0\)\)}, {C[2, 0] \[Rule] 
          4.15621461613164`\/r0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(R\_Nrm[2, 0, r0, r] = 
      4.15621461613164`\/r0\ BesselJ[
          0, \(5.52007811028631`\ r\)\/r0]\)], "Input"],

Cell[BoxData[
    \(\(4.15621461613164`\ BesselJ[0, \(5.52007811028631`\ r\)\/r0]\)\/r0\)], \
"Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "6) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 2, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 1"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 2;\), "\[IndentingNewLine]", \(m\_azm = 
        1;\), "\[IndentingNewLine]", 
    RowBox[{"FullSimplify", "[", " ", 
      RowBox[{"BesselJ", "[", 
        RowBox[{\(m\_azm\), ",", 
          RowBox[{
            StyleBox[\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\/r0\),
              FontSlant->"Italic"], " ", "r"}]}], "]"}], 
      "]"}], "\[IndentingNewLine]", \(NormRot = \
\[Integral]\_0\%\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\)\(\(r0\^2\ \[Rho]\ \
BesselJ[m\_azm, \[Rho]]\^2\ C[n\_rad, m\_azm]\^2\)\/BesselJZeros[m\_azm, \
{n\_rad, n\_rad}]\^2\) \[DifferentialD]\[Rho]\)}], "Input"],

Cell[BoxData[
    \({BesselJ[1, \(7.015586669815615`\ r\)\/r0]}\)], "Output"],

Cell[BoxData[
    \({{0.04503473245716367`\ r0\^2\ C[2, 1]\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[0.04503473245716367`\ r0\^2\ C[2, 1]\^2 \[Equal] 1, 
      C[2, 1]]\)], "Input"],

Cell[BoxData[
    \({{C[2, 1] \[Rule] \(-\(4.712227033967331`\/r0\)\)}, {C[2, 1] \[Rule] 
          4.712227033967331`\/r0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(R\_Nrm[2, 1, r0, r] = 
      4.712227033967331`\/r0\ BesselJ[
          1, \(7.015586669815615`\ r\)\/r0]\)], "Input"],

Cell[BoxData[
    \(\(4.712227033967331`\ BesselJ[1, \(7.015586669815615`\ \
r\)\/r0]\)\/r0\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "7) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 2, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 2"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 2;\), "\[IndentingNewLine]", \(m\_azm = 
        2;\), "\[IndentingNewLine]", 
    RowBox[{"FullSimplify", "[", " ", 
      RowBox[{"BesselJ", "[", 
        RowBox[{\(m\_azm\), ",", 
          RowBox[{
            StyleBox[\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\/r0\),
              FontSlant->"Italic"], " ", "r"}]}], "]"}], 
      "]"}], "\[IndentingNewLine]", \(NormRot = \
\[Integral]\_0\%\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\)\(\(r0\^2\ \[Rho]\ \
BesselJ[m\_azm, \[Rho]]\^2\ C[n\_rad, m\_azm]\^2\)\/BesselJZeros[m\_azm, \
{n\_rad, n\_rad}]\^2\) \[DifferentialD]\[Rho]\)}], "Input"],

Cell[BoxData[
    \({BesselJ[2, \(8.417244140695804`\ r\)\/r0]}\)], "Output"],

Cell[BoxData[
    \({{0.036824254916096776`\ r0\^2\ C[2, 2]\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[0.0368243\ r0\^2\ C[2, 2]\^2 \[Equal] 1, C[2, 2]]\)], "Input"],

Cell[BoxData[
    \({{C[2, 2] \[Rule] \(-\(5.211140109481625`\/r0\)\)}, {C[2, 2] \[Rule] 
          5.211140109481625`\/r0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(R\_Nrm[2, 2, r0, r] = 
      5.211140109481625`\/r0\ BesselJ[
          2, \(8.417244140695804`\ r\)\/r0]\)], "Input"],

Cell[BoxData[
    \(\(5.211140109481625`\ BesselJ[2, \(8.417244140695804`\ \
r\)\/r0]\)\/r0\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "8) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 2, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 2;\), "\[IndentingNewLine]", \(m\_azm = 
        3;\), "\[IndentingNewLine]", 
    RowBox[{"FullSimplify", "[", " ", 
      RowBox[{"BesselJ", "[", 
        RowBox[{\(m\_azm\), ",", 
          RowBox[{
            StyleBox[\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\/r0\),
              FontSlant->"Italic"], " ", "r"}]}], "]"}], 
      "]"}], "\[IndentingNewLine]", \(NormRot = \
\[Integral]\_0\%\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\)\(\(r0\^2\ \[Rho]\ \
BesselJ[m\_azm, \[Rho]]\^2\ C[n\_rad, m\_azm]\^2\)\/BesselJZeros[m\_azm, \
{n\_rad, n\_rad}]\^2\) \[DifferentialD]\[Rho]\)}], "Input"],

Cell[BoxData[
    \({BesselJ[3, \(9.761023130149406`\ r\)\/r0]}\)], "Output"],

Cell[BoxData[
    \({{0.03110436894324665`\ r0\^2\ C[2, 3]\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[0.03110436894324665`\ r0\^2\ C[2, 3]\^2 \[Equal] 1, 
      C[2, 3]]\)], "Input"],

Cell[BoxData[
    \({{C[2, 3] \[Rule] \(-\(5.67008151730802`\/r0\)\)}, {C[2, 3] \[Rule] 
          5.67008151730802`\/r0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(R\_Nrm[2, 3, r0, r] = 
      5.67008151730802`\/r0\ BesselJ[
          3, \(9.761023130149406`\ r\)\/r0]\)], "Input"],

Cell[BoxData[
    \(\(5.67008151730802`\ BesselJ[3, \(9.761023130149406`\ \
r\)\/r0]\)\/r0\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "9) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 3, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 0"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 3;\), "\[IndentingNewLine]", \(m\_azm = 
        0;\), "\[IndentingNewLine]", 
    RowBox[{"FullSimplify", "[", " ", 
      RowBox[{"BesselJ", "[", 
        RowBox[{\(m\_azm\), ",", 
          RowBox[{
            StyleBox[\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\/r0\),
              FontSlant->"Italic"], " ", "r"}]}], "]"}], 
      "]"}], "\[IndentingNewLine]", \(NormRot = \
\[Integral]\_0\%\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\)\(\(r0\^2\ \[Rho]\ \
BesselJ[m\_azm, \[Rho]]\^2\ C[n\_rad, m\_azm]\^2\)\/BesselJZeros[m\_azm, \
{n\_rad, n\_rad}]\^2\) \[DifferentialD]\[Rho]\)}], "Input"],

Cell[BoxData[
    \({BesselJ[0, \(8.653727913113732`\ r\)\/r0]}\)], "Output"],

Cell[BoxData[
    \({{0.03684317556648294`\ r0\^2\ C[3, 0]\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[0.03684317556648294`\ r0\^2\ C[3, 0]\^2 \[Equal] 1, 
      C[3, 0]]\)], "Input"],

Cell[BoxData[
    \({{C[3, 0] \[Rule] \(-\(5.209805047808564`\/r0\)\)}, {C[3, 0] \[Rule] 
          5.209805047808564`\/r0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(R\_Nrm[3, 0, r0, r] = 
      5.209805047808564`\/r0\ BesselJ[
          0, \(8.653727913113732`\ r\)\/r0]\)], "Input"],

Cell[BoxData[
    \(\(5.209805047808564`\ BesselJ[0, \(8.653727913113732`\ \
r\)\/r0]\)\/r0\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "10) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 3, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 1"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 3;\), "\[IndentingNewLine]", \(m\_azm = 
        1;\), "\[IndentingNewLine]", 
    RowBox[{"FullSimplify", "[", " ", 
      RowBox[{"BesselJ", "[", 
        RowBox[{\(m\_azm\), ",", 
          RowBox[{
            StyleBox[\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\/r0\),
              FontSlant->"Italic"], " ", "r"}]}], "]"}], 
      "]"}], "\[IndentingNewLine]", \(NormRot = \
\[Integral]\_0\%\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\)\(\(r0\^2\ \[Rho]\ \
BesselJ[m\_azm, \[Rho]]\^2\ C[n\_rad, m\_azm]\^2\)\/BesselJZeros[m\_azm, \
{n\_rad, n\_rad}]\^2\) \[DifferentialD]\[Rho]\)}], "Input"],

Cell[BoxData[
    \({BesselJ[1, \(10.173468135156398`\ r\)\/r0]}\)], "Output"],

Cell[BoxData[
    \({{0.031176262812662156`\ r0\^2\ C[3, 1]\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[0.031176262812662156`\ r0\^2\ C[3, 1]\^2 \[Equal] 1, 
      C[3, 1]]\)], "Input"],

Cell[BoxData[
    \({{C[3, 1] \[Rule] \(-\(5.663540011909818`\/r0\)\)}, {C[3, 1] \[Rule] 
          5.663540011909818`\/r0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(R\_Nrm[3, 1, r0, r] = 
      5.663540011909818`\/r0\ BesselJ[
          1, \(10.173468135156398`\ r\)\/r0]\)], "Input"],

Cell[BoxData[
    \(\(5.663540011909818`\ BesselJ[1, \(10.173468135156398`\ \
r\)\/r0]\)\/r0\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "11) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 3, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 2"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 3;\), "\[IndentingNewLine]", \(m\_azm = 
        2;\), "\[IndentingNewLine]", 
    RowBox[{"FullSimplify", "[", " ", 
      RowBox[{"BesselJ", "[", 
        RowBox[{\(m\_azm\), ",", 
          RowBox[{
            StyleBox[\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\/r0\),
              FontSlant->"Italic"], " ", "r"}]}], "]"}], 
      "]"}], "\[IndentingNewLine]", \(NormRot = \
\[Integral]\_0\%\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\)\(\(r0\^2\ \[Rho]\ \
BesselJ[m\_azm, \[Rho]]\^2\ C[n\_rad, m\_azm]\^2\)\/BesselJZeros[m\_azm, \
{n\_rad, n\_rad}]\^2\) \[DifferentialD]\[Rho]\)}], "Input"],

Cell[BoxData[
    \({BesselJ[2, \(11.619841172201633`\ r\)\/r0]}\)], "Output"],

Cell[BoxData[
    \({{0.027014904074795405`\ r0\^2\ C[3, 2]\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[0.027014904074795405`\ r0\^2\ C[3, 2]\^2 \[Equal] 1, 
      C[3, 2]]\)], "Input"],

Cell[BoxData[
    \({{C[3, 2] \[Rule] \(-\(6.084127198638522`\/r0\)\)}, {C[3, 2] \[Rule] 
          6.084127198638522`\/r0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(R\_Nrm[3, 2, r0, r] = 
      6.084127198638522`\/r0\ BesselJ[
          2, \(11.619841172201633`\ r\)\/r0]\)], "Input"],

Cell[BoxData[
    \(\(6.084127198638522`\ BesselJ[2, \(11.619841172201633`\ \
r\)\/r0]\)\/r0\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "12) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 3, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 3;\), "\[IndentingNewLine]", \(m\_azm = 
        3;\), "\[IndentingNewLine]", 
    RowBox[{"FullSimplify", "[", " ", 
      RowBox[{"BesselJ", "[", 
        RowBox[{\(m\_azm\), ",", 
          RowBox[{
            StyleBox[\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\/r0\),
              FontSlant->"Italic"], " ", "r"}]}], "]"}], 
      "]"}], "\[IndentingNewLine]", \(NormRot = \
\[Integral]\_0\%\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\)\(\(r0\^2\ \[Rho]\ \
BesselJ[m\_azm, \[Rho]]\^2\ C[n\_rad, m\_azm]\^2\)\/BesselJZeros[m\_azm, \
{n\_rad, n\_rad}]\^2\) \[DifferentialD]\[Rho]\)}], "Input"],

Cell[BoxData[
    \({BesselJ[3, \(13.015200721731633`\ r\)\/r0]}\)], "Output"],

Cell[BoxData[
    \({{0.023822869521141366`\ r0\^2\ C[3, 3]\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[0.023822869521141366`\ r0\^2\ C[3, 3]\^2 \[Equal] 1, 
      C[3, 3]]\)], "Input"],

Cell[BoxData[
    \({{C[3, 3] \[Rule] \(-\(6.478925169577221`\/r0\)\)}, {C[3, 3] \[Rule] 
          6.478925169577221`\/r0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(R\_Nrm[3, 3, r0, r] = 
      6.478925169577221`\/r0\ BesselJ[
          3, \(13.015200721731633`\ r\)\/r0]\)], "Input"],

Cell[BoxData[
    \(\(6.478925169577221`\ BesselJ[3, \(13.015200721731633`\ \
r\)\/r0]\)\/r0\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "13) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 4, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 0"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 4;\), "\[IndentingNewLine]", \(m\_azm = 
        0;\), "\[IndentingNewLine]", 
    RowBox[{"FullSimplify", "[", " ", 
      RowBox[{"BesselJ", "[", 
        RowBox[{\(m\_azm\), ",", 
          RowBox[{
            StyleBox[\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\/r0\),
              FontSlant->"Italic"], " ", "r"}]}], "]"}], 
      "]"}], "\[IndentingNewLine]", \(NormRot = \
\[Integral]\_0\%\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\)\(\(r0\^2\ \[Rho]\ \
BesselJ[m\_azm, \[Rho]]\^2\ C[n\_rad, m\_azm]\^2\)\/BesselJZeros[m\_azm, \
{n\_rad, n\_rad}]\^2\) \[DifferentialD]\[Rho]\)}], "Input"],

Cell[BoxData[
    \({BesselJ[0, \(11.791534439057065`\ r\)\/r0]}\)], "Output"],

Cell[BoxData[
    \({{0.02701878659886208`\ r0\^2\ C[4, 0]\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[0.02701878659886208`\ r0\^2\ C[4, 0]\^2 \[Equal] 1, 
      C[4, 0]]\)], "Input"],

Cell[BoxData[
    \({{C[4, 0] \[Rule] \(-\(6.0836900469025705`\/r0\)\)}, {C[4, 0] \[Rule] 
          6.0836900469025705`\/r0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(R\_Nrm[4, 0, r0, r] = 
      6.0836900469025705`\/r0\ BesselJ[
          0, \(11.791534439057065`\ r\)\/r0]\)], "Input"],

Cell[BoxData[
    \(\(6.0836900469025705`\ BesselJ[0, \(11.791534439057065`\ r\)\/r0]\)\/r0\
\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "14) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 4, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 1"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 4;\), "\[IndentingNewLine]", \(m\_azm = 
        1;\), "\[IndentingNewLine]", 
    RowBox[{"FullSimplify", "[", " ", 
      RowBox[{"BesselJ", "[", 
        RowBox[{\(m\_azm\), ",", 
          RowBox[{
            StyleBox[\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\/r0\),
              FontSlant->"Italic"], " ", "r"}]}], "]"}], 
      "]"}], "\[IndentingNewLine]", \(NormRot = \
\[Integral]\_0\%\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\)\(\(r0\^2\ \[Rho]\ \
BesselJ[m\_azm, \[Rho]]\^2\ C[n\_rad, m\_azm]\^2\)\/BesselJZeros[m\_azm, \
{n\_rad, n\_rad}]\^2\) \[DifferentialD]\[Rho]\)}], "Input"],

Cell[BoxData[
    \({BesselJ[1, \(13.323691936337989`\ r\)\/r0]}\)], "Output"],

Cell[BoxData[
    \({{0.023840415366736162`\ r0\^2\ C[4, 1]\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[0.0238404\ r0\^2\ C[4, 1]\^2 \[Equal] 1, C[4, 1]]\)], "Input"],

Cell[BoxData[
    \({{C[4, 1] \[Rule] \(-\(6.476542668701754`\/r0\)\)}, {C[4, 1] \[Rule] 
          6.476542668701754`\/r0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(R\_Nrm[4, 1, r0, r] = 
      6.476542668701754`\/r0\ BesselJ[
          1, \(13.323691936337989`\ r\)\/r0]\)], "Input"],

Cell[BoxData[
    \(\(6.476542668701754`\ BesselJ[1, \(13.323691936337989`\ \
r\)\/r0]\)\/r0\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "15) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 4, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 2"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 4;\), "\[IndentingNewLine]", \(m\_azm = 
        2;\), "\[IndentingNewLine]", 
    RowBox[{"FullSimplify", "[", " ", 
      RowBox[{"BesselJ", "[", 
        RowBox[{\(m\_azm\), ",", 
          RowBox[{
            StyleBox[\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\/r0\),
              FontSlant->"Italic"], " ", "r"}]}], "]"}], 
      "]"}], "\[IndentingNewLine]", \(NormRot = \
\[Integral]\_0\%\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\)\(\(r0\^2\ \[Rho]\ \
BesselJ[m\_azm, \[Rho]]\^2\ C[n\_rad, m\_azm]\^2\)\/BesselJZeros[m\_azm, \
{n\_rad, n\_rad}]\^2\) \[DifferentialD]\[Rho]\)}], "Input"],

Cell[BoxData[
    \({BesselJ[2, \(14.795951782366128`\ r\)\/r0]}\)], "Output"],

Cell[BoxData[
    \({{0.02132954058104364`\ r0\^2\ C[4, 2]\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[0.02132954058104364`\ r0\^2\ C[4, 2]\^2 \[Equal] 1, 
      C[4, 2]]\)], "Input"],

Cell[BoxData[
    \({{C[4, 2] \[Rule] \(-\(6.847140656222858`\/r0\)\)}, {C[4, 2] \[Rule] 
          6.847140656222858`\/r0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(R\_Nrm[4, 2, r0, r] = 
      6.847140656222858`\/r0\ BesselJ[
          2, \(14.795951782366128`\ r\)\/r0]\)], "Input"],

Cell[BoxData[
    \(\(6.847140656222858`\ BesselJ[2, \(14.795951782366128`\ \
r\)\/r0]\)\/r0\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "16) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 4;\), "\[IndentingNewLine]", \(m\_azm = 
        3;\), "\[IndentingNewLine]", 
    RowBox[{"FullSimplify", "[", " ", 
      RowBox[{"BesselJ", "[", 
        RowBox[{\(m\_azm\), ",", 
          RowBox[{
            StyleBox[\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\/r0\),
              FontSlant->"Italic"], " ", "r"}]}], "]"}], 
      "]"}], "\[IndentingNewLine]", \(NormRot = \
\[Integral]\_0\%\(BesselJZeros[m\_azm, {n\_rad, n\_rad}]\)\(\(r0\^2\ \[Rho]\ \
BesselJ[m\_azm, \[Rho]]\^2\ C[n\_rad, m\_azm]\^2\)\/BesselJZeros[m\_azm, \
{n\_rad, n\_rad}]\^2\) \[DifferentialD]\[Rho]\)}], "Input"],

Cell[BoxData[
    \({BesselJ[3, \(16.223466160328837`\ r\)\/r0]}\)], "Output"],

Cell[BoxData[
    \({{0.019293415489008064`\ r0\^2\ C[4, 3]\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[0.019293415489008064`\ r0\^2\ C[4, 3]\^2 \[Equal] 1, 
      C[4, 3]]\)], "Input"],

Cell[BoxData[
    \({{C[4, 3] \[Rule] \(-\(7.199385706404266`\/r0\)\)}, {C[4, 3] \[Rule] 
          7.199385706404266`\/r0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(R\_Nrm[4, 3, r0, r] = 
      7.199385706404266`\/r0\ BesselJ[
          3, \(16.223466160328837`\ r\)\/r0]\)], "Input"],

Cell[BoxData[
    \(\(7.199385706404266`\ BesselJ[3, \(16.223466160328837`\ \
r\)\/r0]\)\/r0\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
4. Normalized radial wave functions and radial probability densities of the \
two-dimensional quantum rotator\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Resulting normalized radial wave functions of the two-dimensional quantum \
rotator are:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R\_Nrm[1, 0, r0, r]\), "\[IndentingNewLine]", 
    \(R\_Nrm[1, 1, r0, r]\), "\[IndentingNewLine]", 
    \(R\_Nrm[1, 2, r0, r]\), "\[IndentingNewLine]", 
    \(\(\(R\_Nrm[1, 3, r0, r]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(R\_Nrm[2, 0, r0, r]\), "\[IndentingNewLine]", 
    \(R\_Nrm[2, 1, r0, r]\), "\[IndentingNewLine]", 
    \(R\_Nrm[2, 2, r0, r]\), "\[IndentingNewLine]", 
    \(\(\(R\_Nrm[2, 3, r0, r]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(R\_Nrm[3, 0, r0, r]\), "\[IndentingNewLine]", 
    \(R\_Nrm[3, 1, r0, r]\), "\[IndentingNewLine]", 
    \(R\_Nrm[3, 2, r0, r]\), "\[IndentingNewLine]", 
    \(\(\(R\_Nrm[3, 3, r0, r]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(R\_Nrm[4, 0, r0, r]\), "\[IndentingNewLine]", 
    \(R\_Nrm[4, 1, r0, r]\), "\[IndentingNewLine]", 
    \(R\_Nrm[4, 2, r0, r]\), "\[IndentingNewLine]", 
    \(R\_Nrm[4, 3, r0, r]\)}], "Input"],

Cell[BoxData[
    \(\(2.724107444910865`\ BesselJ[0, \(2.4048255576957467`\ \
r\)\/r0]\)\/r0\)], "Output"],

Cell[BoxData[
    \(\(3.511311163594863`\ BesselJ[1, \(3.8317059702075125`\ \
r\)\/r0]\)\/r0\)], "Output"],

Cell[BoxData[
    \(\(4.163508101524556`\ BesselJ[2, \(5.135622301840683`\ \
r\)\/r0]\)\/r0\)], "Output"],

Cell[BoxData[
    \(\(4.741334316925816`\ BesselJ[3, \(6.3801618959386`\ r\)\/r0]\)\/r0\)], \
"Output"],

Cell[BoxData[
    \(\(4.15621461613164`\ BesselJ[0, \(5.52007811028631`\ r\)\/r0]\)\/r0\)], \
"Output"],

Cell[BoxData[
    \(\(4.712227033967331`\ BesselJ[1, \(7.015586669815615`\ \
r\)\/r0]\)\/r0\)], "Output"],

Cell[BoxData[
    \(\(5.211140109481625`\ BesselJ[2, \(8.417244140695804`\ \
r\)\/r0]\)\/r0\)], "Output"],

Cell[BoxData[
    \(\(5.67008151730802`\ BesselJ[3, \(9.761023130149406`\ \
r\)\/r0]\)\/r0\)], "Output"],

Cell[BoxData[
    \(\(5.209805047808564`\ BesselJ[0, \(8.653727913113732`\ \
r\)\/r0]\)\/r0\)], "Output"],

Cell[BoxData[
    \(\(5.663540011909818`\ BesselJ[1, \(10.173468135156398`\ \
r\)\/r0]\)\/r0\)], "Output"],

Cell[BoxData[
    \(\(6.084127198638522`\ BesselJ[2, \(11.619841172201633`\ \
r\)\/r0]\)\/r0\)], "Output"],

Cell[BoxData[
    \(\(6.478925169577221`\ BesselJ[3, \(13.015200721731633`\ \
r\)\/r0]\)\/r0\)], "Output"],

Cell[BoxData[
    \(\(6.0836900469025705`\ BesselJ[0, \(11.791534439057065`\ r\)\/r0]\)\/r0\
\)], "Output"],

Cell[BoxData[
    \(\(6.476542668701754`\ BesselJ[1, \(13.323691936337989`\ \
r\)\/r0]\)\/r0\)], "Output"],

Cell[BoxData[
    \(\(6.847140656222858`\ BesselJ[2, \(14.795951782366128`\ \
r\)\/r0]\)\/r0\)], "Output"],

Cell[BoxData[
    \(\(7.199385706404266`\ BesselJ[3, \(16.223466160328837`\ \
r\)\/r0]\)\/r0\)], "Output"]
}, Open  ]],

Cell["and we have list of the radial functions:", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(R\_Rotat[1, 0, 
          r0] = \(2.724107444910865`\ BesselJ[0, \(2.4048255576957467`\ \
r\)\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[1, 1, 
          r0] = \(3.511311163594863`\ BesselJ[1, \(3.8317059702075125`\ \
r\)\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[1, 2, 
          r0] = \(4.163508101524556`\ BesselJ[2, \(5.135622301840683`\ \
r\)\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(\(R\_Rotat[1, 3, 
          r0] = \(4.741334316925816`\ BesselJ[3, \(6.3801618959386`\ r\)\/r0]\
\)\/r0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[2, 0, 
          r0] = \(4.15621461613164`\ BesselJ[0, \(5.52007811028631`\ r\)\/r0]\
\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[2, 1, 
          r0] = \(4.712227033967331`\ BesselJ[1, \(7.015586669815615`\ \
r\)\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[2, 2, 
          r0] = \(5.211140109481625`\ BesselJ[2, \(8.417244140695804`\ \
r\)\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(\(R\_Rotat[2, 3, 
          r0] = \(5.67008151730802`\ BesselJ[3, \(9.761023130149406`\ \
r\)\/r0]\)\/r0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[3, 0, 
          r0] = \(5.209805047808564`\ BesselJ[0, \(8.653727913113732`\ \
r\)\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[3, 1, 
          r0] = \(5.663540011909818`\ BesselJ[1, \(10.173468135156398`\ \
r\)\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[3, 2, 
          r0] = \(6.084127198638522`\ BesselJ[2, \(11.619841172201633`\ \
r\)\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(\(R\_Rotat[3, 3, 
          r0] = \(6.478925169577221`\ BesselJ[3, \(13.015200721731633`\ \
r\)\/r0]\)\/r0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[4, 0, 
          r0] = \(6.0836900469025705`\ BesselJ[0, \(11.791534439057065`\ \
r\)\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[4, 1, 
          r0] = \(6.476542668701754`\ BesselJ[1, \(13.323691936337989`\ \
r\)\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[4, 2, 
          r0] = \(6.847140656222858`\ BesselJ[2, \(14.795951782366128`\ \
r\)\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[4, 3, 
          r0] = \(7.199385706404266`\ BesselJ[3, \(16.223466160328837`\ \
r\)\/r0]\)\/r0;\)\)}], "Input"],

Cell["\<\
Radial probability densities are calculated by the formulas:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell[BoxData[{
    \(RR\_Rotat[1, 0, r0] = FullSimplify[R\_Rotat[1, 0, r0]\^2\ r]\), "\n", 
    \(RR\_Rotat[1, 1, r0] = FullSimplify[R\_Rotat[1, 1, r0]\^2\ r]\), "\n", 
    \(RR\_Rotat[1, 2, r0] = 
      FullSimplify[\(R\_Rotat[1, 2, r0]\^2\) r]\), "\n", 
    \(\(\(RR\_Rotat[1, 3, r0] = 
      FullSimplify[\(R\_Rotat[1, 3, r0]\^2\) r]\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(RR\_Rotat[2, 0, r0] = 
      FullSimplify[\(R\_Rotat[2, 0, r0]\^2\) r]\), "\n", 
    \(RR\_Rotat[2, 1, r0] = 
      FullSimplify[\(R\_Rotat[2, 1, r0]\^2\) r]\), "\n", 
    \(RR\_Rotat[2, 2, r0] = 
      FullSimplify[\(R\_Rotat[2, 2, r0]\^2\) r]\), "\n", 
    \(\(\(RR\_Rotat[2, 3, r0] = 
      FullSimplify[\(R\_Rotat[2, 3, r0]\^2\) r]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(RR\_Rotat[3, 0, r0] = 
      FullSimplify[\(R\_Rotat[3, 0, r0]\^2\) r]\), "\n", 
    \(RR\_Rotat[3, 1, r0] = 
      FullSimplify[\(R\_Rotat[3, 1, r0]\^2\) r]\), "\n", 
    \(RR\_Rotat[3, 2, r0] = 
      FullSimplify[\(R\_Rotat[3, 2, r0]\^2\) r]\), "\n", 
    \(\(\(RR\_Rotat[3, 3, r0] = 
      FullSimplify[\(R\_Rotat[3, 3, r0]\^2\) r]\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(RR\_Rotat[4, 0, r0] = 
      FullSimplify[\(R\_Rotat[4, 0, r0]\^2\) r]\), "\n", 
    \(RR\_Rotat[4, 1, r0] = 
      FullSimplify[\(R\_Rotat[4, 1, r0]\^2\) r]\), "\n", 
    \(RR\_Rotat[4, 2, r0] = 
      FullSimplify[\(R\_Rotat[4, 2, r0]\^2\) r]\), "\n", 
    \(RR\_Rotat[4, 3, r0] = 
      FullSimplify[\(R\_Rotat[4, 3, r0]\^2\) r]\)}], "Input"],

Cell[BoxData[
    \(\(7.420761371418802`\ r\ BesselJ[0, \(2.4048255576957467`\ \
r\)\/r0]\^2\)\/r0\^2\)], "Output"],

Cell[BoxData[
    \(\(12.32930608758591`\ r\ BesselJ[1, \(3.8317059702075125`\ \
r\)\/r0]\^2\)\/r0\^2\)], "Output"],

Cell[BoxData[
    \(\(17.33479971146061`\ r\ BesselJ[2, \(5.135622301840683`\ r\)\/r0]\^2\)\
\/r0\^2\)], "Output"],

Cell[BoxData[
    \(\(22.480251104858397`\ r\ BesselJ[3, \(6.3801618959386`\ \
r\)\/r0]\^2\)\/r0\^2\)], "Output"],

Cell[BoxData[
    \(\(17.274119935346278`\ r\ BesselJ[0, \(5.52007811028631`\ r\)\/r0]\^2\)\
\/r0\^2\)], "Output"],

Cell[BoxData[
    \(\(22.205083619652548`\ r\ BesselJ[1, \(7.015586669815615`\ \
r\)\/r0]\^2\)\/r0\^2\)], "Output"],

Cell[BoxData[
    \(\(27.155981240648163`\ r\ BesselJ[2, \(8.417244140695804`\ \
r\)\/r0]\^2\)\/r0\^2\)], "Output"],

Cell[BoxData[
    \(\(32.14982441291802`\ r\ BesselJ[3, \(9.761023130149406`\ r\)\/r0]\^2\)\
\/r0\^2\)], "Output"],

Cell[BoxData[
    \(\(27.14206863617159`\ r\ BesselJ[0, \(8.653727913113732`\ r\)\/r0]\^2\)\
\/r0\^2\)], "Output"],

Cell[BoxData[
    \(\(32.075685466503465`\ r\ BesselJ[1, \(10.173468135156398`\ r\)\/r0]\^2\
\)\/r0\^2\)], "Output"],

Cell[BoxData[
    \(\(37.016603769213035`\ r\ BesselJ[2, \(11.619841172201633`\ r\)\/r0]\^2\
\)\/r0\^2\)], "Output"],

Cell[BoxData[
    \(\(41.97647135298122`\ r\ BesselJ[3, \(13.015200721731633`\ \
r\)\/r0]\^2\)\/r0\^2\)], "Output"],

Cell[BoxData[
    \(\(37.0112845867814`\ r\ BesselJ[0, \(11.791534439057065`\ r\)\/r0]\^2\)\
\/r0\^2\)], "Output"],

Cell[BoxData[
    \(\(41.94560493951443`\ r\ BesselJ[1, \(13.323691936337989`\ \
r\)\/r0]\^2\)\/r0\^2\)], "Output"],

Cell[BoxData[
    \(\(46.88333516609999`\ r\ BesselJ[2, \(14.795951782366128`\ \
r\)\/r0]\^2\)\/r0\^2\)], "Output"],

Cell[BoxData[
    \(\(51.83115454957805`\ r\ BesselJ[3, \(16.223466160328837`\ \
r\)\/r0]\^2\)\/r0\^2\)], "Output"]
}, Open  ]],

Cell["\<\
Thus radial probability densities of the two-dimensional quantum rotator are:\
\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(RR\_Rotat[1, 0, 
          r0] = \(7.420761371418802`\ r\ BesselJ[0, \(2.4048255576957467`\ \
r\)\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[1, 1, 
          r0] = \(12.32930608758591`\ r\ BesselJ[1, \(3.8317059702075125`\ \
r\)\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[1, 2, 
          r0] = \(17.33479971146061`\ r\ BesselJ[2, \(5.135622301840683`\ r\)\
\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(\(RR\_Rotat[1, 3, 
          r0] = \(22.480251104858397`\ r\ BesselJ[3, \(6.3801618959386`\ \
r\)\/r0]\^2\)\/r0\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RR\_Rotat[2, 0, 
          r0] = \(17.274119935346278`\ r\ BesselJ[0, \(5.52007811028631`\ r\)\
\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[2, 1, 
          r0] = \(22.205083619652548`\ r\ BesselJ[1, \(7.015586669815615`\ \
r\)\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[2, 2, 
          r0] = \(27.155981240648163`\ r\ BesselJ[2, \(8.417244140695804`\ \
r\)\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[2, 3, 
          r0] = \(32.14982441291802`\ r\ BesselJ[3, \(9.761023130149406`\ r\)\
\/r0]\^2\)\/r0\^2;\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(RR\_Rotat[3, 0, 
          r0] = \(27.14206863617159`\ r\ BesselJ[0, \(8.653727913113732`\ r\)\
\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[3, 1, 
          r0] = \(32.075685466503465`\ r\ BesselJ[1, \(10.173468135156398`\ r\
\)\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[3, 2, 
          r0] = \(37.016603769213035`\ r\ BesselJ[2, \(11.619841172201633`\ r\
\)\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[3, 3, 
          r0] = \(41.97647135298122`\ r\ BesselJ[3, \(13.015200721731633`\ \
r\)\/r0]\^2\)\/r0\^2;\)\[IndentingNewLine]\n\), "\[IndentingNewLine]", 
    \(\(RR\_Rotat[4, 0, 
          r0] = \(37.0112845867814`\ r\ BesselJ[0, \(11.791534439057065`\ r\)\
\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[4, 1, 
          r0] = \(41.94560493951443`\ r\ BesselJ[1, \(13.323691936337989`\ \
r\)\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[4, 2, 
          r0] = \(46.88333516609999`\ r\ BesselJ[2, \(14.795951782366128`\ \
r\)\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[4, 3, 
          r0] = \(51.83115454957805`\ r\ BesselJ[3, \(16.223466160328837`\ \
r\)\/r0]\^2\)\/r0\^2;\)\)}], "Input"],

Cell["", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1016, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.25,
StyleDefinitions -> "Classroom1.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 246, 8, 93, "Subtitle"],
Cell[2519, 82, 197, 5, 124, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2741, 91, 95, 2, 85, "Section"],
Cell[2839, 95, 194, 7, 57, "Text"],
Cell[3036, 104, 62, 1, 63, "Input"],
Cell[3101, 107, 93, 2, 56, "Text"],

Cell[CellGroupData[{
Cell[3219, 113, 338, 7, 85, "Input"],
Cell[3560, 122, 128, 2, 85, "Output"]
}, Open  ]],
Cell[3703, 127, 130, 6, 56, "Text"],
Cell[3836, 135, 97, 2, 56, "Text"],
Cell[3936, 139, 173, 4, 54, "NumberedEquation"],
Cell[4112, 145, 197, 9, 56, "Text"],

Cell[CellGroupData[{
Cell[4334, 158, 112, 2, 64, "Input"],
Cell[4449, 162, 130, 2, 87, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4628, 170, 118, 3, 85, "Section"],
Cell[4749, 175, 286, 9, 80, "Text"],
Cell[5038, 186, 164, 2, 71, "NumberedEquation"],

Cell[CellGroupData[{
Cell[5227, 192, 198, 5, 118, "Input"],
Cell[5428, 199, 76, 1, 63, "Output"]
}, Open  ]],
Cell[5519, 203, 133, 3, 56, "Text"],

Cell[CellGroupData[{
Cell[5677, 210, 227, 6, 143, "Input"],
Cell[5907, 218, 140, 2, 91, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6096, 226, 171, 5, 85, "Section"],
Cell[6270, 233, 122, 3, 56, "Text"],
Cell[6395, 238, 139, 2, 73, "NumberedEquation"],
Cell[6537, 242, 54, 0, 56, "Text"],
Cell[6594, 244, 251, 5, 75, "NumberedEquation"],
Cell[6848, 251, 96, 2, 56, "Text"],
Cell[6947, 255, 264, 10, 72, "NumberedEquation"],
Cell[7214, 267, 261, 10, 56, "Text"],

Cell[CellGroupData[{
Cell[7500, 281, 186, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[7711, 295, 617, 11, 196, "Input"],
Cell[8331, 308, 78, 1, 85, "Output"],
Cell[8412, 311, 77, 1, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8526, 317, 106, 2, 64, "Input"],
Cell[8635, 321, 138, 2, 85, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8810, 328, 139, 3, 86, "Input"],
Cell[8952, 333, 106, 2, 96, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9107, 341, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[9317, 355, 617, 11, 196, "Input"],
Cell[9937, 368, 78, 1, 85, "Output"],
Cell[10018, 371, 77, 1, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10132, 377, 106, 2, 64, "Input"],
Cell[10241, 381, 138, 2, 85, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10416, 388, 139, 3, 86, "Input"],
Cell[10558, 393, 106, 2, 96, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[10713, 401, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[10923, 415, 617, 11, 196, "Input"],
Cell[11543, 428, 77, 1, 85, "Output"],
Cell[11623, 431, 77, 1, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11737, 437, 106, 2, 64, "Input"],
Cell[11846, 441, 138, 2, 85, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12021, 448, 138, 3, 86, "Input"],
Cell[12162, 453, 105, 2, 96, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[12316, 461, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[12526, 475, 617, 11, 196, "Input"],
Cell[13146, 488, 75, 1, 85, "Output"],
Cell[13224, 491, 77, 1, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13338, 497, 106, 2, 64, "Input"],
Cell[13447, 501, 138, 2, 85, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13622, 508, 136, 3, 86, "Input"],
Cell[13761, 513, 103, 2, 96, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[13913, 521, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[14123, 535, 617, 11, 196, "Input"],
Cell[14743, 548, 76, 1, 85, "Output"],
Cell[14822, 551, 78, 1, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14937, 557, 107, 2, 64, "Input"],
Cell[15047, 561, 136, 2, 85, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15220, 568, 136, 3, 86, "Input"],
Cell[15359, 573, 103, 2, 96, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[15511, 581, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[15721, 595, 617, 11, 196, "Input"],
Cell[16341, 608, 77, 1, 85, "Output"],
Cell[16421, 611, 77, 1, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16535, 617, 106, 2, 64, "Input"],
Cell[16644, 621, 138, 2, 85, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16819, 628, 138, 3, 86, "Input"],
Cell[16960, 633, 105, 2, 96, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[17114, 641, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[17324, 655, 617, 11, 196, "Input"],
Cell[17944, 668, 77, 1, 85, "Output"],
Cell[18024, 671, 78, 1, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18139, 677, 88, 1, 64, "Input"],
Cell[18230, 680, 138, 2, 85, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18405, 687, 138, 3, 86, "Input"],
Cell[18546, 692, 105, 2, 96, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[18700, 700, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[18910, 714, 617, 11, 196, "Input"],
Cell[19530, 727, 77, 1, 85, "Output"],
Cell[19610, 730, 77, 1, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19724, 736, 106, 2, 64, "Input"],
Cell[19833, 740, 136, 2, 85, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20006, 747, 137, 3, 86, "Input"],
Cell[20146, 752, 104, 2, 96, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[20299, 760, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[20509, 774, 617, 11, 196, "Input"],
Cell[21129, 787, 77, 1, 85, "Output"],
Cell[21209, 790, 77, 1, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21323, 796, 106, 2, 64, "Input"],
Cell[21432, 800, 138, 2, 85, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21607, 807, 138, 3, 86, "Input"],
Cell[21748, 812, 105, 2, 96, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[21902, 820, 186, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[22113, 834, 617, 11, 196, "Input"],
Cell[22733, 847, 78, 1, 85, "Output"],
Cell[22814, 850, 78, 1, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22929, 856, 107, 2, 64, "Input"],
Cell[23039, 860, 138, 2, 85, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23214, 867, 139, 3, 86, "Input"],
Cell[23356, 872, 106, 2, 96, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[23511, 880, 186, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[23722, 894, 617, 11, 196, "Input"],
Cell[24342, 907, 78, 1, 85, "Output"],
Cell[24423, 910, 78, 1, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24538, 916, 107, 2, 64, "Input"],
Cell[24648, 920, 138, 2, 85, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24823, 927, 139, 3, 86, "Input"],
Cell[24965, 932, 106, 2, 96, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[25120, 940, 186, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[25331, 954, 617, 11, 196, "Input"],
Cell[25951, 967, 78, 1, 85, "Output"],
Cell[26032, 970, 78, 1, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26147, 976, 107, 2, 64, "Input"],
Cell[26257, 980, 138, 2, 85, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26432, 987, 139, 3, 86, "Input"],
Cell[26574, 992, 106, 2, 96, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[26729, 1000, 186, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[26940, 1014, 617, 11, 196, "Input"],
Cell[27560, 1027, 78, 1, 85, "Output"],
Cell[27641, 1030, 77, 1, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27755, 1036, 106, 2, 64, "Input"],
Cell[27864, 1040, 140, 2, 85, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28041, 1047, 140, 3, 86, "Input"],
Cell[28184, 1052, 107, 2, 96, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[28340, 1060, 186, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[28551, 1074, 617, 11, 196, "Input"],
Cell[29171, 1087, 78, 1, 85, "Output"],
Cell[29252, 1090, 78, 1, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29367, 1096, 88, 1, 64, "Input"],
Cell[29458, 1099, 138, 2, 85, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29633, 1106, 139, 3, 86, "Input"],
Cell[29775, 1111, 106, 2, 96, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[29930, 1119, 186, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[30141, 1133, 617, 11, 196, "Input"],
Cell[30761, 1146, 78, 1, 85, "Output"],
Cell[30842, 1149, 77, 1, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30956, 1155, 106, 2, 64, "Input"],
Cell[31065, 1159, 138, 2, 85, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31240, 1166, 139, 3, 86, "Input"],
Cell[31382, 1171, 106, 2, 96, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[31537, 1179, 186, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[31748, 1193, 617, 11, 196, "Input"],
Cell[32368, 1206, 78, 1, 85, "Output"],
Cell[32449, 1209, 78, 1, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32564, 1215, 107, 2, 64, "Input"],
Cell[32674, 1219, 138, 2, 85, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32849, 1226, 139, 3, 86, "Input"],
Cell[32991, 1231, 106, 2, 96, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[33158, 1240, 183, 5, 119, "Section"],
Cell[33344, 1247, 159, 5, 56, "Text"],

Cell[CellGroupData[{
Cell[33528, 1256, 957, 19, 513, "Input"],
Cell[34488, 1277, 106, 2, 96, "Output"],
Cell[34597, 1281, 106, 2, 96, "Output"],
Cell[34706, 1285, 105, 2, 96, "Output"],
Cell[34814, 1289, 103, 2, 96, "Output"],
Cell[34920, 1293, 103, 2, 96, "Output"],
Cell[35026, 1297, 105, 2, 96, "Output"],
Cell[35134, 1301, 105, 2, 96, "Output"],
Cell[35242, 1305, 104, 2, 96, "Output"],
Cell[35349, 1309, 105, 2, 96, "Output"],
Cell[35457, 1313, 106, 2, 96, "Output"],
Cell[35566, 1317, 106, 2, 96, "Output"],
Cell[35675, 1321, 106, 2, 96, "Output"],
Cell[35784, 1325, 107, 2, 96, "Output"],
Cell[35894, 1329, 106, 2, 96, "Output"],
Cell[36003, 1333, 106, 2, 96, "Output"],
Cell[36112, 1337, 106, 2, 96, "Output"]
}, Open  ]],
Cell[36233, 1342, 104, 2, 56, "Text"],
Cell[36340, 1346, 2374, 51, 1161, "Input"],
Cell[38717, 1399, 131, 4, 56, "Text"],

Cell[CellGroupData[{
Cell[38873, 1407, 1515, 33, 514, "Input"],
Cell[40391, 1442, 115, 2, 98, "Output"],
Cell[40509, 1446, 115, 2, 98, "Output"],
Cell[40627, 1450, 114, 2, 98, "Output"],
Cell[40744, 1454, 113, 2, 98, "Output"],
Cell[40860, 1458, 114, 2, 98, "Output"],
Cell[40977, 1462, 115, 2, 98, "Output"],
Cell[41095, 1466, 115, 2, 98, "Output"],
Cell[41213, 1470, 114, 2, 98, "Output"],
Cell[41330, 1474, 114, 2, 98, "Output"],
Cell[41447, 1478, 116, 2, 98, "Output"],
Cell[41566, 1482, 116, 2, 98, "Output"],
Cell[41685, 1486, 115, 2, 98, "Output"],
Cell[41803, 1490, 114, 2, 98, "Output"],
Cell[41920, 1494, 115, 2, 98, "Output"],
Cell[42038, 1498, 115, 2, 98, "Output"],
Cell[42156, 1502, 115, 2, 98, "Output"]
}, Open  ]],
Cell[42286, 1507, 150, 5, 56, "Text"],
Cell[42439, 1514, 2333, 50, 1255, "Input"],
Cell[44775, 1566, 16, 0, 56, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

