(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     24512,        639]*)
(*NotebookOutlinePosition[     25241,        664]*)
(*  CellTagsIndexPosition[     25197,        660]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Part ",
    FontWeight->"Bold"],
  StyleBox["1. Quantum Isotropic Rotator",
    FontWeight->"Bold"],
  "\n1.1. Two-Dimensional Isotropic Quantum Rotator"
}], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
1.1.6. Normalized Wave Functions and Probability Densities of the \
Two-Dimensional Quantum Rotator\
\>", "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
1. Normalized radial and angular wave functions of the two-dimensional \
quantum rotator\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Consider some states of the two-dimensional quantum oscillator defined by \
quantum numbers:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  Cell[BoxData[
      \(n\_rad = 1, 2, 3, 4\)]],
  ",\n",
  Cell[BoxData[
      \(m\_azm = 0, 1, 2, 3\)]]
}], "NumberedEquation"],

Cell[TextData[{
  "We will use \"",
  StyleBox["NumericalMath`BesselZeros`",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  "\" to find radial functions of the two-dimensional quantum rotator."
}], "Text"],

Cell[BoxData[
    \(<< NumericalMath`BesselZeros`\)], "Input"],

Cell["\<\
Normalized radial wave functions of the two-dimensional quantum rotator for \
given quantum numbers are:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(R\_Rotat[1, 0, 
          r0] = \(2.724107444910865`\ BesselJ[0, \(2.4048255576957467`\ \
r\)\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[1, 1, 
          r0] = \(3.7929945592877274`\ BesselJ[\@2, \(4.381447479827306`\ r\)\
\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[1, 2, 
          r0] = \(4.430540052964394`\ BesselJ[\@6, \(5.70058432040823`\ \
r\)\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[1, 3, 
          r0] = \(4.9917511617183115`\ BesselJ[2\ \@3, \(6.944557309670949`\ \
r\)\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[2, 0, 
          r0] = \(4.15621461613164`\ BesselJ[0, \(5.52007811028631`\ r\)\/r0]\
\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[2, 1, 
          r0] = \(4.924605606199757`\ BesselJ[\@2, \(7.604863775917667`\ \
r\)\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[2, 2, 
          r0] = \(5.42167030668399`\ BesselJ[\@6, \(9.027112035039801`\ \
r\)\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[2, 3, 
          r0] = \(5.8724331687105735`\ BesselJ[2\ \@3, \(10.370311238377235`\ \
r\)\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[3, 0, 
          r0] = \(5.209805047808564`\ BesselJ[0, \(8.653727913113732`\ \
r\)\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[3, 1, 
          r0] = \(5.8412881505895395`\ BesselJ[\@2, \(10.779896986906524`\ \
r\)\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[3, 2, 
          r0] = \(6.264432018983282`\ BesselJ[\@6, \(12.252431949142155`\ r\)\
\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[3, 3, 
          r0] = \(6.65486004162976`\ BesselJ[2\ \@3, \(13.649287690577403`\ r\
\)\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[4, 0, 
          r0] = \(6.0836900469025705`\ BesselJ[0, \(11.791534439057065`\ \
r\)\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[4, 1, 
          r0] = \(6.632499631049359`\ BesselJ[\@2, \(13.939757650233451`\ r\)\
\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[4, 2, 
          r0] = \(7.007547679056817`\ BesselJ[\@6, \(15.442468814142474`\ r\)\
\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[4, 3, 
          r0] = \(7.357475297013236`\ BesselJ[2\ \@3, \(16.87362244717725`\ r\
\)\/r0]\)\/r0;\)\)}], "Input"],

Cell["\<\
Radial probability densities of the two-dimensional quantum rotator for given \
quantum numbers are:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(RR\_Rotat[1, 0, 
          r0] = \(7.420761371418802`\ r\ BesselJ[0, \(2.4048255576957467`\ \
r\)\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[1, 1, 
          r0] = \(12.32930608758591`\ r\ BesselJ[1, \(3.8317059702075125`\ \
r\)\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[1, 2, 
          r0] = \(17.33479971146061`\ r\ BesselJ[2, \(5.135622301840683`\ r\)\
\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(\(RR\_Rotat[1, 3, 
          r0] = \(22.480251104858397`\ r\ BesselJ[3, \(6.3801618959386`\ \
r\)\/r0]\^2\)\/r0\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RR\_Rotat[2, 0, 
          r0] = \(17.274119935346278`\ r\ BesselJ[0, \(5.52007811028631`\ r\)\
\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[2, 1, 
          r0] = \(22.205083619652548`\ r\ BesselJ[1, \(7.015586669815615`\ \
r\)\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[2, 2, 
          r0] = \(27.155981240648163`\ r\ BesselJ[2, \(8.417244140695804`\ \
r\)\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[2, 3, 
          r0] = \(32.14982441291802`\ r\ BesselJ[3, \(9.761023130149406`\ r\)\
\/r0]\^2\)\/r0\^2;\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(RR\_Rotat[3, 0, 
          r0] = \(27.14206863617159`\ r\ BesselJ[0, \(8.653727913113732`\ r\)\
\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[3, 1, 
          r0] = \(32.075685466503465`\ r\ BesselJ[1, \(10.173468135156398`\ r\
\)\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[3, 2, 
          r0] = \(37.016603769213035`\ r\ BesselJ[2, \(11.619841172201633`\ r\
\)\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[3, 3, 
          r0] = \(41.97647135298122`\ r\ BesselJ[3, \(13.015200721731633`\ \
r\)\/r0]\^2\)\/r0\^2;\)\n\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(RR\_Rotat[4, 0, 
          r0] = \(37.0112845867814`\ r\ BesselJ[0, \(11.791534439057065`\ r\)\
\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[4, 1, 
          r0] = \(41.94560493951443`\ r\ BesselJ[1, \(13.323691936337989`\ \
r\)\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[4, 2, 
          r0] = \(46.88333516609999`\ r\ BesselJ[2, \(14.795951782366128`\ \
r\)\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[4, 3, 
          r0] = \(51.83115454957805`\ r\ BesselJ[3, \(16.223466160328837`\ \
r\)\/r0]\^2\)\/r0\^2;\)\)}], "Input"],

Cell[TextData[{
  "Normalized angular wave functions and angular probability densities of the \
two-dimensional quantum oscillator for all ",
  Cell[BoxData[
      \(TraditionalForm\`m\_azm\)]],
  " quantum numbers are:"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell[BoxData[{
    \(S[m\_azm, \[CurlyPhi]] = \(\@\(1\/\(2\ \[Pi]\)\)\) \
\[ExponentialE]\^\(\(\[ImaginaryI]\)\(\ \)\(m\_azm\)\(\ \)\(\[CurlyPhi]\)\(\ \
\)\)\), "\[IndentingNewLine]", 
    \(SS[m\_azm, \[CurlyPhi]] = 
      ComplexExpand[
        S[m\_azm, \[CurlyPhi]]*Conjugate[S[m\_azm, \[CurlyPhi]]]]\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi]\ m\_azm\)\/\@\(2\ \[Pi]\)\
\)], "Output"],

Cell[BoxData[
    \(1\/\(2\ \[Pi]\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2. Normalized wave functions of the two-dimensional quantum rotator\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Define wave functions and probability densities of the two-dimensional \
quantum rotator for given quantum numbers:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[Psi]\_Rotat[n\_rad, m\_azm, r0, r, \[CurlyPhi]] = 
      R\_Rotat[n\_rad, m\_azm, r0]\ S[
          m\_azm, \[CurlyPhi]]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, r0, r, \[CurlyPhi]] = 
      RR\_Rotat[n\_rad, m\_azm, r0]\ SS[m\_azm, \[CurlyPhi]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi]\ m\_azm\)\ \
R\_Rotat[n\_rad, m\_azm, r0]\)\/\@\(2\ \[Pi]\)\)], "Output"],

Cell[BoxData[
    \(RR\_Rotat[n\_rad, m\_azm, r0]\/\(2\ \[Pi]\)\)], "Output"]
}, Open  ]],

Cell["\<\
So normalized wave functions of the two-dimensional quantum rotator for given \
quantum numbers are:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[Psi]\_Rotat[1, 0, r0, r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\_Rotat[n\_rad, m\_azm, r0, 
          r, \[CurlyPhi]], {n\_rad \[Rule] 1, 
          m\_azm \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(\[Psi]\_Rotat[1, 1, r0, r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\_Rotat[n\_rad, m\_azm, r0, 
          r, \[CurlyPhi]], {n\_rad \[Rule] 1, 
          m\_azm \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(\[Psi]\_Rotat[1, 2, r0, r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\_Rotat[n\_rad, m\_azm, r0, 
          r, \[CurlyPhi]], {n\_rad \[Rule] 1, 
          m\_azm \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\_Rotat[1, 3, r0, r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\_Rotat[n\_rad, m\_azm, r0, 
          r, \[CurlyPhi]], {n\_rad \[Rule] 1, 
          m\_azm \[Rule] 3}]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Rotat[2, 0, r0, r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\_Rotat[n\_rad, m\_azm, r0, 
          r, \[CurlyPhi]], {n\_rad \[Rule] 2, 
          m\_azm \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(\[Psi]\_Rotat[2, 1, r0, r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\_Rotat[n\_rad, m\_azm, r0, 
          r, \[CurlyPhi]], {n\_rad \[Rule] 2, 
          m\_azm \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(\[Psi]\_Rotat[2, 2, r0, r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\_Rotat[n\_rad, m\_azm, r0, 
          r, \[CurlyPhi]], {n\_rad \[Rule] 2, 
          m\_azm \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\_Rotat[2, 3, r0, r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\_Rotat[n\_rad, m\_azm, r0, 
          r, \[CurlyPhi]], {n\_rad \[Rule] 2, 
          m\_azm \[Rule] 3}]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Rotat[3, 0, r0, r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\_Rotat[n\_rad, m\_azm, r0, 
          r, \[CurlyPhi]], {n\_rad \[Rule] 3, 
          m\_azm \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(\[Psi]\_Rotat[3, 1, r0, r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\_Rotat[n\_rad, m\_azm, r0, 
          r, \[CurlyPhi]], {n\_rad \[Rule] 3, 
          m\_azm \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(\[Psi]\_Rotat[3, 2, r0, r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\_Rotat[n\_rad, m\_azm, r0, 
          r, \[CurlyPhi]], {n\_rad \[Rule] 3, 
          m\_azm \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\_Rotat[3, 3, r0, r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\_Rotat[n\_rad, m\_azm, r0, 
          r, \[CurlyPhi]], {n\_rad \[Rule] 3, 
          m\_azm \[Rule] 3}]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Rotat[4, 0, r0, r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\_Rotat[n\_rad, m\_azm, r0, 
          r, \[CurlyPhi]], {n\_rad \[Rule] 4, m\_azm \[Rule] 0}]\), "\n", 
    \(\[Psi]\_Rotat[4, 1, r0, r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\_Rotat[n\_rad, m\_azm, r0, 
          r, \[CurlyPhi]], {n\_rad \[Rule] 4, m\_azm \[Rule] 1}]\), "\n", 
    \(\[Psi]\_Rotat[4, 2, r0, r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\_Rotat[n\_rad, m\_azm, r0, 
          r, \[CurlyPhi]], {n\_rad \[Rule] 4, m\_azm \[Rule] 2}]\), "\n", 
    \(\[Psi]\_Rotat[4, 3, r0, r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\_Rotat[n\_rad, m\_azm, r0, 
          r, \[CurlyPhi]], {n\_rad \[Rule] 4, m\_azm \[Rule] 3}]\)}], "Input"],

Cell[BoxData[
    \(\(1.0867616361312606`\ BesselJ[0, \(2.4048255576957467`\ r\)\/r0]\)\/r0\
\)], "Output"],

Cell[BoxData[
    \(\(1.5131858990324731`\ \[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi]\)\ \
BesselJ[\@2, \(4.381447479827306`\ r\)\/r0]\)\/r0\)], "Output"],

Cell[BoxData[
    \(\(1.7675297521395`\ \[ExponentialE]\^\(2\ \[ImaginaryI]\ \[CurlyPhi]\)\ \
BesselJ[\@6, \(5.70058432040823`\ r\)\/r0]\)\/r0\)], "Output"],

Cell[BoxData[
    \(\(1.9914205916524041`\ \[ExponentialE]\^\(3\ \[ImaginaryI]\ \[CurlyPhi]\
\)\ BesselJ[2\ \@3, \(6.944557309670949`\ r\)\/r0]\)\/r0\)], "Output"],

Cell[BoxData[
    \(\(1.6580897367973217`\ BesselJ[0, \(5.52007811028631`\ \
r\)\/r0]\)\/r0\)], "Output"],

Cell[BoxData[
    \(\(1.9646333906150109`\ \[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi]\)\ \
BesselJ[\@2, \(7.604863775917667`\ r\)\/r0]\)\/r0\)], "Output"],

Cell[BoxData[
    \(\(2.162933515733246`\ \[ExponentialE]\^\(2\ \[ImaginaryI]\ \
\[CurlyPhi]\)\ BesselJ[\@6, \(9.027112035039801`\ r\)\/r0]\)\/r0\)], "Output"],

Cell[BoxData[
    \(\(2.3427618798304075`\ \[ExponentialE]\^\(3\ \[ImaginaryI]\ \[CurlyPhi]\
\)\ BesselJ[2\ \@3, \(10.370311238377235`\ r\)\/r0]\)\/r0\)], "Output"],

Cell[BoxData[
    \(\(2.0784115062196435`\ BesselJ[0, \(8.653727913113732`\ \
r\)\/r0]\)\/r0\)], "Output"],

Cell[BoxData[
    \(\(2.3303368152780584`\ \[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi]\)\ \
BesselJ[\@2, \(10.779896986906524`\ r\)\/r0]\)\/r0\)], "Output"],

Cell[BoxData[
    \(\(2.499146795072942`\ \[ExponentialE]\^\(2\ \[ImaginaryI]\ \
\[CurlyPhi]\)\ BesselJ[\@6, \(12.252431949142155`\ r\)\/r0]\)\/r0\)], "Output"],

Cell[BoxData[
    \(\(2.6549050407601498`\ \[ExponentialE]\^\(3\ \[ImaginaryI]\ \[CurlyPhi]\
\)\ BesselJ[2\ \@3, \(13.649287690577403`\ r\)\/r0]\)\/r0\)], "Output"],

Cell[BoxData[
    \(\(2.4270411805668104`\ BesselJ[0, \(11.791534439057065`\ r\)\/r0]\)\/r0\
\)], "Output"],

Cell[BoxData[
    \(\(2.6459845275724923`\ \[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi]\)\ \
BesselJ[\@2, \(13.939757650233451`\ r\)\/r0]\)\/r0\)], "Output"],

Cell[BoxData[
    \(\(2.7956070511046933`\ \[ExponentialE]\^\(2\ \[ImaginaryI]\ \[CurlyPhi]\
\)\ BesselJ[\@6, \(15.442468814142474`\ r\)\/r0]\)\/r0\)], "Output"],

Cell[BoxData[
    \(\(2.935207972987669`\ \[ExponentialE]\^\(3\ \[ImaginaryI]\ \
\[CurlyPhi]\)\ BesselJ[2\ \@3, \(16.87362244717725`\ r\)\/r0]\)\/r0\)], \
"Output"]
}, Open  ]],

Cell["\<\
Probability densities of the two-dimensional quantum rotator for given \
quantum numbers are:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[Psi]\[Psi]\_Rotat[1, 0, r0, r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, r0, 
          r, \[CurlyPhi]], {n\_rad \[Rule] 1, 
          m\_azm \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Rotat[1, 1, r0, r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, r0, 
          r, \[CurlyPhi]], {n\_rad \[Rule] 1, 
          m\_azm \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Rotat[1, 2, r0, r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, r0, 
          r, \[CurlyPhi]], {n\_rad \[Rule] 1, 
          m\_azm \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_Rotat[1, 3, r0, r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, r0, 
          r, \[CurlyPhi]], {n\_rad \[Rule] 1, 
          m\_azm \[Rule] 3}]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Rotat[2, 0, r0, r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, r0, 
          r, \[CurlyPhi]], {n\_rad \[Rule] 2, 
          m\_azm \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Rotat[2, 1, r0, r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, r0, 
          r, \[CurlyPhi]], {n\_rad \[Rule] 2, 
          m\_azm \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Rotat[2, 2, r0, r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, r0, 
          r, \[CurlyPhi]], {n\_rad \[Rule] 2, 
          m\_azm \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_Rotat[2, 3, r0, r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, r0, 
          r, \[CurlyPhi]], {n\_rad \[Rule] 2, 
          m\_azm \[Rule] 3}]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Rotat[3, 0, r0, r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, r0, 
          r, \[CurlyPhi]], {n\_rad \[Rule] 3, 
          m\_azm \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Rotat[3, 1, r0, r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, r0, 
          r, \[CurlyPhi]], {n\_rad \[Rule] 3, 
          m\_azm \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Rotat[3, 2, r0, r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, r0, 
          r, \[CurlyPhi]], {n\_rad \[Rule] 3, 
          m\_azm \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_Rotat[3, 3, r0, r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, r0, 
          r, \[CurlyPhi]], {n\_rad \[Rule] 3, m\_azm \[Rule] 3}]\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Rotat[4, 0, r0, r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, r0, 
          r, \[CurlyPhi]], {n\_rad \[Rule] 4, m\_azm \[Rule] 0}]\), "\n", 
    \(\[Psi]\[Psi]\_Rotat[4, 1, r0, r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, r0, 
          r, \[CurlyPhi]], {n\_rad \[Rule] 4, m\_azm \[Rule] 1}]\), "\n", 
    \(\[Psi]\[Psi]\_Rotat[4, 2, r0, r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, r0, 
          r, \[CurlyPhi]], {n\_rad \[Rule] 4, m\_azm \[Rule] 2}]\), "\n", 
    \(\[Psi]\[Psi]\_Rotat[4, 3, r0, r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, r0, 
          r, \[CurlyPhi]], {n\_rad \[Rule] 4, m\_azm \[Rule] 3}]\)}], "Input"],

Cell[BoxData[
    \(\(1.1810508537666946`\ r\ BesselJ[0, \(2.4048255576957467`\ r\)\/r0]\^2\
\)\/r0\^2\)], "Output"],

Cell[BoxData[
    \(\(1.9622700087322944`\ r\ BesselJ[1, \(3.8317059702075125`\ r\)\/r0]\^2\
\)\/r0\^2\)], "Output"],

Cell[BoxData[
    \(\(2.7589190615869175`\ r\ BesselJ[2, \(5.135622301840683`\ \
r\)\/r0]\^2\)\/r0\^2\)], "Output"],

Cell[BoxData[
    \(\(3.5778430852852554`\ r\ BesselJ[3, \(6.3801618959386`\ \
r\)\/r0]\^2\)\/r0\^2\)], "Output"],

Cell[BoxData[
    \(\(2.7492615752726115`\ r\ BesselJ[0, \(5.52007811028631`\ r\)\/r0]\^2\)\
\/r0\^2\)], "Output"],

Cell[BoxData[
    \(\(3.534048819836579`\ r\ BesselJ[1, \(7.015586669815615`\ r\)\/r0]\^2\)\
\/r0\^2\)], "Output"],

Cell[BoxData[
    \(\(4.322008648959936`\ r\ BesselJ[2, \(8.417244140695804`\ r\)\/r0]\^2\)\
\/r0\^2\)], "Output"],

Cell[BoxData[
    \(\(5.116803474852396`\ r\ BesselJ[3, \(9.761023130149406`\ r\)\/r0]\^2\)\
\/r0\^2\)], "Output"],

Cell[BoxData[
    \(\(4.319794389186207`\ r\ BesselJ[0, \(8.653727913113732`\ r\)\/r0]\^2\)\
\/r0\^2\)], "Output"],

Cell[BoxData[
    \(\(5.105003895054893`\ r\ BesselJ[1, \(10.173468135156398`\ \
r\)\/r0]\^2\)\/r0\^2\)], "Output"],

Cell[BoxData[
    \(\(5.891375466344339`\ r\ BesselJ[2, \(11.619841172201633`\ \
r\)\/r0]\^2\)\/r0\^2\)], "Output"],

Cell[BoxData[
    \(\(6.6807629093823016`\ r\ BesselJ[3, \(13.015200721731633`\ r\)\/r0]\^2\
\)\/r0\^2\)], "Output"],

Cell[BoxData[
    \(\(5.890528892167137`\ r\ BesselJ[0, \(11.791534439057065`\ \
r\)\/r0]\^2\)\/r0\^2\)], "Output"],

Cell[BoxData[
    \(\(6.675850367103544`\ r\ BesselJ[1, \(13.323691936337989`\ \
r\)\/r0]\^2\)\/r0\^2\)], "Output"],

Cell[BoxData[
    \(\(7.4617145403189`\ r\ BesselJ[2, \(14.795951782366128`\ \
r\)\/r0]\^2\)\/r0\^2\)], "Output"],

Cell[BoxData[
    \(\(8.249184452725327`\ r\ BesselJ[3, \(16.223466160328837`\ \
r\)\/r0]\^2\)\/r0\^2\)], "Output"]
}, Open  ]],

Cell["\<\
Thus we have list of probability densities of the two-dimensional quantum \
rotator for given quantum numbers are:\
\>", "Text"],

Cell[BoxData[{
    \(\(\[Psi]\[Psi]\_Rotat[1, 0, 
          r0] = \(1.1810508537666946`\ r\ BesselJ[0, \(2.4048255576957467`\ r\
\)\/r0]\^2\)\/r0\^2;\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Rotat[1, 1, 
          r0] = \(1.9622700087322944`\ r\ BesselJ[1, \(3.8317059702075125`\ r\
\)\/r0]\^2\)\/r0\^2;\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Rotat[1, 2, 
          r0] = \(2.7589190615869175`\ r\ BesselJ[2, \(5.135622301840683`\ \
r\)\/r0]\^2\)\/r0\^2;\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_Rotat[1, 3, 
          r0] = \(3.5778430852852554`\ r\ BesselJ[3, \(6.3801618959386`\ \
r\)\/r0]\^2\)\/r0\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Rotat[2, 0, 
          r0] = \(2.7492615752726115`\ r\ BesselJ[0, \(5.52007811028631`\ r\)\
\/r0]\^2\)\/r0\^2;\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Rotat[2, 1, 
          r0] = \(3.534048819836579`\ r\ BesselJ[1, \(7.015586669815615`\ r\)\
\/r0]\^2\)\/r0\^2;\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Rotat[2, 2, 
          r0] = \(4.322008648959936`\ r\ BesselJ[2, \(8.417244140695804`\ r\)\
\/r0]\^2\)\/r0\^2;\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_Rotat[2, 3, 
          r0] = \(5.116803474852396`\ r\ BesselJ[3, \(9.761023130149406`\ r\)\
\/r0]\^2\)\/r0\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Rotat[3, 0, 
          r0] = \(4.319794389186207`\ r\ BesselJ[0, \(8.653727913113732`\ r\)\
\/r0]\^2\)\/r0\^2;\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Rotat[3, 1, 
          r0] = \(5.105003895054893`\ r\ BesselJ[1, \(10.173468135156398`\ \
r\)\/r0]\^2\)\/r0\^2;\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Rotat[3, 2, 
          r0] = \(5.891375466344339`\ r\ BesselJ[2, \(11.619841172201633`\ \
r\)\/r0]\^2\)\/r0\^2;\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_Rotat[3, 3, 
          r0] = \(6.6807629093823016`\ r\ BesselJ[3, \(13.015200721731633`\ r\
\)\/r0]\^2\)\/r0\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Rotat[4, 0, 
          r0] = \(5.890528892167137`\ r\ BesselJ[0, \(11.791534439057065`\ \
r\)\/r0]\^2\)\/r0\^2;\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Rotat[4, 1, 
          r0] = \(6.675850367103544`\ r\ BesselJ[1, \(13.323691936337989`\ \
r\)\/r0]\^2\)\/r0\^2;\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Rotat[4, 2, 
          r0] = \(7.4617145403189`\ r\ BesselJ[2, \(14.795951782366128`\ \
r\)\/r0]\^2\)\/r0\^2;\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Rotat[4, 3, 
          r0] = \(8.249184452725327`\ r\ BesselJ[3, \(16.223466160328837`\ \
r\)\/r0]\^2\)\/r0\^2;\)\)}], "Input"],

Cell["", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1016, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.25,
StyleDefinitions -> "Classroom1.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 246, 8, 93, "Subtitle"],
Cell[2519, 82, 179, 5, 124, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2723, 91, 162, 5, 85, "Section"],
Cell[2888, 98, 163, 5, 56, "Text"],
Cell[3054, 105, 145, 6, 72, "NumberedEquation"],
Cell[3202, 113, 258, 7, 57, "Text"],
Cell[3463, 122, 62, 1, 63, "Input"],
Cell[3528, 125, 175, 5, 56, "Text"],
Cell[3706, 132, 2317, 48, 1142, "Input"],
Cell[6026, 182, 171, 5, 56, "Text"],
Cell[6200, 189, 2333, 50, 1255, "Input"],
Cell[8536, 241, 279, 8, 80, "Text"],

Cell[CellGroupData[{
Cell[8840, 253, 318, 6, 126, "Input"],
Cell[9161, 261, 107, 2, 99, "Output"],
Cell[9271, 265, 49, 1, 85, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9369, 272, 141, 4, 85, "Section"],
Cell[9513, 278, 139, 3, 56, "Text"],

Cell[CellGroupData[{
Cell[9677, 285, 310, 5, 88, "Input"],
Cell[9990, 292, 141, 2, 99, "Output"],
Cell[10134, 296, 77, 1, 85, "Output"]
}, Open  ]],
Cell[10226, 300, 171, 5, 56, "Text"],

Cell[CellGroupData[{
Cell[10422, 309, 3278, 63, 513, "Input"],
Cell[13703, 374, 107, 2, 96, "Output"],
Cell[13813, 378, 157, 2, 100, "Output"],
Cell[13973, 382, 156, 2, 100, "Output"],
Cell[14132, 386, 163, 2, 100, "Output"],
Cell[14298, 390, 105, 2, 96, "Output"],
Cell[14406, 394, 157, 2, 100, "Output"],
Cell[14566, 398, 159, 2, 100, "Output"],
Cell[14728, 402, 164, 2, 100, "Output"],
Cell[14895, 406, 106, 2, 96, "Output"],
Cell[15004, 410, 158, 2, 100, "Output"],
Cell[15165, 414, 160, 2, 100, "Output"],
Cell[15328, 418, 164, 2, 100, "Output"],
Cell[15495, 422, 107, 2, 96, "Output"],
Cell[15605, 426, 158, 2, 100, "Output"],
Cell[15766, 430, 161, 2, 100, "Output"],
Cell[15930, 434, 164, 3, 100, "Output"]
}, Open  ]],
Cell[16109, 440, 164, 5, 56, "Text"],

Cell[CellGroupData[{
Cell[16298, 449, 3442, 62, 513, "Input"],
Cell[19743, 513, 116, 2, 98, "Output"],
Cell[19862, 517, 116, 2, 98, "Output"],
Cell[19981, 521, 115, 2, 98, "Output"],
Cell[20099, 525, 113, 2, 98, "Output"],
Cell[20215, 529, 114, 2, 98, "Output"],
Cell[20332, 533, 114, 2, 98, "Output"],
Cell[20449, 537, 114, 2, 98, "Output"],
Cell[20566, 541, 114, 2, 98, "Output"],
Cell[20683, 545, 114, 2, 98, "Output"],
Cell[20800, 549, 115, 2, 98, "Output"],
Cell[20918, 553, 115, 2, 98, "Output"],
Cell[21036, 557, 116, 2, 98, "Output"],
Cell[21155, 561, 115, 2, 98, "Output"],
Cell[21273, 565, 115, 2, 98, "Output"],
Cell[21391, 569, 113, 2, 98, "Output"],
Cell[21507, 573, 115, 2, 98, "Output"]
}, Open  ]],
Cell[21637, 578, 138, 3, 56, "Text"],
Cell[21778, 583, 2699, 51, 1205, "Input"],
Cell[24480, 636, 16, 0, 56, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

