(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     82469,       2177]*)
(*NotebookOutlinePosition[     83198,       2202]*)
(*  CellTagsIndexPosition[     83154,       2198]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Part ",
    FontWeight->"Bold"],
  StyleBox["1. Quantum Isotropic Rotator",
    FontWeight->"Bold"],
  "\n1.2. Three-Dimensional Isotropic Quantum Rotator"
}], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
1.2.5. Radial probability density and normalization of the radial wave \
functions of Three-Dimensional Quantum Rotator\
\>", "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
1. Radial probability density of the three-dimensional quantum rotator\
\>", "Section"],

Cell[TextData[{
  "We will use \"",
  StyleBox["NumericalMath`BesselZeros`",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  "\"."
}], "Text"],

Cell[BoxData[
    \(<< NumericalMath`BesselZeros`\)], "Input"],

Cell["\<\
Consider radial wave function of the three-dimensional quantum rotator:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(R[n\_rad, l\_orb, r0, r]\), "=", 
      RowBox[{\(C[n\_rad, l\_orb]\), " ", \(\@r\), "  ", 
        RowBox[{"BesselJ", "[", 
          RowBox[{\(l\_orb + 1\/2\), ",", 
            RowBox[{
              StyleBox[\(BesselJZeros[l\_orb + 1\/2, {n\_rad, n\_rad}]\/r0\),
                FontSlant->"Italic"], " ", "r"}]}], "]"}]}]}]], "Input"],

Cell[BoxData[
    \(\@r\ BesselJ[
        1\/2 + l\_orb, \(r\ BesselJZeros[1\/2 + l\_orb, {n\_rad, \
n\_rad}]\)\/r0]\ C[n\_rad, l\_orb]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(C[n\_rad, l\_orb]\)],
    FontSlant->"Italic"],
  "are constants."
}], "Text"],

Cell["\<\
Define radial probability density of the three-dimensional quantum rotator:\
\>", "Text"],

Cell[BoxData[
    \(RR[n\_rad, l\_orb, 
        r\_0] = \(\(|\)\(R[n\_rad, l\_orb, 
          r\_0]\)\( | \^2\)\(\ \)\(r\^2\)\)\)], "NumberedEquation",
  TextAlignment->Center],

Cell[TextData[{
  "As ",
  Cell[BoxData[
      \(R[n\_rad, l\_orb, r0, r]\)],
    FontSlant->"Italic"],
  "is real ",
  "function we have"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell[BoxData[
    \(RR[n\_rad, l\_orb, r0, r] = 
      FullSimplify[\((R[n\_rad, l\_orb, r0, r] r)\)\^2]\)], "Input"],

Cell[BoxData[
    \(r\^3\ BesselJ[1\/2 + l\_orb, \(r\ BesselJZeros[1\/2 + l\_orb, {n\_rad, \
n\_rad}]\)\/r0]\^2\ C[n\_rad, l\_orb]\^2\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2. Dimensionless form of the radial wave functions of the three-dimensional \
quantum rotator\
\>", "Section"],

Cell[TextData[{
  "Transform  radial wave function of ",
  "the three-dimensional quantum rotator",
  " to the dimensionless form using new dimensionless variable \[Rho] and \
constant ",
  Cell[BoxData[
      \(C[n\_rad, l\_orb, r0]\)],
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[BoxData[
    \(r = \(\[Rho]\ r0\)\/BesselJZeros[1\/2 + l\_orb, {n\_rad, n\_rad}], \
\[Rho] = \(r\ BesselJZeros[1\/2 + l\_orb, {n\_rad, n\_rad}]\)\/r0\)], \
"NumberedEquation"],

Cell[CellGroupData[{

Cell[BoxData[
    \(R[n\_rad, l\_orb, r0, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, l\_orb, r0, 
          r], {r \[Rule] \(\[Rho]\ r0\)\/BesselJZeros[1\/2 + l\_orb, {n\_rad, \
n\_rad}]}]\)], "Input"],

Cell[BoxData[
    \(BesselJ[
        1\/2 + l\_orb, \[Rho]]\ \@\(\(r0\ \[Rho]\)\/BesselJZeros[1\/2 + \
l\_orb, {n\_rad, n\_rad}]\)\ C[n\_rad, l\_orb]\)], "Output"]
}, Open  ]],

Cell["\<\
Transform  radial probability density of the three-dimensional quantum \
rotator to the dimensionless form too:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RR[n\_rad, l\_orb, r0, \[Rho]] = 
      FullSimplify[
        ReplaceAll[
          RR[n\_rad, l\_orb, r0, 
            r], {r \[Rule] \(\[Rho]\ r0\)\/BesselJZeros[1\/2 + l\_orb, \
{n\_rad, n\_rad}]}]]\)], "Input"],

Cell[BoxData[
    \(\(r0\^3\ \[Rho]\^3\ BesselJ[1\/2 + l\_orb, \[Rho]]\^2\ C[n\_rad, \
l\_orb]\^2\)\/BesselJZeros[1\/2 + l\_orb, {n\_rad, n\_rad}]\^3\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
3. Normalization procedure for the radial wave functions of the \
three-dimensional quantum rotator\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Consider normalization procedure for radial wave functions. This implies the \
integral condition:\
\>", "Text"],

Cell[BoxData[
    \(\[Integral]\_0\%\[Infinity] RR[n\_rad, l\_orb, \[Lambda], 
            r] \[DifferentialD]r = 1\)], "NumberedEquation"],

Cell["or for dimensionless radial functions:", "Text"],

Cell[BoxData[
    \(\(r0\/BesselJZeros[
              1\/2 + l\_orb, {n\_rad, 
                n\_rad}]\) \(\[Integral]\_0\%\[Infinity] RR[n\_rad, l\_orb, 
              r0, \[Rho]] \[DifferentialD]\[Rho]\) = 1\)], "NumberedEquation"],

Cell["\<\
Normalize radial wave functions for different values of quantum numbers:\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      StyleBox[\(n\_rad\),
        FontSlant->"Italic"]]],
  " =  1, 2, 3, 4\n",
  Cell[BoxData[
      \(l\_orb\)]],
  " = 0, 1, 2, 3"
}], "NumberedEquation"],

Cell[TextData[{
  "We will obtain values for constants ",
  Cell[BoxData[
      \(C[n\_rad, l\_orb]\)],
    FontSlant->"Italic"],
  " and normalized radial wave functions ",
  Cell[BoxData[
      \(R\_Nrm[0, 0, r]\)],
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  "1) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 0"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 1;\), "\[IndentingNewLine]", \(l\_orb = 
        0;\), "\[IndentingNewLine]", 
    RowBox[{"FullSimplify", "[", " ", 
      RowBox[{\(\@r\), "  ", 
        RowBox[{"BesselJ", "[", 
          RowBox[{\(l\_orb + 1\/2\), ",", 
            RowBox[{
              StyleBox[\(BesselJZeros[l\_orb + 1\/2, {n\_rad, n\_rad}]\/r0\),
                FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
      "]"}], "\[IndentingNewLine]", \(\(r0\/BesselJZeros[
            1\/2 + l\_orb, {n\_rad, 
              n\_rad}]\) \(\[Integral]\_0\%\(BesselJZeros[1\/2 + l\_orb, \
{n\_rad, n\_rad}]\)\(\(r0\^3\ \[Rho]\^3\ BesselJ[1\/2 + l\_orb, \[Rho]]\^2\ \
C[n\_rad, l\_orb]\^2\)\/BesselJZeros[1\/2 + l\_orb, {n\_rad, n\_rad}]\^3\) \
\[DifferentialD]\[Rho]\)\)}], "Input"],

Cell[BoxData[
    \({\(0.4501581580785532`\ \@r\ Cos[\(\(1.5707963267948966`\)\(\
\[InvisibleSpace]\)\) - \(3.1415926535897913`\ r\)\/r0]\)\/\@\(r\/r0\)}\)], \
"Output"],

Cell[BoxData[
    \({{0.028640736753437163`\ r0\^4\ C[1, 0]\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[0.028640736753437163`\ r0\^4\ C[1, 0]\^2 \[Equal] 1, 
      C[1, 0]]\)], "Input"],

Cell[BoxData[
    \({{C[1, 0] \[Rule] \(-\(5.908917238718758`\/r0\^2\)\)}, {C[1, 0] \[Rule] 
          5.908917238718758`\/r0\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(R\_Nrm[1, 0, r0, 
        r] = \(5.908917238718758`\/r0\^2\) \(0.4501581580785532`\ \@r\ Cos[\(\
\(1.5707963267948966`\)\(\[InvisibleSpace]\)\) - \(3.1415926535897913`\ \
r\)\/r0]\)\/\@\(r\/r0\)\)], "Input"],

Cell[BoxData[
    \(\(2.6599473004202467`\ \@r\ Cos[\(\(1.5707963267948966`\)\(\
\[InvisibleSpace]\)\) - \(3.1415926535897913`\ r\)\/r0]\)\/\(\@\(r\/r0\)\ \
r0\^2\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "2) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 1"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 1;\), "\[IndentingNewLine]", \(l\_orb = 
        1;\), "\[IndentingNewLine]", 
    RowBox[{"FullSimplify", "[", " ", 
      RowBox[{\(\@r\), "  ", 
        RowBox[{"BesselJ", "[", 
          RowBox[{\(l\_orb + 1\/2\), ",", 
            RowBox[{
              StyleBox[\(BesselJZeros[l\_orb + 1\/2, {n\_rad, n\_rad}]\/r0\),
                FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
      "]"}], "\[IndentingNewLine]", \(\(r0\/BesselJZeros[
            1\/2 + l\_orb, {n\_rad, 
              n\_rad}]\) \(\[Integral]\_0\%\(BesselJZeros[1\/2 + l\_orb, \
{n\_rad, n\_rad}]\)\(\(r0\^3\ \[Rho]\^3\ BesselJ[1\/2 + l\_orb, \[Rho]]\^2\ \
C[n\_rad, l\_orb]\^2\)\/BesselJZeros[1\/2 + l\_orb, {n\_rad, n\_rad}]\^3\) \
\[DifferentialD]\[Rho]\)\)}], "Input"],

Cell[BoxData[
    \({\(0.3764021226965972`\ r\ Cos[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(4.493409457909065`\ r\)\/r0] + 0.08376759924116726`\
\ r0\ Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \
\(4.493409457909065`\ r\)\/r0]\)\/\(\@r\ \@\(r\/r0\)\)}\)], "Output"],

Cell[BoxData[
    \({{0.02528456169415733`\ r0\^4\ C[1, 1]\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[0.02528456169415733`\ r0\^4\ C[1, 1]\^2 \[Equal] 1, 
      C[1, 1]]\)], "Input"],

Cell[BoxData[
    \({{C[1, 1] \[Rule] \(-\(6.28886519074513`\/r0\^2\)\)}, {C[1, 1] \[Rule] 
          6.28886519074513`\/r0\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(R\_Nrm[1, 1, r0, 
        r] = \(6.28886519074513`\/r0\^2\) \(\(1\/\(\@r\ \@\(r\/r0\)\)\) \
\((0.3764021226965972`\ r\ \
Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(4.493409457909065`\ r\
\)\/r0] + 
              0.08376759924116726`\ r0\ Sin[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(4.493409457909065`\ r\)\/r0])\)\)\)], "Input"],

Cell[BoxData[
    \(\(6.28886519074513`\ \((0.3764021226965972`\ r\ \
Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(4.493409457909065`\ r\
\)\/r0] + 0.08376759924116726`\ r0\ Sin[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(4.493409457909065`\ r\)\/r0])\)\)\/\(\@r\ \@\(r\/r0\
\)\ r0\^2\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "3) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 2"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 1;\), "\[IndentingNewLine]", \(l\_orb = 
        2;\), "\[IndentingNewLine]", 
    RowBox[{"FullSimplify", "[", " ", 
      RowBox[{\(\@r\), "  ", 
        RowBox[{"BesselJ", "[", 
          RowBox[{\(l\_orb + 1\/2\), ",", 
            RowBox[{
              StyleBox[\(BesselJZeros[l\_orb + 1\/2, {n\_rad, n\_rad}]\/r0\),
                FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
      "]"}], "\[IndentingNewLine]", \(\(r0\/BesselJZeros[
            1\/2 + l\_orb, {n\_rad, 
              n\_rad}]\) \(\[Integral]\_0\%\(BesselJZeros[1\/2 + l\_orb, \
{n\_rad, n\_rad}]\)\(\(r0\^3\ \[Rho]\^3\ BesselJ[1\/2 + l\_orb, \[Rho]]\^2\ \
C[n\_rad, l\_orb]\^2\)\/BesselJZeros[1\/2 + l\_orb, {n\_rad, n\_rad}]\^3\) \
\[DifferentialD]\[Rho]\)\)}], "Input"],

Cell[BoxData[
    \({\(1\/\(r\^\(3/2\)\ \@\(r\/r0\)\)\)\((\((0.3323521174464318`\ r\^2 - 
                0.030016030571366766`\ r0\^2)\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(5.763459196944853`\ \
r\)\/r0] + 
          0.1729961674523217`\ r\ r0\ Sin[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(5.763459196944853`\ r\)\/r0])\)}\)], "Output"],

Cell[BoxData[
    \({{0.022056963540327833`\ r0\^4\ C[1, 2]\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[0.022056963540327833`\ r0\^4\ C[1, 2]\^2 \[Equal] 1, 
      C[1, 2]]\)], "Input"],

Cell[BoxData[
    \({{C[1, 2] \[Rule] \(-\(6.733287171946806`\/r0\^2\)\)}, {C[1, 2] \[Rule] 
          6.733287171946806`\/r0\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(R\_Nrm[1, 2, r0, 
        r] = \(6.733287171946806`\/r0\^2\) \(1\/\(r\^\(3/2\)\ \@\(r\/r0\)\)\) \
\((\((0.3323521174464318`\ r\^2 - 
                  0.030016030571366766`\ r0\^2)\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(5.763459196944853`\ \
r\)\/r0] + 
            0.1729961674523217`\ r\ r0\ Sin[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(5.763459196944853`\ r\)\/r0])\)\)], "Input"],

Cell[BoxData[
    \(\(\(1\/\(r\^\(3/2\)\ \@\(r\/r0\)\ r0\^2\)\)\((6.733287171946806`\ \
\((\((0.3323521174464318`\ r\^2 - 
                  0.030016030571366766`\ r0\^2)\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(5.763459196944853`\ \
r\)\/r0] + 
            0.1729961674523217`\ r\ r0\ Sin[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(5.763459196944853`\ r\)\/r0])\))\)\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "4) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 1;\), "\[IndentingNewLine]", \(l\_orb = 
        3;\), "\[IndentingNewLine]", 
    RowBox[{"FullSimplify", "[", " ", 
      RowBox[{\(\@r\), "  ", 
        RowBox[{"BesselJ", "[", 
          RowBox[{\(l\_orb + 1\/2\), ",", 
            RowBox[{
              StyleBox[\(BesselJZeros[l\_orb + 1\/2, {n\_rad, n\_rad}]\/r0\),
                FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
      "]"}], "\[IndentingNewLine]", \(Limit[\(r0\/BesselJZeros[
              1\/2 + l\_orb, {n\_rad, 
                n\_rad}]\) \
\(\[Integral]\_\[CurlyEpsilon]\%\(BesselJZeros[1\/2 + l\_orb, {n\_rad, \
n\_rad}]\)\(\(r0\^3\ \[Rho]\^3\ BesselJ[1\/2 + l\_orb, \[Rho]]\^2\ C[n\_rad, \
l\_orb]\^2\)\/BesselJZeros[1\/2 + l\_orb, {n\_rad, n\_rad}]\^3\) \
\[DifferentialD]\[Rho]\), \[CurlyEpsilon] \[Rule] 0]\)}], "Input"],

Cell[BoxData[
    \({\(1\/\(r\^\(5/2\)\ \@\(r\/r0\)\)\)\((\((0.3018323092198434`\ r\^3 - 
                0.09271705851256021`\ r\ r0\^2)\)\ Cos[\(\(6.283185307179586`\
\)\(\[InvisibleSpace]\)\) - \(6.987932000503647`\ r\)\/r0] + 
          r0\ \((0.2591602000689954`\ r\^2 - 
                0.013268168394580504`\ r0\^2)\)\ Sin[\(\(6.283185307179586`\)\
\(\[InvisibleSpace]\)\) - \(6.987932000503647`\ r\)\/r0])\)}\)], "Output"],

Cell[BoxData[
    \({{0.019393629791295205`\ r0\^4\ C[1, 3]\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[0.019393629791295205`\ C[1, 3]\^2 \[Equal] 1, C[1, 3]]\)], "Input"],

Cell[BoxData[
    \({{C[1, 3] \[Rule] \(-7.180760624824514`\)}, {C[1, 3] \[Rule] 
          7.180760624824514`}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(R\_Nrm[1, 3, r0, r] = 
      7.180760624824514` \( 
            1\/r\^3\) \((r\ \((\(-0.09271705851256021`\) + 
                  0.3018323092198434`\ r\^2)\)\ \
Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 
                  6.987932000503647`\ r] + \((\(-0.013268168394580504`\) + 
                  0.2591602000689954`\ r\^2)\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 
                  6.987932000503647`\ r])\)\)], "Input"],

Cell[BoxData[
    \(\(\(1\/r\^3\)\((7.180760624824514`\ \((r\ \((\(-0.09271705851256021`\) \
+ 0.3018323092198434`\ r\^2)\)\ Cos[\(\(6.283185307179586`\)\(\
\[InvisibleSpace]\)\) - 
                  6.987932000503647`\ r] + \((\(-0.013268168394580504`\) + 
                  0.2591602000689954`\ r\^2)\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 
                  6.987932000503647`\ r])\))\)\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "5) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 2, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 0"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 2;\), "\[IndentingNewLine]", \(l\_orb = 
        0;\), "\[IndentingNewLine]", 
    RowBox[{"FullSimplify", "[", " ", 
      RowBox[{\(\@r\), "  ", 
        RowBox[{"BesselJ", "[", 
          RowBox[{\(l\_orb + 1\/2\), ",", 
            RowBox[{
              StyleBox[\(BesselJZeros[l\_orb + 1\/2, {n\_rad, n\_rad}]\/r0\),
                FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
      "]"}], "\[IndentingNewLine]", \(\(r0\/BesselJZeros[
            1\/2 + l\_orb, {n\_rad, 
              n\_rad}]\) \(\[Integral]\_0\%\(BesselJZeros[1\/2 + l\_orb, \
{n\_rad, n\_rad}]\)\(\(r0\^3\ \[Rho]\^3\ BesselJ[1\/2 + l\_orb, \[Rho]]\^2\ \
C[n\_rad, l\_orb]\^2\)\/BesselJZeros[1\/2 + l\_orb, {n\_rad, n\_rad}]\^3\) \
\[DifferentialD]\[Rho]\)\)}], "Input"],

Cell[BoxData[
    \({\(0.3183098861837907`\ \@r\ Cos[\(\(1.5707963267948966`\)\(\
\[InvisibleSpace]\)\) - \(6.283185307179585`\ r\)\/r0]\)\/\@\(r\/r0\)}\)], \
"Output"],

Cell[BoxData[
    \({{0.016245240049471872`\ r0\^4\ C[2, 0]\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[0.016245240049471872`\ r0\^4\ C[2, 0]\^2 \[Equal] 1, 
      C[2, 0]]\)], "Input"],

Cell[BoxData[
    \({{C[2, 0] \[Rule] \(-\(7.845794584890337`\/r0\^2\)\)}, {C[2, 0] \[Rule] 
          7.845794584890337`\/r0\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(R\_Nrm[2, 0, r0, 
        r] = \(7.845794584890337`\/r0\^2\) \(0.3183098861837907`\ \@r\ Cos[\(\
\(1.5707963267948966`\)\(\[InvisibleSpace]\)\) - \(6.283185307179585`\ \
r\)\/r0]\)\/\@\(r\/r0\)\)], "Input"],

Cell[BoxData[
    \(\(2.4973939813378445`\ \@r\ Cos[\(\(1.5707963267948966`\)\(\
\[InvisibleSpace]\)\) - \(6.283185307179585`\ r\)\/r0]\)\/\(\@\(r\/r0\)\ \
r0\^2\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "6) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 2, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 1"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 2;\), "\[IndentingNewLine]", \(l\_orb = 
        1;\), "\[IndentingNewLine]", 
    RowBox[{"FullSimplify", "[", " ", 
      RowBox[{\(\@r\), "  ", 
        RowBox[{"BesselJ", "[", 
          RowBox[{\(l\_orb + 1\/2\), ",", 
            RowBox[{
              StyleBox[\(BesselJZeros[l\_orb + 1\/2, {n\_rad, n\_rad}]\/r0\),
                FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
      "]"}], "\[IndentingNewLine]", \(\(r0\/BesselJZeros[
            1\/2 + l\_orb, {n\_rad, 
              n\_rad}]\) \(\[Integral]\_0\%\(BesselJZeros[1\/2 + l\_orb, \
{n\_rad, n\_rad}]\)\(\(r0\^3\ \[Rho]\^3\ BesselJ[1\/2 + l\_orb, \[Rho]]\^2\ \
C[n\_rad, l\_orb]\^2\)\/BesselJZeros[1\/2 + l\_orb, {n\_rad, n\_rad}]\^3\) \
\[DifferentialD]\[Rho]\)\)}], "Input"],

Cell[BoxData[
    \({\(0.28706730919827866`\ r\ Cos[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(7.725251836937706`\ r\)\/r0] + 0.03715960531224213`\
\ r0\ Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \
\(7.725251836937706`\ r\)\/r0]\)\/\(\@r\ \@\(r\/r0\)\)}\)], "Output"],

Cell[BoxData[
    \({{0.014074126680737544`\ r0\^4\ C[2, 1]\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[0.014074126680737544`\ r0\^4\ C[2, 1]\^2 \[Equal] 1, 
      C[2, 1]]\)], "Input"],

Cell[BoxData[
    \({{C[2, 1] \[Rule] \(-\(8.429256550635898`\/r0\^2\)\)}, {C[2, 1] \[Rule] 
          8.429256550635898`\/r0\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(R\_Nrm[2, 1, r0, 
        r] = \(8.429256550635898`\/r0\^2\) \(\(1\/\(\@r\ \@\(r\/r0\)\)\) \
\((0.28706730919827866`\ r\ Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\
\) - \(7.725251836937706`\ r\)\/r0] + 
              0.03715960531224213`\ r0\ Sin[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(7.725251836937706`\ r\)\/r0])\)\)\)], "Input"],

Cell[BoxData[
    \(\(8.429256550635898`\ \((0.28706730919827866`\ r\ \
Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(7.725251836937706`\ r\
\)\/r0] + 0.03715960531224213`\ r0\ Sin[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(7.725251836937706`\ r\)\/r0])\)\)\/\(\@r\ \@\(r\/r0\
\)\ r0\^2\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "7) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 2, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 2"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 2;\), "\[IndentingNewLine]", \(l\_orb = 
        2;\), "\[IndentingNewLine]", 
    RowBox[{"FullSimplify", "[", " ", 
      RowBox[{\(\@r\), "  ", 
        RowBox[{"BesselJ", "[", 
          RowBox[{\(l\_orb + 1\/2\), ",", 
            RowBox[{
              StyleBox[\(BesselJZeros[l\_orb + 1\/2, {n\_rad, n\_rad}]\/r0\),
                FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
      "]"}], "\[IndentingNewLine]", \(\(r0\/BesselJZeros[
            1\/2 + l\_orb, {n\_rad, 
              n\_rad}]\) \(\[Integral]\_0\%\(BesselJZeros[1\/2 + l\_orb, \
{n\_rad, n\_rad}]\)\(\(r0\^3\ \[Rho]\^3\ BesselJ[1\/2 + l\_orb, \[Rho]]\^2\ \
C[n\_rad, l\_orb]\^2\)\/BesselJZeros[1\/2 + l\_orb, {n\_rad, n\_rad}]\^3\) \
\[DifferentialD]\[Rho]\)\)}], "Input"],

Cell[BoxData[
    \({\(1\/\(r\^\(3/2\)\ \@\(r\/r0\)\)\)\((\((0.2645686853222971`\ r\^2 - 
                0.00959518174141225`\ r0\^2)\)\ Cos[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(9.09501133069512`\ r\)\/r0] + 
          0.08726828665822337`\ r\ r0\ Sin[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(9.09501133069512`\ r\)\/r0])\)}\)], "Output"],

Cell[BoxData[
    \({{0.012670740180471741`\ r0\^4\ C[2, 2]\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[0.012670740180471741`\ r0\^4\ C[2, 2]\^2 \[Equal] 1, 
      C[2, 2]]\)], "Input"],

Cell[BoxData[
    \({{C[2, 2] \[Rule] \(-\(8.88380479563113`\/r0\^2\)\)}, {C[2, 2] \[Rule] 
          8.88380479563113`\/r0\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(R\_Nrm[2, 2, r0, 
        r] = \(8.88380479563113`\/r0\^2\) \(1\/\(r\^\(3/2\)\ \@\(r\/r0\)\)\) \
\((\((0.2645686853222971`\ r\^2 - 
                  0.00959518174141225`\ r0\^2)\)\ Cos[\(\(4.71238898038469`\)\
\(\[InvisibleSpace]\)\) - \(9.09501133069512`\ r\)\/r0] + 
            0.08726828665822337`\ r\ r0\ Sin[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(9.09501133069512`\ r\)\/r0])\)\)], "Input"],

Cell[BoxData[
    \(\(\(1\/\(r\^\(3/2\)\ \@\(r\/r0\)\ r0\^2\)\)\((8.88380479563113`\ \
\((\((0.2645686853222971`\ r\^2 - 
                  0.00959518174141225`\ r0\^2)\)\ Cos[\(\(4.71238898038469`\)\
\(\[InvisibleSpace]\)\) - \(9.09501133069512`\ r\)\/r0] + 
            0.08726828665822337`\ r\ r0\ Sin[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(9.09501133069512`\ r\)\/r0])\))\)\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "8) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 2, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 2;\), "\[IndentingNewLine]", \(l\_orb = 
        3;\), "\[IndentingNewLine]", 
    RowBox[{"FullSimplify", "[", " ", 
      RowBox[{\(\@r\), "  ", 
        RowBox[{"BesselJ", "[", 
          RowBox[{\(l\_orb + 1\/2\), ",", 
            RowBox[{
              StyleBox[\(BesselJZeros[l\_orb + 1\/2, {n\_rad, n\_rad}]\/r0\),
                FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
      "]"}], "\[IndentingNewLine]", \(Limit[\(r0\/BesselJZeros[
              1\/2 + l\_orb, {n\_rad, 
                n\_rad}]\) \
\(\[Integral]\_\[CurlyEpsilon]\%\(BesselJZeros[1\/2 + l\_orb, {n\_rad, \
n\_rad}]\)\(\(r0\^3\ \[Rho]\^3\ BesselJ[1\/2 + l\_orb, \[Rho]]\^2\ C[n\_rad, \
l\_orb]\^2\)\/BesselJZeros[1\/2 + l\_orb, {n\_rad, n\_rad}]\^3\) \
\[DifferentialD]\[Rho]\), \[CurlyEpsilon] \[Rule] 0]\)}], "Input"],

Cell[BoxData[
    \({\(1\/\(r\^\(5/2\)\ \@\(r\/r0\)\)\)\((\((0.24721012729596964`\ r\^3 - 
                0.034171363187267656`\ r\ r0\^2)\)\ \
Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(10.417118547512036`\ \
r\)\/r0] + 
          r0\ \((0.14238685650074237`\ r\^2 - 
                0.0032803085643514102`\ r0\^2)\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(10.417118547512036`\ \
r\)\/r0])\)}\)], "Output"],

Cell[BoxData[
    \({{0.01160906518747518`\ r0\^4\ C[2, 3]\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[0.01160906518747518`\ r0\^4\ C[2, 3]\^2 \[Equal] 1, 
      C[2, 3]]\)], "Input"],

Cell[BoxData[
    \({{C[2, 3] \[Rule] \(-\(9.281141096227815`\/r0\^2\)\)}, {C[2, 3] \[Rule] 
          9.281141096227815`\/r0\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(R\_Nrm[2, 3, r0, 
        r] = \(9.281141096227815`\/r0\^2\) \(1\/\(r\^\(5/2\)\ \@\(r\/r0\)\)\) \
\((\((0.24721012729596964`\ r\^3 - 
                  0.034171363187267656`\ r\ r0\^2)\)\ \
Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(10.417118547512036`\ \
r\)\/r0] + 
            r0\ \((0.14238685650074237`\ r\^2 - 
                  0.0032803085643514102`\ r0\^2)\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(10.417118547512036`\ \
r\)\/r0])\)\)], "Input"],

Cell[BoxData[
    \(\(\(1\/\(r\^\(5/2\)\ \@\(r\/r0\)\ r0\^2\)\)\((9.281141096227815`\ \
\((\((0.24721012729596964`\ r\^3 - 
                  0.034171363187267656`\ r\ r0\^2)\)\ \
Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(10.417118547512036`\ \
r\)\/r0] + 
            r0\ \((0.14238685650074237`\ r\^2 - 
                  0.0032803085643514102`\ r0\^2)\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(10.417118547512036`\ \
r\)\/r0])\))\)\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "9) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 3, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 0"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 3;\), "\[IndentingNewLine]", \(l\_orb = 
        0;\), "\[IndentingNewLine]", 
    RowBox[{"FullSimplify", "[", " ", 
      RowBox[{\(\@r\), "  ", 
        RowBox[{"BesselJ", "[", 
          RowBox[{\(l\_orb + 1\/2\), ",", 
            RowBox[{
              StyleBox[\(BesselJZeros[l\_orb + 1\/2, {n\_rad, n\_rad}]\/r0\),
                FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
      "]"}], "\[IndentingNewLine]", \(\(r0\/BesselJZeros[
            1\/2 + l\_orb, {n\_rad, 
              n\_rad}]\) \(\[Integral]\_0\%\(BesselJZeros[1\/2 + l\_orb, \
{n\_rad, n\_rad}]\)\(\(r0\^3\ \[Rho]\^3\ BesselJ[1\/2 + l\_orb, \[Rho]]\^2\ \
C[n\_rad, l\_orb]\^2\)\/BesselJZeros[1\/2 + l\_orb, {n\_rad, n\_rad}]\^3\) \
\[DifferentialD]\[Rho]\)\)}], "Input"],

Cell[BoxData[
    \({\(0.2598989337427179`\ \@r\ Cos[\(\(1.5707963267948966`\)\(\
\[InvisibleSpace]\)\) - \(9.424777960902889`\ r\)\/r0]\)\/\@\(r\/r0\)}\)], \
"Output"],

Cell[BoxData[
    \({{0.011067798510471799`\ r0\^4\ C[3, 0]\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[0.011067798510471799`\ r0\^4\ C[3, 0]\^2 \[Equal] 1, 
      C[3, 0]]\)], "Input"],

Cell[BoxData[
    \({{C[3, 0] \[Rule] \(-\(9.505377688840852`\/r0\^2\)\)}, {C[3, 0] \[Rule] 
          9.505377688840852`\/r0\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(R\_Nrm[3, 0, r0, 
        r] = \(9.505377688840852`\/r0\^2\) \(0.2598989337427179`\ \@r\ Cos[\(\
\(1.5707963267948966`\)\(\[InvisibleSpace]\)\) - \(9.424777960902889`\ \
r\)\/r0]\)\/\@\(r\/r0\)\)], "Input"],

Cell[BoxData[
    \(\(2.4704375261515574`\ \@r\ Cos[\(\(1.5707963267948966`\)\(\
\[InvisibleSpace]\)\) - \(9.424777960902889`\ r\)\/r0]\)\/\(\@\(r\/r0\)\ \
r0\^2\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "10) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 3, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 1"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 3;\), "\[IndentingNewLine]", \(l\_orb = 
        1;\), "\[IndentingNewLine]", 
    RowBox[{"FullSimplify", "[", " ", 
      RowBox[{\(\@r\), "  ", 
        RowBox[{"BesselJ", "[", 
          RowBox[{\(l\_orb + 1\/2\), ",", 
            RowBox[{
              StyleBox[\(BesselJZeros[l\_orb + 1\/2, {n\_rad, n\_rad}]\/r0\),
                FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
      "]"}], "\[IndentingNewLine]", \(\(r0\/BesselJZeros[
            1\/2 + l\_orb, {n\_rad, 
              n\_rad}]\) \(\[Integral]\_0\%\(BesselJZeros[1\/2 + l\_orb, \
{n\_rad, n\_rad}]\)\(\(r0\^3\ \[Rho]\^3\ BesselJ[1\/2 + l\_orb, \[Rho]]\^2\ \
C[n\_rad, l\_orb]\^2\)\/BesselJZeros[1\/2 + l\_orb, {n\_rad, n\_rad}]\^3\) \
\[DifferentialD]\[Rho]\)\)}], "Input"],

Cell[BoxData[
    \({\(0.2416265857850596`\ r\ Cos[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(10.90412165949781`\ r\)\/r0] + \
0.022159197533768875`\ r0\ \
Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(10.90412165949781`\ r\
\)\/r0]\)\/\(\@r\ \@\(r\/r0\)\)}\)], "Output"],

Cell[BoxData[
    \({{0.009852301501456148`\ r0\^4\ C[3, 1]\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[0.009852301501456148`\ r0\^4\ C[3, 1]\^2 \[Equal] 1, 
      C[3, 1]]\)], "Input"],

Cell[BoxData[
    \({{C[3, 1] \[Rule] \(-\(10.07467750670633`\/r0\^2\)\)}, {C[3, 1] \[Rule] 
          10.07467750670633`\/r0\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(R\_Nrm[3, 1, r0, 
        r] = \(10.07467750670633`\/r0\^2\) \(\(1\/\(\@r\ \@\(r\/r0\)\)\) \
\((0.2416265857850596`\ r\ \
Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(10.90412165949781`\ r\
\)\/r0] + 
              0.022159197533768875`\ r0\ Sin[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(10.90412165949781`\ r\)\/r0])\)\)\)], "Input"],

Cell[BoxData[
    \(\(10.07467750670633`\ \((0.2416265857850596`\ r\ \
Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(10.90412165949781`\ r\
\)\/r0] + 0.022159197533768875`\ r0\ Sin[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(10.90412165949781`\ r\)\/r0])\)\)\/\(\@r\ \@\(r\/r0\
\)\ r0\^2\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "11) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 3, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 2"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 3;\), "\[IndentingNewLine]", \(l\_orb = 
        2;\), "\[IndentingNewLine]", 
    RowBox[{"FullSimplify", "[", " ", 
      RowBox[{\(\@r\), "  ", 
        RowBox[{"BesselJ", "[", 
          RowBox[{\(l\_orb + 1\/2\), ",", 
            RowBox[{
              StyleBox[\(BesselJZeros[l\_orb + 1\/2, {n\_rad, n\_rad}]\/r0\),
                FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
      "]"}], "\[IndentingNewLine]", \(\(r0\/BesselJZeros[
            1\/2 + l\_orb, {n\_rad, 
              n\_rad}]\) \(\[Integral]\_0\%\(BesselJZeros[1\/2 + l\_orb, \
{n\_rad, n\_rad}]\)\(\(r0\^3\ \[Rho]\^3\ BesselJ[1\/2 + l\_orb, \[Rho]]\^2\ \
C[n\_rad, l\_orb]\^2\)\/BesselJZeros[1\/2 + l\_orb, {n\_rad, n\_rad}]\^3\) \
\[DifferentialD]\[Rho]\)\)}], "Input"],

Cell[BoxData[
    \({\(1\/\(r\^\(3/2\)\ \@\(r\/r0\)\)\)\((\((0.22729133392011303`\ r\^2 - 
                0.004490300397068933`\ r0\^2)\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(12.322940970607872`\ r\
\)\/r0] + 
          0.05533370673337756`\ r\ r0\ Sin[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(12.322940970607872`\ r\)\/r0])\)}\)], "Output"],

Cell[BoxData[
    \({{0.009023785677140659`\ r0\^4\ C[3, 2]\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[0.009023785677140659`\ r0\^4\ C[3, 2]\^2 \[Equal] 1, 
      C[3, 2]]\)], "Input"],

Cell[BoxData[
    \({{C[3, 2] \[Rule] \(-\(10.527024024151833`\/r0\^2\)\)}, {C[3, 
            2] \[Rule] 10.527024024151833`\/r0\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(R\_Nrm[3, 2, r0, 
        r] = \(10.527024024151833`\/r0\^2\) \(1\/\(r\^\(3/2\)\ \
\@\(r\/r0\)\)\) \((\((0.22729133392011303`\ r\^2 - 
                  0.004490300397068933`\ r0\^2)\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(12.322940970607872`\ r\
\)\/r0] + 
            0.05533370673337756`\ r\ r0\ Sin[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(12.322940970607872`\ r\)\/r0])\)\)], "Input"],

Cell[BoxData[
    \(\(\(1\/\(r\^\(3/2\)\ \@\(r\/r0\)\ r0\^2\)\)\((10.527024024151833`\ \
\((\((0.22729133392011303`\ r\^2 - 
                  0.004490300397068933`\ r0\^2)\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(12.322940970607872`\ r\
\)\/r0] + 
            0.05533370673337756`\ r\ r0\ Sin[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(12.322940970607872`\ r\)\/r0])\))\)\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "12) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 3, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 3;\), "\[IndentingNewLine]", \(l\_orb = 
        3;\), "\[IndentingNewLine]", 
    RowBox[{"FullSimplify", "[", " ", 
      RowBox[{\(\@r\), "  ", 
        RowBox[{"BesselJ", "[", 
          RowBox[{\(l\_orb + 1\/2\), ",", 
            RowBox[{
              StyleBox[\(BesselJZeros[l\_orb + 1\/2, {n\_rad, n\_rad}]\/r0\),
                FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
      "]"}], "\[IndentingNewLine]", \(Limit[\(r0\/BesselJZeros[
              1\/2 + l\_orb, {n\_rad, 
                n\_rad}]\) \
\(\[Integral]\_\[CurlyEpsilon]\%\(BesselJZeros[1\/2 + l\_orb, {n\_rad, \
n\_rad}]\)\(\(r0\^3\ \[Rho]\^3\ BesselJ[1\/2 + l\_orb, \[Rho]]\^2\ C[n\_rad, \
l\_orb]\^2\)\/BesselJZeros[1\/2 + l\_orb, {n\_rad, n\_rad}]\^3\) \
\[DifferentialD]\[Rho]\), \[CurlyEpsilon] \[Rule] 0]\)}], "Input"],

Cell[BoxData[
    \({\(1\/\(r\^\(5/2\)\ \@\(r\/r0\)\)\)\((\((0.215581313417243`\ r\^3 - 
                0.017234019526460444`\ r\ r0\^2)\)\ \
Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(13.698023153276466`\ \
r\)\/r0] + 
          r0\ \((0.09442879939898956`\ r\^2 - 
                0.0012581391733403658`\ r0\^2)\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(13.698023153276466`\ \
r\)\/r0])\)}\)], "Output"],

Cell[BoxData[
    \({{0.00839524720095147`\ r0\^4\ C[3, 3]\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[0.00839524720095147`\ r0\^4\ C[3, 3]\^2 \[Equal] 1, 
      C[3, 3]]\)], "Input"],

Cell[BoxData[
    \({{C[3, 3] \[Rule] \(-\(10.91398256569498`\/r0\^2\)\)}, {C[3, 3] \[Rule] 
          10.91398256569498`\/r0\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(R\_Nrm[3, 3, r0, 
        r] = \(10.91398256569498`\/r0\^2\) \(1\/\(r\^\(5/2\)\ \@\(r\/r0\)\)\) \
\((\((0.215581313417243`\ r\^3 - 
                  0.017234019526460444`\ r\ r0\^2)\)\ \
Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(13.698023153276466`\ \
r\)\/r0] + 
            r0\ \((0.09442879939898956`\ r\^2 - 
                  0.0012581391733403658`\ r0\^2)\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(13.698023153276466`\ \
r\)\/r0])\)\)], "Input"],

Cell[BoxData[
    \(\(\(1\/\(r\^\(5/2\)\ \@\(r\/r0\)\ r0\^2\)\)\((10.91398256569498`\ \
\((\((0.215581313417243`\ r\^3 - 
                  0.017234019526460444`\ r\ r0\^2)\)\ \
Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(13.698023153276466`\ \
r\)\/r0] + 
            r0\ \((0.09442879939898956`\ r\^2 - 
                  0.0012581391733403658`\ r0\^2)\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(13.698023153276466`\ \
r\)\/r0])\))\)\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "13) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 4, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 0"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 4;\), "\[IndentingNewLine]", \(l\_orb = 
        0;\), "\[IndentingNewLine]", 
    RowBox[{"FullSimplify", "[", " ", 
      RowBox[{\(\@r\), "  ", 
        RowBox[{"BesselJ", "[", 
          RowBox[{\(l\_orb + 1\/2\), ",", 
            RowBox[{
              StyleBox[\(BesselJZeros[l\_orb + 1\/2, {n\_rad, n\_rad}]\/r0\),
                FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
      "]"}], "\[IndentingNewLine]", \(\(r0\/BesselJZeros[
            1\/2 + l\_orb, {n\_rad, 
              n\_rad}]\) \(\[Integral]\_0\%\(BesselJZeros[1\/2 + l\_orb, \
{n\_rad, n\_rad}]\)\(\(r0\^3\ \[Rho]\^3\ BesselJ[1\/2 + l\_orb, \[Rho]]\^2\ \
C[n\_rad, l\_orb]\^2\)\/BesselJZeros[1\/2 + l\_orb, {n\_rad, n\_rad}]\^3\) \
\[DifferentialD]\[Rho]\)\)}], "Input"],

Cell[BoxData[
    \({\(0.22507907903899615`\ \@r\ Cos[\(\(1.5707963267948966`\)\(\
\[InvisibleSpace]\)\) - \(12.566370614390479`\ r\)\/r0]\)\/\@\(r\/r0\)}\)], \
"Output"],

Cell[BoxData[
    \({{0.008363228983746753`\ r0\^4\ C[4, 0]\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[0.008363228983746753`\ r0\^4\ C[4, 0]\^2 \[Equal] 1, 
      C[4, 0]]\)], "Input"],

Cell[BoxData[
    \({{C[4, 0] \[Rule] \(-\(10.934854434934302`\/r0\^2\)\)}, {C[4, 
            0] \[Rule] 10.934854434934302`\/r0\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(R\_Nrm[4, 0, r0, 
        r] = \(10.934854434934302`\/r0\^2\) \(0.22507907903899615`\ \@r\ Cos[\
\(\(1.5707963267948966`\)\(\[InvisibleSpace]\)\) - \(12.566370614390479`\ r\)\
\/r0]\)\/\@\(r\/r0\)\)], "Input"],

Cell[BoxData[
    \(\(2.4612069656404953`\ \@r\ Cos[\(\(1.5707963267948966`\)\(\
\[InvisibleSpace]\)\) - \(12.566370614390479`\ r\)\/r0]\)\/\(\@\(r\/r0\)\ \
r0\^2\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "14) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 4, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 1"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 4;\), "\[IndentingNewLine]", \(l\_orb = 
        1;\), "\[IndentingNewLine]", 
    RowBox[{"FullSimplify", "[", " ", 
      RowBox[{\(\@r\), "  ", 
        RowBox[{"BesselJ", "[", 
          RowBox[{\(l\_orb + 1\/2\), ",", 
            RowBox[{
              StyleBox[\(BesselJZeros[l\_orb + 1\/2, {n\_rad, n\_rad}]\/r0\),
                FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
      "]"}], "\[IndentingNewLine]", \(\(r0\/BesselJZeros[
            1\/2 + l\_orb, {n\_rad, 
              n\_rad}]\) \(\[Integral]\_0\%\(BesselJZeros[1\/2 + l\_orb, \
{n\_rad, n\_rad}]\)\(\(r0\^3\ \[Rho]\^3\ BesselJ[1\/2 + l\_orb, \[Rho]]\^2\ \
C[n\_rad, l\_orb]\^2\)\/BesselJZeros[1\/2 + l\_orb, {n\_rad, n\_rad}]\^3\) \
\[DifferentialD]\[Rho]\)\)}], "Input"],

Cell[BoxData[
    \({\(0.21274127679590746`\ r\ Cos[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(14.06619391285005`\ r\)\/r0] + 0.01512429574865732`\
\ r0\ Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \
\(14.06619391285005`\ r\)\/r0]\)\/\(\@r\ \@\(r\/r0\)\)}\)], "Output"],

Cell[BoxData[
    \({{0.007600040316521364`\ r0\^4\ C[4, 1]\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[0.007600040316521364`\ r0\^4\ C[4, 1]\^2 \[Equal] 1, 
      C[4, 1]]\)], "Input"],

Cell[BoxData[
    \({{C[4, 1] \[Rule] \(-\(11.470756268503296`\/r0\^2\)\)}, {C[4, 
            1] \[Rule] 11.470756268503296`\/r0\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(R\_Nrm[4, 1, r0, 
        r] = \(11.470756268503296`\/r0\^2\) \(\(1\/\(\@r\ \@\(r\/r0\)\)\) \
\((0.21274127679590746`\ r\ Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\
\) - \(14.06619391285005`\ r\)\/r0] + 
              0.01512429574865732`\ r0\ Sin[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(14.06619391285005`\ r\)\/r0])\)\)\)], "Input"],

Cell[BoxData[
    \(\(11.470756268503296`\ \((0.21274127679590746`\ r\ \
Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(14.06619391285005`\ r\
\)\/r0] + 0.01512429574865732`\ r0\ Sin[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(14.06619391285005`\ r\)\/r0])\)\)\/\(\@r\ \@\(r\/r0\
\)\ r0\^2\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "15) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 4, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 2"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 4;\), "\[IndentingNewLine]", \(l\_orb = 
        2;\), "\[IndentingNewLine]", 
    RowBox[{"FullSimplify", "[", " ", 
      RowBox[{\(\@r\), "  ", 
        RowBox[{"BesselJ", "[", 
          RowBox[{\(l\_orb + 1\/2\), ",", 
            RowBox[{
              StyleBox[\(BesselJZeros[l\_orb + 1\/2, {n\_rad, n\_rad}]\/r0\),
                FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
      "]"}], "\[IndentingNewLine]", \(\(r0\/BesselJZeros[
            1\/2 + l\_orb, {n\_rad, 
              n\_rad}]\) \(\[Integral]\_0\%\(BesselJZeros[1\/2 + l\_orb, \
{n\_rad, n\_rad}]\)\(\(r0\^3\ \[Rho]\^3\ BesselJ[1\/2 + l\_orb, \[Rho]]\^2\ \
C[n\_rad, l\_orb]\^2\)\/BesselJZeros[1\/2 + l\_orb, {n\_rad, n\_rad}]\^3\) \
\[DifferentialD]\[Rho]\)\)}], "Input"],

Cell[BoxData[
    \({\(1\/\(r\^\(3/2\)\ \@\(r\/r0\)\)\)\((\((0.2025674811476966`\ r\^2 - 
                0.002524699232190157`\ r0\^2)\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(15.514603010898883`\ r\
\)\/r0] + 
          0.0391697063093515`\ r\ r0\ Sin[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(15.514603010898883`\ r\)\/r0])\)}\)], "Output"],

Cell[BoxData[
    \({{0.007048318638827617`\ r0\^4\ C[4, 2]\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[0.007048318638827617`\ r0\^4\ C[4, 2]\^2 \[Equal] 1, 
      C[4, 2]]\)], "Input"],

Cell[BoxData[
    \({{C[4, 2] \[Rule] \(-\(11.911247130504961`\/r0\^2\)\)}, {C[4, 
            2] \[Rule] 11.911247130504961`\/r0\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(R\_Nrm[4, 2, r0, 
        r] = \(11.911247130504961`\/r0\^2\) \(1\/\(r\^\(3/2\)\ \
\@\(r\/r0\)\)\) \((\((0.2025674811476966`\ r\^2 - 
                  0.002524699232190157`\ r0\^2)\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(15.514603010898883`\ r\
\)\/r0] + 
            0.0391697063093515`\ r\ r0\ Sin[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(15.514603010898883`\ r\)\/r0])\)\)], "Input"],

Cell[BoxData[
    \(\(\(1\/\(r\^\(3/2\)\ \@\(r\/r0\)\ r0\^2\)\)\((11.911247130504961`\ \
\((\((0.2025674811476966`\ r\^2 - 
                  0.002524699232190157`\ r0\^2)\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(15.514603010898883`\ r\
\)\/r0] + 
            0.0391697063093515`\ r\ r0\ Sin[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(15.514603010898883`\ r\)\/r0])\))\)\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "16) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{\(n\_rad = 4;\), "\[IndentingNewLine]", \(l\_orb = 
        3;\), "\[IndentingNewLine]", 
    RowBox[{"FullSimplify", "[", " ", 
      RowBox[{\(\@r\), "  ", 
        RowBox[{"BesselJ", "[", 
          RowBox[{\(l\_orb + 1\/2\), ",", 
            RowBox[{
              StyleBox[\(BesselJZeros[l\_orb + 1\/2, {n\_rad, n\_rad}]\/r0\),
                FontSlant->"Italic"], " ", "r"}]}], "]"}]}], 
      "]"}], "\[IndentingNewLine]", \(Limit[\(r0\/BesselJZeros[
              1\/2 + l\_orb, {n\_rad, 
                n\_rad}]\) \
\(\[Integral]\_\[CurlyEpsilon]\%\(BesselJZeros[1\/2 + l\_orb, {n\_rad, \
n\_rad}]\)\(\(r0\^3\ \[Rho]\^3\ BesselJ[1\/2 + l\_orb, \[Rho]]\^2\ C[n\_rad, \
l\_orb]\^2\)\/BesselJZeros[1\/2 + l\_orb, {n\_rad, n\_rad}]\^3\) \
\[DifferentialD]\[Rho]\), \[CurlyEpsilon] \[Rule] 0]\)}], "Input"],

Cell[BoxData[
    \({\(1\/\(r\^\(5/2\)\ \@\(r\/r0\)\)\)\((\((0.19395162042753517`\ r\^3 - 
                0.01015776298606729`\ r\ r0\^2)\)\ Cos[\(\(6.283185307179586`\
\)\(\[InvisibleSpace]\)\) - \(16.92362128522231`\ r\)\/r0] + 
          r0\ \((0.06876245355250067`\ r\^2 - 
                0.0006002121422403276`\ r0\^2)\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(16.92362128522231`\ r\
\)\/r0])\)}\)], "Output"],

Cell[BoxData[
    \({{0.006619695892991664`\ r0\^4\ C[4, 3]\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[0.006619695892991664`\ r0\^4\ C[4, 3]\^2 \[Equal] 1, 
      C[4, 3]]\)], "Input"],

Cell[BoxData[
    \({{C[4, 3] \[Rule] \(-\(12.290823460947369`\/r0\^2\)\)}, {C[4, 
            3] \[Rule] 12.290823460947369`\/r0\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(R\_Nrm[4, 3, r0, 
        r] = \(12.290823460947369`\/r0\^2\) \(1\/\(r\^\(5/2\)\ \
\@\(r\/r0\)\)\) \((\((0.19395162042753517`\ r\^3 - 
                  0.01015776298606729`\ r\ r0\^2)\)\ \
Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(16.92362128522231`\ r\
\)\/r0] + r0\ \((0.06876245355250067`\ r\^2 - 
                  0.0006002121422403276`\ r0\^2)\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(16.92362128522231`\ r\
\)\/r0])\)\)], "Input"],

Cell[BoxData[
    \(\(\(1\/\(r\^\(5/2\)\ \@\(r\/r0\)\ r0\^2\)\)\((12.290823460947369`\ \
\((\((0.19395162042753517`\ r\^3 - 
                  0.01015776298606729`\ r\ r0\^2)\)\ \
Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(16.92362128522231`\ r\
\)\/r0] + r0\ \((0.06876245355250067`\ r\^2 - 
                  0.0006002121422403276`\ r0\^2)\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(16.92362128522231`\ r\
\)\/r0])\))\)\)\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
4. Normalized radial wave functions of the three-dimensional quantum \
rotator\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["Resulting normalized radial wave functions are:", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(R\_Rotat[1, 0, 
          r0] = \(2.6599473004202467`\ \@r\ Cos[\(\(1.5707963267948966`\)\(\
\[InvisibleSpace]\)\) - \(3.1415926535897913`\ r\)\/r0]\)\/\(\@\(r\/r0\)\ \
r0\^2\);\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[1, 1, 
          r0] = \(1\/\(\@r\ \@\(r\/r0\)\ r0\^2\)\) \((6.28886519074513`\ \
\((0.3764021226965972`\ r\ \
Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(4.493409457909065`\ r\
\)\/r0] + 
                  0.08376759924116726`\ r0\ Sin[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(4.493409457909065`\ r\)\/r0])\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(R\_Rotat[1, 2, 
          r0] = \(1\/\(r\^\(3/2\)\ \@\(r\/r0\)\ r0\^2\)\) \
\((6.733287171946806`\ \((\((0.3323521174464318`\ r\^2 - 
                        0.030016030571366766`\ r0\^2)\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(5.763459196944853`\ \
r\)\/r0] + 
                  0.1729961674523217`\ r\ r0\ Sin[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(5.763459196944853`\ r\)\/r0])\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(R\_Rotat[1, 3, 
          r0] = \(1\/r\^3\) \((7.180760624824514`\ \((r\ \
\((\(-0.09271705851256021`\) + 
                        0.3018323092198434`\ r\^2)\)\ \
Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 
                        6.987932000503647`\ r] + \
\((\(-0.013268168394580504`\) + 
                        0.2591602000689954`\ r\^2)\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 
                        6.987932000503647`\ \
r])\))\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[2, 0, 
          r0] = \(2.4973939813378445`\ \@r\ Cos[\(\(1.5707963267948966`\)\(\
\[InvisibleSpace]\)\) - \(6.283185307179585`\ r\)\/r0]\)\/\(\@\(r\/r0\)\ \
r0\^2\);\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[2, 1, 
          r0] = \(1\/\(\@r\ \@\(r\/r0\)\ r0\^2\)\) \((8.429256550635898`\ \
\((0.28706730919827866`\ r\ Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\
\) - \(7.725251836937706`\ r\)\/r0] + 
                  0.03715960531224213`\ r0\ Sin[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(7.725251836937706`\ r\)\/r0])\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(R\_Rotat[2, 2, 
          r0] = \(1\/\(r\^\(3/2\)\ \@\(r\/r0\)\ r0\^2\)\) \
\((8.88380479563113`\ \((\((0.2645686853222971`\ r\^2 - 
                        0.00959518174141225`\ r0\^2)\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(9.09501133069512`\ r\)\
\/r0] + 0.08726828665822337`\ r\ r0\ Sin[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(9.09501133069512`\ r\)\/r0])\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(R\_Rotat[2, 3, 
          r0] = \(1\/\(r\^\(5/2\)\ \@\(r\/r0\)\ r0\^2\)\) \
\((9.281141096227815`\ \((\((0.24721012729596964`\ r\^3 - 
                        0.034171363187267656`\ r\ r0\^2)\)\ \
Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(10.417118547512036`\ \
r\)\/r0] + r0\ \((0.14238685650074237`\ r\^2 - 
                        0.0032803085643514102`\ r0\^2)\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(10.417118547512036`\ \
r\)\/r0])\))\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[3, 0, 
          r0] = \(2.4704375261515574`\ \@r\ Cos[\(\(1.5707963267948966`\)\(\
\[InvisibleSpace]\)\) - \(9.424777960902889`\ r\)\/r0]\)\/\(\@\(r\/r0\)\ \
r0\^2\);\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[3, 1, 
          r0] = \(1\/\(\@r\ \@\(r\/r0\)\ r0\^2\)\) \((10.07467750670633`\ \
\((0.2416265857850596`\ r\ \
Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(10.90412165949781`\ r\
\)\/r0] + 
                  0.022159197533768875`\ r0\ Sin[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(10.90412165949781`\ r\)\/r0])\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(R\_Rotat[3, 2, 
          r0] = \(1\/\(r\^\(3/2\)\ \@\(r\/r0\)\ r0\^2\)\) \
\((10.527024024151833`\ \((\((0.22729133392011303`\ r\^2 - 
                        0.004490300397068933`\ r0\^2)\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(12.322940970607872`\ r\
\)\/r0] + 
                  0.05533370673337756`\ r\ r0\ Sin[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(12.322940970607872`\ r\)\/r0])\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(R\_Rotat[3, 3, 
          
          r0] = \(1\/\(r\^\(5/2\)\ \@\(r\/r0\)\ r0\^2\)\) \
\((10.91398256569498`\ \((\((0.215581313417243`\ r\^3 - 
                        0.017234019526460444`\ r\ r0\^2)\)\ \
Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(13.698023153276466`\ \
r\)\/r0] + r0\ \((0.09442879939898956`\ r\^2 - 
                        0.0012581391733403658`\ r0\^2)\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(13.698023153276466`\ \
r\)\/r0])\))\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[4, 0, 
          r0] = \(2.4612069656404953`\ \@r\ Cos[\(\(1.5707963267948966`\)\(\
\[InvisibleSpace]\)\) - \(12.566370614390479`\ r\)\/r0]\)\/\(\@\(r\/r0\)\ \
r0\^2\);\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[4, 1, 
          r0] = \(1\/\(\@r\ \@\(r\/r0\)\ r0\^2\)\) \((11.470756268503296`\ \
\((0.21274127679590746`\ r\ Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\
\) - \(14.06619391285005`\ r\)\/r0] + 
                  0.01512429574865732`\ r0\ Sin[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(14.06619391285005`\ r\)\/r0])\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(R\_Rotat[4, 2, 
          r0] = \(1\/\(r\^\(3/2\)\ \@\(r\/r0\)\ r0\^2\)\) \
\((11.911247130504961`\ \((\((0.2025674811476966`\ r\^2 - 
                        0.002524699232190157`\ r0\^2)\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(15.514603010898883`\ r\
\)\/r0] + 
                  0.0391697063093515`\ r\ r0\ Sin[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(15.514603010898883`\ r\)\/r0])\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(R\_Rotat[4, 3, 
          r0] = \(1\/\(r\^\(5/2\)\ \@\(r\/r0\)\ r0\^2\)\) \
\((12.290823460947369`\ \((\((0.19395162042753517`\ r\^3 - 
                        0.01015776298606729`\ r\ r0\^2)\)\ \
Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(16.92362128522231`\ r\
\)\/r0] + r0\ \((0.06876245355250067`\ r\^2 - 
                        0.0006002121422403276`\ r0\^2)\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(16.92362128522231`\ r\
\)\/r0])\))\);\)\)}], "Input"],

Cell["Radial probability densities are calculated by the formulas:", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell[BoxData[{
    \(RR\_Rotat[1, 0, r0] = 
      FullSimplify[\((R\_Rotat[1, 0, r0] r)\)\^2]\), "\n", 
    \(RR\_Rotat[1, 1, r0] = 
      FullSimplify[\((R\_Rotat[1, 1, r0] r)\)\^2]\), "\n", 
    \(RR\_Rotat[1, 2, r0] = 
      FullSimplify[\((R\_Rotat[1, 2, r0] r)\)\^2]\), "\n", 
    \(\(\(RR\_Rotat[1, 3, r0] = 
      FullSimplify[\((R\_Rotat[1, 3, r0] r)\)\^2]\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(RR\_Rotat[2, 0, r0] = 
      FullSimplify[\((R\_Rotat[2, 0, r0] r)\)\^2]\), "\n", 
    \(RR\_Rotat[2, 1, r0] = 
      FullSimplify[\((R\_Rotat[2, 1, r0] r)\)\^2]\), "\n", 
    \(RR\_Rotat[2, 2, r0] = 
      FullSimplify[\((R\_Rotat[2, 2, r0] r)\)\^2]\), "\n", 
    \(\(\(RR\_Rotat[2, 3, r0] = 
      FullSimplify[\((R\_Rotat[2, 3, r0] r)\)\^2]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(RR\_Rotat[3, 0, r0] = 
      FullSimplify[\((R\_Rotat[3, 0, r0] r)\)\^2]\), "\n", 
    \(RR\_Rotat[3, 1, r0] = 
      FullSimplify[\((R\_Rotat[3, 1, r0] r)\)\^2]\), "\n", 
    \(RR\_Rotat[3, 2, r0] = 
      FullSimplify[\((R\_Rotat[3, 2, r0] r)\)\^2]\), "\n", 
    \(\(\(RR\_Rotat[3, 3, r0] = 
      FullSimplify[\((R\_Rotat[3, 3, r0] r)\)\^2]\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(RR\_Rotat[4, 0, r0] = 
      FullSimplify[\((R\_Rotat[4, 0, r0] r)\)\^2]\), "\n", 
    \(RR\_Rotat[4, 1, r0] = 
      FullSimplify[\((R\_Rotat[4, 1, r0] r)\)\^2]\), "\n", 
    \(RR\_Rotat[4, 2, r0] = 
      FullSimplify[\((R\_Rotat[4, 2, r0] r)\)\^2]\), "\n", 
    \(RR\_Rotat[4, 3, r0] = 
      FullSimplify[\((R\_Rotat[4, 3, r0] r)\)\^2]\)}], "Input"],

Cell[BoxData[
    \(\(7.075319641012959`\ r\^2\ Cos[\(\(1.5707963267948966`\)\(\
\[InvisibleSpace]\)\) - \(3.1415926535897913`\ r\)\/r0]\^2\)\/r0\^3\)], \
"Output"],

Cell[BoxData[
    \(\(39.549825387365786`\ \((0.3764021226965972`\ r\ \
Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(4.493409457909065`\ r\
\)\/r0] + 0.08376759924116726`\ r0\ Sin[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(4.493409457909065`\ r\)\/r0])\)\^2\)\/r0\^3\)], \
"Output"],

Cell[BoxData[
    \(\(\(1\/\(r\^2\ r0\^3\)\)\((45.33715613990341`\ \
\((\((0.3323521174464318`\ r\^2 - 0.030016030571366766`\ r0\^2)\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(5.763459196944853`\ \
r\)\/r0] + 0.1729961674523217`\ r\ r0\ Sin[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(5.763459196944853`\ r\)\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/r\^4\)\((51.56332315103015`\ \((r\ \((\(-0.09271705851256021`\) \
+ 0.3018323092198434`\ r\^2)\)\ Cos[\(\(6.283185307179586`\)\(\
\[InvisibleSpace]\)\) - 6.987932000503647`\ r] + \
\((\(-0.013268168394580504`\) + 0.2591602000689954`\ r\^2)\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ r])\
\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(6.23697669802249`\ r\^2\ Cos[\(\(1.5707963267948966`\)\(\
\[InvisibleSpace]\)\) - \(6.283185307179585`\ r\)\/r0]\^2\)\/r0\^3\)], \
"Output"],

Cell[BoxData[
    \(\(71.0523659964382`\ \((0.28706730919827866`\ r\ \
Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(7.725251836937706`\ r\
\)\/r0] + 0.03715960531224213`\ r0\ Sin[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(7.725251836937706`\ r\)\/r0])\)\^2\)\/r0\^3\)], \
"Output"],

Cell[BoxData[
    \(\(\(1\/\(r\^2\ r0\^3\)\)\((78.92198764687868`\ \
\((\((0.2645686853222971`\ r\^2 - 0.00959518174141225`\ r0\^2)\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(9.09501133069512`\ r\)\
\/r0] + 0.08726828665822337`\ r\ r0\ Sin[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(9.09501133069512`\ r\)\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(r\^4\ r0\^3\)\)\((86.13958004808885`\ \
\((\((0.24721012729596964`\ r\^3 - 0.034171363187267656`\ r\ r0\^2)\)\ Cos[\(\
\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(10.417118547512036`\ \
r\)\/r0] + r0\ \((0.14238685650074237`\ r\^2 - 0.0032803085643514102`\ r0\^2)\
\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(10.417118547512036`\ r\)\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(6.103061570617827`\ r\^2\ Cos[\(\(1.5707963267948966`\)\(\
\[InvisibleSpace]\)\) - \(9.424777960902889`\ r\)\/r0]\^2\)\/r0\^3\)], \
"Output"],

Cell[BoxData[
    \(\(101.49912686413447`\ \((0.2416265857850596`\ r\ \
Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(10.90412165949781`\ r\
\)\/r0] + 0.022159197533768875`\ r0\ Sin[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(10.90412165949781`\ r\)\/r0])\)\^2\)\/r0\^3\)], \
"Output"],

Cell[BoxData[
    \(\(\(1\/\(r\^2\ r0\^3\)\)\((110.81823480506986`\ \
\((\((0.22729133392011303`\ r\^2 - 0.004490300397068933`\ r0\^2)\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(12.322940970607872`\ r\
\)\/r0] + 0.05533370673337756`\ r\ r0\ Sin[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(12.322940970607872`\ r\)\/r0])\)\^2)\)\)\)], \
"Output"],

Cell[BoxData[
    \(\(\(1\/\(r\^4\ r0\^3\)\)\((119.11501544429397`\ \
\((\((0.215581313417243`\ r\^3 - 0.017234019526460444`\ r\ r0\^2)\)\ \
Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(13.698023153276466`\ \
r\)\/r0] + r0\ \((0.09442879939898956`\ r\^2 - 0.0012581391733403658`\ r0\^2)\
\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ r\)\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(6.057539727717295`\ r\^2\ Cos[\(\(1.5707963267948966`\)\(\
\[InvisibleSpace]\)\) - \(12.566370614390479`\ r\)\/r0]\^2\)\/r0\^3\)], \
"Output"],

Cell[BoxData[
    \(\(131.57824937140765`\ \((0.21274127679590746`\ r\ \
Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(14.06619391285005`\ r\
\)\/r0] + 0.01512429574865732`\ r0\ Sin[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(14.06619391285005`\ r\)\/r0])\)\^2\)\/r0\^3\)], \
"Output"],

Cell[BoxData[
    \(\(\(1\/\(r\^2\ r0\^3\)\)\((141.87780820396267`\ \
\((\((0.2025674811476966`\ r\^2 - 0.002524699232190157`\ r0\^2)\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(15.514603010898883`\ r\
\)\/r0] + 0.0391697063093515`\ r\ r0\ Sin[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(15.514603010898883`\ r\)\/r0])\)\^2)\)\)\)], \
"Output"],

Cell[BoxData[
    \(\(\(1\/\(r\^4\ r0\^3\)\)\((151.06434134817425`\ \
\((\((0.19395162042753517`\ r\^3 - 0.01015776298606729`\ r\ r0\^2)\)\ \
Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(16.92362128522231`\ r\
\)\/r0] + r0\ \((0.06876245355250067`\ r\^2 - 0.0006002121422403276`\ \
r0\^2)\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ r\)\/r0])\)\^2)\)\)\)], "Output"]
}, Open  ]],

Cell["\<\
Thus radial probability densities of the three-dimensional quantum rotator \
are:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(RR\_Rotat[1, 0, 
          r0] = \(7.075319641012959`\ r\^2\ Cos[\(\(1.5707963267948966`\)\(\
\[InvisibleSpace]\)\) - \(3.1415926535897913`\ r\)\/r0]\^2\)\/r0\^3;\)\), "\n\
", 
    \(\(RR\_Rotat[1, 1, 
          r0] = \(1\/r0\^3\) \((39.549825387365786`\ \((0.3764021226965972`\ \
r\ Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(4.493409457909065`\
\ r\)\/r0] + 0.08376759924116726`\ r0\ Sin[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(4.493409457909065`\ r\)\/r0])\)\^2)\);\)\), "\n", 
    \(\(RR\_Rotat[1, 2, 
          r0] = \(1\/\(r\^2\ r0\^3\)\) \((45.33715613990341`\ \
\((\((0.3323521174464318`\ r\^2 - 0.030016030571366766`\ r0\^2)\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(5.763459196944853`\ \
r\)\/r0] + 0.1729961674523217`\ r\ r0\ Sin[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(5.763459196944853`\ r\)\/r0])\)\^2)\);\)\), "\n", 
    \(\(\(RR\_Rotat[1, 3, 
          r0] = \(1\/r\^4\) \((51.56332315103015`\ \((r\ \
\((\(-0.09271705851256021`\) + 0.3018323092198434`\ r\^2)\)\ \
Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ r] \
+ \((\(-0.013268168394580504`\) + 0.2591602000689954`\ r\^2)\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ r])\
\)\^2)\);\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(RR\_Rotat[2, 0, 
          r0] = \(6.23697669802249`\ r\^2\ Cos[\(\(1.5707963267948966`\)\(\
\[InvisibleSpace]\)\) - \(6.283185307179585`\ r\)\/r0]\^2\)\/r0\^3;\)\), "\n\
", 
    \(\(RR\_Rotat[2, 1, 
          r0] = \(1\/r0\^3\) \((71.0523659964382`\ \((0.28706730919827866`\ r\
\ Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(7.725251836937706`\ \
r\)\/r0] + 0.03715960531224213`\ r0\ Sin[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(7.725251836937706`\ r\)\/r0])\)\^2)\);\)\), "\n", 
    \(\(RR\_Rotat[2, 2, 
          r0] = \(1\/\(r\^2\ r0\^3\)\) \((78.92198764687868`\ \
\((\((0.2645686853222971`\ r\^2 - 0.00959518174141225`\ r0\^2)\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(9.09501133069512`\ r\)\
\/r0] + 0.08726828665822337`\ r\ r0\ Sin[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(9.09501133069512`\ r\)\/r0])\)\^2)\);\)\), "\n", 
    \(\(\(RR\_Rotat[2, 3, 
          r0] = \(1\/\(r\^4\ r0\^3\)\) \((86.13958004808885`\ \
\((\((0.24721012729596964`\ r\^3 - 0.034171363187267656`\ r\ r0\^2)\)\ Cos[\(\
\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(10.417118547512036`\ \
r\)\/r0] + r0\ \((0.14238685650074237`\ r\^2 - 0.0032803085643514102`\ r0\^2)\
\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(10.417118547512036`\ r\)\/r0])\)\^2)\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RR\_Rotat[3, 0, 
          r0] = \(6.103061570617827`\ r\^2\ Cos[\(\(1.5707963267948966`\)\(\
\[InvisibleSpace]\)\) - \(9.424777960902889`\ r\)\/r0]\^2\)\/r0\^3;\)\), "\n\
", 
    \(\(RR\_Rotat[3, 1, 
          r0] = \(1\/r0\^3\) \((101.49912686413447`\ \((0.2416265857850596`\ \
r\ Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(10.90412165949781`\
\ r\)\/r0] + 0.022159197533768875`\ r0\ Sin[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(10.90412165949781`\ r\)\/r0])\)\^2)\);\)\), "\n", 
    \(\(RR\_Rotat[3, 2, 
          r0] = \(1\/\(r\^2\ r0\^3\)\) \((110.81823480506986`\ \
\((\((0.22729133392011303`\ r\^2 - 0.004490300397068933`\ r0\^2)\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(12.322940970607872`\ r\
\)\/r0] + 0.05533370673337756`\ r\ r0\ Sin[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(12.322940970607872`\ r\)\/r0])\)\^2)\);\)\), "\n", 
    \(\(\(RR\_Rotat[3, 3, 
          r0] = \(1\/\(r\^4\ r0\^3\)\) \((119.11501544429397`\ \
\((\((0.215581313417243`\ r\^3 - 0.017234019526460444`\ r\ r0\^2)\)\ \
Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(13.698023153276466`\ \
r\)\/r0] + r0\ \((0.09442879939898956`\ r\^2 - 0.0012581391733403658`\ r0\^2)\
\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ r\)\/r0])\)\^2)\);\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(RR\_Rotat[4, 0, 
          r0] = \(6.057539727717295`\ r\^2\ Cos[\(\(1.5707963267948966`\)\(\
\[InvisibleSpace]\)\) - \(12.566370614390479`\ r\)\/r0]\^2\)\/r0\^3;\)\), "\n\
", 
    \(\(RR\_Rotat[4, 1, 
          r0] = \(1\/r0\^3\) \((131.57824937140765`\ \((0.21274127679590746`\ \
r\ Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(14.06619391285005`\
\ r\)\/r0] + 0.01512429574865732`\ r0\ Sin[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(14.06619391285005`\ r\)\/r0])\)\^2)\);\)\), "\n", 
    \(\(RR\_Rotat[4, 2, 
          r0] = \(1\/\(r\^2\ r0\^3\)\) \((141.87780820396267`\ \
\((\((0.2025674811476966`\ r\^2 - 0.002524699232190157`\ r0\^2)\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(15.514603010898883`\ r\
\)\/r0] + 0.0391697063093515`\ r\ r0\ Sin[\(\(4.71238898038469`\)\(\
\[InvisibleSpace]\)\) - \(15.514603010898883`\ r\)\/r0])\)\^2)\);\)\), "\n", 
    \(\(RR\_Rotat[4, 3, 
          r0] = \(1\/\(r\^4\ r0\^3\)\) \((151.06434134817425`\ \
\((\((0.19395162042753517`\ r\^3 - 0.01015776298606729`\ r\ r0\^2)\)\ \
Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(16.92362128522231`\ r\
\)\/r0] + r0\ \((0.06876245355250067`\ r\^2 - 0.0006002121422403276`\ \
r0\^2)\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ r\)\/r0])\)\^2)\);\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
5. Normalized radial wave functions and radial probability densities of the \
three-dimensional quantum rotator in the Cartesian rectangular coordinates\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
To obtain radial wave functions and radial probability densities of the \
three-dimensional quantum rotator in the Cartesian rectangular coordinates we \
will use coordinate transformations:\
\>", "Text"],

Cell[BoxData[
    \(\(r = \@\(x^2 + y^2 + z^2\);\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(FullSimplify[RR\_Rotat[1, 0, r0]]\), "\n", 
    \(FullSimplify[RR\_Rotat[1, 1, r0]]\), "\n", 
    \(FullSimplify[RR\_Rotat[1, 2, r0]]\), "\n", 
    \(\(\(FullSimplify[RR\_Rotat[1, 3, r0]]\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(FullSimplify[RR\_Rotat[2, 0, r0]]\), "\n", 
    \(FullSimplify[RR\_Rotat[2, 1, r0]]\), "\n", 
    \(FullSimplify[RR\_Rotat[2, 2, r0]]\), "\n", 
    \(\(\(FullSimplify[RR\_Rotat[2, 3, r0]]\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(FullSimplify[RR\_Rotat[3, 0, r0]]\), "\n", 
    \(FullSimplify[RR\_Rotat[3, 1, r0]]\), "\n", 
    \(FullSimplify[RR\_Rotat[3, 2, r0]]\), "\n", 
    \(\(\(FullSimplify[RR\_Rotat[3, 3, r0]]\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(FullSimplify[RR\_Rotat[4, 0, r0]]\), "\n", 
    \(FullSimplify[RR\_Rotat[4, 1, r0]]\), "\n", 
    \(FullSimplify[RR\_Rotat[4, 2, r0]]\), "\n", 
    \(FullSimplify[RR\_Rotat[4, 3, r0]]\)}], "Input"],

Cell[BoxData[
    \(\(7.075319641012959`\ \((x\^2 + y\^2 + z\^2)\)\ \
Cos[\(\(1.5707963267948966`\)\(\[InvisibleSpace]\)\) - \(3.1415926535897913`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0]\^2\)\/r0\^3\)], "Output"],

Cell[BoxData[
    \(\(\(1\/r0\^3\)\((39.549825387365786`\ \((0.3764021226965972`\ \@\(x\^2 \
+ y\^2 + z\^2\)\ Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \
\(4.493409457909065`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.08376759924116726`\ \
r0\ Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \
\(4.493409457909065`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + 
              z\^2)\)\)\)\((45.33715613990341`\ \
\((\((\(-0.030016030571366766`\)\ r0\^2 + 0.3323521174464318`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(5.763459196944853`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.1729961674523217`\ \
r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(5.763459196944853`\ \@\
\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\((x\^2 + y\^2 + z\^2)\)\^2\)\((51.56332315103015`\ \((\@\(x\^2 \
+ y\^2 + z\^2\)\ \((\(-0.09271705851256021`\) + 0.3018323092198434`\ \((x\^2 \
+ y\^2 + z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
6.987932000503647`\ \@\(x\^2 + y\^2 + z\^2\)] + \((\(-0.013268168394580504`\) \
+ 0.2591602000689954`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(6.23697669802249`\ \((x\^2 + y\^2 + z\^2)\)\ \
Cos[\(\(1.5707963267948966`\)\(\[InvisibleSpace]\)\) - \(6.283185307179585`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0]\^2\)\/r0\^3\)], "Output"],

Cell[BoxData[
    \(\(\(1\/r0\^3\)\((71.0523659964382`\ \((0.28706730919827866`\ \@\(x\^2 + \
y\^2 + z\^2\)\ Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \
\(7.725251836937706`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.03715960531224213`\ \
r0\ Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \
\(7.725251836937706`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + 
              z\^2)\)\)\)\((78.92198764687868`\ \((\((\(-0.00959518174141225`\
\)\ r0\^2 + 0.2645686853222971`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(9.09501133069512`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.08726828665822337`\ r0\ \@\(x\^2 + y\^2 + \
z\^2\)\ Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(9.09501133069512`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^2\)\)\((86.13958004808885`\ \
\((\@\(x\^2 + y\^2 + z\^2\)\ \((\(-0.034171363187267656`\)\ r0\^2 + \
0.24721012729596964`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(6.283185307179586`\
\)\(\[InvisibleSpace]\)\) - \(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\
\/r0] + r0\ \((\(-0.0032803085643514102`\)\ r0\^2 + 0.14238685650074237`\ \
\((x\^2 + y\^2 + z\^2)\))\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(10.417118547512036`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(6.103061570617827`\ \((x\^2 + y\^2 + z\^2)\)\ \
Cos[\(\(1.5707963267948966`\)\(\[InvisibleSpace]\)\) - \(9.424777960902889`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0]\^2\)\/r0\^3\)], "Output"],

Cell[BoxData[
    \(\(\(1\/r0\^3\)\((101.49912686413447`\ \((0.2416265857850596`\ \@\(x\^2 \
+ y\^2 + z\^2\)\ Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \
\(10.90412165949781`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.022159197533768875`\
\ r0\ Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \
\(10.90412165949781`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + 
              z\^2)\)\)\)\((110.81823480506986`\ \
\((\((\(-0.004490300397068933`\)\ r0\^2 + 0.22729133392011303`\ \((x\^2 + \
y\^2 + z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(12.322940970607872`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.05533370673337756`\
\ r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(12.322940970607872`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^2\)\)\((119.11501544429397`\ \
\((\@\(x\^2 + y\^2 + z\^2\)\ \((\(-0.017234019526460444`\)\ r0\^2 + \
0.215581313417243`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\
\(\[InvisibleSpace]\)\) - \(13.698023153276466`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + r0\ \((\(-0.0012581391733403658`\)\ r0\^2 + \
0.09442879939898956`\ \((x\^2 + y\^2 + z\^2)\))\)\ Sin[\(\(6.283185307179586`\
\)\(\[InvisibleSpace]\)\) - \(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\
\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(6.057539727717295`\ \((x\^2 + y\^2 + z\^2)\)\ \
Cos[\(\(1.5707963267948966`\)\(\[InvisibleSpace]\)\) - \(12.566370614390479`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0]\^2\)\/r0\^3\)], "Output"],

Cell[BoxData[
    \(\(\(1\/r0\^3\)\((131.57824937140765`\ \((0.21274127679590746`\ \@\(x\^2 \
+ y\^2 + z\^2\)\ Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \
\(14.06619391285005`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.01512429574865732`\ \
r0\ Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \
\(14.06619391285005`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + 
              z\^2)\)\)\)\((141.87780820396267`\ \
\((\((\(-0.002524699232190157`\)\ r0\^2 + 0.2025674811476966`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(15.514603010898883`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.0391697063093515`\ \
r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(15.514603010898883`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^2\)\)\((151.06434134817425`\ \
\((\@\(x\^2 + y\^2 + z\^2\)\ \((\(-0.01015776298606729`\)\ r0\^2 + \
0.19395162042753517`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(6.283185307179586`\
\)\(\[InvisibleSpace]\)\) - \(16.92362128522231`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + r0\ \((\(-0.0006002121422403276`\)\ r0\^2 + \
0.06876245355250067`\ \((x\^2 + y\^2 + z\^2)\))\)\ Sin[\(\(6.283185307179586`\
\)\(\[InvisibleSpace]\)\) - \(16.92362128522231`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"]
}, Open  ]],

Cell["\<\
Resulting normalized radial wave functions in the Cartesian rectangular \
coordinates are:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(RR\_\(Rotat, Cart\)[1, 0, 
          r0] = \(\(1\/r0\^3\)\((7.075319641012959`\ \((x\^2 + y\^2 + 
                z\^2)\)\ Cos[\(\(1.5707963267948966`\)\(\[InvisibleSpace]\)\) \
- \(3.1415926535897913`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0]\^2)\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(RR\_\(Rotat, Cart\)[1, 1, 
          r0] = \(1\/r0\^3\) \((39.549825387365786`\ \((0.3764021226965972`\ \
\@\(x\^2 + y\^2 + z\^2\)\ Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) \
- \(4.493409457909065`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + \
0.08376759924116726`\ r0\ Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) \
- \(4.493409457909065`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(RR\_\(Rotat, Cart\)[1, 2, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((45.33715613990341`\ \
\((\((\(-0.030016030571366766`\)\ r0\^2 + 0.3323521174464318`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(5.763459196944853`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.1729961674523217`\ \
r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(5.763459196944853`\ \@\
\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_\(Rotat, Cart\)[1, 3, 
          r0] = \(1\/\((x\^2 + y\^2 + z\^2)\)\^2\) \((51.56332315103015`\ \((\
\@\(x\^2 + y\^2 + z\^2\)\ \((\(-0.09271705851256021`\) + 0.3018323092198434`\ \
\((x\^2 + y\^2 + z\^2)\))\)\ \
Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)] + \((\(-0.013268168394580504`\) + \
0.2591602000689954`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)])\)\^2)\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RR\_\(Rotat, Cart\)[2, 0, 
          r0] = \(6.23697669802249`\ \((x\^2 + y\^2 + z\^2)\)\ \
Cos[\(\(1.5707963267948966`\)\(\[InvisibleSpace]\)\) - \(6.283185307179585`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0]\^2\)\/r0\^3;\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(Rotat, Cart\)[2, 1, 
          r0] = \(1\/r0\^3\) \((71.0523659964382`\ \((0.28706730919827866`\ \
\@\(x\^2 + y\^2 + z\^2\)\ Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) \
- \(7.725251836937706`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + \
0.03715960531224213`\ r0\ Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) \
- \(7.725251836937706`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(RR\_\(Rotat, Cart\)[2, 2, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((78.92198764687868`\ \
\((\((\(-0.00959518174141225`\)\ r0\^2 + 0.2645686853222971`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(9.09501133069512`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.08726828665822337`\ \
r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(9.09501133069512`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_\(Rotat, Cart\)[2, 3, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^2\)\) \
\((86.13958004808885`\ \((\@\(x\^2 + y\^2 + z\^2\)\ \
\((\(-0.034171363187267656`\)\ r0\^2 + 0.24721012729596964`\ \((x\^2 + y\^2 + \
z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0032803085643514102`\)\ r0\^2 + 0.14238685650074237`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RR\_\(Rotat, Cart\)[3, 0, 
          r0] = \(6.103061570617827`\ \((x\^2 + y\^2 + z\^2)\)\ \
Cos[\(\(1.5707963267948966`\)\(\[InvisibleSpace]\)\) - \(9.424777960902889`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0]\^2\)\/r0\^3;\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(Rotat, Cart\)[3, 1, 
          
          r0] = \(1\/r0\^3\) \((101.49912686413447`\ \((0.2416265857850596`\ \
\@\(x\^2 + y\^2 + z\^2\)\ Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) \
- \(10.90412165949781`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + \
0.022159197533768875`\ r0\ \
Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(10.90412165949781`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(Rotat, Cart\)[3, 2, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((110.81823480506986`\ \
\((\((\(-0.004490300397068933`\)\ r0\^2 + 0.22729133392011303`\ \((x\^2 + \
y\^2 + z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(12.322940970607872`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.05533370673337756`\
\ r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(12.322940970607872`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_\(Rotat, Cart\)[3, 3, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^2\)\) \
\((119.11501544429397`\ \((\@\(x\^2 + y\^2 + z\^2\)\ \
\((\(-0.017234019526460444`\)\ r0\^2 + 0.215581313417243`\ \((x\^2 + y\^2 + z\
\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0012581391733403658`\)\ r0\^2 + 0.09442879939898956`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RR\_\(Rotat, Cart\)[4, 0, 
          r0] = \(\(1\/r0\^3\)\((6.057539727717295`\ \((x\^2 + y\^2 + 
                z\^2)\)\ Cos[\(\(1.5707963267948966`\)\(\[InvisibleSpace]\)\) \
- \(12.566370614390479`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0]\^2)\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(RR\_\(Rotat, Cart\)[4, 1, 
          r0] = \(1\/r0\^3\) \((131.57824937140765`\ \((0.21274127679590746`\ \
\@\(x\^2 + y\^2 + z\^2\)\ Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) \
- \(14.06619391285005`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + \
0.01512429574865732`\ r0\ Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) \
- \(14.06619391285005`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(RR\_\(Rotat, Cart\)[4, 2, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((141.87780820396267`\ \
\((\((\(-0.002524699232190157`\)\ r0\^2 + 0.2025674811476966`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(15.514603010898883`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.0391697063093515`\ \
r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(15.514603010898883`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(Rotat, Cart\)[4, 3, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^2\)\) \
\((151.06434134817425`\ \((\@\(x\^2 + y\^2 + z\^2\)\ \
\((\(-0.01015776298606729`\)\ r0\^2 + 0.19395162042753517`\ \((x\^2 + y\^2 + \
z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0006002121422403276`\)\ r0\^2 + 0.06876245355250067`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\)}], "Input"],

Cell["", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1016, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.25,
StyleDefinitions -> "Classroom1.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 248, 8, 93, "Subtitle"],
Cell[2521, 82, 199, 5, 124, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2745, 91, 97, 2, 85, "Section"],
Cell[2845, 95, 194, 7, 57, "Text"],
Cell[3042, 104, 62, 1, 63, "Input"],
Cell[3107, 107, 95, 2, 56, "Text"],

Cell[CellGroupData[{
Cell[3227, 113, 367, 7, 125, "Input"],
Cell[3597, 122, 149, 3, 96, "Output"]
}, Open  ]],
Cell[3761, 128, 130, 6, 56, "Text"],
Cell[3894, 136, 99, 2, 56, "Text"],
Cell[3996, 140, 176, 4, 54, "NumberedEquation"],
Cell[4175, 146, 197, 9, 56, "Text"],

Cell[CellGroupData[{
Cell[4397, 159, 117, 2, 64, "Input"],
Cell[4517, 163, 147, 2, 98, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4713, 171, 120, 3, 85, "Section"],
Cell[4836, 176, 281, 9, 80, "Text"],
Cell[5120, 187, 180, 3, 92, "NumberedEquation"],

Cell[CellGroupData[{
Cell[5325, 194, 205, 5, 129, "Input"],
Cell[5533, 201, 163, 3, 116, "Output"]
}, Open  ]],
Cell[5711, 207, 135, 3, 56, "Text"],

Cell[CellGroupData[{
Cell[5871, 214, 234, 6, 154, "Input"],
Cell[6108, 222, 163, 2, 113, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6320, 230, 173, 5, 85, "Section"],
Cell[6496, 237, 122, 3, 56, "Text"],
Cell[6621, 242, 139, 2, 73, "NumberedEquation"],
Cell[6763, 246, 54, 0, 56, "Text"],
Cell[6820, 248, 234, 4, 82, "NumberedEquation"],
Cell[7057, 254, 96, 2, 56, "Text"],
Cell[7156, 258, 190, 8, 74, "NumberedEquation"],
Cell[7349, 268, 261, 10, 56, "Text"],

Cell[CellGroupData[{
Cell[7635, 282, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[7845, 296, 773, 14, 303, "Input"],
Cell[8621, 312, 169, 3, 119, "Output"],
Cell[8793, 317, 78, 1, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8908, 323, 107, 2, 64, "Input"],
Cell[9018, 327, 144, 2, 85, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9199, 334, 227, 4, 204, "Input"],
Cell[9429, 340, 178, 3, 119, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9656, 349, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[9866, 363, 773, 14, 303, "Input"],
Cell[10642, 379, 289, 4, 115, "Output"],
Cell[10934, 385, 77, 1, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11048, 391, 106, 2, 64, "Input"],
Cell[11157, 395, 142, 2, 85, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11336, 402, 375, 7, 294, "Input"],
Cell[11714, 411, 321, 5, 115, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[12084, 422, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[12294, 436, 773, 14, 303, "Input"],
Cell[13070, 452, 371, 6, 158, "Output"],
Cell[13444, 460, 78, 1, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13559, 466, 107, 2, 64, "Input"],
Cell[13669, 470, 144, 2, 85, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13850, 477, 436, 8, 264, "Input"],
Cell[14289, 487, 412, 7, 158, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[14750, 500, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[14960, 514, 827, 15, 336, "Input"],
Cell[15790, 531, 430, 6, 158, "Output"],
Cell[16223, 539, 78, 1, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16338, 545, 93, 1, 64, "Input"],
Cell[16434, 548, 126, 2, 63, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16597, 555, 474, 9, 215, "Input"],
Cell[17074, 566, 425, 7, 113, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[17548, 579, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[17758, 593, 773, 14, 303, "Input"],
Cell[18534, 609, 168, 3, 119, "Output"],
Cell[18705, 614, 78, 1, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18820, 620, 107, 2, 64, "Input"],
Cell[18930, 624, 144, 2, 85, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19111, 631, 226, 4, 204, "Input"],
Cell[19340, 637, 177, 3, 119, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[19566, 646, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[19776, 660, 773, 14, 303, "Input"],
Cell[20552, 676, 290, 4, 115, "Output"],
Cell[20845, 682, 78, 1, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20960, 688, 107, 2, 64, "Input"],
Cell[21070, 692, 144, 2, 85, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21251, 699, 375, 6, 294, "Input"],
Cell[21629, 707, 323, 5, 115, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[22001, 718, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[22211, 732, 773, 14, 303, "Input"],
Cell[22987, 748, 367, 5, 158, "Output"],
Cell[23357, 755, 78, 1, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23472, 761, 107, 2, 64, "Input"],
Cell[23582, 765, 142, 2, 85, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23761, 772, 431, 7, 264, "Input"],
Cell[24195, 781, 407, 6, 158, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[24651, 793, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[24861, 807, 827, 15, 336, "Input"],
Cell[25691, 824, 440, 8, 158, "Output"],
Cell[26134, 834, 77, 1, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26248, 840, 106, 2, 64, "Input"],
Cell[26357, 844, 144, 2, 85, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26538, 851, 507, 10, 289, "Input"],
Cell[27048, 863, 483, 9, 158, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[27580, 878, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[27790, 892, 773, 14, 303, "Input"],
Cell[28566, 908, 168, 3, 119, "Output"],
Cell[28737, 913, 78, 1, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28852, 919, 107, 2, 64, "Input"],
Cell[28962, 923, 144, 2, 85, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29143, 930, 226, 4, 204, "Input"],
Cell[29372, 936, 177, 3, 119, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[29598, 945, 186, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[29809, 959, 773, 14, 303, "Input"],
Cell[30585, 975, 292, 5, 115, "Output"],
Cell[30880, 982, 78, 1, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30995, 988, 107, 2, 64, "Input"],
Cell[31105, 992, 144, 2, 85, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31286, 999, 377, 7, 294, "Input"],
Cell[31666, 1008, 323, 5, 115, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[32038, 1019, 186, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[32249, 1033, 773, 14, 303, "Input"],
Cell[33025, 1049, 375, 6, 158, "Output"],
Cell[33403, 1057, 78, 1, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33518, 1063, 107, 2, 64, "Input"],
Cell[33628, 1067, 148, 2, 85, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33813, 1074, 441, 8, 264, "Input"],
Cell[34257, 1084, 417, 7, 158, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[34723, 1097, 186, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[34934, 1111, 827, 15, 336, "Input"],
Cell[35764, 1128, 438, 8, 158, "Output"],
Cell[36205, 1138, 77, 1, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36319, 1144, 106, 2, 64, "Input"],
Cell[36428, 1148, 144, 2, 85, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36609, 1155, 505, 10, 289, "Input"],
Cell[37117, 1167, 481, 9, 158, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[37647, 1182, 186, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[37858, 1196, 773, 14, 303, "Input"],
Cell[38634, 1212, 170, 3, 119, "Output"],
Cell[38807, 1217, 78, 1, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38922, 1223, 107, 2, 64, "Input"],
Cell[39032, 1227, 148, 2, 85, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[39217, 1234, 229, 4, 204, "Input"],
Cell[39449, 1240, 178, 3, 119, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[39676, 1249, 186, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[39887, 1263, 773, 14, 303, "Input"],
Cell[40663, 1279, 290, 4, 115, "Output"],
Cell[40956, 1285, 78, 1, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41071, 1291, 107, 2, 64, "Input"],
Cell[41181, 1295, 148, 2, 85, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41366, 1302, 376, 6, 294, "Input"],
Cell[41745, 1310, 324, 5, 115, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[42118, 1321, 186, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[42329, 1335, 773, 14, 303, "Input"],
Cell[43105, 1351, 373, 6, 158, "Output"],
Cell[43481, 1359, 78, 1, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43596, 1365, 107, 2, 64, "Input"],
Cell[43706, 1369, 148, 2, 85, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43891, 1376, 439, 8, 264, "Input"],
Cell[44333, 1386, 415, 7, 158, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[44797, 1399, 186, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[45008, 1413, 827, 15, 336, "Input"],
Cell[45838, 1430, 435, 7, 158, "Output"],
Cell[46276, 1439, 78, 1, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[46391, 1445, 107, 2, 64, "Input"],
Cell[46501, 1449, 148, 2, 85, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[46686, 1456, 492, 9, 289, "Input"],
Cell[47181, 1467, 468, 8, 158, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[47710, 1482, 152, 5, 85, "Section"],
Cell[47865, 1489, 110, 2, 56, "Text"],
Cell[47978, 1493, 6393, 123, 4018, "Input"],
Cell[54374, 1618, 123, 2, 56, "Text"],

Cell[CellGroupData[{
Cell[54522, 1624, 1567, 35, 514, "Input"],
Cell[56092, 1661, 164, 3, 98, "Output"],
Cell[56259, 1666, 304, 5, 98, "Output"],
Cell[56566, 1673, 364, 5, 139, "Output"],
Cell[56933, 1680, 375, 6, 117, "Output"],
Cell[57311, 1688, 162, 3, 98, "Output"],
Cell[57476, 1693, 303, 5, 98, "Output"],
Cell[57782, 1700, 362, 5, 191, "Output"],
Cell[58147, 1707, 416, 6, 139, "Output"],
Cell[58566, 1715, 163, 3, 98, "Output"],
Cell[58732, 1720, 305, 5, 98, "Output"],
Cell[59040, 1727, 371, 6, 191, "Output"],
Cell[59414, 1735, 415, 6, 139, "Output"],
Cell[59832, 1743, 164, 3, 98, "Output"],
Cell[59999, 1748, 305, 5, 98, "Output"],
Cell[60307, 1755, 369, 6, 191, "Output"],
Cell[60679, 1763, 414, 6, 139, "Output"]
}, Open  ]],
Cell[61108, 1772, 152, 5, 56, "Text"],
Cell[61263, 1779, 5419, 91, 3838, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[66719, 1875, 226, 5, 119, "Section"],
Cell[66948, 1882, 214, 4, 80, "Text"],
Cell[67165, 1888, 63, 1, 69, "Input"],

Cell[CellGroupData[{
Cell[67253, 1893, 926, 19, 513, "Input"],
Cell[68182, 1914, 207, 3, 106, "Output"],
Cell[68392, 1919, 384, 5, 240, "Output"],
Cell[68779, 1926, 497, 8, 261, "Output"],
Cell[69279, 1936, 509, 7, 169, "Output"],
Cell[69791, 1945, 205, 3, 106, "Output"],
Cell[69999, 1950, 383, 5, 240, "Output"],
Cell[70385, 1957, 493, 7, 261, "Output"],
Cell[70881, 1966, 562, 8, 310, "Output"],
Cell[71446, 1976, 206, 3, 106, "Output"],
Cell[71655, 1981, 385, 5, 240, "Output"],
Cell[72043, 1988, 502, 8, 261, "Output"],
Cell[72548, 1998, 561, 8, 310, "Output"],
Cell[73112, 2008, 207, 3, 106, "Output"],
Cell[73322, 2013, 385, 5, 240, "Output"],
Cell[73710, 2020, 500, 8, 261, "Output"],
Cell[74213, 2030, 560, 8, 310, "Output"]
}, Open  ]],
Cell[74788, 2041, 161, 5, 56, "Text"],
Cell[74952, 2048, 7482, 124, 5424, "Input"],
Cell[82437, 2174, 16, 0, 56, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

