(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     94651,       1990]*)
(*NotebookOutlinePosition[     95380,       2015]*)
(*  CellTagsIndexPosition[     95336,       2011]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Part ",
    FontWeight->"Bold"],
  StyleBox["1. Quantum Isotropic Rotator",
    FontWeight->"Bold"],
  "\n1.2. Three-Dimensional Isotropic Quantum Rotator"
}], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
1.2.8. Probability Densities of the Three-Dimensional Quantum Rotator\
\>", "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
1. Normalized probability densities of the three-dimensional quantum \
rotator\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "We will use \"",
  StyleBox["NumericalMath`BesselZeros`",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  "\" to find radial functions of the three-dimensional quantum rotator."
}], "Text"],

Cell[BoxData[
    \(<< NumericalMath`BesselZeros`\)], "Input"],

Cell["\<\
Consider some states of the three-dimensional quantum rotator defined by \
quantum numbers:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  Cell[BoxData[
      \(n\_rad = 0, 1, 2, 3\)],
    FontSlant->"Italic"],
  "\n",
  Cell[BoxData[
      \(l\_orb = 0, 1, 2, 3\)],
    FontSlant->"Italic"],
  "\n",
  Cell[BoxData[
      \(m\_azm = 0, 1, 2, 3\)],
    FontSlant->"Italic"]
}], "NumberedEquation"],

Cell["\<\
Wave functions and probability densities of the quantum rotator is\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(\[Psi]\_Rotat[n\_rad, l\_orb, m\_azm, r0] = 
      R\_Rotat[n\_rad, l\_orb, r0]\ Y[l\_orb, m\_azm]\)], "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      StyleBox[\(R\_Oscl[n\_rad, l\_orb, r0]\),
        FontSlant->"Italic"]]],
  " is the radial wave function and ",
  Cell[BoxData[
      StyleBox[\(Y[l\_orb, m\_azm]\),
        FontSlant->"Italic"]]],
  " is the angular wave function."
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Normalized radial wave functions and radial probability densities of the \
three-dimensional quantum rotator for given quantum numbers in the Cartesian \
rectangular coordinates are:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(RR\_\(Rotat, Cart\)[1, 0, 
          r0] = \(1\/r0\^3\) \((7.075319641012959`\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Cos[\(\(1.5707963267948966`\)\(\[InvisibleSpace]\)\
\) - \(3.1415926535897913`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0]\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(RR\_\(Rotat, Cart\)[1, 1, 
          r0] = \(1\/r0\^3\) \((39.549825387365786`\ \((0.3764021226965972`\ \
\@\(x\^2 + y\^2 + z\^2\)\ Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) \
- \(4.493409457909065`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + \
0.08376759924116726`\ r0\ Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) \
- \(4.493409457909065`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(RR\_\(Rotat, Cart\)[1, 2, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((45.33715613990341`\ \
\((\((\(-0.030016030571366766`\)\ r0\^2 + 0.3323521174464318`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(5.763459196944853`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.1729961674523217`\ \
r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(5.763459196944853`\ \@\
\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_\(Rotat, Cart\)[1, 3, 
          r0] = \(1\/\((x\^2 + y\^2 + z\^2)\)\^2\) \((51.56332315103015`\ \((\
\@\(x\^2 + y\^2 + z\^2\)\ \((\(-0.09271705851256021`\) + 0.3018323092198434`\ \
\((x\^2 + y\^2 + z\^2)\))\)\ \
Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)] + \((\(-0.013268168394580504`\) + \
0.2591602000689954`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)])\)\^2)\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RR\_\(Rotat, Cart\)[2, 0, 
          r0] = \(6.23697669802249`\ \((x\^2 + y\^2 + z\^2)\)\ \
Cos[\(\(1.5707963267948966`\)\(\[InvisibleSpace]\)\) - \(6.283185307179585`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0]\^2\)\/r0\^3;\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(Rotat, Cart\)[2, 1, 
          r0] = \(1\/r0\^3\) \((71.0523659964382`\ \((0.28706730919827866`\ \
\@\(x\^2 + y\^2 + z\^2\)\ Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) \
- \(7.725251836937706`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + \
0.03715960531224213`\ r0\ Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) \
- \(7.725251836937706`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(RR\_\(Rotat, Cart\)[2, 2, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((78.92198764687868`\ \
\((\((\(-0.00959518174141225`\)\ r0\^2 + 0.2645686853222971`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(9.09501133069512`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.08726828665822337`\ \
r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(9.09501133069512`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_\(Rotat, Cart\)[2, 3, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^2\)\) \
\((86.13958004808885`\ \((\@\(x\^2 + y\^2 + z\^2\)\ \
\((\(-0.034171363187267656`\)\ r0\^2 + 0.24721012729596964`\ \((x\^2 + y\^2 + \
z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0032803085643514102`\)\ r0\^2 + 0.14238685650074237`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RR\_\(Rotat, Cart\)[3, 0, 
          r0] = \(6.103061570617827`\ \((x\^2 + y\^2 + z\^2)\)\ \
Cos[\(\(1.5707963267948966`\)\(\[InvisibleSpace]\)\) - \(9.424777960902889`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0]\^2\)\/r0\^3;\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(Rotat, Cart\)[3, 1, 
          
          r0] = \(1\/r0\^3\) \((101.49912686413447`\ \((0.2416265857850596`\ \
\@\(x\^2 + y\^2 + z\^2\)\ Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) \
- \(10.90412165949781`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + \
0.022159197533768875`\ r0\ \
Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(10.90412165949781`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(Rotat, Cart\)[3, 2, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((110.81823480506986`\ \
\((\((\(-0.004490300397068933`\)\ r0\^2 + 0.22729133392011303`\ \((x\^2 + \
y\^2 + z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(12.322940970607872`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.05533370673337756`\
\ r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(12.322940970607872`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_\(Rotat, Cart\)[3, 3, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^2\)\) \
\((119.11501544429397`\ \((\@\(x\^2 + y\^2 + z\^2\)\ \
\((\(-0.017234019526460444`\)\ r0\^2 + 0.215581313417243`\ \((x\^2 + y\^2 + z\
\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0012581391733403658`\)\ r0\^2 + 0.09442879939898956`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RR\_\(Rotat, Cart\)[4, 0, 
          r0] = \(1\/r0\^3\) \((6.057539727717295`\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Cos[\(\(1.5707963267948966`\)\(\[InvisibleSpace]\)\
\) - \(12.566370614390479`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0]\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(RR\_\(Rotat, Cart\)[4, 1, 
          r0] = \(1\/r0\^3\) \((131.57824937140765`\ \((0.21274127679590746`\ \
\@\(x\^2 + y\^2 + z\^2\)\ Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) \
- \(14.06619391285005`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + \
0.01512429574865732`\ r0\ Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) \
- \(14.06619391285005`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(RR\_\(Rotat, Cart\)[4, 2, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((141.87780820396267`\ \
\((\((\(-0.002524699232190157`\)\ r0\^2 + 0.2025674811476966`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(15.514603010898883`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.0391697063093515`\ \
r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(15.514603010898883`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(Rotat, Cart\)[4, 3, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^2\)\) \
\((151.06434134817425`\ \((\@\(x\^2 + y\^2 + z\^2\)\ \
\((\(-0.01015776298606729`\)\ r0\^2 + 0.19395162042753517`\ \((x\^2 + y\^2 + \
z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0006002121422403276`\)\ r0\^2 + 0.06876245355250067`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\)}], "Input"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(Cart\)\" is similar to \
existing symbol \"\!\(Part\)\"."\)], "Message"]
}, Open  ]],

Cell["\<\
Normalized angular wave functions (spherical harmonics) and angular \
probability densities of the three-dimensional quantum oscillator for given \
quantum numbers in the Cartesian rectangular coordinates are:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(YY\_Cart[0, 0] = 1\/\(4\ \[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(YY\_Cart[1, 
          0] = \(3\ z\^2\)\/\(4\ \[Pi]\ \((x\^2 + y\^2 + z\^2)\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(YY\_Cart[1, 
          1] = \(3\ \((x\^2 + y\^2)\)\)\/\(8\ \[Pi]\ \((x\^2 + y\^2 + z\^2)\)\
\);\)\), "\[IndentingNewLine]", 
    \(\(YY\_Cart[2, 
          0] = \(5\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\)\/\(16\ \[Pi]\ \((x\^2 + \
y\^2 + z\^2)\)\^2\);\)\), "\[IndentingNewLine]", 
    \(\(YY\_Cart[2, 
          1] = \(15\ \((x\^2 + y\^2)\)\ z\^2\)\/\(8\ \[Pi]\ \((x\^2 + y\^2 + \
z\^2)\)\^2\);\)\), "\[IndentingNewLine]", 
    \(\(YY\_Cart[2, 
          2] = \(15\ \((x\^2 + y\^2)\)\^2\)\/\(32\ \[Pi]\ \((x\^2 + y\^2 + \
z\^2)\)\^2\);\)\), "\[IndentingNewLine]", 
    \(\(YY\_Cart[3, 
          0] = \(7\ \((3\ \((x\^2 + y\^2)\)\ z - 2\ z\^3)\)\^2\)\/\(16\ \[Pi]\
\ \((x\^2 + y\^2 + z\^2)\)\^3\);\)\), "\[IndentingNewLine]", 
    \(\(YY\_Cart[3, 
          1] = \(21\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 - 4\ \
z\^2)\)\^2\)\/\(64\ \[Pi]\ \((x\^2 + y\^2 + z\^2)\)\^3\);\)\), "\
\[IndentingNewLine]", 
    \(\(YY\_Cart[3, 
          2] = \(105\ \((x\^2 + y\^2)\)\^2\ z\^2\)\/\(32\ \[Pi]\ \((x\^2 + \
y\^2 + z\^2)\)\^3\);\)\), "\[IndentingNewLine]", 
    \(\(YY\_Cart[3, 
          3] = \(35\ \((x\^2 + y\^2)\)\^3\)\/\(64\ \[Pi]\ \((x\^2 + y\^2 + \
z\^2)\)\^3\);\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2. Calculation probability densities of the three-dimensional quantum rotator \
for given quantum numbers in the Cartesian rectangular coordinates\
\>", "Section"],

Cell["\<\
Normalized wave functions and probability densities of the three-dimensional \
quantum rotator for given quantum numbers are:\
\>", "Text"],

Cell[BoxData[
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[n\_rad, l\_orb, m\_azm, r0] = 
      RR\_\(Rotat, Cart\)[n\_rad, l\_orb, r0]\ YY\_Cart[l\_orb, 
          m\_azm]\)], "NumberedEquation"],

Cell[CellGroupData[{

Cell[TextData[{
  "1) ",
  Cell[BoxData[
      \(n\_rad = 1\)],
    FontSlant->"Italic"]
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 0, 0, r0] = 
      RR\_\(Rotat, Cart\)[n\_rad, l\_orb, r0]\ YY\_Cart[l\_orb, 
          m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(0.5630360474111934`\ \((x\^2 + y\^2 + z\^2)\)\ \
Cos[\(\(1.5707963267948966`\)\(\[InvisibleSpace]\)\) - \(3.1415926535897913`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0]\^2\)\/r0\^3\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 1, 0, r0] = 
      RR\_\(Rotat, Cart\)[n\_rad, l\_orb, r0]\ YY\_Cart[l\_orb, 
          m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + 
              z\^2)\)\)\)\((9.441825313230899`\ z\^2\ \((0.3764021226965972`\ \
\@\(x\^2 + y\^2 + z\^2\)\ Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) \
- \(4.493409457909065`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + \
0.08376759924116726`\ r0\ Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) \
- \(4.493409457909065`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 1, 1, r0] = 
      RR\_\(Rotat, Cart\)[n\_rad, l\_orb, r0]\ YY\_Cart[l\_orb, 
          m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + 
              z\^2)\)\)\)\((4.720912656615449`\ \((x\^2 + 
            y\^2)\)\ \((0.3764021226965972`\ \@\(x\^2 + y\^2 + z\^2\)\ Cos[\(\
\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(4.493409457909065`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.08376759924116726`\ r0\ \
Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(4.493409457909065`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 2, 0, r0] = 
      RR\_\(Rotat, Cart\)[n\_rad, l\_orb, r0]\ YY\_Cart[l\_orb, 
          m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\)\((4.509770315871688`\ \
\((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((\((\(-0.030016030571366766`\)\ r0\^2 + \
0.3323521174464318`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\
\(\[InvisibleSpace]\)\) - \(5.763459196944853`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + 0.1729961674523217`\ r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(5.763459196944853`\ \@\
\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 2, 1, r0] = 
      RR\_\(Rotat, Cart\)[n\_rad, l\_orb, r0]\ YY\_Cart[l\_orb, 
          m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\)\((27.05862189523013`\ \
\((x\^2 + 
            y\^2)\)\ z\^2\ \((\((\(-0.030016030571366766`\)\ r0\^2 + \
0.3323521174464318`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\
\(\[InvisibleSpace]\)\) - \(5.763459196944853`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + 0.1729961674523217`\ r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(5.763459196944853`\ \@\
\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 2;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 2, 2, r0] = 
      RR\_\(Rotat, Cart\)[n\_rad, l\_orb, r0]\ YY\_Cart[l\_orb, 
          m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\)\((6.764655473807532`\ \
\((x\^2 + y\^2)\)\^2\ \((\((\(-0.030016030571366766`\)\ r0\^2 + \
0.3323521174464318`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\
\(\[InvisibleSpace]\)\) - \(5.763459196944853`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + 0.1729961674523217`\ r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(5.763459196944853`\ \@\
\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 3, 0, r0] = 
      RR\_\(Rotat, Cart\)[n\_rad, l\_orb, r0]\ YY\_Cart[l\_orb, 
          m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\(1\/\((x\^2 + y\^2 + z\^2)\)\^5\)\((7.180738041514811`\ \((3\ \
\((x\^2 + y\^2)\)\ z - 2\ z\^3)\)\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ \
\((\(-0.09271705851256021`\) + 0.3018323092198434`\ \((x\^2 + y\^2 + z\^2)\))\
\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)] + \((\(-0.013268168394580504`\) + \
0.2591602000689954`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)])\)\^2)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 3, 1, r0] = 
      RR\_\(Rotat, Cart\)[n\_rad, l\_orb, r0]\ YY\_Cart[l\_orb, 
          m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\(1\/\((x\^2 + y\^2 + z\^2)\)\^5\)\((5.385553531136108`\ \((x\^2 + 
            y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((\@\(x\^2 + y\^2 + \
z\^2\)\ \((\(-0.09271705851256021`\) + 0.3018323092198434`\ \((x\^2 + y\^2 + \
z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
6.987932000503647`\ \@\(x\^2 + y\^2 + z\^2\)] + \((\(-0.013268168394580504`\) \
+ 0.2591602000689954`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)])\)\^2)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 2;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 3, 2, r0] = 
      RR\_\(Rotat, Cart\)[n\_rad, l\_orb, r0]\ YY\_Cart[l\_orb, 
          m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\(1\/\((x\^2 + y\^2 + z\^2)\)\^5\)\((53.85553531136109`\ \((x\^2 + \
y\^2)\)\^2\ z\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ \((\(-0.09271705851256021`\) + \
0.3018323092198434`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)] + \((\(-0.013268168394580504`\) + \
0.2591602000689954`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)])\)\^2)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\n", 
    \(\(l\_orb = 3;\)\), "\n", 
    \(\(m\_azm = 3;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 3, 3, r0] = 
      RR\_\(Rotat, Cart\)[n\_rad, l\_orb, r0]\ YY\_Cart[l\_orb, 
          m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\(1\/\((x\^2 + y\^2 + z\^2)\)\^5\)\((8.975922551893515`\ \((x\^2 + \
y\^2)\)\^3\ \((\@\(x\^2 + y\^2 + z\^2\)\ \((\(-0.09271705851256021`\) + \
0.3018323092198434`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)] + \((\(-0.013268168394580504`\) + \
0.2591602000689954`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)])\)\^2)\)\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "2) ",
  Cell[BoxData[
      \(n\_rad = 2\)],
    FontSlant->"Italic"]
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 0, 0, r0] = 
      RR\_\(Rotat, Cart\)[n\_rad, l\_orb, r0]\ YY\_Cart[l\_orb, 
          m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(0.4963228357196234`\ \((x\^2 + y\^2 + z\^2)\)\ \
Cos[\(\(1.5707963267948966`\)\(\[InvisibleSpace]\)\) - \(6.283185307179585`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0]\^2\)\/r0\^3\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 1, 0, r0] = 
      RR\_\(Rotat, Cart\)[n\_rad, l\_orb, r0]\ YY\_Cart[l\_orb, 
          m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + 
              z\^2)\)\)\)\((16.962502900061462`\ z\^2\ \
\((0.28706730919827866`\ \@\(x\^2 + y\^2 + z\^2\)\ Cos[\(\(3.141592653589793`\
\)\(\[InvisibleSpace]\)\) - \(7.725251836937706`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + 0.03715960531224213`\ r0\ Sin[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(7.725251836937706`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 1, 1, r0] = 
      RR\_\(Rotat, Cart\)[n\_rad, l\_orb, r0]\ YY\_Cart[l\_orb, 
          m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + 
              z\^2)\)\)\)\((8.481251450030731`\ \((x\^2 + 
            y\^2)\)\ \((0.28706730919827866`\ \@\(x\^2 + y\^2 + z\^2\)\ \
Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(7.725251836937706`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.03715960531224213`\ r0\ \
Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(7.725251836937706`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 2, 0, r0] = 
      RR\_\(Rotat, Cart\)[n\_rad, l\_orb, r0]\ YY\_Cart[l\_orb, 
          m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\)\((7.850515282898902`\ \
\((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((\((\(-0.00959518174141225`\)\ r0\^2 + \
0.2645686853222971`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\
\(\[InvisibleSpace]\)\) - \(9.09501133069512`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + 0.08726828665822337`\ r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(9.09501133069512`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 2, 1, r0] = 
      RR\_\(Rotat, Cart\)[n\_rad, l\_orb, r0]\ YY\_Cart[l\_orb, 
          m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\)\((47.10309169739341`\ \
\((x\^2 + 
            y\^2)\)\ z\^2\ \((\((\(-0.00959518174141225`\)\ r0\^2 + \
0.2645686853222971`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\
\(\[InvisibleSpace]\)\) - \(9.09501133069512`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + 0.08726828665822337`\ r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(9.09501133069512`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 2;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 2, 2, r0] = 
      RR\_\(Rotat, Cart\)[n\_rad, l\_orb, r0]\ YY\_Cart[l\_orb, 
          m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\)\((11.775772924348352`\ \
\((x\^2 + y\^2)\)\^2\ \((\((\(-0.00959518174141225`\)\ r0\^2 + \
0.2645686853222971`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\
\(\[InvisibleSpace]\)\) - \(9.09501133069512`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + 0.08726828665822337`\ r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(9.09501133069512`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 3, 0, r0] = 
      RR\_\(Rotat, Cart\)[n\_rad, l\_orb, r0]\ YY\_Cart[l\_orb, 
          m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\)\((11.995847465449176`\ \
\((3\ \((x\^2 + y\^2)\)\ z - 2\ z\^3)\)\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ \
\((\(-0.034171363187267656`\)\ r0\^2 + 0.24721012729596964`\ \((x\^2 + y\^2 + \
z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0032803085643514102`\)\ r0\^2 + 0.14238685650074237`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 3, 1, r0] = 
      RR\_\(Rotat, Cart\)[n\_rad, l\_orb, r0]\ YY\_Cart[l\_orb, 
          m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\)\((8.996885599086882`\ \
\((x\^2 + 
            y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((\@\(x\^2 + y\^2 + \
z\^2\)\ \((\(-0.034171363187267656`\)\ r0\^2 + 0.24721012729596964`\ \((x\^2 \
+ y\^2 + z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0032803085643514102`\)\ r0\^2 + 0.14238685650074237`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 2;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 3, 2, r0] = 
      RR\_\(Rotat, Cart\)[n\_rad, l\_orb, r0]\ YY\_Cart[l\_orb, 
          m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\)\((89.96885599086882`\ \
\((x\^2 + y\^2)\)\^2\ z\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ \
\((\(-0.034171363187267656`\)\ r0\^2 + 0.24721012729596964`\ \((x\^2 + y\^2 + \
z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0032803085643514102`\)\ r0\^2 + 0.14238685650074237`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\n", 
    \(\(l\_orb = 3;\)\), "\n", 
    \(\(m\_azm = 3;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 3, 3, r0] = 
      RR\_\(Rotat, Cart\)[n\_rad, l\_orb, r0]\ YY\_Cart[l\_orb, 
          m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\)\((14.994809331811469`\ \
\((x\^2 + y\^2)\)\^3\ \((\@\(x\^2 + y\^2 + z\^2\)\ \
\((\(-0.034171363187267656`\)\ r0\^2 + 0.24721012729596964`\ \((x\^2 + y\^2 + \
z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0032803085643514102`\)\ r0\^2 + 0.14238685650074237`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "3) ",
  Cell[BoxData[
      \(n\_rad = 3\)],
    FontSlant->"Italic"]
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 0, 0, r0] = 
      RR\_\(Rotat, Cart\)[n\_rad, l\_orb, r0]\ YY\_Cart[l\_orb, 
          m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(0.4856662084790068`\ \((x\^2 + y\^2 + z\^2)\)\ \
Cos[\(\(1.5707963267948966`\)\(\[InvisibleSpace]\)\) - \(9.424777960902889`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0]\^2\)\/r0\^3\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 1, 0, r0] = 
      RR\_\(Rotat, Cart\)[n\_rad, l\_orb, r0]\ YY\_Cart[l\_orb, 
          m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + 
              z\^2)\)\)\)\((24.231131639907577`\ z\^2\ \((0.2416265857850596`\
\ \@\(x\^2 + y\^2 + z\^2\)\ Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\
\) - \(10.90412165949781`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + \
0.022159197533768875`\ r0\ \
Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(10.90412165949781`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 1, 1, r0] = 
      RR\_\(Rotat, Cart\)[n\_rad, l\_orb, r0]\ YY\_Cart[l\_orb, 
          m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + 
              z\^2)\)\)\)\((12.115565819953789`\ \((x\^2 + 
            y\^2)\)\ \((0.2416265857850596`\ \@\(x\^2 + y\^2 + z\^2\)\ Cos[\(\
\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(10.90412165949781`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.022159197533768875`\ r0\ \
Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(10.90412165949781`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 2, 0, r0] = 
      RR\_\(Rotat, Cart\)[n\_rad, l\_orb, r0]\ YY\_Cart[l\_orb, 
          m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\)\((11.023293658715744`\ \
\((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((\((\(-0.004490300397068933`\)\ r0\^2 + \
0.22729133392011303`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(12.322940970607872`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.05533370673337756`\ r0\ \@\(x\^2 + y\^2 + \
z\^2\)\ Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(12.322940970607872`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 2, 1, r0] = 
      RR\_\(Rotat, Cart\)[n\_rad, l\_orb, r0]\ YY\_Cart[l\_orb, 
          m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\)\((66.13976195229446`\ \
\((x\^2 + 
            y\^2)\)\ z\^2\ \((\((\(-0.004490300397068933`\)\ r0\^2 + \
0.22729133392011303`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(12.322940970607872`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.05533370673337756`\ r0\ \@\(x\^2 + y\^2 + \
z\^2\)\ Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(12.322940970607872`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 2;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 2, 2, r0] = 
      RR\_\(Rotat, Cart\)[n\_rad, l\_orb, r0]\ YY\_Cart[l\_orb, 
          m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\)\((16.534940488073616`\ \
\((x\^2 + y\^2)\)\^2\ \((\((\(-0.004490300397068933`\)\ r0\^2 + \
0.22729133392011303`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(12.322940970607872`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.05533370673337756`\ r0\ \@\(x\^2 + y\^2 + \
z\^2\)\ Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(12.322940970607872`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 3, 0, r0] = 
      RR\_\(Rotat, Cart\)[n\_rad, l\_orb, r0]\ YY\_Cart[l\_orb, 
          m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\)\((16.58802556637349`\ \
\((3\ \((x\^2 + y\^2)\)\ z - 2\ z\^3)\)\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ \
\((\(-0.017234019526460444`\)\ r0\^2 + 0.215581313417243`\ \((x\^2 + y\^2 + z\
\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0012581391733403658`\)\ r0\^2 + 0.09442879939898956`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 3, 1, r0] = 
      RR\_\(Rotat, Cart\)[n\_rad, l\_orb, r0]\ YY\_Cart[l\_orb, 
          m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\)\((12.441019174780115`\ \
\((x\^2 + 
            y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((\@\(x\^2 + y\^2 + \
z\^2\)\ \((\(-0.017234019526460444`\)\ r0\^2 + 0.215581313417243`\ \((x\^2 + \
y\^2 + z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0012581391733403658`\)\ r0\^2 + 0.09442879939898956`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 2;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 3, 2, r0] = 
      RR\_\(Rotat, Cart\)[n\_rad, l\_orb, r0]\ YY\_Cart[l\_orb, 
          m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\)\((124.41019174780115`\ \
\((x\^2 + y\^2)\)\^2\ z\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ \
\((\(-0.017234019526460444`\)\ r0\^2 + 0.215581313417243`\ \((x\^2 + y\^2 + z\
\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0012581391733403658`\)\ r0\^2 + 0.09442879939898956`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\n", 
    \(\(l\_orb = 3;\)\), "\n", 
    \(\(m\_azm = 3;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 3, 3, r0] = 
      RR\_\(Rotat, Cart\)[n\_rad, l\_orb, r0]\ YY\_Cart[l\_orb, 
          m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\)\((20.73503195796686`\ \
\((x\^2 + y\^2)\)\^3\ \((\@\(x\^2 + y\^2 + z\^2\)\ \
\((\(-0.017234019526460444`\)\ r0\^2 + 0.215581313417243`\ \((x\^2 + y\^2 + z\
\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0012581391733403658`\)\ r0\^2 + 0.09442879939898956`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "4) ",
  Cell[BoxData[
      \(n\_rad = 4\)],
    FontSlant->"Italic"]
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 4;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 0, 0, r0] = 
      RR\_\(Rotat, Cart\)[n\_rad, l\_orb, r0]\ YY\_Cart[l\_orb, 
          m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(0.4820436953208706`\ \((x\^2 + y\^2 + z\^2)\)\ \
Cos[\(\(1.5707963267948966`\)\(\[InvisibleSpace]\)\) - \(12.566370614390479`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0]\^2\)\/r0\^3\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 4;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 1, 0, r0] = 
      RR\_\(Rotat, Cart\)[n\_rad, l\_orb, r0]\ YY\_Cart[l\_orb, 
          m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + 
              z\^2)\)\)\)\((31.4119931862564`\ z\^2\ \((0.21274127679590746`\ \
\@\(x\^2 + y\^2 + z\^2\)\ Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) \
- \(14.06619391285005`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + \
0.01512429574865732`\ r0\ Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) \
- \(14.06619391285005`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 4;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 1, 1, r0] = 
      RR\_\(Rotat, Cart\)[n\_rad, l\_orb, r0]\ YY\_Cart[l\_orb, 
          m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + 
              z\^2)\)\)\)\((15.7059965931282`\ \((x\^2 + 
            y\^2)\)\ \((0.21274127679590746`\ \@\(x\^2 + y\^2 + z\^2\)\ \
Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(14.06619391285005`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.01512429574865732`\ r0\ \
Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(14.06619391285005`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 4;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 2, 0, r0] = 
      RR\_\(Rotat, Cart\)[n\_rad, l\_orb, r0]\ YY\_Cart[l\_orb, 
          m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\)\((14.112846556690327`\ \
\((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((\((\(-0.002524699232190157`\)\ r0\^2 + \
0.2025674811476966`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\
\(\[InvisibleSpace]\)\) - \(15.514603010898883`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + 0.0391697063093515`\ r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(15.514603010898883`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 4;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 2, 1, r0] = 
      RR\_\(Rotat, Cart\)[n\_rad, l\_orb, r0]\ YY\_Cart[l\_orb, 
          m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\)\((84.67707934014196`\ \
\((x\^2 + 
            y\^2)\)\ z\^2\ \((\((\(-0.002524699232190157`\)\ r0\^2 + \
0.2025674811476966`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\
\(\[InvisibleSpace]\)\) - \(15.514603010898883`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + 0.0391697063093515`\ r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(15.514603010898883`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 4;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 2;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 2, 2, r0] = 
      RR\_\(Rotat, Cart\)[n\_rad, l\_orb, r0]\ YY\_Cart[l\_orb, 
          m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\)\((21.16926983503549`\ \
\((x\^2 + y\^2)\)\^2\ \((\((\(-0.002524699232190157`\)\ r0\^2 + \
0.2025674811476966`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\
\(\[InvisibleSpace]\)\) - \(15.514603010898883`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + 0.0391697063093515`\ r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(15.514603010898883`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 4;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 3, 0, r0] = 
      RR\_\(Rotat, Cart\)[n\_rad, l\_orb, r0]\ YY\_Cart[l\_orb, 
          m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\)\((21.037307069172908`\ \
\((3\ \((x\^2 + y\^2)\)\ z - 2\ z\^3)\)\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ \
\((\(-0.01015776298606729`\)\ r0\^2 + 0.19395162042753517`\ \((x\^2 + y\^2 + \
z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0006002121422403276`\)\ r0\^2 + 0.06876245355250067`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 4;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 3, 1, r0] = 
      RR\_\(Rotat, Cart\)[n\_rad, l\_orb, r0]\ YY\_Cart[l\_orb, 
          m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\)\((15.777980301879683`\ \
\((x\^2 + 
            y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((\@\(x\^2 + y\^2 + \
z\^2\)\ \((\(-0.01015776298606729`\)\ r0\^2 + 0.19395162042753517`\ \((x\^2 + \
y\^2 + z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0006002121422403276`\)\ r0\^2 + 0.06876245355250067`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 4;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 2;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 3, 2, r0] = 
      RR\_\(Rotat, Cart\)[n\_rad, l\_orb, r0]\ YY\_Cart[l\_orb, 
          m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\)\((157.77980301879683`\ \
\((x\^2 + y\^2)\)\^2\ z\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ \
\((\(-0.01015776298606729`\)\ r0\^2 + 0.19395162042753517`\ \((x\^2 + y\^2 + \
z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0006002121422403276`\)\ r0\^2 + 0.06876245355250067`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 4;\)\), "\n", 
    \(\(l\_orb = 3;\)\), "\n", 
    \(\(m\_azm = 3;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 3, 3, r0] = 
      RR\_\(Rotat, Cart\)[n\_rad, l\_orb, r0]\ YY\_Cart[l\_orb, 
          m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\)\((26.29663383646614`\ \
\((x\^2 + y\^2)\)\^3\ \((\@\(x\^2 + y\^2 + z\^2\)\ \((\(-0.01015776298606729`\
\)\ r0\^2 + 0.19395162042753517`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(16.92362128522231`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \((\(-0.0006002121422403276`\)\ r0\^2 + \
0.06876245355250067`\ \((x\^2 + y\^2 + z\^2)\))\)\ Sin[\(\(6.283185307179586`\
\)\(\[InvisibleSpace]\)\) - \(16.92362128522231`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
3. List of wave functions and probability densities of the three-dimensional \
quantum oscillator for given quantum numbers\
\>", "Section"],

Cell["\<\
Probability densities in the Cartesian rectangular coordinates:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 0, 0, r0]\), "\n", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 1, 0, r0]\), "\n", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 1, 1, r0]\), "\n", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 2, 0, r0]\), "\n", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 2, 1, r0]\), "\n", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 2, 2, r0]\), "\n", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 3, 0, r0]\), "\n", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 3, 1, r0]\), "\n", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 3, 2, r0]\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 3, 3, r0]\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 0, 0, r0]\), "\n", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 1, 0, r0]\), "\n", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 1, 1, r0]\), "\n", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 2, 0, r0]\), "\n", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 2, 1, r0]\), "\n", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 2, 2, r0]\), "\n", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 3, 0, r0]\), "\n", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 3, 1, r0]\), "\n", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 3, 2, r0]\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 3, 3, r0]\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 0, 0, r0]\), "\n", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 1, 0, r0]\), "\n", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 1, 1, r0]\), "\n", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 2, 0, r0]\), "\n", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 2, 1, r0]\), "\n", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 2, 2, r0]\), "\n", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 3, 0, r0]\), "\n", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 3, 1, r0]\), "\n", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 3, 2, r0]\), "\n", 
    \(\(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 3, 3, r0]\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 0, 0, r0]\), "\n", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 1, 0, r0]\), "\n", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 1, 1, r0]\), "\n", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 2, 0, r0]\), "\n", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 2, 1, r0]\), "\n", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 2, 2, r0]\), "\n", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 3, 0, r0]\), "\n", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 3, 1, r0]\), "\n", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 3, 2, r0]\), "\n", 
    \(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 3, 3, r0]\)}], "Input"],

Cell[BoxData[
    \(\(0.5630360474111934`\ \((x\^2 + y\^2 + z\^2)\)\ \
Cos[\(\(1.5707963267948966`\)\(\[InvisibleSpace]\)\) - \(3.1415926535897913`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0]\^2\)\/r0\^3\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + 
              z\^2)\)\)\)\((9.441825313230899`\ z\^2\ \((0.3764021226965972`\ \
\@\(x\^2 + y\^2 + z\^2\)\ Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) \
- \(4.493409457909065`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + \
0.08376759924116726`\ r0\ Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) \
- \(4.493409457909065`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], \
"Output"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + 
              z\^2)\)\)\)\((4.720912656615449`\ \((x\^2 + 
            y\^2)\)\ \((0.3764021226965972`\ \@\(x\^2 + y\^2 + z\^2\)\ Cos[\(\
\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(4.493409457909065`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.08376759924116726`\ r0\ \
Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(4.493409457909065`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\)\((4.509770315871688`\ \
\((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((\((\(-0.030016030571366766`\)\ r0\^2 + \
0.3323521174464318`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\
\(\[InvisibleSpace]\)\) - \(5.763459196944853`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + 0.1729961674523217`\ r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(5.763459196944853`\ \@\
\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\)\((27.05862189523013`\ \
\((x\^2 + 
            y\^2)\)\ z\^2\ \((\((\(-0.030016030571366766`\)\ r0\^2 + \
0.3323521174464318`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\
\(\[InvisibleSpace]\)\) - \(5.763459196944853`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + 0.1729961674523217`\ r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(5.763459196944853`\ \@\
\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\)\((6.764655473807532`\ \
\((x\^2 + y\^2)\)\^2\ \((\((\(-0.030016030571366766`\)\ r0\^2 + \
0.3323521174464318`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\
\(\[InvisibleSpace]\)\) - \(5.763459196944853`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + 0.1729961674523217`\ r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(5.763459196944853`\ \@\
\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\((x\^2 + y\^2 + z\^2)\)\^5\)\((7.180738041514811`\ \((3\ \
\((x\^2 + y\^2)\)\ z - 2\ z\^3)\)\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ \
\((\(-0.09271705851256021`\) + 0.3018323092198434`\ \((x\^2 + y\^2 + z\^2)\))\
\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)] + \((\(-0.013268168394580504`\) + \
0.2591602000689954`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\((x\^2 + y\^2 + z\^2)\)\^5\)\((5.385553531136108`\ \((x\^2 + 
            y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((\@\(x\^2 + y\^2 + \
z\^2\)\ \((\(-0.09271705851256021`\) + 0.3018323092198434`\ \((x\^2 + y\^2 + \
z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
6.987932000503647`\ \@\(x\^2 + y\^2 + z\^2\)] + \((\(-0.013268168394580504`\) \
+ 0.2591602000689954`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\((x\^2 + y\^2 + z\^2)\)\^5\)\((53.85553531136109`\ \((x\^2 + \
y\^2)\)\^2\ z\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ \((\(-0.09271705851256021`\) + \
0.3018323092198434`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)] + \((\(-0.013268168394580504`\) + \
0.2591602000689954`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\((x\^2 + y\^2 + z\^2)\)\^5\)\((8.975922551893515`\ \((x\^2 + \
y\^2)\)\^3\ \((\@\(x\^2 + y\^2 + z\^2\)\ \((\(-0.09271705851256021`\) + \
0.3018323092198434`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)] + \((\(-0.013268168394580504`\) + \
0.2591602000689954`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(0.4963228357196234`\ \((x\^2 + y\^2 + z\^2)\)\ \
Cos[\(\(1.5707963267948966`\)\(\[InvisibleSpace]\)\) - \(6.283185307179585`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0]\^2\)\/r0\^3\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + 
              z\^2)\)\)\)\((16.962502900061462`\ z\^2\ \
\((0.28706730919827866`\ \@\(x\^2 + y\^2 + z\^2\)\ Cos[\(\(3.141592653589793`\
\)\(\[InvisibleSpace]\)\) - \(7.725251836937706`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + 0.03715960531224213`\ r0\ Sin[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(7.725251836937706`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + 
              z\^2)\)\)\)\((8.481251450030731`\ \((x\^2 + 
            y\^2)\)\ \((0.28706730919827866`\ \@\(x\^2 + y\^2 + z\^2\)\ \
Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(7.725251836937706`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.03715960531224213`\ r0\ \
Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(7.725251836937706`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\)\((7.850515282898902`\ \
\((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((\((\(-0.00959518174141225`\)\ r0\^2 + \
0.2645686853222971`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\
\(\[InvisibleSpace]\)\) - \(9.09501133069512`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + 0.08726828665822337`\ r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(9.09501133069512`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\)\((47.10309169739341`\ \
\((x\^2 + 
            y\^2)\)\ z\^2\ \((\((\(-0.00959518174141225`\)\ r0\^2 + \
0.2645686853222971`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\
\(\[InvisibleSpace]\)\) - \(9.09501133069512`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + 0.08726828665822337`\ r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(9.09501133069512`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\)\((11.775772924348352`\ \
\((x\^2 + y\^2)\)\^2\ \((\((\(-0.00959518174141225`\)\ r0\^2 + \
0.2645686853222971`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\
\(\[InvisibleSpace]\)\) - \(9.09501133069512`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + 0.08726828665822337`\ r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(9.09501133069512`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\)\((11.995847465449176`\ \
\((3\ \((x\^2 + y\^2)\)\ z - 2\ z\^3)\)\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ \
\((\(-0.034171363187267656`\)\ r0\^2 + 0.24721012729596964`\ \((x\^2 + y\^2 + \
z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0032803085643514102`\)\ r0\^2 + 0.14238685650074237`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\)\((8.996885599086882`\ \
\((x\^2 + 
            y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((\@\(x\^2 + y\^2 + \
z\^2\)\ \((\(-0.034171363187267656`\)\ r0\^2 + 0.24721012729596964`\ \((x\^2 \
+ y\^2 + z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0032803085643514102`\)\ r0\^2 + 0.14238685650074237`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\)\((89.96885599086882`\ \
\((x\^2 + y\^2)\)\^2\ z\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ \
\((\(-0.034171363187267656`\)\ r0\^2 + 0.24721012729596964`\ \((x\^2 + y\^2 + \
z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0032803085643514102`\)\ r0\^2 + 0.14238685650074237`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\)\((14.994809331811469`\ \
\((x\^2 + y\^2)\)\^3\ \((\@\(x\^2 + y\^2 + z\^2\)\ \
\((\(-0.034171363187267656`\)\ r0\^2 + 0.24721012729596964`\ \((x\^2 + y\^2 + \
z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0032803085643514102`\)\ r0\^2 + 0.14238685650074237`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(0.4856662084790068`\ \((x\^2 + y\^2 + z\^2)\)\ \
Cos[\(\(1.5707963267948966`\)\(\[InvisibleSpace]\)\) - \(9.424777960902889`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0]\^2\)\/r0\^3\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + 
              z\^2)\)\)\)\((24.231131639907577`\ z\^2\ \((0.2416265857850596`\
\ \@\(x\^2 + y\^2 + z\^2\)\ Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\
\) - \(10.90412165949781`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + \
0.022159197533768875`\ r0\ \
Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(10.90412165949781`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + 
              z\^2)\)\)\)\((12.115565819953789`\ \((x\^2 + 
            y\^2)\)\ \((0.2416265857850596`\ \@\(x\^2 + y\^2 + z\^2\)\ Cos[\(\
\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(10.90412165949781`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.022159197533768875`\ r0\ \
Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(10.90412165949781`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\)\((11.023293658715744`\ \
\((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((\((\(-0.004490300397068933`\)\ r0\^2 + \
0.22729133392011303`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(12.322940970607872`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.05533370673337756`\ r0\ \@\(x\^2 + y\^2 + \
z\^2\)\ Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(12.322940970607872`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\)\((66.13976195229446`\ \
\((x\^2 + 
            y\^2)\)\ z\^2\ \((\((\(-0.004490300397068933`\)\ r0\^2 + \
0.22729133392011303`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(12.322940970607872`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.05533370673337756`\ r0\ \@\(x\^2 + y\^2 + \
z\^2\)\ Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(12.322940970607872`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\)\((16.534940488073616`\ \
\((x\^2 + y\^2)\)\^2\ \((\((\(-0.004490300397068933`\)\ r0\^2 + \
0.22729133392011303`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(12.322940970607872`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.05533370673337756`\ r0\ \@\(x\^2 + y\^2 + \
z\^2\)\ Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(12.322940970607872`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\)\((16.58802556637349`\ \
\((3\ \((x\^2 + y\^2)\)\ z - 2\ z\^3)\)\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ \
\((\(-0.017234019526460444`\)\ r0\^2 + 0.215581313417243`\ \((x\^2 + y\^2 + z\
\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0012581391733403658`\)\ r0\^2 + 0.09442879939898956`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\)\((12.441019174780115`\ \
\((x\^2 + 
            y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((\@\(x\^2 + y\^2 + \
z\^2\)\ \((\(-0.017234019526460444`\)\ r0\^2 + 0.215581313417243`\ \((x\^2 + \
y\^2 + z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0012581391733403658`\)\ r0\^2 + 0.09442879939898956`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\)\((124.41019174780115`\ \
\((x\^2 + y\^2)\)\^2\ z\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ \
\((\(-0.017234019526460444`\)\ r0\^2 + 0.215581313417243`\ \((x\^2 + y\^2 + z\
\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0012581391733403658`\)\ r0\^2 + 0.09442879939898956`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\)\((20.73503195796686`\ \
\((x\^2 + y\^2)\)\^3\ \((\@\(x\^2 + y\^2 + z\^2\)\ \
\((\(-0.017234019526460444`\)\ r0\^2 + 0.215581313417243`\ \((x\^2 + y\^2 + z\
\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0012581391733403658`\)\ r0\^2 + 0.09442879939898956`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(0.4820436953208706`\ \((x\^2 + y\^2 + z\^2)\)\ \
Cos[\(\(1.5707963267948966`\)\(\[InvisibleSpace]\)\) - \(12.566370614390479`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0]\^2\)\/r0\^3\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + 
              z\^2)\)\)\)\((31.4119931862564`\ z\^2\ \((0.21274127679590746`\ \
\@\(x\^2 + y\^2 + z\^2\)\ Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) \
- \(14.06619391285005`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + \
0.01512429574865732`\ r0\ Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) \
- \(14.06619391285005`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], \
"Output"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + 
              z\^2)\)\)\)\((15.7059965931282`\ \((x\^2 + 
            y\^2)\)\ \((0.21274127679590746`\ \@\(x\^2 + y\^2 + z\^2\)\ \
Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(14.06619391285005`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.01512429574865732`\ r0\ \
Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(14.06619391285005`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\)\((14.112846556690327`\ \
\((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((\((\(-0.002524699232190157`\)\ r0\^2 + \
0.2025674811476966`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\
\(\[InvisibleSpace]\)\) - \(15.514603010898883`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + 0.0391697063093515`\ r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(15.514603010898883`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\)\((84.67707934014196`\ \
\((x\^2 + 
            y\^2)\)\ z\^2\ \((\((\(-0.002524699232190157`\)\ r0\^2 + \
0.2025674811476966`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\
\(\[InvisibleSpace]\)\) - \(15.514603010898883`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + 0.0391697063093515`\ r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(15.514603010898883`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\)\((21.16926983503549`\ \
\((x\^2 + y\^2)\)\^2\ \((\((\(-0.002524699232190157`\)\ r0\^2 + \
0.2025674811476966`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\
\(\[InvisibleSpace]\)\) - \(15.514603010898883`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + 0.0391697063093515`\ r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(15.514603010898883`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\)\((21.037307069172908`\ \
\((3\ \((x\^2 + y\^2)\)\ z - 2\ z\^3)\)\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ \
\((\(-0.01015776298606729`\)\ r0\^2 + 0.19395162042753517`\ \((x\^2 + y\^2 + \
z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0006002121422403276`\)\ r0\^2 + 0.06876245355250067`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\)\((15.777980301879683`\ \
\((x\^2 + 
            y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((\@\(x\^2 + y\^2 + \
z\^2\)\ \((\(-0.01015776298606729`\)\ r0\^2 + 0.19395162042753517`\ \((x\^2 + \
y\^2 + z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0006002121422403276`\)\ r0\^2 + 0.06876245355250067`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\)\((157.77980301879683`\ \
\((x\^2 + y\^2)\)\^2\ z\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ \
\((\(-0.01015776298606729`\)\ r0\^2 + 0.19395162042753517`\ \((x\^2 + y\^2 + \
z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0006002121422403276`\)\ r0\^2 + 0.06876245355250067`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\)\((26.29663383646614`\ \
\((x\^2 + y\^2)\)\^3\ \((\@\(x\^2 + y\^2 + z\^2\)\ \((\(-0.01015776298606729`\
\)\ r0\^2 + 0.19395162042753517`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(16.92362128522231`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \((\(-0.0006002121422403276`\)\ r0\^2 + \
0.06876245355250067`\ \((x\^2 + y\^2 + z\^2)\))\)\ Sin[\(\(6.283185307179586`\
\)\(\[InvisibleSpace]\)\) - \(16.92362128522231`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0])\)\^2)\)\)\)], "Output"]
}, Open  ]],

Cell["Thus we have", "Text"],

Cell[BoxData[{
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 0, 0, 
          r0] = \(1\/r0\^3\) \((0.5630360474111934`\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Cos[\(\(1.5707963267948966`\)\(\[InvisibleSpace]\)\
\) - \(3.1415926535897913`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0]\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 1, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((9.441825313230899`\ z\^2\ \
\((0.3764021226965972`\ \@\(x\^2 + y\^2 + z\^2\)\ \
Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(4.493409457909065`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.08376759924116726`\ r0\ \
Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(4.493409457909065`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 1, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((4.720912656615449`\ \((x\^2 + 
                  y\^2)\)\ \((0.3764021226965972`\ \@\(x\^2 + y\^2 + z\^2\)\ \
Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(4.493409457909065`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.08376759924116726`\ r0\ \
Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(4.493409457909065`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 2, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((4.509770315871688`\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \
\((\((\(-0.030016030571366766`\)\ r0\^2 + 0.3323521174464318`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(5.763459196944853`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.1729961674523217`\ \
r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(5.763459196944853`\ \@\
\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 2, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((27.05862189523013`\ \((x\^2 + 
                  y\^2)\)\ z\^2\ \((\((\(-0.030016030571366766`\)\ r0\^2 + \
0.3323521174464318`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\
\(\[InvisibleSpace]\)\) - \(5.763459196944853`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + 0.1729961674523217`\ r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(5.763459196944853`\ \@\
\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 2, 2, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((6.764655473807532`\ \((x\^2 + y\^2)\)\^2\ \((\((\(-0.030016030571366766`\)\
\ r0\^2 + 0.3323521174464318`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(5.763459196944853`\ \@\
\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.1729961674523217`\ r0\ \@\(x\^2 + y\^2 + \
z\^2\)\ Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(5.763459196944853`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 3, 0, 
          r0] = \(1\/\((x\^2 + y\^2 + z\^2)\)\^5\) \((7.180738041514811`\ \
\((3\ \((x\^2 + y\^2)\)\ z - 2\ z\^3)\)\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ \
\((\(-0.09271705851256021`\) + 0.3018323092198434`\ \((x\^2 + y\^2 + z\^2)\))\
\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)] + \((\(-0.013268168394580504`\) + \
0.2591602000689954`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 3, 1, 
          r0] = \(1\/\((x\^2 + y\^2 + z\^2)\)\^5\) \((5.385553531136108`\ \
\((x\^2 + 
                  y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((\@\(x\^2 + y\^2 \
+ z\^2\)\ \((\(-0.09271705851256021`\) + 0.3018323092198434`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
6.987932000503647`\ \@\(x\^2 + y\^2 + z\^2\)] + \((\(-0.013268168394580504`\) \
+ 0.2591602000689954`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 3, 2, 
          r0] = \(1\/\((x\^2 + y\^2 + z\^2)\)\^5\) \((53.85553531136109`\ \
\((x\^2 + y\^2)\)\^2\ z\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ \
\((\(-0.09271705851256021`\) + 0.3018323092198434`\ \((x\^2 + y\^2 + z\^2)\))\
\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)] + \((\(-0.013268168394580504`\) + \
0.2591602000689954`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[1, 3, 3, 
          r0] = \(1\/\((x\^2 + y\^2 + z\^2)\)\^5\) \((8.975922551893515`\ \
\((x\^2 + y\^2)\)\^3\ \((\@\(x\^2 + y\^2 + z\^2\)\ \((\(-0.09271705851256021`\
\) + 0.3018323092198434`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)] + \((\(-0.013268168394580504`\) + \
0.2591602000689954`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - 6.987932000503647`\ \
\@\(x\^2 + y\^2 + z\^2\)])\)\^2)\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 0, 0, 
          r0] = \(1\/r0\^3\) \((0.4963228357196234`\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Cos[\(\(1.5707963267948966`\)\(\[InvisibleSpace]\)\
\) - \(6.283185307179585`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0]\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 1, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((16.962502900061462`\ z\^2\ \
\((0.28706730919827866`\ \@\(x\^2 + y\^2 + z\^2\)\ Cos[\(\(3.141592653589793`\
\)\(\[InvisibleSpace]\)\) - \(7.725251836937706`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + 0.03715960531224213`\ r0\ Sin[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(7.725251836937706`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 1, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((8.481251450030731`\ \((x\^2 + 
                  y\^2)\)\ \((0.28706730919827866`\ \@\(x\^2 + y\^2 + z\^2\)\ \
Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(7.725251836937706`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.03715960531224213`\ r0\ \
Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(7.725251836937706`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 2, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((7.850515282898902`\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \
\((\((\(-0.00959518174141225`\)\ r0\^2 + 0.2645686853222971`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(9.09501133069512`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.08726828665822337`\ \
r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(9.09501133069512`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 2, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((47.10309169739341`\ \((x\^2 + 
                  y\^2)\)\ z\^2\ \((\((\(-0.00959518174141225`\)\ r0\^2 + \
0.2645686853222971`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\
\(\[InvisibleSpace]\)\) - \(9.09501133069512`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + 0.08726828665822337`\ r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(9.09501133069512`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 2, 2, 
          
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((11.775772924348352`\ \((x\^2 + y\^2)\)\^2\ \((\((\(-0.00959518174141225`\)\
\ r0\^2 + 0.2645686853222971`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(9.09501133069512`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.08726828665822337`\ r0\ \@\(x\^2 + y\^2 + \
z\^2\)\ Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(9.09501133069512`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 3, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((11.995847465449176`\ \((3\ \((x\^2 + y\^2)\)\ z - 2\ z\^3)\)\^2\ \
\((\@\(x\^2 + y\^2 + z\^2\)\ \((\(-0.034171363187267656`\)\ r0\^2 + \
0.24721012729596964`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(6.283185307179586`\
\)\(\[InvisibleSpace]\)\) - \(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\
\/r0] + r0\ \((\(-0.0032803085643514102`\)\ r0\^2 + 0.14238685650074237`\ \
\((x\^2 + y\^2 + z\^2)\))\)\ \
Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(10.417118547512036`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 3, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((8.996885599086882`\ \((x\^2 + 
                  y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((\@\(x\^2 + y\^2 \
+ z\^2\)\ \((\(-0.034171363187267656`\)\ r0\^2 + 0.24721012729596964`\ \
\((x\^2 + y\^2 + z\^2)\))\)\ \
Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \(10.417118547512036`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \((\(-0.0032803085643514102`\)\ r0\^2 + \
0.14238685650074237`\ \((x\^2 + y\^2 + z\^2)\))\)\ Sin[\(\(6.283185307179586`\
\)\(\[InvisibleSpace]\)\) - \(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\
\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 3, 2, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((89.96885599086882`\ \((x\^2 + y\^2)\)\^2\ z\^2\ \((\@\(x\^2 + y\^2 + \
z\^2\)\ \((\(-0.034171363187267656`\)\ r0\^2 + 0.24721012729596964`\ \((x\^2 \
+ y\^2 + z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0032803085643514102`\)\ r0\^2 + 0.14238685650074237`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[2, 3, 3, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((14.994809331811469`\ \((x\^2 + y\^2)\)\^3\ \((\@\(x\^2 + y\^2 + z\^2\)\ \
\((\(-0.034171363187267656`\)\ r0\^2 + 0.24721012729596964`\ \((x\^2 + y\^2 + \
z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0032803085643514102`\)\ r0\^2 + 0.14238685650074237`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(10.417118547512036`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 0, 0, 
          r0] = \(1\/r0\^3\) \((0.4856662084790068`\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Cos[\(\(1.5707963267948966`\)\(\[InvisibleSpace]\)\
\) - \(9.424777960902889`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0]\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 1, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((24.231131639907577`\ z\^2\ \
\((0.2416265857850596`\ \@\(x\^2 + y\^2 + z\^2\)\ \
Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(10.90412165949781`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.022159197533768875`\ r0\ \
Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(10.90412165949781`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 1, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((12.115565819953789`\ \((x\^2 + 
                  y\^2)\)\ \((0.2416265857850596`\ \@\(x\^2 + y\^2 + z\^2\)\ \
Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(10.90412165949781`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.022159197533768875`\ r0\ \
Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(10.90412165949781`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 2, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((11.023293658715744`\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \
\((\((\(-0.004490300397068933`\)\ r0\^2 + 0.22729133392011303`\ \((x\^2 + \
y\^2 + z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(12.322940970607872`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.05533370673337756`\
\ r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(12.322940970607872`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 2, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((66.13976195229446`\ \((x\^2 + 
                  y\^2)\)\ z\^2\ \((\((\(-0.004490300397068933`\)\ r0\^2 + \
0.22729133392011303`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(12.322940970607872`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.05533370673337756`\ r0\ \@\(x\^2 + y\^2 + \
z\^2\)\ Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(12.322940970607872`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 2, 2, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((16.534940488073616`\ \((x\^2 + y\^2)\)\^2\ \
\((\((\(-0.004490300397068933`\)\ r0\^2 + 0.22729133392011303`\ \((x\^2 + \
y\^2 + z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(12.322940970607872`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.05533370673337756`\
\ r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(12.322940970607872`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 3, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((16.58802556637349`\ \((3\ \((x\^2 + y\^2)\)\ z - 2\ z\^3)\)\^2\ \
\((\@\(x\^2 + y\^2 + z\^2\)\ \((\(-0.017234019526460444`\)\ r0\^2 + \
0.215581313417243`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\
\(\[InvisibleSpace]\)\) - \(13.698023153276466`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + r0\ \((\(-0.0012581391733403658`\)\ r0\^2 + \
0.09442879939898956`\ \((x\^2 + y\^2 + z\^2)\))\)\ Sin[\(\(6.283185307179586`\
\)\(\[InvisibleSpace]\)\) - \(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\
\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 3, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((12.441019174780115`\ \((x\^2 + 
                  y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((\@\(x\^2 + y\^2 \
+ z\^2\)\ \((\(-0.017234019526460444`\)\ r0\^2 + 0.215581313417243`\ \((x\^2 \
+ y\^2 + z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0012581391733403658`\)\ r0\^2 + 0.09442879939898956`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 3, 2, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((124.41019174780115`\ \((x\^2 + y\^2)\)\^2\ z\^2\ \((\@\(x\^2 + y\^2 + z\^2\
\)\ \((\(-0.017234019526460444`\)\ r0\^2 + 0.215581313417243`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0012581391733403658`\)\ r0\^2 + 0.09442879939898956`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[3, 3, 3, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((20.73503195796686`\ \((x\^2 + y\^2)\)\^3\ \((\@\(x\^2 + y\^2 + z\^2\)\ \((\
\(-0.017234019526460444`\)\ r0\^2 + 0.215581313417243`\ \((x\^2 + y\^2 + \
z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0012581391733403658`\)\ r0\^2 + 0.09442879939898956`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(13.698023153276466`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 0, 0, 
          r0] = \(1\/r0\^3\) \((0.4820436953208706`\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Cos[\(\(1.5707963267948966`\)\(\[InvisibleSpace]\)\
\) - \(12.566370614390479`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0]\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 1, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((31.4119931862564`\ z\^2\ \
\((0.21274127679590746`\ \@\(x\^2 + y\^2 + z\^2\)\ Cos[\(\(3.141592653589793`\
\)\(\[InvisibleSpace]\)\) - \(14.06619391285005`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + 0.01512429574865732`\ r0\ Sin[\(\(3.141592653589793`\)\(\
\[InvisibleSpace]\)\) - \(14.06619391285005`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 1, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + 
                    z\^2)\)\)\) \((15.7059965931282`\ \((x\^2 + 
                  y\^2)\)\ \((0.21274127679590746`\ \@\(x\^2 + y\^2 + z\^2\)\ \
Cos[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(14.06619391285005`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.01512429574865732`\ r0\ \
Sin[\(\(3.141592653589793`\)\(\[InvisibleSpace]\)\) - \(14.06619391285005`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 2, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((14.112846556690327`\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \
\((\((\(-0.002524699232190157`\)\ r0\^2 + 0.2025674811476966`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(15.514603010898883`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.0391697063093515`\ \
r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(15.514603010898883`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 2, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((84.67707934014196`\ \((x\^2 + 
                  y\^2)\)\ z\^2\ \((\((\(-0.002524699232190157`\)\ r0\^2 + \
0.2025674811476966`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(4.71238898038469`\)\
\(\[InvisibleSpace]\)\) - \(15.514603010898883`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + 0.0391697063093515`\ r0\ \@\(x\^2 + y\^2 + z\^2\)\ \
Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(15.514603010898883`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 2, 2, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^3\)\) \
\((21.16926983503549`\ \((x\^2 + y\^2)\)\^2\ \((\((\(-0.002524699232190157`\)\
\ r0\^2 + 0.2025674811476966`\ \((x\^2 + y\^2 + z\^2)\))\)\ \
Cos[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \(15.514603010898883`\ \
\@\(x\^2 + y\^2 + z\^2\)\)\/r0] + 0.0391697063093515`\ r0\ \@\(x\^2 + y\^2 + \
z\^2\)\ Sin[\(\(4.71238898038469`\)\(\[InvisibleSpace]\)\) - \
\(15.514603010898883`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 3, 0, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((21.037307069172908`\ \((3\ \((x\^2 + y\^2)\)\ z - 2\ z\^3)\)\^2\ \
\((\@\(x\^2 + y\^2 + z\^2\)\ \((\(-0.01015776298606729`\)\ r0\^2 + \
0.19395162042753517`\ \((x\^2 + y\^2 + z\^2)\))\)\ Cos[\(\(6.283185307179586`\
\)\(\[InvisibleSpace]\)\) - \(16.92362128522231`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0] + r0\ \((\(-0.0006002121422403276`\)\ r0\^2 + \
0.06876245355250067`\ \((x\^2 + y\^2 + z\^2)\))\)\ Sin[\(\(6.283185307179586`\
\)\(\[InvisibleSpace]\)\) - \(16.92362128522231`\ \@\(x\^2 + y\^2 + \
z\^2\)\)\/r0])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 3, 1, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((15.777980301879683`\ \((x\^2 + 
                  y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((\@\(x\^2 + y\^2 \
+ z\^2\)\ \((\(-0.01015776298606729`\)\ r0\^2 + 0.19395162042753517`\ \((x\^2 \
+ y\^2 + z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0006002121422403276`\)\ r0\^2 + 0.06876245355250067`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 3, 2, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((157.77980301879683`\ \((x\^2 + y\^2)\)\^2\ z\^2\ \((\@\(x\^2 + y\^2 + z\^2\
\)\ \((\(-0.01015776298606729`\)\ r0\^2 + 0.19395162042753517`\ \((x\^2 + \
y\^2 + z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0006002121422403276`\)\ r0\^2 + 0.06876245355250067`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Rotat, Cart\)[4, 3, 3, 
          r0] = \(1\/\(r0\^3\ \((x\^2 + y\^2 + z\^2)\)\^5\)\) \
\((26.29663383646614`\ \((x\^2 + y\^2)\)\^3\ \((\@\(x\^2 + y\^2 + z\^2\)\ \((\
\(-0.01015776298606729`\)\ r0\^2 + 0.19395162042753517`\ \((x\^2 + y\^2 + \
z\^2)\))\)\ Cos[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0] + r0\ \
\((\(-0.0006002121422403276`\)\ r0\^2 + 0.06876245355250067`\ \((x\^2 + y\^2 \
+ z\^2)\))\)\ Sin[\(\(6.283185307179586`\)\(\[InvisibleSpace]\)\) - \
\(16.92362128522231`\ \@\(x\^2 + y\^2 + z\^2\)\)\/r0])\)\^2)\);\)\)}], "Input"],

Cell["", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1016, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.25,
StyleDefinitions -> "Classroom1.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 248, 8, 93, "Subtitle"],
Cell[2521, 82, 149, 4, 97, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2695, 90, 152, 5, 85, "Section"],
Cell[2850, 97, 260, 7, 57, "Text"],
Cell[3113, 106, 62, 1, 63, "Input"],
Cell[3178, 109, 162, 5, 56, "Text"],
Cell[3343, 116, 276, 12, 90, "NumberedEquation"],
Cell[3622, 130, 137, 4, 56, "Text"],
Cell[3762, 136, 142, 2, 53, "NumberedEquation"],
Cell[3907, 140, 342, 12, 56, "Text"],
Cell[4252, 154, 253, 6, 80, "Text"],

Cell[CellGroupData[{
Cell[4530, 164, 7480, 124, 5476, "Input"],
Cell[12013, 290, 181, 3, 51, "Message"]
}, Open  ]],
Cell[12209, 296, 280, 6, 80, "Text"],
Cell[12492, 304, 1382, 29, 649, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13911, 338, 173, 3, 119, "Section"],
Cell[14087, 343, 149, 3, 56, "Text"],
Cell[14239, 348, 187, 3, 54, "NumberedEquation"],

Cell[CellGroupData[{
Cell[14451, 355, 106, 5, 89, "Subsection"],

Cell[CellGroupData[{
Cell[14582, 364, 310, 6, 139, "Input"],
Cell[14895, 372, 208, 3, 106, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15140, 380, 310, 6, 139, "Input"],
Cell[15453, 388, 436, 7, 244, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15926, 400, 310, 6, 139, "Input"],
Cell[16239, 408, 460, 7, 244, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16736, 420, 310, 6, 139, "Input"],
Cell[17049, 428, 517, 7, 261, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17603, 440, 310, 6, 139, "Input"],
Cell[17916, 448, 523, 8, 261, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18476, 461, 310, 6, 139, "Input"],
Cell[18789, 469, 507, 7, 261, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19333, 481, 310, 6, 139, "Input"],
Cell[19646, 489, 555, 8, 210, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20238, 502, 310, 6, 139, "Input"],
Cell[20551, 510, 573, 8, 210, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21161, 523, 310, 6, 139, "Input"],
Cell[21474, 531, 539, 8, 210, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22050, 544, 276, 6, 139, "Input"],
Cell[22329, 552, 533, 8, 210, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[22911, 566, 106, 5, 89, "Subsection"],

Cell[CellGroupData[{
Cell[23042, 575, 310, 6, 139, "Input"],
Cell[23355, 583, 207, 3, 106, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23599, 591, 310, 6, 139, "Input"],
Cell[23912, 599, 438, 7, 244, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24387, 611, 310, 6, 139, "Input"],
Cell[24700, 619, 461, 7, 244, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25198, 631, 310, 6, 139, "Input"],
Cell[25511, 639, 515, 7, 261, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26063, 651, 310, 6, 139, "Input"],
Cell[26376, 659, 521, 8, 261, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26934, 672, 310, 6, 139, "Input"],
Cell[27247, 680, 506, 7, 261, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27790, 692, 310, 6, 139, "Input"],
Cell[28103, 700, 607, 8, 310, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28747, 713, 310, 6, 139, "Input"],
Cell[29060, 721, 626, 9, 322, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29723, 735, 310, 6, 139, "Input"],
Cell[30036, 743, 590, 8, 310, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30663, 756, 276, 6, 139, "Input"],
Cell[30942, 764, 585, 8, 310, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[31576, 778, 106, 5, 89, "Subsection"],

Cell[CellGroupData[{
Cell[31707, 787, 310, 6, 139, "Input"],
Cell[32020, 795, 207, 3, 106, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32264, 803, 310, 6, 139, "Input"],
Cell[32577, 811, 438, 7, 244, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33052, 823, 310, 6, 139, "Input"],
Cell[33365, 831, 462, 7, 244, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33864, 843, 310, 6, 139, "Input"],
Cell[34177, 851, 522, 7, 261, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[34736, 863, 310, 6, 139, "Input"],
Cell[35049, 871, 527, 8, 261, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35613, 884, 310, 6, 139, "Input"],
Cell[35926, 892, 512, 7, 261, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36475, 904, 310, 6, 139, "Input"],
Cell[36788, 912, 604, 8, 310, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37429, 925, 310, 6, 139, "Input"],
Cell[37742, 933, 625, 9, 310, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38404, 947, 310, 6, 139, "Input"],
Cell[38717, 955, 589, 8, 310, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[39343, 968, 276, 6, 139, "Input"],
Cell[39622, 976, 582, 8, 310, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[40253, 990, 106, 5, 89, "Subsection"],

Cell[CellGroupData[{
Cell[40384, 999, 310, 6, 139, "Input"],
Cell[40697, 1007, 208, 3, 106, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[40942, 1015, 310, 6, 139, "Input"],
Cell[41255, 1023, 436, 7, 244, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41728, 1035, 310, 6, 139, "Input"],
Cell[42041, 1043, 460, 7, 244, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[42538, 1055, 310, 6, 139, "Input"],
Cell[42851, 1063, 520, 7, 261, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43408, 1075, 310, 6, 139, "Input"],
Cell[43721, 1083, 525, 8, 261, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[44283, 1096, 310, 6, 139, "Input"],
Cell[44596, 1104, 509, 7, 261, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[45142, 1116, 310, 6, 139, "Input"],
Cell[45455, 1124, 604, 8, 310, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[46096, 1137, 310, 6, 139, "Input"],
Cell[46409, 1145, 624, 9, 322, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47070, 1159, 310, 6, 139, "Input"],
Cell[47383, 1167, 588, 8, 310, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[48008, 1180, 276, 6, 139, "Input"],
Cell[48287, 1188, 581, 8, 310, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[48929, 1203, 150, 3, 119, "Section"],
Cell[49082, 1208, 87, 2, 56, "Text"],

Cell[CellGroupData[{
Cell[49194, 1214, 2486, 43, 1153, "Input"],
Cell[51683, 1259, 208, 3, 106, "Output"],
Cell[51894, 1264, 436, 7, 244, "Output"],
Cell[52333, 1273, 460, 7, 244, "Output"],
Cell[52796, 1282, 517, 7, 261, "Output"],
Cell[53316, 1291, 523, 8, 261, "Output"],
Cell[53842, 1301, 507, 7, 261, "Output"],
Cell[54352, 1310, 555, 8, 210, "Output"],
Cell[54910, 1320, 573, 8, 210, "Output"],
Cell[55486, 1330, 539, 8, 210, "Output"],
Cell[56028, 1340, 533, 8, 210, "Output"],
Cell[56564, 1350, 207, 3, 106, "Output"],
Cell[56774, 1355, 438, 7, 244, "Output"],
Cell[57215, 1364, 461, 7, 244, "Output"],
Cell[57679, 1373, 515, 7, 261, "Output"],
Cell[58197, 1382, 521, 8, 261, "Output"],
Cell[58721, 1392, 506, 7, 261, "Output"],
Cell[59230, 1401, 607, 8, 310, "Output"],
Cell[59840, 1411, 626, 9, 322, "Output"],
Cell[60469, 1422, 590, 8, 310, "Output"],
Cell[61062, 1432, 585, 8, 310, "Output"],
Cell[61650, 1442, 207, 3, 106, "Output"],
Cell[61860, 1447, 438, 7, 244, "Output"],
Cell[62301, 1456, 462, 7, 244, "Output"],
Cell[62766, 1465, 522, 7, 261, "Output"],
Cell[63291, 1474, 527, 8, 261, "Output"],
Cell[63821, 1484, 512, 7, 261, "Output"],
Cell[64336, 1493, 604, 8, 310, "Output"],
Cell[64943, 1503, 625, 9, 310, "Output"],
Cell[65571, 1514, 589, 8, 310, "Output"],
Cell[66163, 1524, 582, 8, 310, "Output"],
Cell[66748, 1534, 208, 3, 106, "Output"],
Cell[66959, 1539, 436, 7, 244, "Output"],
Cell[67398, 1548, 460, 7, 244, "Output"],
Cell[67861, 1557, 520, 7, 261, "Output"],
Cell[68384, 1566, 525, 8, 261, "Output"],
Cell[68912, 1576, 509, 7, 261, "Output"],
Cell[69424, 1585, 604, 8, 310, "Output"],
Cell[70031, 1595, 624, 9, 322, "Output"],
Cell[70658, 1606, 588, 8, 310, "Output"],
Cell[71249, 1616, 581, 8, 310, "Output"]
}, Open  ]],
Cell[71845, 1627, 28, 0, 56, "Text"],
Cell[71876, 1629, 22740, 356, 15083, "Input"],
Cell[94619, 1987, 16, 0, 56, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

