(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     84396,       1721]*)
(*NotebookOutlinePosition[     85125,       1746]*)
(*  CellTagsIndexPosition[     85081,       1742]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Part ",
    FontWeight->"Bold"],
  StyleBox["2. Quantum Isotropic Oscillator",
    FontWeight->"Bold"],
  "\n2.1. One-Dimensional Isotropic Quantum Oscillator"
}], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
2.1.3. Visualization of the Wave Functions and Probability Densities of the \
One-Dimensional Quantum Oscillator\
\>", "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
1. Normalized wave functions and probability densities of the one-dimensional \
quantum oscillator\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[StyleBox["In this file we will present visualizations in \
individual scales for states defined by given quantum numbers.",
  FontWeight->"Bold"]], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Consider some states of the one-dimensional quantum oscillator defined by \
quantum numbers:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["n = 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10", "NumberedEquation"],

Cell[TextData[{
  "We will use \"",
  StyleBox["Graphics`FilledPlot`",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  "\" tool in this part to give vivid presentation of functions."
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(<< Graphics`FilledPlot`\)], "Input"],

Cell["\<\
Determine parameter \[Lambda] of the one-dimensional quantum oscillator:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(\(\(\[Lambda] = 1;\)\(\ \)\)\)], "Input"],

Cell["\<\
Normalized wave functions and radial probability densities of the \
one-dimensional quantum oscillator for given quantum numbers (1) are:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["Normalized wave functions:", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(\[Psi][
          0, \[Lambda]] = \(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ \
\[Lambda]\^\(1/4\)\)\/\[Pi]\^\(1/4\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi][
          1, \[Lambda]] = \(\@2\ \[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\
\)\)\ x\ \[Lambda]\^\(3/4\)\)\/\[Pi]\^\(1/4\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi][
          2, \[Lambda]] = \(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ \
\[Lambda]\^\(1/4\)\ \((\(-1\) + 2\ x\^2\ \[Lambda])\)\)\/\(\@2\ \
\[Pi]\^\(1/4\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi][
          3, \[Lambda]] = \(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ \
x\ \[Lambda]\^\(3/4\)\ \((\(-3\) + 2\ x\^2\ \[Lambda])\)\)\/\(\@3\ \
\[Pi]\^\(1/4\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi][
          4, \[Lambda]] = \(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ \
\[Lambda]\^\(1/4\)\ \((3 + 4\ x\^2\ \[Lambda]\ \((\(-3\) + x\^2\ \
\[Lambda])\))\)\)\/\(2\ \@6\ \[Pi]\^\(1/4\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi][
          5, \[Lambda]] = \(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ \
x\ \[Lambda]\^\(3/4\)\ \((15 + 4\ x\^2\ \[Lambda]\ \((\(-5\) + x\^2\ \
\[Lambda])\))\)\)\/\(2\ \@15\ \[Pi]\^\(1/4\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi][
          6, \[Lambda]] = \(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ \
\[Lambda]\^\(1/4\)\ \((\(-15\) + 90\ x\^2\ \[Lambda] - 60\ x\^4\ \[Lambda]\^2 \
+ 8\ x\^6\ \[Lambda]\^3)\)\)\/\(12\ \@5\ \[Pi]\^\(1/4\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi][
          7, \[Lambda]] = \(\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ \
x\ \[Lambda]\^\(3/4\)\ \((\(-105\) + 210\ x\^2\ \[Lambda] - 84\ x\^4\ \
\[Lambda]\^2 + 8\ x\^6\ \[Lambda]\^3)\)\)\/\(6\ \@70\ \[Pi]\^\(1/4\)\);\)\), \
"\[IndentingNewLine]", 
    \(\(\[Psi][
          8, \[Lambda]] = \(1\/\(24\ \@70\ \[Pi]\^\(1/4\)\)\) \((\
\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ \[Lambda]\^\(1/4\)\ \((105 \
+ 8\ x\^2\ \[Lambda]\ \((\(-105\) + 
                        x\^2\ \[Lambda]\ \((105 + 
                              2\ x\^2\ \[Lambda]\ \((\(-14\) + 
                                    x\^2\ \[Lambda])\))\))\))\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi][
          9, \[Lambda]] = \(1\/\(72\ \@35\ \[Pi]\^\(1/4\)\)\) \((\
\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ x\ \[Lambda]\^\(3/4\)\ \
\((945 + 8\ x\^2\ \[Lambda]\ \((\(-315\) + 
                        x\^2\ \[Lambda]\ \((189 + 
                              2\ x\^2\ \[Lambda]\ \((\(-18\) + 
                                    x\^2\ \[Lambda])\))\))\))\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi][
          10, \[Lambda]] = \(1\/\(720\ \@7\ \[Pi]\^\(1/4\)\)\) \((\
\[ExponentialE]\^\(-\(\(x\^2\ \[Lambda]\)\/2\)\)\ \[Lambda]\^\(1/4\)\ \
\((\(-945\) + 2\ x\^2\ \[Lambda]\ \((4725 + 
                        4\ x\^2\ \[Lambda]\ \((\(-1575\) + 
                              2\ x\^2\ \[Lambda]\ \((315 + 
                                    x\^2\ \[Lambda]\ \((\(-45\) + 
                                        2\ x\^2\ \[Lambda])\))\))\))\))\))\);\
\)\)}], "Input"],

Cell["Probability densities:", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(\[Psi]\[Psi][
          0, \[Lambda]]\  = \(\[ExponentialE]\^\(\(-x\^2\)\ \[Lambda]\)\ \@\
\[Lambda]\)\/\@\[Pi];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi][
          1, \[Lambda]]\  = \(2\ \[ExponentialE]\^\(\(-x\^2\)\ \[Lambda]\)\ x\
\^2\ \[Lambda]\^\(3/2\)\)\/\@\[Pi];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi][
          2, \[Lambda]]\  = \(\[ExponentialE]\^\(\(-x\^2\)\ \[Lambda]\)\ \@\
\[Lambda]\ \((\(-1\) + 2\ x\^2\ \[Lambda])\)\^2\)\/\(2\ \@\[Pi]\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi][
          3, \[Lambda]]\  = \(\[ExponentialE]\^\(\(-x\^2\)\ \[Lambda]\)\ x\^2\
\ \[Lambda]\^\(3/2\)\ \((\(-3\) + 2\ x\^2\ \[Lambda])\)\^2\)\/\(3\ \@\[Pi]\);\
\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi][
          4, \[Lambda]]\  = \(\[ExponentialE]\^\(\(-x\^2\)\ \[Lambda]\)\ \@\
\[Lambda]\ \((3 + 4\ x\^2\ \[Lambda]\ \((\(-3\) + x\^2\ \
\[Lambda])\))\)\^2\)\/\(24\ \@\[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi][
          5, \[Lambda]]\  = \(\[ExponentialE]\^\(\(-x\^2\)\ \[Lambda]\)\ x\^2\
\ \[Lambda]\^\(3/2\)\ \((15 + 4\ x\^2\ \[Lambda]\ \((\(-5\) + x\^2\ \
\[Lambda])\))\)\^2\)\/\(60\ \@\[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi][
          6, \[Lambda]]\  = \(\[ExponentialE]\^\(\(-x\^2\)\ \[Lambda]\)\ \@\
\[Lambda]\ \((\(-15\) + 90\ x\^2\ \[Lambda] - 60\ x\^4\ \[Lambda]\^2 + 8\ \
x\^6\ \[Lambda]\^3)\)\^2\)\/\(720\ \@\[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi][
          7, \[Lambda]]\  = \(\[ExponentialE]\^\(\(-x\^2\)\ \[Lambda]\)\ x\^2\
\ \[Lambda]\^\(3/2\)\ \((\(-105\) + 210\ x\^2\ \[Lambda] - 84\ x\^4\ \
\[Lambda]\^2 + 8\ x\^6\ \[Lambda]\^3)\)\^2\)\/\(2520\ \@\[Pi]\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi][
          8, \[Lambda]]\  = \(\[ExponentialE]\^\(\(-x\^2\)\ \[Lambda]\)\ \@\
\[Lambda]\ \((105 + 8\ x\^2\ \[Lambda]\ \((\(-105\) + x\^2\ \[Lambda]\ \((105 \
+ 2\ x\^2\ \[Lambda]\ \((\(-14\) + x\^2\ \[Lambda])\))\))\))\)\^2\)\/\(40320\ \
\@\[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi][
          9, \[Lambda]]\  = \(\[ExponentialE]\^\(\(-x\^2\)\ \[Lambda]\)\ x\^2\
\ \[Lambda]\^\(3/2\)\ \((945 + 8\ x\^2\ \[Lambda]\ \((\(-315\) + x\^2\ \
\[Lambda]\ \((189 + 2\ x\^2\ \[Lambda]\ \((\(-18\) + x\^2\ \
\[Lambda])\))\))\))\)\^2\)\/\(181440\ \@\[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi][
          10, \[Lambda]]\  = \(1\/\(3628800\ \@\[Pi]\)\) \((\[ExponentialE]\^\
\(\(-x\^2\)\ \[Lambda]\)\ \@\[Lambda]\ \((\(-945\) + 2\ x\^2\ \[Lambda]\ \
\((4725 + 4\ x\^2\ \[Lambda]\ \((\(-1575\) + 2\ x\^2\ \[Lambda]\ \((315 + \
x\^2\ \[Lambda]\ \((\(-45\) + 2\ x\^2\ \[Lambda])\))\))\))\))\)\^2)\);\)\)}], \
"Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "2. ",
  StyleBox["Visualization ",
    TextAlignment->Left,
    TextJustification->0],
  "of the wave functions and radial probability densities of the \
one-dimensional quantum oscillator"
}], "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Now we present plots of  the wave functions and probability densities of the \
one-dimensional quantum oscillator.
We will obtain two-dimensional plots for functions and probability densities \
and present surface (three-dimensional) profile for probability densities.\
\>", "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox["Parameters of Plots:",
    FontWeight->"Bold"],
  "\n",
  StyleBox["2d Plots",
    FontWeight->"Bold"],
  "\n\t\tVariable Range: {x2dMin, x2dMax}\n\t\tPlot Range for 2d Plots: \
{PR2dMin, PR2dMax}\n\t\tImage Size for 2d Plots: {IS2dHorz, IS2dVert}\n\n",
  StyleBox["3d Plots",
    FontWeight->"Bold"],
  "\n\t\tVariable Range: {x3dMin, x3dMax, y3dMin, y3dMax}\n\t\tPlot Range for \
3d Plots: {PR3dMin, PR3dMax}\n\t\tPlot Points for 3d Plots: {N3d}\n\t\tImage \
Size for 3d Plots: {IS3DHorz, IS3DVert}\n\t\tViewPoint for 3d Plots: {VP1, \
VP2, VP3} or {WP1, WP2, WP3}"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(IS2dHorz = 425;\)\), "\[IndentingNewLine]", 
    \(\(\(IS2dVert = 250;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(IS3dHorz = 425;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 250;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(VP1 = 0.000;\)\), "\[IndentingNewLine]", 
    \(\(VP2 = \(-1.825\);\)\), "\[IndentingNewLine]", 
    \(\(\(VP3 = 1.25;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WP1 = \(-0.5\);\)\), "\[IndentingNewLine]", 
    \(\(WP2 = \(-3\);\)\), "\[IndentingNewLine]", 
    \(\(\(WP3 = 1.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(AR = 1/2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(N3dIn = 75;\)\)}], "Input"],

Cell[CellGroupData[{

Cell[TextData[{
  "1) ",
  Cell[BoxData[
      \(n\)],
    FontSlant->"Italic"],
  " = 0"
}], "Subsection"],

Cell[BoxData[{
    \(\ \(\(n = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(N3d = N3dIn + n\ 10;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = \(-3.5\);\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 3.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.05\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.775;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-3\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 3;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-3\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.6;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1d\[Psi]\[Psi]\_Oscl[n, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{\[Psi][n, \[Lambda]], \[Psi]\[Psi][
              n, \[Lambda]]}, \[IndentingNewLine]{x, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] "\<Wave functions for  n \
=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n, \ \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi][n, \[Lambda]]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n, \ \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n, \ \[Lambda]], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] "\<3D vision for \
 n=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n, \ \[Lambda], x3dMin, x3dMax, 
        y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
        VP3, N3d] = 
      DensityPlot[\[Psi]\[Psi][n, \ \[Lambda]], \[IndentingNewLine]{x, 
          x3dMin, x3dMax}, {y, y3dMin, 
          y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
          N3d, \[IndentingNewLine]Mesh -> 
          False, \[IndentingNewLine]Axes \[Rule] 
          False, \[IndentingNewLine]Background \[Rule] 
          GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
          GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
          AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
            IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] "\<3D vision for  \
n=0\>"]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n, \ \[Lambda], x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[\[Psi]\[Psi][n, \ \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {WP1, \ 
              WP2, \ WP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[1, 0, 1]}, {{0.`, 1.`, 2.`}, 
                RGBColor[1, 1, 
                  1]}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] "\<3D vision \
for  n=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph1d\[Psi]\[Psi]\_Oscl[n, \ \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n, \ \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, {Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n, \ \[Lambda], x3dMin, 
              x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
              VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[
              n, \ \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {750, 
          400}, \[IndentingNewLine]PlotLabel \[Rule] "\<Presentation of wave \
function for n=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "2) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 0, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 1"
}], "Subsection"],

Cell[BoxData[{
    \(\ \(\(n = 1\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(N3d = N3dIn + n\ 10;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = \(-3.5\);\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 3.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.655\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.655;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-3\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 3;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-3\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.44;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1d\[Psi]\[Psi]\_Oscl[n, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{\[Psi][n, \[Lambda]], \[Psi]\[Psi][
              n, \[Lambda]]}, \[IndentingNewLine]{x, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] "\<Wave functions for  \
n=1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n, \ \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi][n, \[Lambda]]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n, \ \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n, \ \[Lambda]], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] "\<3D vision for \
 n=1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
            RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
            RGBColor[0, 1, 0]}, {{0.`, 1.`, 1.`}, 
            RGBColor[0, 0, 1]}};\)\), "\[IndentingNewLine]", 
    \(\(\(ViewPoint -> {\(-1.262\), \ \(-5.864\), \ 
          5.458};\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n, \ \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi][n, \ \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] "\<3D vision \
for  n=1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n, \ \[Lambda], x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[\[Psi]\[Psi][n, \ \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {WP1, \ 
              WP2, \ WP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[1, 0, 1]}, {{0.`, 1.`, 2.`}, 
                RGBColor[1, 1, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] "\<3D vision for \
 n=1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph1d\[Psi]\[Psi]\_Oscl[n, \ \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n, \ \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, {Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n, \ \[Lambda], x3dMin, 
              x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
              VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[
              n, \ \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {750, 
          400}, \[IndentingNewLine]PlotLabel \[Rule] "\<Presentation  of wave \
function for  n=1\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "3) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 0, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 2"
}], "Subsection"],

Cell[BoxData[{
    \(\ \(\(n\  = 2\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(N3d = N3dIn + n\ 10;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = \(-3.5\);\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 3.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.655\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.655;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-3\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 3;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-3\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.4;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1d\[Psi]\[Psi]\_Oscl[n, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{\[Psi][n, \[Lambda]], \[Psi]\[Psi][
              n, \[Lambda]]}, \[IndentingNewLine]{x, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] "\<Wave functions for  \
n=2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n, \ \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi][n, \[Lambda]]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n, \ \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n, \ \[Lambda]], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] "\<3D vision for \
 n=2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n, \ \[Lambda], x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = DensityPlot[\[Psi]\[Psi][
            n, \ \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] "\<3D vision \
for  n=2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n, \ \[Lambda], x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[\[Psi]\[Psi][n, \ \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {WP1, \ 
              WP2, \ WP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[1, 0, 1]}, {{0.`, 1.`, 2.`}, 
                RGBColor[1, 1, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] "\<3D vision for \
 n=2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph1d\[Psi]\[Psi]\_Oscl[n, \ \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n, \ \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, {Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n, \ \[Lambda], x3dMin, 
              x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
              VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[
              n, \ \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {750, 
          400}, \[IndentingNewLine]PlotLabel \[Rule] "\<Presentation  of wave \
function for  n=2\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "4) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 0, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[BoxData[{
    \(\ \(\(n\  = 3\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(N3d = N3dIn + n\ 10;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = \(-4\);\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 4;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.655\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.655;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-3.5\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 3.5;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-3.5\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 3.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.4;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1d\[Psi]\[Psi]\_Oscl[n, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{\[Psi][n, \[Lambda]], \[Psi]\[Psi][
              n, \[Lambda]]}, \[IndentingNewLine]{x, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] "\<Wave functions for  \
n=3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n, \ \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi][n, \[Lambda]]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n, \ \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n, \ \[Lambda]], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] "\<3D vision for \
 n=3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n, \ \[Lambda], x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = DensityPlot[\[Psi]\[Psi][
            n, \ \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] "\<3D vision \
for  n=3\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n, \ \[Lambda], x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[\[Psi]\[Psi][n, \ \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {WP1, \ 
              WP2, \ WP3}, \[IndentingNewLine]AspectRatio \[Rule]  .5, \
\[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[1, 0, 1]}, {{0.`, 1.`, 2.`}, RGBColor[1, 1, 1]}}, 
          ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] "\<3D vision \
for  n=3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph1d\[Psi]\[Psi]\_Oscl[n, \ \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n, \ \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, {Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n, \ \[Lambda], x3dMin, 
              x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
              VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[
              n, \ \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {750, 
          400}, \[IndentingNewLine]PlotLabel \[Rule] "\<Presentation  of wave \
function for  n=3\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "5) ",
  Cell[BoxData[
      \(n\)],
    FontSlant->"Italic"],
  " = 4"
}], "Subsection"],

Cell[BoxData[{
    \(\ \(\(n\  = 4\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(N3d = N3dIn + n\ 10;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = \(-4.5\);\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 4.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.5\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.6;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-4\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 4;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.375;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1d\[Psi]\[Psi]\_Oscl[n, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{\[Psi][n, \[Lambda]], \[Psi]\[Psi][
              n, \[Lambda]]}, \[IndentingNewLine]{x, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] "\<Wave functions for  \
n=4\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n, \ \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi][n, \[Lambda]]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n, \ \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n, \ \[Lambda]], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] "\<3D vision for \
 n=4\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n, \ \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi][n, \ \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] "\<3D vision \
for  n=4\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n, \ \[Lambda], x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[\[Psi]\[Psi][n, \ \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {WP1, \ 
              WP2, \ WP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[1, 0, 1]}, {{0.`, 1.`, 2.`}, 
                RGBColor[1, 1, 
                  1]}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] "\<3D vision \
for  n=4\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph1d\[Psi]\[Psi]\_Oscl[n, \ \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n, \ \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, {Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n, \ \[Lambda], x3dMin, 
              x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
              VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[
              n, \ \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {750, 
          400}, \[IndentingNewLine]PlotLabel \[Rule] "\<Presentation  of wave \
function for  n=4\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "6) ",
  Cell[BoxData[
      \(n\)],
    FontSlant->"Italic"],
  " = 5"
}], "Subsection"],

Cell[BoxData[{
    \(\ \(\(n = 5\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(N3d = N3dIn + n\ 10;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = \(-4.5\);\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 4.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.6\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.6;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-4\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 4;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.35;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1d\[Psi]\[Psi]\_Oscl[n, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{\[Psi][n, \[Lambda]], \[Psi]\[Psi][
              n, \[Lambda]]}, \[IndentingNewLine]{x, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] "\<Wave functions for  \
n=5\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n, \ \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi][n, \[Lambda]]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n, \ \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n, \ \[Lambda]], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] "\<3D vision for \
 n=5\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n, \ \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi][n, \ \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] "\<3D vision \
for  n=5\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n, \ \[Lambda], x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[\[Psi]\[Psi][n, \ \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {WP1, \ 
              WP2, \ WP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[1, 0, 1]}, {{0.`, 1.`, 2.`}, 
                RGBColor[1, 1, 
                  1]}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] "\<3D vision \
for  n=5\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph1d\[Psi]\[Psi]\_Oscl[n, \ \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n, \ \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, {Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n, \ \[Lambda], x3dMin, 
              x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
              VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[
              n, \ \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {750, 
          400}, \[IndentingNewLine]PlotLabel \[Rule] "\<Presentation  of wave \
function for  n=5\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "7) ",
  Cell[BoxData[
      \(n\)],
    FontSlant->"Italic"],
  " = 6"
}], "Subsection"],

Cell[BoxData[{
    \(\ \(\(n\  = 6\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(N3d = N3dIn + n\ 10;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = \(-5\);\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.47\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.58;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4.5\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4.5;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-4.5\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 4.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.35;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1d\[Psi]\[Psi]\_Oscl[n, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{\[Psi][n, \[Lambda]], \[Psi]\[Psi][
              n, \[Lambda]]}, \[IndentingNewLine]{x, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] "\<Wave functions for  \
n=6\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n, \ \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi][n, \[Lambda]]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n, \ \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n, \ \[Lambda]], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] "\<3D vision for \
 n=6\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n, \ \[Lambda], x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = DensityPlot[\[Psi]\[Psi][
            n, \ \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] "\<3D vision \
for  n=6\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n, \ \[Lambda], x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[\[Psi]\[Psi][n, \ \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {WP1, \ 
              WP2, \ WP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[1, 0, 1]}, {{0.`, 1.`, 2.`}, 
                RGBColor[1, 1, 
                  1]}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] "\<3D vision \
for  n=6\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph1d\[Psi]\[Psi]\_Oscl[n, \ \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n, \ \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, {Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n, \ \[Lambda], x3dMin, 
              x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
              VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[
              n, \ \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {750, 
          400}, \[IndentingNewLine]PlotLabel \[Rule] "\<Presentation  of wave \
function for  n=6\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "8) ",
  Cell[BoxData[
      \(n\)],
    FontSlant->"Italic"],
  " = 7"
}], "Subsection"],

Cell[BoxData[{
    \(\ \(\(n\  = 7\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(N3d = N3dIn + n\ 10;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = \(-5\);\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.56\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.56;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4.5\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4.5;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-4.5\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 4.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.34;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1d\[Psi]\[Psi]\_Oscl[n, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{\[Psi][n, \[Lambda]], \[Psi]\[Psi][
              n, \[Lambda]]}, \[IndentingNewLine]{x, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] "\<Wave functions for  \
n=7\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n, \ \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi][n, \[Lambda]]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n, \ \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n, \ \[Lambda]], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] "\<3D vision for \
 n=7\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n, \ \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi][n, \ \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] "\<3D vision \
for  n=7\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n, \ \[Lambda], x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[\[Psi]\[Psi][n, \ \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {WP1, \ 
              WP2, \ WP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[1, 0, 1]}, {{0.`, 1.`, 2.`}, 
                RGBColor[1, 1, 
                  1]}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] "\<3D vision \
for  n=7\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph1d\[Psi]\[Psi]\_Oscl[n, \ \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n, \ \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, {Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n, \ \[Lambda], x3dMin, 
              x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
              VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[
              n, \ \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {750, 
          400}, \[IndentingNewLine]PlotLabel \[Rule] "\<Presentation  of wave \
function for  n=7\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "9) ",
  Cell[BoxData[
      \(n\)],
    FontSlant->"Italic"],
  " = 8"
}], "Subsection"],

Cell[BoxData[{
    \(\ \(\(n\  = 8\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(N3d = N3dIn + n\ 10;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = \(-5.5\);\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 5.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.45\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.56;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-5\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 5;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-5\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.325;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1d\[Psi]\[Psi]\_Oscl[n, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{\[Psi][n, \[Lambda]], \[Psi]\[Psi][
              n, \[Lambda]]}, \[IndentingNewLine]{x, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] "\<Wave functions for  \
n=8\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n, \ \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi][n, \[Lambda]]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n, \ \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n, \ \[Lambda]], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] "\<3D vision for \
 n=8\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n, \ \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi][n, \ \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] "\<3D vision \
for  n=8\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n, \ \[Lambda], x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[\[Psi]\[Psi][n, \ \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {WP1, \ 
              WP2, \ WP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[1, 0, 1]}, {{0.`, 1.`, 2.`}, 
                RGBColor[1, 1, 
                  1]}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] "\<3D vision \
for  n=8\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph1d\[Psi]\[Psi]\_Oscl[n, \ \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n, \ \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, {Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n, \ \[Lambda], x3dMin, 
              x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
              VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[
              n, \ \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {750, 
          400}, \[IndentingNewLine]PlotLabel \[Rule] "\<Presentation  of wave \
function for  n=8\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "10) ",
  Cell[BoxData[
      \(n\)],
    FontSlant->"Italic"],
  " = 9"
}], "Subsection"],

Cell[BoxData[{
    \(\ \(\(n\  = 9\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(N3d = N3dIn + n\ 10;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = \(-5.5\);\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 5.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.55\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.55;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-5\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 5;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-5\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.34;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1d\[Psi]\[Psi]\_Oscl[n, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{\[Psi][n, \[Lambda]], \[Psi]\[Psi][
              n, \[Lambda]]}, \[IndentingNewLine]{x, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] "\<Wave functions for  \
n=9\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n, \ \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi][n, \[Lambda]]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n, \ \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n, \ \[Lambda]], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] "\<3D vision for \
 n=9\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n, \ \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi][n, \ \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] "\<3D vision \
for  n=9\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n, \ \[Lambda], x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[\[Psi]\[Psi][n, \ \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {WP1, \ 
              WP2, \ WP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[1, 0, 1]}, {{0.`, 1.`, 2.`}, 
                RGBColor[1, 1, 
                  1]}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] "\<3D vision \
for  n=9\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph1d\[Psi]\[Psi]\_Oscl[n, \ \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n, \ \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, {Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n, \ \[Lambda], x3dMin, 
              x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
              VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[
              n, \ \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {750, 
          400}, \[IndentingNewLine]PlotLabel \[Rule] "\<Presentation  of wave \
function for  n=9\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "11) ",
  Cell[BoxData[
      \(n\)],
    FontSlant->"Italic"],
  " = 10"
}], "Subsection"],

Cell[BoxData[{
    \(\(\(n\  = 10\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(N3d = N3dIn + n\ 10;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = \(-6\);\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 6;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.45\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.55;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-5.5\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 5.5;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-5.5\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 5.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1d\[Psi]\[Psi]\_Oscl[n, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{\[Psi][n, \[Lambda]], \[Psi]\[Psi][
              n, \[Lambda]]}, \[IndentingNewLine]{x, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[0.01], 
              Thickness[0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] "\<Wave functions for  \
n=10\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n, \ \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi][n, \[Lambda]]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n, \ \[Lambda], x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n, \ \[Lambda]], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] "\<3D vision for \
 n=10\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n, \ \[Lambda], x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = DensityPlot[\[Psi]\[Psi][
            n, \ \[Lambda]], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, 
            y3dMin, y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] "\<3D vision \
for  n=10\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n, \ \[Lambda], x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[\[Psi]\[Psi][n, \ \[Lambda]], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {WP1, \ 
              WP2, \ WP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[1, 0, 1]}, {{0.`, 1.`, 2.`}, 
                RGBColor[1, 1, 
                  1]}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] "\<3D vision \
for  n=10\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph1d\[Psi]\[Psi]\_Oscl[n, \ \[Lambda], x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n, \ \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, {Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n, \ \[Lambda], x3dMin, 
              x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
              VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[
              n, \ \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {750, 
          400}, \[IndentingNewLine]PlotLabel \[Rule] "\<Presentation  of wave \
function for  n=10\>"]\)}], "Input"],

Cell["", "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1016, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.25,
StyleDefinitions -> "Classroom1.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 252, 8, 93, "Subtitle"],
Cell[2525, 82, 192, 5, 124, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2742, 91, 172, 5, 85, "Section"],
Cell[2917, 98, 216, 4, 56, "Text"],
Cell[3136, 104, 163, 5, 56, "Text"],
Cell[3302, 111, 64, 0, 52, "NumberedEquation"],
Cell[3369, 113, 293, 9, 57, "Text"],
Cell[3665, 124, 56, 1, 63, "Input"],
Cell[3724, 127, 143, 4, 56, "Text"],
Cell[3870, 133, 61, 1, 63, "Input"],
Cell[3934, 136, 208, 5, 80, "Text"],
Cell[4145, 143, 89, 2, 56, "Text"],
Cell[4237, 147, 3102, 57, 965, "Input"],
Cell[7342, 206, 85, 2, 56, "Text"],
Cell[7430, 210, 2672, 47, 900, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10139, 262, 270, 9, 119, "Section"],
Cell[10412, 273, 292, 5, 116, "Text"],
Cell[10707, 280, 666, 17, 452, "Text"],
Cell[11376, 299, 775, 17, 463, "Input"],

Cell[CellGroupData[{
Cell[12176, 320, 107, 6, 89, "Subsection"],
Cell[12286, 328, 6344, 113, 2388, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18667, 446, 185, 10, 89, "Subsection"],
Cell[18855, 458, 6714, 120, 2488, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25606, 583, 185, 10, 89, "Subsection"],
Cell[25794, 595, 6371, 112, 2413, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32202, 712, 185, 10, 89, "Subsection"],
Cell[32390, 724, 6321, 111, 2413, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38748, 840, 107, 6, 89, "Subsection"],
Cell[38858, 848, 6370, 113, 2388, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[45265, 966, 107, 6, 89, "Subsection"],
Cell[45375, 974, 6367, 113, 2388, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[51779, 1092, 107, 6, 89, "Subsection"],
Cell[51889, 1100, 6374, 112, 2413, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[58300, 1217, 107, 6, 89, "Subsection"],
Cell[58410, 1225, 6375, 113, 2388, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[64822, 1343, 107, 6, 89, "Subsection"],
Cell[64932, 1351, 6372, 113, 2388, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[71341, 1469, 108, 6, 89, "Subsection"],
Cell[71452, 1477, 6371, 113, 2388, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[77860, 1595, 109, 6, 89, "Subsection"],
Cell[77972, 1603, 6377, 112, 2413, "Input"],
Cell[84352, 1717, 16, 0, 56, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

