(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     11004,        406]*)
(*NotebookOutlinePosition[     11712,        430]*)
(*  CellTagsIndexPosition[     11668,        426]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Part ",
    FontWeight->"Bold"],
  StyleBox["2. Quantum Isotropic Oscillator",
    FontWeight->"Bold"],
  "\n2.2. Two-Dimensional Isotropic Quantum Oscillator"
}], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
2.2.1. Schrodinger Equation for Two-Dimensional Quantum Oscillator\
\>", "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["1. Two-dimensional quantum oscillator", "Section"],

Cell["\<\
Two-dimensional quantum oscillator is particle moving in field with potential \
energy:\
\>", "Text"],

Cell[BoxData[
    \(\(\(V[r] = 1\/2\ r\^2\ \[Omega]\^2\ m\_0\)\(,\)\)\)], "NumberedEquation"],

Cell[TextData[{
  Cell[BoxData[
      \(m\_0\)],
    FontSlant->"Italic"],
  " is mass of oscillating particle, \[Omega] is frequency of oscillations.\n\
That is potential energy of particle ",
  Cell[BoxData[
      RowBox[{
        StyleBox["V",
          FontSlant->"Italic"], 
        StyleBox["[",
          FontSlant->"Italic"], 
        StyleBox["r",
          FontWeight->"Bold",
          FontSlant->"Plain"], 
        StyleBox["]",
          FontSlant->"Italic"]}]]],
  " depends only upon the polar coordinate ",
  Cell[BoxData[
      StyleBox["r",
        FontSlant->"Italic"]]],
  "."
}], "Text"],

Cell["Two-dimensional Schrodinger equation in the central field is", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"\[CapitalDelta]\[Psi]", "[", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], "]"}], "+", 
        RowBox[{\(\(2\ m\_0\)\/\[HBar]\^2\), \((En - V[r])\), 
          RowBox[{"\[Psi]", "[", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], "]"}]}]}], "=", "0"}]], "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      StyleBox["En",
        FontWeight->"Bold"]],
    FontSlant->"Italic"],
  " is total energy of particle, ",
  Cell[BoxData[
      RowBox[{
        StyleBox["\[Psi]",
          FontSlant->"Italic"], 
        StyleBox["[",
          FontSlant->"Italic"], 
        StyleBox["r",
          FontWeight->"Bold",
          FontSlant->"Plain"], 
        StyleBox["]",
          FontSlant->"Italic"]}]]],
  "is ",
  "wave function of particle."
}], "Text"],

Cell["Thus Schrodinger equation is:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"\[CapitalDelta]\[Psi]", "[", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], "]"}], "+", 
        RowBox[{\(\(2\ m\_0\)\/\[HBar]\^2\), \((En - 
              1\/2\ r\^2\ \[Omega]\^2\ m\_0)\), 
          RowBox[{"\[Psi]", "[", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], "]"}]}]}], "=", "0"}]], "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      RowBox[{
        StyleBox["\[Psi]",
          FontSlant->"Italic"], 
        StyleBox["[",
          FontSlant->"Italic"], 
        StyleBox["r",
          FontWeight->"Bold",
          FontSlant->"Plain"], 
        StyleBox["]",
          FontSlant->"Italic"]}]]],
  " is function of two polar coordinates:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"\[Psi]", "[", 
        StyleBox["r",
          FontWeight->"Bold",
          FontSlant->"Plain"], "]"}], 
      "=", \(\[Psi][r, \[CurlyPhi]]\)}]], "NumberedEquation"],

Cell[TextData[{
  Cell[BoxData[
      StyleBox["\[CapitalDelta]",
        FontSlant->"Italic"]]],
  " is the Laplacian in the polar coordinates:"
}], "Text"],

Cell[BoxData[
    \(\[CapitalDelta] = \[CapitalDelta]\_r + 
        1\/r\^2\ \[CapitalDelta]\_\[CurlyPhi]\)], "NumberedEquation"],

Cell[TextData[{
  Cell[BoxData[
      \(\[CapitalDelta]\_r\)],
    FontSlant->"Italic"],
  " is ",
  "the radial ",
  "operator",
  ":"
}], "Text"],

Cell[BoxData[
    \(\[CapitalDelta]\_r = \(1\/r\) \((\[PartialD]\_r\((r\ \[PartialD]\_r)\))\
\)\)], "NumberedEquation"],

Cell[TextData[{
  Cell[BoxData[
      \(\[CapitalDelta]\_\[CurlyPhi]\)],
    FontSlant->"Italic"],
  " is ",
  "the angular operator",
  ":"
}], "Text"],

Cell[BoxData[
    \(\[CapitalDelta]\_\[CurlyPhi] = \[PartialD]\_\(\[CurlyPhi], \
\[CurlyPhi]\)\)], "NumberedEquation"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. Separation of variables", "Section"],

Cell[TextData[{
  "We will try to solve Schrodinger equation (3) by a value of wave function \
",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["\[Psi]",
            FontSlant->"Italic"], 
          StyleBox["[",
            FontSlant->"Italic"], 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["]",
            FontSlant->"Italic"]}], 
        StyleBox["=",
          FontSlant->"Italic"], 
        StyleBox[\(\[Psi][r, \[CurlyPhi]]\),
          FontSlant->"Italic"]}]]],
  " which is the product of separate functions of ",
  Cell[BoxData[
      StyleBox[\(r, \[CurlyPhi]\),
        FontSlant->"Italic"]]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\[Psi][r, \[CurlyPhi]] = R[r]\ S[\[CurlyPhi]]\)], "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      StyleBox[\(R[r]\),
        FontSlant->"Italic"]]],
  "is the radial wave function and ",
  Cell[BoxData[
      StyleBox[\(S[\[CurlyPhi]]\),
        FontSlant->"Italic"]]],
  " is the angular wave function."
}], "Text"],

Cell["\<\
Separated equations for the radial and angular wave functions are\
\>", "Text"],

Cell[BoxData[
    \(\(\(\(\[CapitalDelta]\_r\) 
          R[r] + \(\(2\ m\_0\)\/\[HBar]\^2\) \((E - 
              V[r] - \[CapitalLambda]\/r\^2)\) R[r] = 
      0\)\(,\)\)\)], "NumberedEquation"],

Cell[BoxData[
    \(\(\(\(\[CapitalDelta]\_\[CurlyPhi]\) 
          S[\[CurlyPhi]] + \[CapitalLambda]\ S[\[CurlyPhi]] = 
      0\)\(,\)\)\)], "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(\[CapitalLambda]\)],
    FontSlant->"Italic"],
  " is constant."
}], "Text"],

Cell["\<\
Solutions of the equation (9) for the angular wave function are\
\>", "Text"],

Cell[BoxData[
    \(S[\[CurlyPhi]] = \(S[
          m\_azm, \[CurlyPhi]] = \(\@\(1\/\(2\ \[Pi]\)\)\) \
\[ExponentialE]\^\(\(\[ImaginaryI]\)\(\ \)\(m\_azm\)\(\ \)\(\[CurlyPhi]\)\(\ \
\)\)\)\)], "NumberedEquation"],

Cell[TextData[{
  "and ",
  Cell[BoxData[
      \(\[CapitalLambda]\)],
    FontSlant->"Italic"],
  " is equal to"
}], "Text"],

Cell[BoxData[
    \(\(\(\[CapitalLambda] = m\_azm\^2\)\(,\)\)\)], "NumberedEquation"],

Cell[TextData[{
  Cell[BoxData[
      StyleBox[\(m\_azm\),
        FontSlant->"Italic"]]],
  " is azimuthal quantum number:"
}], "Text"],

Cell[BoxData[
    \(m\_azm\  = 
      0, \(\[PlusMinus]1\), \(\[PlusMinus]2\), \(\[PlusMinus]3\),  ... \)], \
"NumberedEquation"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["3. Radial equation for two-dimensional quantum \
oscillator",
  FontSlant->"Plain"]], "Section",
  FontSlant->"Italic"],

Cell["Radial equation for two-dimensional quantum oscillator is:", "Text"],

Cell[BoxData[
    \(\(1\/r\) \((\[PartialD]\_r\((r\ \[PartialD]\_r)\))\) 
          R[r] + \(\(2\ m\_0\)\/\[HBar]\^2\) \((E - 
              1\/2\ r\^2\ \[Omega]\^2\ m\_0 - m\_azm\^2\/r\^2)\) R[r] = 
      0\)], "NumberedEquation"],

Cell[TextData[{
  "or in the \"",
  StyleBox["InputForm",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  "\":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{\(D[R[r], {r, 2}]\), "+", \(\((1/r)\)*D[R[r], r]\), "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"2", "*", 
              SubscriptBox["m", 
                StyleBox["0",
                  "TI"]], "*", \(En/\[HBar]^2\)}], ")"}], "*", \(R[r]\)}], 
        "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{"-", 
                SubscriptBox["m", 
                  StyleBox["0",
                    "TI"]]}], "*", \(r\^2\), " ", \(\[Omega]\^2\), 
              " ", \(m\_0/\[HBar]^2\)}], ")"}], "*", \(R[r]\)}], 
        "-", \(\((m\_azm\^2/r^2)\)*R[r]\)}], "\[Equal]", "0"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(\(2\ En\ R[r]\ m\_0\)\/\[HBar]\^2\), 
        "-", \(\(r\^2\ \[Omega]\^2\ R[r]\ m\_0\%2\)\/\[HBar]\^2\), 
        "-", \(\(R[r]\ m\_azm\%2\)\/r\^2\), "+", 
        FractionBox[
          RowBox[{
            SuperscriptBox["R", "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}], "r"], "+", 
        RowBox[{
          SuperscriptBox["R", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}], "==", 
      "0"}]], "Output"]
}, Open  ]],

Cell[BoxData[""], "Text"]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1016, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "Classroom1.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 252, 8, 93, "Subtitle"],
Cell[2525, 82, 146, 4, 97, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2696, 90, 56, 0, 85, "Section"],
Cell[2755, 92, 111, 3, 56, "Text"],
Cell[2869, 97, 93, 1, 68, "NumberedEquation"],
Cell[2965, 100, 608, 22, 92, "Text"],
Cell[3576, 124, 76, 0, 56, "Text"],
Cell[3655, 126, 426, 11, 68, "NumberedEquation"],
Cell[4084, 139, 496, 20, 56, "Text"],
Cell[4583, 161, 45, 0, 56, "Text"],
Cell[4631, 163, 466, 12, 68, "NumberedEquation"],
Cell[5100, 177, 370, 14, 56, "Text"],
Cell[5473, 193, 209, 6, 53, "NumberedEquation"],
Cell[5685, 201, 157, 5, 56, "Text"],
Cell[5845, 208, 129, 2, 68, "NumberedEquation"],
Cell[5977, 212, 147, 8, 56, "Text"],
Cell[6127, 222, 119, 2, 68, "NumberedEquation"],
Cell[6249, 226, 152, 7, 56, "Text"],
Cell[6404, 235, 118, 2, 53, "NumberedEquation"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6559, 242, 45, 0, 85, "Section"],
Cell[6607, 244, 709, 24, 80, "Text"],
Cell[7319, 270, 89, 1, 53, "NumberedEquation"],
Cell[7411, 273, 268, 10, 56, "Text"],
Cell[7682, 285, 89, 2, 56, "Text"],
Cell[7774, 289, 196, 4, 68, "NumberedEquation"],
Cell[7973, 295, 161, 3, 53, "NumberedEquation"],
Cell[8137, 300, 128, 6, 56, "Text"],
Cell[8268, 308, 87, 2, 56, "Text"],
Cell[8358, 312, 212, 4, 86, "NumberedEquation"],
Cell[8573, 318, 125, 6, 56, "Text"],
Cell[8701, 326, 85, 1, 54, "NumberedEquation"],
Cell[8789, 329, 136, 5, 56, "Text"],
Cell[8928, 336, 129, 3, 53, "NumberedEquation"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9094, 344, 143, 3, 85, "Section"],
Cell[9240, 349, 74, 0, 56, "Text"],
Cell[9317, 351, 231, 4, 71, "NumberedEquation"],
Cell[9551, 357, 175, 7, 57, "Text"],

Cell[CellGroupData[{
Cell[9751, 368, 688, 18, 88, "Input"],
Cell[10442, 388, 506, 12, 89, "Output"]
}, Open  ]],
Cell[10963, 403, 25, 0, 55, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

