(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     29561,        999]*)
(*NotebookOutlinePosition[     30372,       1025]*)
(*  CellTagsIndexPosition[     30328,       1021]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Part ",
    FontWeight->"Bold"],
  StyleBox["2. Quantum Isotropic Oscillator",
    FontWeight->"Bold"],
  "\n2.3. Three-Dimensional Isotropic Quantum Oscillator"
}], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
2.3.2. Radial Equation of the Three-Dimensional Quantum Oscillator:
General Solutions, Radial Wave Functions  and Energy Levels\
\>", "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["1. Radial equation of the two-dimensional quantum oscillator", "Section"],

Cell[TextData[{
  "Consider radial equation (",
  StyleBox["RadDifEqnQntOsc",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  ") of the two-dimensional quantum oscillator:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"RadDifEqnQntOsc", "=", 
      RowBox[{
        RowBox[{\(D[R[r], {r, 2}]\), "+", \(\((1/r)\)*D[R[r], r]\), "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"2", "*", 
                SubscriptBox["m", 
                  StyleBox["0",
                    "TI"]], "*", \(En/\[HBar]^2\)}], ")"}], "*", \(R[r]\)}], 
          "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{\(-2\), "*", 
                SubscriptBox["m", 
                  StyleBox["0",
                    "TI"]], "*", \(V[r]/\[HBar]^2\)}], ")"}], "*", \(R[r]\)}],
           "-", \(\((m\_azm\^2/r\^2)\)*R[r]\)}], "\[Equal]", "0"}]}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(\(2\ En\ R[r]\ m\_0\)\/\[HBar]\^2\), 
        "-", \(\(R[r]\ m\_azm\%2\)\/r\^2\), 
        "-", \(\(2\ R[r]\ m\_0\ V[r]\)\/\[HBar]\^2\), "+", 
        FractionBox[
          RowBox[{
            SuperscriptBox["R", "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}], "r"], "+", 
        RowBox[{
          SuperscriptBox["R", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}], "==", 
      "0"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(V[r]\)],
    FontSlant->"Italic"],
  " is potential energy of oscillator:"
}], "Text"],

Cell[BoxData[
    \(\(\(V[r] = 1\/2\ r\^2\ \[Omega]\^2\ m\_0\)\(,\)\)\)], "NumberedEquation"],

Cell[TextData[{
  Cell[BoxData[
      \(m\_0\)],
    FontSlant->"Italic"],
  " is mass of oscillating particle, \[Omega] is frequency of oscillations, \
",
  Cell[BoxData[
      \(\(\(m\_azm\)\(\ \)\)\)],
    FontSlant->"Italic"],
  " is azimuth quantum number, ",
  Cell[BoxData[
      \(En\)],
    FontSlant->"Italic"],
  "  is total energy of oscillator,  ",
  Cell[BoxData[
      \(R[r]\)],
    FontSlant->"Italic"],
  " is radial part of wave function of oscillator."
}], "Text"],

Cell[TextData[{
  "Substitute expression for potential energy ",
  Cell[BoxData[
      \(V[r]\)],
    FontSlant->"Italic"],
  " to radial equation (",
  StyleBox["RadDifEqnQntOsc",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  ") and use extra denotations:"
}], "Text"],

Cell[BoxData[
    \(k = \@\(2\ \(m\_0\) En\)\/\[HBar], \ \[Lambda] = \(\(\ \)\(\(m\_0\) \
\[Omega]\)\)\/\[HBar]\)], "NumberedEquation",
  TextAlignment->Center],

Cell["and we will have", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RadDifEqnQntOsc1 = 
      Simplify[ReplaceAll[
          RadDifEqnQntOsc, {V[r] \[Rule] 1\/2\ r\^2\ \[Omega]\^2\ m\_0, 
            En \[Rule] \(k\^2\ \[HBar]\^2\)\/\(2\ m\_0\), 
            m\_0 \[Rule] \(\[Lambda]\ \[HBar]\)\/\[Omega]}]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(R[
            r]\ \((\(k\^2\ \[Lambda]\ \[HBar]\)\/\(\[Omega]\ m\_0\) - \(r\^2\ \
\[Lambda]\ \[Omega]\ m\_0\)\/\[HBar] - m\_azm\%2\/r\^2)\)\), "+", 
        FractionBox[
          RowBox[{
            SuperscriptBox["R", "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}], "r"], "+", 
        RowBox[{
          SuperscriptBox["R", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}], "==", 
      "0"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RadDifEqnQntOsc2 = 
      Simplify[ReplaceAll[
          RadDifEqnQntOsc1, {m\_0 \[Rule] \(\[Lambda]\ \[HBar]\)\/\[Omega]}]]\
\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(R[r]\ \((k\^2 - r\^2\ \[Lambda]\^2 - m\_azm\%2\/r\^2)\)\), 
        "+", 
        FractionBox[
          RowBox[{
            SuperscriptBox["R", "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}], "r"], "+", 
        RowBox[{
          SuperscriptBox["R", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}], "==", 
      "0"}]], "Output"]
}, Open  ]],

Cell["\<\
These transformation give dimensionless form of the radial equation.
We will seek solution of radial equation with substitution:\
\>", "Text"],

Cell[BoxData[
    \(R[r] = \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^m\_azm\ v[
          r]\)], "NumberedEquation",
  TextAlignment->Center],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[r] = \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^m\_azm*
        v[r]\), "\[IndentingNewLine]", 
    \(RadDifEqnQntOsc3 = 
      Simplify[R[r]\ \((k\^2 - r\^2\ \[Lambda]\^2 - m\_azm\%2\/r\^2)\) + 
            D[R[r], r]\/r + D[R[r], {r, 2}]] \[Equal] 0\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^m\_azm\ v[
        r]\)], "Output"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\), 
        " ", \(r\^\(\(-1\) + m\_azm\)\), " ", 
        RowBox[{"(", 
          
          RowBox[{\(r\ \((k\^2 - 2\ \[Lambda] - 2\ \[Lambda]\ m\_azm)\)\ v[
                r]\), "+", 
            RowBox[{\((1 - 2\ r\^2\ \[Lambda] + 2\ m\_azm)\), " ", 
              RowBox[{
                SuperscriptBox["v", "\[Prime]",
                  MultilineFunction->None], "[", "r", "]"}]}], "+", 
            RowBox[{"r", " ", 
              RowBox[{
                SuperscriptBox["v", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], "==",
       "0"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "and will solve with \"",
  StyleBox["DSolve",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  "\" tool:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DSolve[RadDifEqnQntOsc3, v[r], r]\)], "Input"],

Cell[BoxData[
    \({{v[
            r] \[Rule] \((\(-1\))\)\^\(-m\_azm\)\ r\^\(\(-2\)\ m\_azm\)\ \
\[Lambda]\^\(-m\_azm\)\ C[2]\ Hypergeometric1F1[
                1\/2 - k\^2\/\(4\ \[Lambda]\) - m\_azm\/2, 1 - m\_azm, 
                r\^2\ \[Lambda]] + 
            C[1]\ Hypergeometric1F1[
                1\/2 - k\^2\/\(4\ \[Lambda]\) + m\_azm\/2, 1 + m\_azm, 
                r\^2\ \[Lambda]]}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "General solution for ",
  Cell[BoxData[
      \(v[r]\)],
    FontSlant->"Italic"],
  "is superposition of two independent fundamental solutions:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(v2[r] = \ \((\(-1\))\)\^\(-m\_azm\)\ r\^\(\(-2\)\ m\_azm\)\ \[Lambda]\^\
\(-m\_azm\)\ C[2]\ Hypergeometric1F1[
          1\/2 - k\^2\/\(4\ \[Lambda]\) - m\_azm\/2, 1 - m\_azm, 
          r\^2\ \[Lambda]]\), "\[IndentingNewLine]", 
    \(v1[r] = 
      C[1]\ Hypergeometric1F1[1\/2 - k\^2\/\(4\ \[Lambda]\) + m\_azm\/2, 
          1 + m\_azm, r\^2\ \[Lambda]]\)}], "Input",
  TextAlignment->Center],

Cell[BoxData[
    \(\((\(-1\))\)\^\(-m\_azm\)\ r\^\(\(-2\)\ m\_azm\)\ \
\[Lambda]\^\(-m\_azm\)\ C[2]\ Hypergeometric1F1[
        1\/2 - k\^2\/\(4\ \[Lambda]\) - m\_azm\/2, 1 - m\_azm, 
        r\^2\ \[Lambda]]\)], "Output"],

Cell[BoxData[
    \(C[1]\ Hypergeometric1F1[1\/2 - k\^2\/\(4\ \[Lambda]\) + m\_azm\/2, 
        1 + m\_azm, r\^2\ \[Lambda]]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "where Hypergeometric1F1 are the Kummer confluent hypergeometric functions \
",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Null]\_1\) \(\(F\_1\)(a; b; z)\)\)], 
    "InlineFormula"],
  " ",
  "and ",
  Cell[BoxData[
      \(\:0421[1]\)],
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  " and  ",
  Cell[BoxData[
      \(\:0421[2]\)],
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  " are constants.",
  "\nAs a result we have solution of the radial equation as superposition of \
two component:"
}], "Text"],

Cell[BoxData[
    \(R[r] = R2[r] + R1[r]\)], "NumberedEquation",
  TextAlignment->Center],

Cell["where", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R2[r] = 
      C[2]\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \(r\^m\_azm\) \
\((\(-1\))\)\^\(-m\_azm\)\ r\^\(\(-2\)\ m\_azm\)\ \[Lambda]\^\(-m\_azm\)\ \
Hypergeometric1F1[1\/2 - k\^2\/\(4\ \[Lambda]\) - m\_azm\/2, 1 - m\_azm, 
          r\^2\ \[Lambda]]\), "\[IndentingNewLine]", 
    \(R1[r] = 
      C[1] \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^m\_azm\ \
Hypergeometric1F1[1\/2 - k\^2\/\(4\ \[Lambda]\) + m\_azm\/2, 1 + m\_azm, 
          r\^2\ \[Lambda]]\)}], "Input"],

Cell[BoxData[
    \(\((\(-1\))\)\^\(-m\_azm\)\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\
\)\)\ r\^\(-m\_azm\)\ \[Lambda]\^\(-m\_azm\)\ C[2]\ Hypergeometric1F1[
        1\/2 - k\^2\/\(4\ \[Lambda]\) - m\_azm\/2, 1 - m\_azm, 
        r\^2\ \[Lambda]]\)], "Output"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^m\_azm\ C[
        1]\ Hypergeometric1F1[1\/2 - k\^2\/\(4\ \[Lambda]\) + m\_azm\/2, 
        1 + m\_azm, r\^2\ \[Lambda]]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Now we analyze behavior of functions  ",
  Cell[BoxData[
      \(R1[r]\)],
    FontSlant->"Italic"],
  " and  ",
  Cell[BoxData[
      \(R2[r]\)],
    FontSlant->"Italic"],
  " are constants near zero.\nTake Taylor series of   ",
  Cell[BoxData[
      \(R1[r]\)],
    FontSlant->"Italic"],
  " and  ",
  Cell[BoxData[
      \(R2[r]\)],
    FontSlant->"Italic"],
  "near zero:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{
      RowBox[{
        StyleBox[
          RowBox[{
            StyleBox["HG2",
              FontSlant->"Italic"], "Taylor2"}]], "[", 
        StyleBox["r",
          FontSlant->"Italic"], "]"}], 
      "=", \(Series[
        Hypergeometric1F1[1\/2 - k\^2\/\(4\ \[Lambda]\) - m\_azm\/2, 
          1 - m\_azm, r\^2\ \[Lambda]], {r, \ 0, \ 
          2}]\)}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox[
          RowBox[{"HG", 
            StyleBox["1",
              FontSlant->"Italic"], "Taylor2"}]], "[", 
        StyleBox["r",
          FontSlant->"Italic"], "]"}], 
      "=", \(Series[
        Hypergeometric1F1[1\/2 - k\^2\/\(4\ \[Lambda]\) + m\_azm\/2, 
          1 + m\_azm, r\^2\ \[Lambda]], {r, \ 0, \ 2}]\)}]}], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      "1", "+", \(\(\[Lambda]\ \((1\/2 - k\^2\/\(4\ \[Lambda]\) - 
                  m\_azm\/2)\)\ r\^2\)\/\(1 - m\_azm\)\), "+", 
        InterpretationBox[\(O[r]\^3\),
          SeriesData[ r, 0, {}, 0, 3, 1]]}],
      SeriesData[ r, 0, {1, 0, 
        Times[ \[Lambda], 
          Power[ 
            Plus[ 1, 
              Times[ -1, 
                Subscript[ m, azm]]], -1], 
          Plus[ 
            Rational[ 1, 2], 
            Times[ 
              Rational[ -1, 4], 
              Power[ k, 2], 
              Power[ \[Lambda], -1]], 
            Times[ 
              Rational[ -1, 2], 
              Subscript[ m, azm]]]]}, 0, 3, 1]]], "Output"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      "1", "+", \(\(\[Lambda]\ \((1\/2 - k\^2\/\(4\ \[Lambda]\) + 
                  m\_azm\/2)\)\ r\^2\)\/\(1 + m\_azm\)\), "+", 
        InterpretationBox[\(O[r]\^3\),
          SeriesData[ r, 0, {}, 0, 3, 1]]}],
      SeriesData[ r, 0, {1, 0, 
        Times[ \[Lambda], 
          Plus[ 
            Rational[ 1, 2], 
            Times[ 
              Rational[ -1, 4], 
              Power[ k, 2], 
              Power[ \[Lambda], -1]], 
            Times[ 
              Rational[ 1, 2], 
              Subscript[ m, azm]]], 
          Power[ 
            Plus[ 1, 
              Subscript[ m, azm]], -1]]}, 0, 3, 1]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "and take Taylor series of radial functions ",
  " ",
  Cell[BoxData[
      \(R1[r]\)],
    FontSlant->"Italic"],
  " and  ",
  Cell[BoxData[
      \(R2[r]\)],
    FontSlant->"Italic"],
  "near zero:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{\(R2Taylor2[r]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(\((\(-1\))\)\^\(-m\_azm\)\), 
          " ", \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\), 
          " ", \(r\^\(-m\_azm\)\), " ", \(\[Lambda]\^\(-m\_azm\)\), 
          " ", \(C[2]\), " ", 
          RowBox[{
            StyleBox[
              RowBox[{
                StyleBox["HG2",
                  FontSlant->"Italic"], "Taylor2"}]], "[", 
            StyleBox["r",
              FontSlant->"Italic"], "]"}]}], "]"}]}], "\[IndentingNewLine]", 
    RowBox[{\(R1Taylor1[r]\), "=", 
      RowBox[{"FullSimplify", "[", 
        RowBox[{\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\), 
          " ", \(r\^m\_azm\), \(C[1]\), " ", 
          RowBox[{
            StyleBox[
              RowBox[{"HG", 
                StyleBox["1",
                  FontSlant->"Italic"], "Taylor2"}]], "[", 
            StyleBox["r",
              FontSlant->"Italic"], "]"}]}], "]"}]}]}], "Input"],

Cell[BoxData[
    RowBox[{\(r\^\(-m\_azm\)\), " ", 
      RowBox[{"(", 
        InterpretationBox[
          
          RowBox[{\(\((\(-1\))\)\^\(-m\_azm\)\ \[Lambda]\^\(-m\_azm\)\ C[2]\),
             "+", \(\(\((\(-1\))\)\^\(-m\_azm\)\ k\^2\ \[Lambda]\^\(-m\_azm\)\
\ C[2]\ r\^2\)\/\(4\ \((\(-1\) + m\_azm)\)\)\), "+", 
            InterpretationBox[\(O[r]\^3\),
              SeriesData[ r, 0, {}, 0, 3, 1]]}],
          SeriesData[ r, 0, {
            Times[ 
              Power[ -1, 
                Times[ -1, 
                  Subscript[ m, azm]]], 
              Power[ \[Lambda], 
                Times[ -1, 
                  Subscript[ m, azm]]], 
              C[ 2]], 0, 
            Times[ 
              Rational[ 1, 4], 
              Power[ -1, 
                Times[ -1, 
                  Subscript[ m, azm]]], 
              Power[ k, 2], 
              Power[ \[Lambda], 
                Times[ -1, 
                  Subscript[ m, azm]]], 
              C[ 2], 
              Power[ 
                Plus[ -1, 
                  Subscript[ m, azm]], -1]]}, 0, 3, 1]], ")"}]}]], "Output"],

Cell[BoxData[
    RowBox[{\(r\^m\_azm\), " ", 
      RowBox[{"(", 
        InterpretationBox[
          
          RowBox[{\(C[1]\), 
            "+", \(\(k\^2\ C[1]\ r\^2\)\/\(\(-4\) - 4\ m\_azm\)\), "+", 
            InterpretationBox[\(O[r]\^3\),
              SeriesData[ r, 0, {}, 0, 3, 1]]}],
          SeriesData[ r, 0, {
            C[ 1], 0, 
            Times[ 
              Power[ k, 2], 
              C[ 1], 
              Power[ 
                Plus[ -4, 
                  Times[ -4, 
                    Subscript[ m, azm]]], -1]]}, 0, 3, 1]], ")"}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "This implies that\n1)  ",
  Cell[BoxData[
      \(R1[r]\)],
    FontSlant->"Italic"],
  " tends to zero and ",
  Cell[BoxData[
      \(R2[r]\)],
    FontSlant->"Italic"],
  "diverges near zero with positive ",
  Cell[BoxData[
      StyleBox[\(m\_azm\),
        FontSlant->"Italic"]]],
  " (",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  ">0),",
  StyleBox["\n",
    FontSlant->"Italic"],
  "2) ",
  Cell[BoxData[
      \(R2[r]\)],
    FontSlant->"Italic"],
  "tends to zero and  ",
  Cell[BoxData[
      \(R1[r]\)],
    FontSlant->"Italic"],
  "diverges near zero with negative ",
  Cell[BoxData[
      StyleBox[\(m\_azm\),
        FontSlant->"Italic"]]],
  " (",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  "<0)."
}], "Text"],

Cell["Therefore we wave:", "Text"],

Cell[BoxData[
    RowBox[{\(R[r]\), "=", 
      RowBox[{"{", GridBox[{
            {\(R1[r]\ \ \((m\_azm > 0)\)\)},
            {\(R2[r]\ \ \((m\_azm < 0)\)\)}
            }]}]}]], "NumberedEquation",
  TextAlignment->Center],

Cell[TextData[{
  "Moreover  ",
  Cell[BoxData[
      \(R2[r]\)],
    FontSlant->"Italic"],
  "relates (accurate to constant) to  ",
  Cell[BoxData[
      \(R1[r]\)],
    FontSlant->"Italic"],
  " by substitution:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["R2",
          FontSlant->"Italic"], "[", \(m\_azm, r\), "]"}], "=", 
      RowBox[{
        StyleBox["R1",
          FontSlant->"Italic"], "[", \(\(-m\_azm\), r\), 
        "]"}]}]], "NumberedEquation",
  TextAlignment->Center],

Cell["So we will use solution", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(R[r] = 
      C[m\_azm, \[Lambda]] \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
r\^\(\(|\)\(m\_azm\)\(|\)\)\ Hypergeometric1F1[
          1\/2 - k\^2\/\(4\ \[Lambda]\) + \(\(|\)\(m\_azm\)\(|\)\)\/2, \
\(\(1\)\(+\)\) | m\_azm | , r\^2\ \[Lambda]]\)], "Input"],

Cell[BoxData[
    \(Syntax::"tsntxi" \(\(:\)\(\ \)\) 
      "\"\!\(| m\_azm |\)\" is incomplete; more input is \
needed.\!\(\"\"\)"\)], "Message"],

Cell[BoxData[
    StyleBox[
      RowBox[{\(R[r]\), "=", 
        RowBox[{\(C[
            m\_azm, \[Lambda]]\), \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\
\/2\)\)\), " ", 
          SuperscriptBox["r", 
            ErrorBox[\(\(|\)\(m\_azm\)\(|\)\)]], 
          " ", \(Hypergeometric1F1[
            1\/2 - k\^2\/\(4\ \[Lambda]\) + \(\(|\)\(m\_azm\)\(|\)\)\/2, \
\(\(1\)\(+\)\) | m\_azm | , r\^2\ \[Lambda]]\)}]}],
      ShowStringCharacters->True]], "Message"]
}, Open  ]],

Cell["and taking into account condition (6)", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(R[m\_azm, \[Lambda], r] = 
      C[m\_azm, \[Lambda]] \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
r\^m\_azm\ Hypergeometric1F1[1\/2 - k\^2\/\(4\ \[Lambda]\) + m\_azm\/2, 
          1 + m\_azm, r\^2\ \[Lambda]]\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^m\_azm\ C[
        m\_azm, \[Lambda]]\ Hypergeometric1F1[
        1\/2 - k\^2\/\(4\ \[Lambda]\) + m\_azm\/2, 1 + m\_azm, 
        r\^2\ \[Lambda]]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2. Condition for energy levels of the two-dimensional quantum oscillator\
\>", "Section"],

Cell["\<\
Finiteness of the wave function at infinity gives the second condition for \
radial functions of the two-dimensional quantum oscillator:\
\>", "Text"],

Cell[BoxData[
    \(1\/2 - k\^2\/\(4\ \[Lambda]\) - 
        m\_azm\/2 = \(-n\_rad\), \[IndentingNewLine]n\_rad = \ 0, 1, 2, 
    3,  ... \)], "NumberedEquation",
  TextAlignment->Center],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " are the radial quantum numbers.\nThis implies that hypergeometric \
functions has to be polynomial:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ExpTblR = 
      Expand[TableForm[
          Table[Hypergeometric1F1[\(-n\_rad\), 1 - m\_azm, 
              r\^2\ \[Lambda]], {n\_rad, 4}]]]\)], "Input",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(1 - \(r\^2\ \[Lambda]\)\/\(1 - m\_azm\)\)},
          {\(1 - \(2\ r\^2\ \[Lambda]\)\/\(1 - m\_azm\) + \(r\^4\ \
\[Lambda]\^2\)\/\(\((1 - m\_azm)\)\ \((2 - m\_azm)\)\)\)},
          {\(1 - \(3\ r\^2\ \[Lambda]\)\/\(1 - m\_azm\) + \(3\ r\^4\ \
\[Lambda]\^2\)\/\(\((1 - m\_azm)\)\ \((2 - m\_azm)\)\) - \(r\^6\ \[Lambda]\^3\
\)\/\(\((1 - m\_azm)\)\ \((2 - m\_azm)\)\ \((3 - m\_azm)\)\)\)},
          {\(1 - \(4\ r\^2\ \[Lambda]\)\/\(1 - m\_azm\) + \(6\ r\^4\ \
\[Lambda]\^2\)\/\(\((1 - m\_azm)\)\ \((2 - m\_azm)\)\) - \(4\ r\^6\ \[Lambda]\
\^3\)\/\(\((1 - m\_azm)\)\ \((2 - m\_azm)\)\ \((3 - m\_azm)\)\) + \(r\^8\ \
\[Lambda]\^4\)\/\(\((1 - m\_azm)\)\ \((2 - m\_azm)\)\ \((3 - m\_azm)\)\ \((4 \
- m\_azm)\)\)\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Plus[ 1, 
          Times[ -1, 
            Power[ r, 2], \[Lambda], 
            Power[ 
              Plus[ 1, 
                Times[ -1, 
                  Subscript[ m, azm]]], -1]]], 
        Plus[ 1, 
          Times[ -2, 
            Power[ r, 2], \[Lambda], 
            Power[ 
              Plus[ 1, 
                Times[ -1, 
                  Subscript[ m, azm]]], -1]], 
          Times[ 
            Power[ r, 4], 
            Power[ \[Lambda], 2], 
            Power[ 
              Plus[ 1, 
                Times[ -1, 
                  Subscript[ m, azm]]], -1], 
            Power[ 
              Plus[ 2, 
                Times[ -1, 
                  Subscript[ m, azm]]], -1]]], 
        Plus[ 1, 
          Times[ -3, 
            Power[ r, 2], \[Lambda], 
            Power[ 
              Plus[ 1, 
                Times[ -1, 
                  Subscript[ m, azm]]], -1]], 
          Times[ 3, 
            Power[ r, 4], 
            Power[ \[Lambda], 2], 
            Power[ 
              Plus[ 1, 
                Times[ -1, 
                  Subscript[ m, azm]]], -1], 
            Power[ 
              Plus[ 2, 
                Times[ -1, 
                  Subscript[ m, azm]]], -1]], 
          Times[ -1, 
            Power[ r, 6], 
            Power[ \[Lambda], 3], 
            Power[ 
              Plus[ 1, 
                Times[ -1, 
                  Subscript[ m, azm]]], -1], 
            Power[ 
              Plus[ 2, 
                Times[ -1, 
                  Subscript[ m, azm]]], -1], 
            Power[ 
              Plus[ 3, 
                Times[ -1, 
                  Subscript[ m, azm]]], -1]]], 
        Plus[ 1, 
          Times[ -4, 
            Power[ r, 2], \[Lambda], 
            Power[ 
              Plus[ 1, 
                Times[ -1, 
                  Subscript[ m, azm]]], -1]], 
          Times[ 6, 
            Power[ r, 4], 
            Power[ \[Lambda], 2], 
            Power[ 
              Plus[ 1, 
                Times[ -1, 
                  Subscript[ m, azm]]], -1], 
            Power[ 
              Plus[ 2, 
                Times[ -1, 
                  Subscript[ m, azm]]], -1]], 
          Times[ -4, 
            Power[ r, 6], 
            Power[ \[Lambda], 3], 
            Power[ 
              Plus[ 1, 
                Times[ -1, 
                  Subscript[ m, azm]]], -1], 
            Power[ 
              Plus[ 2, 
                Times[ -1, 
                  Subscript[ m, azm]]], -1], 
            Power[ 
              Plus[ 3, 
                Times[ -1, 
                  Subscript[ m, azm]]], -1]], 
          Times[ 
            Power[ r, 8], 
            Power[ \[Lambda], 4], 
            Power[ 
              Plus[ 1, 
                Times[ -1, 
                  Subscript[ m, azm]]], -1], 
            Power[ 
              Plus[ 2, 
                Times[ -1, 
                  Subscript[ m, azm]]], -1], 
            Power[ 
              Plus[ 3, 
                Times[ -1, 
                  Subscript[ m, azm]]], -1], 
            Power[ 
              Plus[ 4, 
                Times[ -1, 
                  Subscript[ m, azm]]], -1]]]}]]], "Output"]
}, Open  ]],

Cell["Thus we have:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(R[n\_rad, m\_azm, \[Lambda], r] = 
      C[n\_rad, 
          m\_azm, \[Lambda]] \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\
\ r\^m\_azm\ Hypergeometric1F1[\(-n\_rad\), 1 + m\_azm, 
          r\^2\ \[Lambda]]\)], "Input",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^m\_azm\ C[n\_rad, 
        m\_azm, \[Lambda]]\ Hypergeometric1F1[\(-n\_rad\), 1 + m\_azm, 
        r\^2\ \[Lambda]]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
3. Energy levels of the two-dimensional quantum oscillator\
\>", "Section"],

Cell[TextData[{
  "Condition (7) give us possibility to obtain energy levels of the \
two-dimensional quantum oscillator.\nTo obtain energy levels we will use \
expressions (2) and \"",
  StyleBox["Solve",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  "\" Tool:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[Lambda] = \((m\_0*\[Omega])\)/\[HBar];\)\), "\n", 
    \(Solve[{1\/2 - k\^2\/\(4\ \[Lambda]\) + m\_azm\/2 == \(-n\_rad\), 
        En == \(k\^2\ \[HBar]\^2\)\/\(2\ m\_0\)}, {En, k}]\)}], "Input"],

Cell[BoxData[
    \({{En \[Rule] \[Omega]\ \[HBar]\ \((1 + m\_azm + 2\ n\_rad)\), 
        k \[Rule] \(-\(\(\@\[Omega]\ \@m\_0\ \@\(2 + 2\ m\_azm + 4\ \
n\_rad\)\)\/\@\[HBar]\)\)}, {En \[Rule] \[Omega]\ \[HBar]\ \((1 + m\_azm + 
                2\ n\_rad)\), 
        k \[Rule] \(\@\[Omega]\ \@m\_0\ \@\(2 + 2\ m\_azm + 4\ n\_rad\)\)\/\@\
\[HBar]}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "As a result we have quantified energy levels depending on quantum numbers \
",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " and ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(En[n\_rad, 
        m\_azm, \[Lambda]] = \[Omega]\ \[HBar]\ \((1 + m\_azm + 
            2\ n\_rad)\)\)], "Input"],

Cell[BoxData[
    \(\[Omega]\ \[HBar]\ \((1 + m\_azm + 2\ n\_rad)\)\)], "Output"]
}, Open  ]],

Cell["or", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(En[n, m\_azm, \[Lambda]] = 
      Simplify[ReplaceAll[\[Omega]\ \[HBar]\ \((1 + m\_azm + 2\ n\_rad)\), 
          n\_rad \[Rule] \((n - m\_azm)\)/2]]\)], "Input"],

Cell[BoxData[
    \(\((1 + n)\)\ \[Omega]\ \[HBar]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "where ",
  StyleBox["n",
    FontSlant->"Italic"],
  " is total quantum number:"
}], "Text"],

Cell[BoxData[{
    \(n = 2  n\_rad + m\_azm\), "\n", 
    \(n = \ 0, 1, 2, 3,  ... \)}], "NumberedEquation",
  TextAlignment->Center],

Cell["\<\
Using denotations (2) we can write down the radial function of the \
two-dimensional quantum oscillator in the forms:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Clear[\[Lambda]]\), "\[IndentingNewLine]", 
    \(R[n\_rad, m\_azm, \[Lambda], r] = 
      C[n\_rad, 
          m\_azm] \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^m\_azm\
\ Hypergeometric1F1[\(-n\_rad\), 1 + m\_azm, 
          r\^2\ \[Lambda]]\), "\[IndentingNewLine]", 
    \(R[n\_rad, m\_azm, \[Omega], r] = 
      Simplify[ReplaceAll[
          R[n\_rad, m\_azm, \[Lambda], 
            r], {\[Lambda] \[Rule] \(\[Omega]\ m\_0\)\/\[HBar]}]]\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^m\_azm\ C[n\_rad, 
        m\_azm]\ Hypergeometric1F1[\(-n\_rad\), 1 + m\_azm, 
        r\^2\ \[Lambda]]\)], "Output"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\(r\^2\ \[Omega]\ m\_0\)\/\(2\ \[HBar]\)\)\)\ \
r\^m\_azm\ C[n\_rad, m\_azm]\ Hypergeometric1F1[\(-n\_rad\), 
        1 + m\_azm, \(r\^2\ \[Omega]\ m\_0\)\/\[HBar]]\)], "Output"]
}, Open  ]],

Cell["", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1016, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.25,
StyleDefinitions -> FrontEnd`FileName[{ParentDirectory[]}, "Classroom1.nb", \
CharacterEncoding -> "WindowsCyrillic"]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 254, 8, 93, "Subtitle"],
Cell[2527, 82, 207, 5, 124, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2759, 91, 79, 0, 85, "Section"],
Cell[2841, 93, 236, 7, 57, "Text"],

Cell[CellGroupData[{
Cell[3102, 104, 685, 17, 113, "Input"],
Cell[3790, 123, 493, 12, 89, "Output"]
}, Open  ]],
Cell[4298, 138, 138, 6, 56, "Text"],
Cell[4439, 146, 93, 1, 68, "NumberedEquation"],
Cell[4535, 149, 484, 18, 80, "Text"],
Cell[5022, 169, 323, 11, 57, "Text"],
Cell[5348, 182, 160, 3, 75, "NumberedEquation"],
Cell[5511, 187, 32, 0, 56, "Text"],

Cell[CellGroupData[{
Cell[5568, 191, 272, 5, 119, "Input"],
Cell[5843, 198, 500, 12, 96, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6380, 215, 159, 4, 85, "Input"],
Cell[6542, 221, 424, 11, 96, "Output"]
}, Open  ]],
Cell[6981, 235, 152, 3, 92, "Text"],
Cell[7136, 240, 152, 3, 64, "NumberedEquation"],

Cell[CellGroupData[{
Cell[7313, 247, 298, 5, 161, "Input"],
Cell[7614, 254, 108, 2, 73, "Output"],
Cell[7725, 258, 702, 16, 73, "Output"]
}, Open  ]],
Cell[8442, 277, 187, 7, 57, "Text"],

Cell[CellGroupData[{
Cell[8654, 288, 66, 1, 63, "Input"],
Cell[8723, 291, 414, 8, 144, "Output"]
}, Open  ]],
Cell[9152, 302, 176, 6, 56, "Text"],

Cell[CellGroupData[{
Cell[9353, 312, 418, 8, 144, "Input"],
Cell[9774, 322, 223, 4, 88, "Output"],
Cell[10000, 328, 138, 2, 88, "Output"]
}, Open  ]],
Cell[10153, 333, 571, 22, 92, "Text"],
Cell[10727, 357, 89, 2, 53, "NumberedEquation"],
Cell[10819, 361, 68, 2, 56, "Text"],

Cell[CellGroupData[{
Cell[10912, 367, 515, 9, 183, "Input"],
Cell[11430, 378, 266, 4, 88, "Output"],
Cell[11699, 384, 208, 3, 88, "Output"]
}, Open  ]],
Cell[11922, 390, 407, 18, 92, "Text"],

Cell[CellGroupData[{
Cell[12354, 412, 788, 23, 144, "Input"],
Cell[13145, 437, 716, 21, 103, "Output"],
Cell[13864, 460, 686, 20, 103, "Output"]
}, Open  ]],
Cell[14565, 483, 230, 11, 56, "Text"],

Cell[CellGroupData[{
Cell[14820, 498, 1004, 24, 114, "Input"],
Cell[15827, 524, 1112, 31, 91, "Output"],
Cell[16942, 557, 581, 17, 91, "Output"]
}, Open  ]],
Cell[17538, 577, 783, 37, 128, "Text"],
Cell[18324, 616, 34, 0, 56, "Text"],
Cell[18361, 618, 225, 6, 70, "NumberedEquation"],
Cell[18589, 626, 226, 10, 56, "Text"],
Cell[18818, 638, 288, 9, 53, "NumberedEquation"],
Cell[19109, 649, 39, 0, 56, "Text"],

Cell[CellGroupData[{
Cell[19173, 653, 285, 5, 88, "Input"],
Cell[19461, 660, 146, 3, 30, "Message"],
Cell[19610, 665, 465, 11, 48, "Message"]
}, Open  ]],
Cell[20090, 679, 53, 0, 56, "Text"],

Cell[CellGroupData[{
Cell[20168, 683, 250, 4, 88, "Input"],
Cell[20421, 689, 233, 4, 88, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[20703, 699, 99, 2, 85, "Section"],
Cell[20805, 703, 160, 3, 56, "Text"],
Cell[20968, 708, 187, 4, 98, "NumberedEquation"],
Cell[21158, 714, 205, 7, 92, "Text"],

Cell[CellGroupData[{
Cell[21388, 725, 221, 6, 88, "Input"],
Cell[21612, 733, 4110, 128, 218, "Output"]
}, Open  ]],
Cell[25737, 864, 29, 0, 56, "Text"],

Cell[CellGroupData[{
Cell[25791, 868, 294, 7, 73, "Input"],
Cell[26088, 877, 202, 3, 73, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[26339, 886, 85, 2, 85, "Section"],
Cell[26427, 890, 328, 9, 93, "Text"],

Cell[CellGroupData[{
Cell[26780, 903, 220, 3, 119, "Input"],
Cell[27003, 908, 362, 6, 180, "Output"]
}, Open  ]],
Cell[27380, 917, 248, 11, 56, "Text"],

Cell[CellGroupData[{
Cell[27653, 932, 134, 3, 63, "Input"],
Cell[27790, 937, 81, 1, 63, "Output"]
}, Open  ]],
Cell[27886, 941, 18, 0, 56, "Text"],

Cell[CellGroupData[{
Cell[27929, 945, 182, 3, 63, "Input"],
Cell[28114, 950, 64, 1, 63, "Output"]
}, Open  ]],
Cell[28193, 954, 111, 5, 56, "Text"],
Cell[28307, 961, 133, 3, 78, "NumberedEquation"],
Cell[28443, 966, 141, 3, 56, "Text"],

Cell[CellGroupData[{
Cell[28609, 973, 488, 10, 145, "Input"],
Cell[29100, 985, 191, 3, 73, "Output"],
Cell[29294, 990, 220, 3, 88, "Output"]
}, Open  ]],
Cell[29529, 996, 16, 0, 56, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

