(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     51965,       1663]*)
(*NotebookOutlinePosition[     52694,       1688]*)
(*  CellTagsIndexPosition[     52650,       1684]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Part ",
    FontWeight->"Bold"],
  StyleBox["2. Quantum Isotropic Oscillator",
    FontWeight->"Bold"],
  "\n2.2. One-Dimensional Isotropic Quantum Oscillator"
}], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
2.2.3. Radial Probability Density and Normalization of the Radial Wave \
Functions of the Two-Dimensional Quantum Oscillator\
\>", "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
1. Radial probability density of the two-dimensional quantum oscillator\
\>", "Section"],

Cell["\<\
Consider radial wave function of the two-dimensional quantum oscillator:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(R[n\_rad, m\_azm, \[Lambda], r] = 
      C[n\_rad, 
          m\_azm] \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^m\_azm\
\ Hypergeometric1F1[\(-n\_rad\), 1 + m\_azm, r\^2\ \[Lambda]]\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^m\_azm\ C[n\_rad, 
        m\_azm]\ Hypergeometric1F1[\(-n\_rad\), 1 + m\_azm, 
        r\^2\ \[Lambda]]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(C[n\_rad, m\_azm]\)],
    FontSlant->"Italic"],
  "is constant."
}], "Text"],

Cell["\<\
Define radial probability density of the two-dimensional quantum \
oscillator:\
\>", "Text"],

Cell[BoxData[
    \(RR[n\_rad, m\_azm, \[Lambda], 
        r] = \(\(|\)\(R[n\_rad, m\_azm, \[Lambda], 
          r]\)\( | \^2\)\(\ \)\(r\)\)\)], "NumberedEquation",
  TextAlignment->Center],

Cell[TextData[{
  "As ",
  Cell[BoxData[
      \(R[n\_rad, m\_azm, \[Lambda], r]\)],
    FontSlant->"Italic"],
  "is real ",
  "function we have"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell[BoxData[
    \(RR[n\_rad, m\_azm, \[Lambda], r] = 
      FullSimplify[R[n\_rad, m\_azm, \[Lambda], r]\^2\ r]\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^\(1 + 2\ m\_azm\)\ \
C[n\_rad, m\_azm]\^2\ Hypergeometric1F1[\(-n\_rad\), 1 + m\_azm, r\^2\ \
\[Lambda]]\^2\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2. Dimensionless form of the radial wave functions of the two-dimensional \
quantum oscillator\
\>", "Section"],

Cell[TextData[{
  "Transform  radial wave function of ",
  "the two-dimensional quantum oscillator",
  " to the dimensionless form using new dimensionless variable \[Rho] and \
constant ",
  Cell[BoxData[
      \(C[n\_rad, l\_orb, \[Lambda]]\)],
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[BoxData[
    \(\[Rho] = r \@ \[Lambda], r = \[Rho]\/\@\[Lambda]\)], "NumberedEquation"],

Cell[CellGroupData[{

Cell[BoxData[
    \(R[n\_rad, m\_azm, \[Rho]] = 
      FullSimplify[
        ReplaceAll[
          R[n\_rad, m\_azm, \[Lambda], 
            r], {r \[Rule] \[Rho]\/\@\[Lambda]}]]\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \
\((\[Rho]\/\@\[Lambda])\)\^m\_azm\ C[n\_rad, 
        m\_azm]\ Hypergeometric1F1[\(-n\_rad\), 
        1 + m\_azm, \[Rho]\^2]\)], "Output"]
}, Open  ]],

Cell["\<\
Transform radial probability density of the two-dimensional quantum \
oscillator to the dimensionless form too:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RR[n\_rad, m\_azm, \[Rho]] = 
      FullSimplify[
        ReplaceAll[
          RR[n\_rad, m\_azm, \[Lambda], 
            r], {r \[Rule] \[Rho]\/\@\[Lambda]}]]\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\[Rho]\^2\)\ \((\[Rho]\/\@\[Lambda])\)\^\(1 + 2\ \
m\_azm\)\ C[n\_rad, m\_azm]\^2\ Hypergeometric1F1[\(-n\_rad\), 1 + m\_azm, \
\[Rho]\^2]\^2\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
3. Normalization procedure for the radial wave functions of quantum \
oscillator\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Consider normalization procedure for radial wave functions of the \
two-dimensional quantum oscillator.
This implies the integral condition:\
\>", "Text"],

Cell[BoxData[
    \(\[Integral]\_0\%\[Infinity] RR[n\_rad, m\_azm, \[Lambda], 
            r] \[DifferentialD]r = 1\)], "NumberedEquation"],

Cell["or for dimensionless radial functions:", "Text"],

Cell[BoxData[
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[n\_rad, 
              m\_azm, \[Rho]] \[DifferentialD]\[Rho]\) = 
      1\)], "NumberedEquation"],

Cell["\<\
Normalize radial wave functions for different values of quantum numbers:\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      StyleBox[\(n\_rad\),
        FontSlant->"Italic"]]],
  " = 0, 1, 2, 3\n",
  Cell[BoxData[
      \(m\_azm\)]],
  " = 0, 1, 2, 3"
}], "NumberedEquation"],

Cell[TextData[{
  "We will obtain values for constants ",
  Cell[BoxData[
      \(C[n\_rad, m\_azm]\)],
    FontSlant->"Italic"],
  " and normalized radial wave functions ",
  Cell[BoxData[
      \(R\_Nrm[n\_rad, m\_azm, r]\)],
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  "1) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 0, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 0"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[0, 0, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, m\_azm, \[Rho]], {n\_rad \[Rule] 0, 
          m\_azm \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(RR[0, 0, \[Rho]] = 
      ReplaceAll[
        RR[n\_rad, m\_azm, \[Rho]], {n\_rad \[Rule] 0, 
          m\_azm \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[0, 
            0, \[Rho]] \[DifferentialD]\[Rho]\)\), "\[IndentingNewLine]", 
    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[0, 
                0, \[Rho]] \[DifferentialD]\[Rho]\) \[Equal] 1, 
      C[0, 0]]\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ C[0, 0]\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\[Rho]\^2\)\ \[Rho]\ C[0, \
0]\^2\)\/\@\[Lambda]\)], "Output"],

Cell[BoxData[
    \(C[0, 0]\^2\/\(2\ \[Lambda]\)\)], "Output"],

Cell[BoxData[
    \({{C[0, 0] \[Rule] \(-\@2\)\ \@\[Lambda]}, {C[0, 
            0] \[Rule] \@2\ \@\[Lambda]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R\_Nrm[0, 
        0, \[Rho]] = \@2\ \(\@\[Lambda]\) \
\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\), "\[IndentingNewLine]", 
    \(R\_Nrm[0, 0, r] = 
      FullSimplify[
        ReplaceAll[
          R\_Nrm[0, 
            0, \[Rho]], {\[Rho] \[Rule] 
              r\ \@\[Lambda]}]]\), "\[IndentingNewLine]", 
    \(RR\_Nrm[0, 0, r] = FullSimplify[R\_Nrm[0, 0, r]\^2\ r]\)}], "Input"],

Cell[BoxData[
    \(\@2\ \[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \@\[Lambda]\)], "Output"],

Cell[BoxData[
    \(\@2\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \@\[Lambda]\)], \
"Output"],

Cell[BoxData[
    \(2\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \[Lambda]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "2) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 0, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 1"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[0, 1, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, m\_azm, \[Rho]], {n\_rad \[Rule] 0, 
          m\_azm \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(RR[0, 1, \[Rho]] = 
      ReplaceAll[
        RR[n\_rad, m\_azm, \[Rho]], {n\_rad \[Rule] 0, 
          m\_azm \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[0, 
            1, \[Rho]] \[DifferentialD]\[Rho]\)\), "\[IndentingNewLine]", 
    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[0, 
                1, \[Rho]] \[DifferentialD]\[Rho]\) \[Equal] 1, 
      C[0, 1]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Rho]\ C[0, \
1]\)\/\@\[Lambda]\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\[Rho]\^2\)\ \[Rho]\^3\ C[0, 1]\^2\)\/\[Lambda]\^\
\(3/2\)\)], "Output"],

Cell[BoxData[
    \(C[0, 1]\^2\/\(2\ \[Lambda]\^2\)\)], "Output"],

Cell[BoxData[
    \({{C[0, 1] \[Rule] \(-\@2\)\ \[Lambda]}, {C[0, 
            1] \[Rule] \@2\ \[Lambda]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R\_Nrm[0, 
        1, \[Rho]] = \@2\ \[Lambda] \( \[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\
\ \[Rho]\)\/\@\[Lambda]\), "\[IndentingNewLine]", 
    \(R\_Nrm[0, 1, r] = 
      FullSimplify[
        ReplaceAll[
          R\_Nrm[0, 
            1, \[Rho]], {\[Rho] \[Rule] 
              r\ \@\[Lambda]}]]\), "\[IndentingNewLine]", 
    \(RR\_Nrm[0, 1, r] = FullSimplify[R\_Nrm[0, 1, r]\^2\ r]\)}], "Input"],

Cell[BoxData[
    \(\@2\ \[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \@\[Lambda]\ \[Rho]\)], \
"Output"],

Cell[BoxData[
    \(\@2\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\ \[Lambda]\)], \
"Output"],

Cell[BoxData[
    \(2\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^3\ \[Lambda]\^2\)], \
"Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "3) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 0, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 2"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[0, 2, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, m\_azm, \[Rho]], {n\_rad \[Rule] 0, 
          m\_azm \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(RR[0, 2, \[Rho]] = 
      ReplaceAll[
        RR[n\_rad, m\_azm, \[Rho]], {n\_rad \[Rule] 0, 
          m\_azm \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[0, 
            2, \[Rho]] \[DifferentialD]\[Rho]\)\), "\[IndentingNewLine]", 
    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[0, 
                2, \[Rho]] \[DifferentialD]\[Rho]\) \[Equal] 1, 
      C[0, 2]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Rho]\^2\ C[0, 2]\)\/\
\[Lambda]\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\[Rho]\^2\)\ \[Rho]\^5\ C[0, 2]\^2\)\/\[Lambda]\^\
\(5/2\)\)], "Output"],

Cell[BoxData[
    \(C[0, 2]\^2\/\[Lambda]\^3\)], "Output"],

Cell[BoxData[
    \({{C[0, 2] \[Rule] \(-\[Lambda]\^\(3/2\)\)}, {C[0, 
            2] \[Rule] \[Lambda]\^\(3/2\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R\_Nrm[0, 
        2, \[Rho]] = \(\[Lambda]\^\(3/
              2\)\) \(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Rho]\^2\)\/\
\[Lambda]\), "\[IndentingNewLine]", 
    \(R\_Nrm[0, 2, r] = 
      FullSimplify[
        ReplaceAll[
          R\_Nrm[0, 
            2, \[Rho]], {\[Rho] \[Rule] 
              r\ \@\[Lambda]}]]\), "\[IndentingNewLine]", 
    \(RR\_Nrm[0, 2, r] = FullSimplify[R\_Nrm[0, 2, r]\^2\ r]\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \@\[Lambda]\ \[Rho]\^2\)], \
"Output"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^2\ \
\[Lambda]\^\(3/2\)\)], "Output"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^5\ \[Lambda]\^3\)], \
"Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "4) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 0, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[0, 3, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, m\_azm, \[Rho]], {n\_rad \[Rule] 0, 
          m\_azm \[Rule] 3}]\), "\[IndentingNewLine]", 
    \(RR[0, 3, \[Rho]] = 
      ReplaceAll[
        RR[n\_rad, m\_azm, \[Rho]], {n\_rad \[Rule] 0, 
          m\_azm \[Rule] 3}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[0, 
            3, \[Rho]] \[DifferentialD]\[Rho]\)\), "\[IndentingNewLine]", 
    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[0, 
                3, \[Rho]] \[DifferentialD]\[Rho]\) \[Equal] 1, 
      C[0, 3]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Rho]\^3\ C[0, 3]\)\/\
\[Lambda]\^\(3/2\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\[Rho]\^2\)\ \[Rho]\^7\ C[0, 3]\^2\)\/\[Lambda]\^\
\(7/2\)\)], "Output"],

Cell[BoxData[
    \(\(3\ C[0, 3]\^2\)\/\[Lambda]\^4\)], "Output"],

Cell[BoxData[
    \({{C[0, 3] \[Rule] \(-\(\[Lambda]\^2\/\@3\)\)}, {C[0, 
            3] \[Rule] \[Lambda]\^2\/\@3}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R\_Nrm[0, 
        3, \[Rho]] = \(\[Lambda]\^2\/\@3\) \
\(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Rho]\^3\)\/\[Lambda]\^\(3/2\)\), \
"\[IndentingNewLine]", 
    \(R\_Nrm[0, 3, r] = 
      FullSimplify[
        ReplaceAll[
          R\_Nrm[0, 
            3, \[Rho]], {\[Rho] \[Rule] 
              r\ \@\[Lambda]}]]\), "\[IndentingNewLine]", 
    \(RR\_Nrm[0, 3, r] = FullSimplify[R\_Nrm[0, 3, r]\^2\ r]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \@\[Lambda]\ \[Rho]\^3\)\/\@3\
\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^3\ \
\[Lambda]\^2\)\/\@3\)], "Output"],

Cell[BoxData[
    \(1\/3\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^7\ \[Lambda]\^4\)], \
"Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "5) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 0"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[1, 0, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, m\_azm, \[Rho]], {n\_rad \[Rule] 1, 
          m\_azm \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(RR[1, 0, \[Rho]] = 
      ReplaceAll[
        RR[n\_rad, m\_azm, \[Rho]], {n\_rad \[Rule] 1, 
          m\_azm \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[1, 
            0, \[Rho]] \[DifferentialD]\[Rho]\)\), "\[IndentingNewLine]", 
    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[1, 
                0, \[Rho]] \[DifferentialD]\[Rho]\) \[Equal] 1, 
      C[1, 0]]\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \((1 - \[Rho]\^2)\)\ C[1, 
        0]\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\[Rho]\^2\)\ \[Rho]\ \((1 - \[Rho]\^2)\)\^2\ C[1, \
0]\^2\)\/\@\[Lambda]\)], "Output"],

Cell[BoxData[
    \(C[1, 0]\^2\/\(2\ \[Lambda]\)\)], "Output"],

Cell[BoxData[
    \({{C[1, 0] \[Rule] \(-\@2\)\ \@\[Lambda]}, {C[1, 
            0] \[Rule] \@2\ \@\[Lambda]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R\_Nrm[1, 
        0, \[Rho]] = \@2\ \(\@\[Lambda]\) \
\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \((1 - \[Rho]\^2)\)\), "\
\[IndentingNewLine]", 
    \(R\_Nrm[1, 0, r] = 
      FullSimplify[
        ReplaceAll[
          R\_Nrm[1, 
            0, \[Rho]], {\[Rho] \[Rule] 
              r\ \@\[Lambda]}]]\), "\[IndentingNewLine]", 
    \(RR\_Nrm[1, 0, r] = FullSimplify[R\_Nrm[1, 0, r]\^2\ r]\)}], "Input"],

Cell[BoxData[
    \(\@2\ \[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \@\[Lambda]\ \((1 - \[Rho]\
\^2)\)\)], "Output"],

Cell[BoxData[
    \(\@2\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \@\[Lambda]\ \
\((1 - r\^2\ \[Lambda])\)\)], "Output"],

Cell[BoxData[
    \(2\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \[Lambda]\ \((\(-1\) + \
r\^2\ \[Lambda])\)\^2\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "6) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 1"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[1, 1, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, m\_azm, \[Rho]], {n\_rad \[Rule] 1, 
          m\_azm \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(RR[1, 1, \[Rho]] = 
      ReplaceAll[
        RR[n\_rad, m\_azm, \[Rho]], {n\_rad \[Rule] 1, 
          m\_azm \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[1, 
            1, \[Rho]] \[DifferentialD]\[Rho]\)\), "\[IndentingNewLine]", 
    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[1, 
                1, \[Rho]] \[DifferentialD]\[Rho]\) \[Equal] 1, 
      C[1, 1]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Rho]\ \((1 - \
\[Rho]\^2\/2)\)\ C[1, 1]\)\/\@\[Lambda]\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\[Rho]\^2\)\ \[Rho]\^3\ \((1 - \[Rho]\^2\/2)\)\^2\
\ C[1, 1]\^2\)\/\[Lambda]\^\(3/2\)\)], "Output"],

Cell[BoxData[
    \(C[1, 1]\^2\/\(4\ \[Lambda]\^2\)\)], "Output"],

Cell[BoxData[
    \({{C[1, 1] \[Rule] \(-2\)\ \[Lambda]}, {C[1, 1] \[Rule] 
          2\ \[Lambda]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R\_Nrm[1, 1, \[Rho]] = 
      2\ \[Lambda] \( \[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Rho]\ \((1 - \
\[Rho]\^2\/2)\)\)\/\@\[Lambda]\), "\[IndentingNewLine]", 
    \(R\_Nrm[1, 1, r] = 
      FullSimplify[
        ReplaceAll[
          R\_Nrm[1, 
            1, \[Rho]], {\[Rho] \[Rule] 
              r\ \@\[Lambda]}]]\), "\[IndentingNewLine]", 
    \(RR\_Nrm[1, 1, r] = FullSimplify[R\_Nrm[1, 1, r]\^2\ r]\)}], "Input"],

Cell[BoxData[
    \(2\ \[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \@\[Lambda]\ \[Rho]\ \((1 - \
\[Rho]\^2\/2)\)\)], "Output"],

Cell[BoxData[
    \(\(-\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\)\ r\ \[Lambda]\ \
\((\(-2\) + r\^2\ \[Lambda])\)\)], "Output"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^3\ \[Lambda]\^2\ \
\((\(-2\) + r\^2\ \[Lambda])\)\^2\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "7) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 2"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[1, 2, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, m\_azm, \[Rho]], {n\_rad \[Rule] 1, 
          m\_azm \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(RR[1, 2, \[Rho]] = 
      ReplaceAll[
        RR[n\_rad, m\_azm, \[Rho]], {n\_rad \[Rule] 1, 
          m\_azm \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[1, 
            2, \[Rho]] \[DifferentialD]\[Rho]\)\), "\[IndentingNewLine]", 
    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[1, 
                2, \[Rho]] \[DifferentialD]\[Rho]\) \[Equal] 1, 
      C[1, 2]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Rho]\^2\ \((1 - \
\[Rho]\^2\/3)\)\ C[1, 2]\)\/\[Lambda]\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\[Rho]\^2\)\ \[Rho]\^5\ \((1 - \[Rho]\^2\/3)\)\^2\
\ C[1, 2]\^2\)\/\[Lambda]\^\(5/2\)\)], "Output"],

Cell[BoxData[
    \(C[1, 2]\^2\/\(3\ \[Lambda]\^3\)\)], "Output"],

Cell[BoxData[
    \({{C[1, 2] \[Rule] \(-\@3\)\ \[Lambda]\^\(3/2\)}, {C[1, 
            2] \[Rule] \@3\ \[Lambda]\^\(3/2\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R\_Nrm[1, 
        2, \[Rho]] = \@3\ \(\[Lambda]\^\(3/
              2\)\) \(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Rho]\^2\ \((1 \
- \[Rho]\^2\/3)\)\)\/\[Lambda]\), "\[IndentingNewLine]", 
    \(R\_Nrm[1, 2, r] = 
      FullSimplify[
        ReplaceAll[
          R\_Nrm[1, 
            2, \[Rho]], {\[Rho] \[Rule] 
              r\ \@\[Lambda]}]]\), "\[IndentingNewLine]", 
    \(RR\_Nrm[1, 2, r] = FullSimplify[R\_Nrm[1, 2, r]\^2\ r]\)}], "Input"],

Cell[BoxData[
    \(\@3\ \[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \@\[Lambda]\ \[Rho]\^2\ \
\((1 - \[Rho]\^2\/3)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^2\ \
\[Lambda]\^\(3/2\)\ \((\(-3\) + r\^2\ \[Lambda])\)\)\/\@3\)\)\)], "Output"],

Cell[BoxData[
    \(1\/3\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^5\ \[Lambda]\^3\ \
\((\(-3\) + r\^2\ \[Lambda])\)\^2\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "8) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[1, 3, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, m\_azm, \[Rho]], {n\_rad \[Rule] 1, 
          m\_azm \[Rule] 3}]\), "\[IndentingNewLine]", 
    \(RR[1, 3, \[Rho]] = 
      ReplaceAll[
        RR[n\_rad, m\_azm, \[Rho]], {n\_rad \[Rule] 1, 
          m\_azm \[Rule] 3}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[1, 
            3, \[Rho]] \[DifferentialD]\[Rho]\)\), "\[IndentingNewLine]", 
    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[1, 
                3, \[Rho]] \[DifferentialD]\[Rho]\) \[Equal] 1, 
      C[1, 3]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Rho]\^3\ \((1 - \
\[Rho]\^2\/4)\)\ C[1, 3]\)\/\[Lambda]\^\(3/2\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\[Rho]\^2\)\ \[Rho]\^7\ \((1 - \[Rho]\^2\/4)\)\^2\
\ C[1, 3]\^2\)\/\[Lambda]\^\(7/2\)\)], "Output"],

Cell[BoxData[
    \(\(3\ C[1, 3]\^2\)\/\(4\ \[Lambda]\^4\)\)], "Output"],

Cell[BoxData[
    \({{C[1, 3] \[Rule] \(-\(\(2\ \[Lambda]\^2\)\/\@3\)\)}, {C[1, 
            3] \[Rule] \(2\ \[Lambda]\^2\)\/\@3}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R\_Nrm[1, 
        3, \[Rho]] = \(\(2\ \[Lambda]\^2\)\/\@3\) \(\[ExponentialE]\^\(-\(\
\[Rho]\^2\/2\)\)\ \[Rho]\^3\ \((1 - \[Rho]\^2\/4)\)\)\/\[Lambda]\^\(3/2\)\), \
"\[IndentingNewLine]", 
    \(R\_Nrm[1, 3, r] = 
      FullSimplify[
        ReplaceAll[
          R\_Nrm[1, 
            3, \[Rho]], {\[Rho] \[Rule] 
              r\ \@\[Lambda]}]]\), "\[IndentingNewLine]", 
    \(RR\_Nrm[1, 3, r] = FullSimplify[R\_Nrm[1, 3, r]\^2\ r]\)}], "Input"],

Cell[BoxData[
    \(\(2\ \[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \@\[Lambda]\ \[Rho]\^3\ \
\((1 - \[Rho]\^2\/4)\)\)\/\@3\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^3\ \
\[Lambda]\^2\ \((\(-4\) + r\^2\ \[Lambda])\)\)\/\(2\ \@3\)\)\)\)], "Output"],

Cell[BoxData[
    \(1\/12\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^7\ \[Lambda]\^4\ \
\((\(-4\) + r\^2\ \[Lambda])\)\^2\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "9) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 2, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 0"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[2, 0, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, m\_azm, \[Rho]], {n\_rad \[Rule] 2, 
          m\_azm \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(RR[2, 0, \[Rho]] = 
      ReplaceAll[
        RR[n\_rad, m\_azm, \[Rho]], {n\_rad \[Rule] 2, 
          m\_azm \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[2, 
            0, \[Rho]] \[DifferentialD]\[Rho]\)\), "\[IndentingNewLine]", 
    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[2, 
                0, \[Rho]] \[DifferentialD]\[Rho]\) \[Equal] 1, 
      C[2, 0]]\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \((1 - 
          2\ \[Rho]\^2 + \[Rho]\^4\/2)\)\ C[2, 0]\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\[Rho]\^2\)\ \[Rho]\ \((1 - 2\ \[Rho]\^2 + \[Rho]\
\^4\/2)\)\^2\ C[2, 0]\^2\)\/\@\[Lambda]\)], "Output"],

Cell[BoxData[
    \(C[2, 0]\^2\/\(2\ \[Lambda]\)\)], "Output"],

Cell[BoxData[
    \({{C[2, 0] \[Rule] \(-\@2\)\ \@\[Lambda]}, {C[2, 
            0] \[Rule] \@2\ \@\[Lambda]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R\_Nrm[2, 
        0, \[Rho]] = \@2\ \(\@\[Lambda]\) \
\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \((1 - 
            2\ \[Rho]\^2 + \[Rho]\^4\/2)\)\), "\[IndentingNewLine]", 
    \(R\_Nrm[2, 0, r] = 
      FullSimplify[
        ReplaceAll[
          R\_Nrm[2, 
            0, \[Rho]], {\[Rho] \[Rule] 
              r\ \@\[Lambda]}]]\), "\[IndentingNewLine]", 
    \(RR\_Nrm[2, 0, r] = FullSimplify[R\_Nrm[2, 0, r]\^2\ r]\)}], "Input"],

Cell[BoxData[
    \(\@2\ \[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \@\[Lambda]\ \((1 - 
          2\ \[Rho]\^2 + \[Rho]\^4\/2)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \@\[Lambda]\ \((2 + \
r\^2\ \[Lambda]\ \((\(-4\) + r\^2\ \[Lambda])\))\)\)\/\@2\)], "Output"],

Cell[BoxData[
    \(1\/2\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \[Lambda]\ \((2 + r\
\^2\ \[Lambda]\ \((\(-4\) + r\^2\ \[Lambda])\))\)\^2\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "10) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 2, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 1"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[2, 1, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, m\_azm, \[Rho]], {n\_rad \[Rule] 2, 
          m\_azm \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(RR[2, 1, \[Rho]] = 
      ReplaceAll[
        RR[n\_rad, m\_azm, \[Rho]], {n\_rad \[Rule] 2, 
          m\_azm \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[2, 
            1, \[Rho]] \[DifferentialD]\[Rho]\)\), "\[IndentingNewLine]", 
    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[2, 
                1, \[Rho]] \[DifferentialD]\[Rho]\) \[Equal] 1, 
      C[2, 1]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Rho]\ \((1 - \[Rho]\^2 + \
\[Rho]\^4\/6)\)\ C[2, 1]\)\/\@\[Lambda]\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\[Rho]\^2\)\ \[Rho]\^3\ \((1 - \[Rho]\^2 + \[Rho]\
\^4\/6)\)\^2\ C[2, 1]\^2\)\/\[Lambda]\^\(3/2\)\)], "Output"],

Cell[BoxData[
    \(C[2, 1]\^2\/\(6\ \[Lambda]\^2\)\)], "Output"],

Cell[BoxData[
    \({{C[2, 1] \[Rule] \(-\@6\)\ \[Lambda]}, {C[2, 
            1] \[Rule] \@6\ \[Lambda]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R\_Nrm[2, 
        1, \[Rho]] = \@6\ \[Lambda] \( \[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\
\ \[Rho]\ \((1 - \[Rho]\^2 + \[Rho]\^4\/6)\)\)\/\@\[Lambda]\), "\
\[IndentingNewLine]", 
    \(R\_Nrm[2, 1, r] = 
      FullSimplify[
        ReplaceAll[
          R\_Nrm[2, 
            1, \[Rho]], {\[Rho] \[Rule] 
              r\ \@\[Lambda]}]]\), "\[IndentingNewLine]", 
    \(RR\_Nrm[2, 1, r] = FullSimplify[R\_Nrm[2, 1, r]\^2\ r]\)}], "Input"],

Cell[BoxData[
    \(\@6\ \[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \@\[Lambda]\ \[Rho]\ \((1 \
- \[Rho]\^2 + \[Rho]\^4\/6)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\ \[Lambda]\ \((6 \
+ r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \[Lambda])\))\)\)\/\@6\)], "Output"],

Cell[BoxData[
    \(1\/6\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^3\ \[Lambda]\^2\ \
\((6 + r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \[Lambda])\))\)\^2\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "11) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 2, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 2"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[2, 2, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, m\_azm, \[Rho]], {n\_rad \[Rule] 2, 
          m\_azm \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(RR[2, 2, \[Rho]] = 
      ReplaceAll[
        RR[n\_rad, m\_azm, \[Rho]], {n\_rad \[Rule] 2, 
          m\_azm \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[2, 
            2, \[Rho]] \[DifferentialD]\[Rho]\)\), "\[IndentingNewLine]", 
    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[2, 
                2, \[Rho]] \[DifferentialD]\[Rho]\) \[Equal] 1, 
      C[2, 2]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Rho]\^2\ \((1 - \(2\ \[Rho]\
\^2\)\/3 + \[Rho]\^4\/12)\)\ C[2, 2]\)\/\[Lambda]\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\[Rho]\^2\)\ \[Rho]\^5\ \((1 - \(2\ \
\[Rho]\^2\)\/3 + \[Rho]\^4\/12)\)\^2\ C[2, 2]\^2\)\/\[Lambda]\^\(5/2\)\)], \
"Output"],

Cell[BoxData[
    \(C[2, 2]\^2\/\(6\ \[Lambda]\^3\)\)], "Output"],

Cell[BoxData[
    \({{C[2, 2] \[Rule] \(-\@6\)\ \[Lambda]\^\(3/2\)}, {C[2, 
            2] \[Rule] \@6\ \[Lambda]\^\(3/2\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R\_Nrm[2, 
        2, \[Rho]] = \@6\ \(\[Lambda]\^\(3/
              2\)\) \(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Rho]\^2\ \((1 \
- \(2\ \[Rho]\^2\)\/3 + \[Rho]\^4\/12)\)\)\/\[Lambda]\), \
"\[IndentingNewLine]", 
    \(R\_Nrm[2, 2, r] = 
      FullSimplify[
        ReplaceAll[
          R\_Nrm[2, 
            2, \[Rho]], {\[Rho] \[Rule] 
              r\ \@\[Lambda]}]]\), "\[IndentingNewLine]", 
    \(RR\_Nrm[2, 2, r] = FullSimplify[R\_Nrm[2, 2, r]\^2\ r]\)}], "Input"],

Cell[BoxData[
    \(\@6\ \[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \@\[Lambda]\ \[Rho]\^2\ \
\((1 - \(2\ \[Rho]\^2\)\/3 + \[Rho]\^4\/12)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^2\ \
\[Lambda]\^\(3/2\)\ \((\(-6\) + r\^2\ \[Lambda])\)\ \((\(-2\) + r\^2\ \
\[Lambda])\)\)\/\(2\ \@6\)\)], "Output"],

Cell[BoxData[
    \(1\/24\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^5\ \[Lambda]\^3\ \
\((\(-6\) + r\^2\ \[Lambda])\)\^2\ \((\(-2\) + r\^2\ \[Lambda])\)\^2\)], \
"Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "12) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 2, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[2, 3, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, m\_azm, \[Rho]], {n\_rad \[Rule] 2, 
          m\_azm \[Rule] 3}]\), "\[IndentingNewLine]", 
    \(RR[2, 3, \[Rho]] = 
      ReplaceAll[
        RR[n\_rad, m\_azm, \[Rho]], {n\_rad \[Rule] 2, 
          m\_azm \[Rule] 3}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[2, 
            3, \[Rho]] \[DifferentialD]\[Rho]\)\), "\[IndentingNewLine]", 
    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[2, 
                3, \[Rho]] \[DifferentialD]\[Rho]\) \[Equal] 1, 
      C[2, 3]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Rho]\^3\ \((1 - \
\[Rho]\^2\/2 + \[Rho]\^4\/20)\)\ C[2, 3]\)\/\[Lambda]\^\(3/2\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\[Rho]\^2\)\ \[Rho]\^7\ \((1 - \[Rho]\^2\/2 + \
\[Rho]\^4\/20)\)\^2\ C[2, 3]\^2\)\/\[Lambda]\^\(7/2\)\)], "Output"],

Cell[BoxData[
    \(\(3\ C[2, 3]\^2\)\/\(10\ \[Lambda]\^4\)\)], "Output"],

Cell[BoxData[
    \({{C[2, 3] \[Rule] \(-\@\(10\/3\)\)\ \[Lambda]\^2}, {C[2, 
            3] \[Rule] \@\(10\/3\)\ \[Lambda]\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R\_Nrm[2, 
        3, \[Rho]] = \@\(10\/3\)\ \(\[Lambda]\^2\) \(\[ExponentialE]\^\(-\(\
\[Rho]\^2\/2\)\)\ \[Rho]\^3\ \((1 - \[Rho]\^2\/2 + \[Rho]\^4\/20)\)\)\/\
\[Lambda]\^\(3/2\)\), "\[IndentingNewLine]", 
    \(R\_Nrm[2, 3, r] = 
      FullSimplify[
        ReplaceAll[
          R\_Nrm[2, 
            3, \[Rho]], {\[Rho] \[Rule] 
              r\ \@\[Lambda]}]]\), "\[IndentingNewLine]", 
    \(RR\_Nrm[2, 3, r] = FullSimplify[R\_Nrm[2, 3, r]\^2\ r]\)}], "Input"],

Cell[BoxData[
    \(\@\(10\/3\)\ \[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \@\[Lambda]\ \
\[Rho]\^3\ \((1 - \[Rho]\^2\/2 + \[Rho]\^4\/20)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^3\ \[Lambda]\^2\ \
\((20 + r\^2\ \[Lambda]\ \((\(-10\) + r\^2\ \[Lambda])\))\)\)\/\(2\ \
\@30\)\)], "Output"],

Cell[BoxData[
    \(1\/120\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^7\ \[Lambda]\^4\ \
\((20 + r\^2\ \[Lambda]\ \((\(-10\) + r\^2\ \[Lambda])\))\)\^2\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "13) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 3, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 0"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[3, 0, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, m\_azm, \[Rho]], {n\_rad \[Rule] 3, 
          m\_azm \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(RR[3, 0, \[Rho]] = 
      ReplaceAll[
        RR[n\_rad, m\_azm, \[Rho]], {n\_rad \[Rule] 3, 
          m\_azm \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[3, 
            0, \[Rho]] \[DifferentialD]\[Rho]\)\), "\[IndentingNewLine]", 
    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[3, 
                0, \[Rho]] \[DifferentialD]\[Rho]\) \[Equal] 1, 
      C[3, 0]]\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \((1 - 
          3\ \[Rho]\^2 + \(3\ \[Rho]\^4\)\/2 - \[Rho]\^6\/6)\)\ C[3, 
        0]\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\[Rho]\^2\)\ \[Rho]\ \((1 - 3\ \[Rho]\^2 + \(3\ \
\[Rho]\^4\)\/2 - \[Rho]\^6\/6)\)\^2\ C[3, 0]\^2\)\/\@\[Lambda]\)], "Output"],

Cell[BoxData[
    \(C[3, 0]\^2\/\(2\ \[Lambda]\)\)], "Output"],

Cell[BoxData[
    \({{C[3, 0] \[Rule] \(-\@2\)\ \@\[Lambda]}, {C[3, 
            0] \[Rule] \@2\ \@\[Lambda]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R\_Nrm[3, 
        0, \[Rho]] = \@2\ \(\@\[Lambda]\) \
\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \((1 - 
            3\ \[Rho]\^2 + \(3\ \[Rho]\^4\)\/2 - \[Rho]\^6\/6)\)\), "\
\[IndentingNewLine]", 
    \(R\_Nrm[3, 0, r] = 
      FullSimplify[
        ReplaceAll[
          R\_Nrm[3, 
            0, \[Rho]], {\[Rho] \[Rule] 
              r\ \@\[Lambda]}]]\), "\[IndentingNewLine]", 
    \(RR\_Nrm[3, 0, r] = FullSimplify[R\_Nrm[3, 0, r]\^2\ r]\)}], "Input"],

Cell[BoxData[
    \(\@2\ \[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \@\[Lambda]\ \((1 - 
          3\ \[Rho]\^2 + \(3\ \[Rho]\^4\)\/2 - \[Rho]\^6\/6)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \@\[Lambda]\ \((6 - \
r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \[Lambda])\)\ \((\(-3\) + r\^2\ \[Lambda])\
\))\)\)\/\(3\ \@2\)\)], "Output"],

Cell[BoxData[
    \(1\/18\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \[Lambda]\ \((\(-6\
\) + r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \[Lambda])\)\ \((\(-3\) + r\^2\ \
\[Lambda])\))\)\^2\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "14) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 3, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 1"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[3, 1, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, m\_azm, \[Rho]], {n\_rad \[Rule] 3, 
          m\_azm \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(RR[3, 1, \[Rho]] = 
      ReplaceAll[
        RR[n\_rad, m\_azm, \[Rho]], {n\_rad \[Rule] 3, 
          m\_azm \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[3, 
            1, \[Rho]] \[DifferentialD]\[Rho]\)\), "\[IndentingNewLine]", 
    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[3, 
                1, \[Rho]] \[DifferentialD]\[Rho]\) \[Equal] 1, 
      C[3, 1]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Rho]\ \((1 - \(3\ \[Rho]\^2\
\)\/2 + \[Rho]\^4\/2 - \[Rho]\^6\/24)\)\ C[3, 1]\)\/\@\[Lambda]\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\[Rho]\^2\)\ \[Rho]\^3\ \((1 - \(3\ \
\[Rho]\^2\)\/2 + \[Rho]\^4\/2 - \[Rho]\^6\/24)\)\^2\ C[3, \
1]\^2\)\/\[Lambda]\^\(3/2\)\)], "Output"],

Cell[BoxData[
    \(C[3, 1]\^2\/\(8\ \[Lambda]\^2\)\)], "Output"],

Cell[BoxData[
    \({{C[3, 1] \[Rule] \(-2\)\ \@2\ \[Lambda]}, {C[3, 1] \[Rule] 
          2\ \@2\ \[Lambda]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R\_Nrm[3, 1, \[Rho]] = 
      2\ \@2\ \[Lambda] \( \[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Rho]\ \
\((1 - \(3\ \[Rho]\^2\)\/2 + \[Rho]\^4\/2 - \
\[Rho]\^6\/24)\)\)\/\@\[Lambda]\), "\[IndentingNewLine]", 
    \(R\_Nrm[3, 1, r] = 
      FullSimplify[
        ReplaceAll[
          R\_Nrm[3, 
            1, \[Rho]], {\[Rho] \[Rule] 
              r\ \@\[Lambda]}]]\), "\[IndentingNewLine]", 
    \(RR\_Nrm[3, 1, r] = FullSimplify[R\_Nrm[3, 1, r]\^2\ r]\)}], "Input"],

Cell[BoxData[
    \(2\ \@2\ \[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \@\[Lambda]\ \[Rho]\ \
\((1 - \(3\ \[Rho]\^2\)\/2 + \[Rho]\^4\/2 - \[Rho]\^6\/24)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\ \[Lambda]\ \
\((\(-24\) + 
                r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \[Lambda])\)\^2)\)\)\/\(6\ \
\@2\)\)\)\)], "Output"],

Cell[BoxData[
    \(1\/72\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^3\ \[Lambda]\^2\ \
\((\(-24\) + r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \[Lambda])\)\^2)\)\^2\)], \
"Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "15) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 3, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 2"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[3, 2, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, m\_azm, \[Rho]], {n\_rad \[Rule] 3, 
          m\_azm \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(RR[3, 2, \[Rho]] = 
      ReplaceAll[
        RR[n\_rad, m\_azm, \[Rho]], {n\_rad \[Rule] 3, 
          m\_azm \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[3, 
            2, \[Rho]] \[DifferentialD]\[Rho]\)\), "\[IndentingNewLine]", 
    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[3, 
                2, \[Rho]] \[DifferentialD]\[Rho]\) \[Equal] 1, 
      C[3, 2]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Rho]\^2\ \((1 - \[Rho]\^2 + \
\[Rho]\^4\/4 - \[Rho]\^6\/60)\)\ C[3, 2]\)\/\[Lambda]\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\[Rho]\^2\)\ \[Rho]\^5\ \((1 - \[Rho]\^2 + \[Rho]\
\^4\/4 - \[Rho]\^6\/60)\)\^2\ C[3, 2]\^2\)\/\[Lambda]\^\(5/2\)\)], "Output"],

Cell[BoxData[
    \(C[3, 2]\^2\/\(10\ \[Lambda]\^3\)\)], "Output"],

Cell[BoxData[
    \({{C[3, 2] \[Rule] \(-\@10\)\ \[Lambda]\^\(3/2\)}, {C[3, 
            2] \[Rule] \@10\ \[Lambda]\^\(3/2\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R\_Nrm[3, 
        2, \[Rho]] = \@10\ \(\[Lambda]\^\(3/
              2\)\) \(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Rho]\^2\ \((1 \
- \[Rho]\^2 + \[Rho]\^4\/4 - \[Rho]\^6\/60)\)\)\/\[Lambda]\), "\
\[IndentingNewLine]", 
    \(R\_Nrm[3, 2, r] = 
      FullSimplify[
        ReplaceAll[
          R\_Nrm[3, 
            2, \[Rho]], {\[Rho] \[Rule] 
              r\ \@\[Lambda]}]]\), "\[IndentingNewLine]", 
    \(RR\_Nrm[3, 2, r] = FullSimplify[R\_Nrm[3, 2, r]\^2\ r]\)}], "Input"],

Cell[BoxData[
    \(\@10\ \[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \@\[Lambda]\ \[Rho]\^2\ \
\((1 - \[Rho]\^2 + \[Rho]\^4\/4 - \[Rho]\^6\/60)\)\)], "Output"],

Cell[BoxData[
    \(\@10\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^2\ \[Lambda]\
\^\(3/2\)\ \((1 - 
          1\/60\ r\^2\ \[Lambda]\ \((60 + 
                r\^2\ \[Lambda]\ \((\(-15\) + 
                      r\^2\ \[Lambda])\))\))\)\)], "Output"],

Cell[BoxData[
    \(10\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^5\ \[Lambda]\^3\ \((1 \
- 1\/60\ r\^2\ \[Lambda]\ \((60 + r\^2\ \[Lambda]\ \((\(-15\) + r\^2\ \
\[Lambda])\))\))\)\^2\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "16) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 3, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[3, 3, \[Rho]] = 
      ReplaceAll[
        R[n\_rad, m\_azm, \[Rho]], {n\_rad \[Rule] 3, 
          m\_azm \[Rule] 3}]\), "\[IndentingNewLine]", 
    \(RR[3, 3, \[Rho]] = 
      ReplaceAll[
        RR[n\_rad, m\_azm, \[Rho]], {n\_rad \[Rule] 3, 
          m\_azm \[Rule] 3}]\), "\[IndentingNewLine]", 
    \(\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[3, 
            3, \[Rho]] \[DifferentialD]\[Rho]\)\), "\[IndentingNewLine]", 
    \(Solve[\(1\/\@\[Lambda]\) \(\[Integral]\_0\%\[Infinity] RR[3, 
                3, \[Rho]] \[DifferentialD]\[Rho]\) \[Equal] 1, 
      C[3, 3]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Rho]\^3\ \((1 - \(3\ \[Rho]\
\^2\)\/4 + \(3\ \[Rho]\^4\)\/20 - \[Rho]\^6\/120)\)\ C[3, \
3]\)\/\[Lambda]\^\(3/2\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\[Rho]\^2\)\ \[Rho]\^7\ \((1 - \(3\ \
\[Rho]\^2\)\/4 + \(3\ \[Rho]\^4\)\/20 - \[Rho]\^6\/120)\)\^2\ C[3, 3]\^2\)\/\
\[Lambda]\^\(7/2\)\)], "Output"],

Cell[BoxData[
    \(\(3\ C[3, 3]\^2\)\/\(20\ \[Lambda]\^4\)\)], "Output"],

Cell[BoxData[
    \({{C[3, 3] \[Rule] \(-2\)\ \@\(5\/3\)\ \[Lambda]\^2}, {C[3, 3] \[Rule] 
          2\ \@\(5\/3\)\ \[Lambda]\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R\_Nrm[3, 3, \[Rho]] = 
      2\ \@\(5\/3\)\ \(\[Lambda]\^2\) \
\(\[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \[Rho]\^3\ \((1 - \(3\ \
\[Rho]\^2\)\/4 + \(3\ \[Rho]\^4\)\/20 - \[Rho]\^6\/120)\)\)\/\[Lambda]\^\(3/2\
\)\), "\[IndentingNewLine]", 
    \(R\_Nrm[3, 3, r] = 
      FullSimplify[
        ReplaceAll[
          R\_Nrm[3, 
            3, \[Rho]], {\[Rho] \[Rule] 
              r\ \@\[Lambda]}]]\), "\[IndentingNewLine]", 
    \(RR\_Nrm[3, 3, r] = FullSimplify[R\_Nrm[3, 3, r]\^2\ r]\)}], "Input"],

Cell[BoxData[
    \(2\ \@\(5\/3\)\ \[ExponentialE]\^\(-\(\[Rho]\^2\/2\)\)\ \@\[Lambda]\ \
\[Rho]\^3\ \((1 - \(3\ \[Rho]\^2\)\/4 + \(3\ \[Rho]\^4\)\/20 - \
\[Rho]\^6\/120)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^3\ \
\[Lambda]\^2\ \((\(-120\) + 
                r\^2\ \[Lambda]\ \((90 + 
                      r\^2\ \[Lambda]\ \((\(-18\) + 
                            r\^2\ \[Lambda])\))\))\)\)\/\(12\ \@15\)\)\)\)], \
"Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^7\ \[Lambda]\^4\ \
\((\(-120\) + r\^2\ \[Lambda]\ \((90 + r\^2\ \[Lambda]\ \((\(-18\) + r\^2\ \
\[Lambda])\))\))\)\^2\)\/2160\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
4. Normalized radial wave functions of the two-dimensional quantum oscillator\
\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Resulting normalized radial wave functions of the two-dimensional quantum \
oscillator are:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(R\_Oscl[0, 
          0, \[Lambda]] = \@2\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\
\)\ \@\[Lambda];\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[0, 0, \[Lambda]] = 
        2\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \[Lambda];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[0, 
          1, \[Lambda]] = \@2\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\
\)\ r\ \[Lambda];\)\), "\[IndentingNewLine]", 
    \(\(RR\_Oscl[0, 2, \[Lambda]] = 
        2\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \[Lambda];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[0, 
          2, \[Lambda]] = \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\
\^2\ \[Lambda]\^\(3/2\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[0, 
          2, \[Lambda]] = \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^5\ \
\[Lambda]\^3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[0, 
          3, \[Lambda]] = \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
r\^3\ \[Lambda]\^2\)\/\@3;\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[0, 3, \[Lambda]] = 
        1\/3\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^7\ \
\[Lambda]\^4;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[1, 
          0, \[Lambda]] = \@2\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\
\)\ \@\[Lambda]\ \((1 - r\^2\ \[Lambda])\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[1, 0, \[Lambda]] = 
        2\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \[Lambda]\ \((1 - \
r\^2\ \[Lambda])\)\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[1, 
          1, \[Lambda]] = \(-\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\
\)\ r\ \[Lambda]\ \((\(-2\) + 
              r\^2\ \[Lambda])\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[1, 
          1, \[Lambda]] = \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^3\ \
\[Lambda]\^2\ \((\(-2\) + r\^2\ \[Lambda])\)\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[1, 
          2, \[Lambda]] = \(-\(\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\
\)\)\ r\^2\ \[Lambda]\^\(3/2\)\ \((\(-3\) + 
                    r\^2\ \[Lambda])\)\)\/\@3\)\);\)\), \
"\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[1, 2, \[Lambda]] = 
        1\/3\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^5\ \[Lambda]\^3\ \
\((\(-3\) + r\^2\ \[Lambda])\)\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[1, 
          3, \[Lambda]] = \(-\(\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\
\)\)\ r\^3\ \[Lambda]\^2\ \((\(-4\) + 
                    r\^2\ \[Lambda])\)\)\/\(2\ \@3\)\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[1, 3, \[Lambda]] = 
        1\/12\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^7\ \[Lambda]\^4\ \
\((\(-4\) + r\^2\ \[Lambda])\)\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[2, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
\@\[Lambda]\ \((2 + r\^2\ \[Lambda]\ \((\(-4\) + r\^2\ \
\[Lambda])\))\)\)\/\@2;\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[2, 0, \[Lambda]] = 
        1\/2\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \[Lambda]\ \((2 + \
r\^2\ \[Lambda]\ \((\(-4\) + r\^2\ \[Lambda])\))\)\^2;\)\(\[IndentingNewLine]\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[2, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
r\ \[Lambda]\ \((6 + r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \
\[Lambda])\))\)\)\/\@6;\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[2, 1, \[Lambda]] = 
        1\/6\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^3\ \[Lambda]\^2\ \
\((6 + r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \[Lambda])\))\)\^2;\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[2, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
r\^2\ \[Lambda]\^\(3/2\)\ \((\(-6\) + r\^2\ \[Lambda])\)\ \((\(-2\) + r\^2\ \
\[Lambda])\)\)\/\(2\ \@6\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[2, 2, \[Lambda]] = 
        1\/24\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^5\ \[Lambda]\^3\ \
\((\(-6\) + r\^2\ \[Lambda])\)\^2\ \((\(-2\) + r\^2\ \[Lambda])\)\^2;\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[2, 
          3, \[Lambda]] = \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
r\^3\ \[Lambda]\^2\ \((20 + r\^2\ \[Lambda]\ \((\(-10\) + r\^2\ \[Lambda])\))\
\)\)\/\(2\ \@30\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[2, 3, \[Lambda]] = 
        1\/120\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^7\ \[Lambda]\^4\
\ \((20 + r\^2\ \[Lambda]\ \((\(-10\) + r\^2\ \[Lambda])\))\)\^2;\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[3, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
\@\[Lambda]\ \((6 - r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \[Lambda])\)\ \
\((\(-3\) + r\^2\ \[Lambda])\))\)\)\/\(3\ \@2\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[3, 0, \[Lambda]] = 
        1\/18\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \[Lambda]\ \((6 \
- r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \[Lambda])\)\ \((\(-3\) + r\^2\ \
\[Lambda])\))\)\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[3, 
          1, \[Lambda]] = \(-\(\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\
\)\)\ r\ \[Lambda]\ \((\(-24\) + 
                    r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \[Lambda])\)\^2)\)\)\/\
\(6\ \@2\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[3, 1, \[Lambda]] = 
        1\/72\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^3\ \[Lambda]\^2\ \
\((\(-24\) + r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \[Lambda])\)\^2)\)\^2;\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[3, 
          2, \[Lambda]] = \@10\ \[ExponentialE]\^\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\)\ r\^2\ \[Lambda]\^\(3/2\)\ \((1 - 
              1\/60\ r\^2\ \[Lambda]\ \((60 + 
                    r\^2\ \[Lambda]\ \((\(-15\) + 
                          r\^2\ \[Lambda])\))\))\);\)\), \
"\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[3, 2, \[Lambda]] = 
        10\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^5\ \[Lambda]\^3\ \
\((1 - 1\/60\ r\^2\ \[Lambda]\ \((60 + r\^2\ \[Lambda]\ \((\(-15\) + r\^2\ \
\[Lambda])\))\))\)\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[3, 
          3, \[Lambda]] = \(-\(1\/\(12\ \@15\)\)\) \
\((\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^3\ \[Lambda]\^2\ \
\((\(-120\) + r\^2\ \[Lambda]\ \((90 + 
                        r\^2\ \[Lambda]\ \((\(-18\) + 
                              r\^2\ \[Lambda])\))\))\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(RR\_Oscl[3, 
          3, \[Lambda]] = \(1\/2160\) \((\[ExponentialE]\^\(\(-r\^2\)\ \
\[Lambda]\)\ r\^7\ \[Lambda]\^4\ \((\(-120\) + r\^2\ \[Lambda]\ \((90 + r\^2\ \
\[Lambda]\ \((\(-18\) + r\^2\ \[Lambda])\))\))\)\^2)\);\)\)}], "Input"],

Cell["", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1016, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.25,
StyleDefinitions -> "Classroom1.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 252, 8, 93, "Subtitle"],
Cell[2525, 82, 204, 5, 124, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2754, 91, 98, 2, 85, "Section"],
Cell[2855, 95, 96, 2, 56, "Text"],

Cell[CellGroupData[{
Cell[2976, 101, 225, 4, 73, "Input"],
Cell[3204, 107, 191, 3, 73, "Output"]
}, Open  ]],
Cell[3410, 113, 128, 6, 56, "Text"],
Cell[3541, 121, 102, 3, 56, "Text"],
Cell[3646, 126, 189, 4, 54, "NumberedEquation"],
Cell[3838, 132, 204, 9, 56, "Text"],

Cell[CellGroupData[{
Cell[4067, 145, 126, 2, 64, "Input"],
Cell[4196, 149, 187, 3, 67, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4432, 158, 121, 3, 85, "Section"],
Cell[4556, 163, 289, 9, 80, "Text"],
Cell[4848, 174, 92, 1, 73, "NumberedEquation"],

Cell[CellGroupData[{
Cell[4965, 179, 191, 5, 92, "Input"],
Cell[5159, 186, 201, 4, 101, "Output"]
}, Open  ]],
Cell[5375, 193, 135, 3, 56, "Text"],

Cell[CellGroupData[{
Cell[5535, 200, 193, 5, 92, "Input"],
Cell[5731, 207, 195, 3, 103, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5975, 216, 154, 5, 85, "Section"],
Cell[6132, 223, 164, 4, 92, "Text"],
Cell[6299, 229, 139, 2, 73, "NumberedEquation"],
Cell[6441, 233, 54, 0, 56, "Text"],
Cell[6498, 235, 170, 3, 77, "NumberedEquation"],
Cell[6671, 240, 96, 2, 56, "Text"],
Cell[6770, 244, 189, 8, 74, "NumberedEquation"],
Cell[6962, 254, 271, 10, 56, "Text"],

Cell[CellGroupData[{
Cell[7258, 268, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[7468, 282, 623, 13, 212, "Input"],
Cell[8094, 297, 81, 1, 73, "Output"],
Cell[8178, 300, 104, 2, 102, "Output"],
Cell[8285, 304, 62, 1, 88, "Output"],
Cell[8350, 307, 124, 2, 71, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8511, 314, 402, 10, 133, "Input"],
Cell[8916, 326, 90, 1, 73, "Output"],
Cell[9009, 329, 102, 2, 73, "Output"],
Cell[9114, 333, 92, 1, 67, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9255, 340, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[9465, 354, 623, 13, 212, "Input"],
Cell[10091, 369, 108, 2, 109, "Output"],
Cell[10202, 373, 114, 2, 92, "Output"],
Cell[10319, 377, 65, 1, 88, "Output"],
Cell[10387, 380, 120, 2, 71, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10544, 387, 422, 10, 174, "Input"],
Cell[10969, 399, 100, 2, 73, "Output"],
Cell[11072, 403, 103, 2, 73, "Output"],
Cell[11178, 407, 100, 2, 67, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[11327, 415, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[11537, 429, 623, 13, 212, "Input"],
Cell[12163, 444, 109, 2, 99, "Output"],
Cell[12275, 448, 114, 2, 92, "Output"],
Cell[12392, 452, 58, 1, 88, "Output"],
Cell[12453, 455, 128, 2, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12618, 462, 445, 11, 162, "Input"],
Cell[13066, 475, 98, 2, 73, "Output"],
Cell[13167, 479, 110, 2, 73, "Output"],
Cell[13280, 483, 97, 2, 67, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[13426, 491, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[13636, 505, 623, 13, 212, "Input"],
Cell[14262, 520, 118, 2, 99, "Output"],
Cell[14383, 524, 114, 2, 92, "Output"],
Cell[14500, 528, 65, 1, 88, "Output"],
Cell[14568, 531, 130, 2, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14735, 538, 440, 11, 174, "Input"],
Cell[15178, 551, 107, 2, 109, "Output"],
Cell[15288, 555, 113, 2, 108, "Output"],
Cell[15404, 559, 103, 2, 85, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[15556, 567, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[15766, 581, 623, 13, 212, "Input"],
Cell[16392, 596, 111, 2, 73, "Output"],
Cell[16506, 600, 128, 2, 102, "Output"],
Cell[16637, 604, 62, 1, 88, "Output"],
Cell[16702, 607, 124, 2, 71, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16863, 614, 425, 11, 133, "Input"],
Cell[17291, 627, 113, 2, 73, "Output"],
Cell[17407, 631, 129, 2, 73, "Output"],
Cell[17539, 635, 129, 2, 67, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[17717, 643, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[17927, 657, 623, 13, 212, "Input"],
Cell[18553, 672, 132, 2, 116, "Output"],
Cell[18688, 676, 141, 2, 104, "Output"],
Cell[18832, 680, 65, 1, 88, "Output"],
Cell[18900, 683, 114, 2, 63, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19051, 690, 442, 10, 182, "Input"],
Cell[19496, 702, 122, 2, 88, "Output"],
Cell[19621, 706, 135, 2, 73, "Output"],
Cell[19759, 710, 132, 2, 67, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[19940, 718, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[20150, 732, 623, 13, 212, "Input"],
Cell[20776, 747, 133, 2, 106, "Output"],
Cell[20912, 751, 141, 2, 104, "Output"],
Cell[21056, 755, 65, 1, 88, "Output"],
Cell[21124, 758, 138, 2, 71, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21299, 765, 474, 11, 170, "Input"],
Cell[21776, 778, 127, 2, 88, "Output"],
Cell[21906, 782, 160, 2, 108, "Output"],
Cell[22069, 786, 138, 2, 85, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[22256, 794, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[22466, 808, 623, 13, 212, "Input"],
Cell[23092, 823, 142, 2, 106, "Output"],
Cell[23237, 827, 141, 2, 104, "Output"],
Cell[23381, 831, 72, 1, 88, "Output"],
Cell[23456, 834, 144, 2, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23637, 841, 471, 11, 182, "Input"],
Cell[24111, 854, 134, 2, 116, "Output"],
Cell[24248, 858, 161, 2, 108, "Output"],
Cell[24412, 862, 139, 2, 85, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[24600, 870, 185, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[24810, 884, 623, 13, 212, "Input"],
Cell[25436, 899, 131, 2, 88, "Output"],
Cell[25570, 903, 146, 2, 114, "Output"],
Cell[25719, 907, 62, 1, 88, "Output"],
Cell[25784, 910, 124, 2, 71, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25945, 917, 454, 11, 150, "Input"],
Cell[26402, 930, 140, 2, 88, "Output"],
Cell[26545, 934, 165, 2, 108, "Output"],
Cell[26713, 938, 159, 2, 85, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[26921, 946, 186, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[27132, 960, 623, 13, 212, "Input"],
Cell[27758, 975, 144, 2, 116, "Output"],
Cell[27905, 979, 153, 2, 104, "Output"],
Cell[28061, 983, 65, 1, 88, "Output"],
Cell[28129, 986, 120, 2, 71, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28286, 993, 460, 11, 182, "Input"],
Cell[28749, 1006, 136, 2, 88, "Output"],
Cell[28888, 1010, 166, 2, 108, "Output"],
Cell[29057, 1014, 165, 2, 85, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[29271, 1022, 186, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[29482, 1036, 623, 13, 212, "Input"],
Cell[30108, 1051, 156, 2, 106, "Output"],
Cell[30267, 1055, 166, 3, 104, "Output"],
Cell[30436, 1060, 65, 1, 88, "Output"],
Cell[30504, 1063, 138, 2, 71, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30679, 1070, 499, 12, 170, "Input"],
Cell[31181, 1084, 150, 2, 88, "Output"],
Cell[31334, 1088, 192, 3, 108, "Output"],
Cell[31529, 1093, 176, 3, 85, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[31754, 1102, 186, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[31965, 1116, 623, 13, 212, "Input"],
Cell[32591, 1131, 158, 2, 106, "Output"],
Cell[32752, 1135, 157, 2, 104, "Output"],
Cell[32912, 1139, 73, 1, 88, "Output"],
Cell[32988, 1142, 142, 2, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33167, 1149, 488, 11, 173, "Input"],
Cell[33658, 1162, 151, 2, 98, "Output"],
Cell[33812, 1166, 184, 3, 108, "Output"],
Cell[33999, 1171, 169, 2, 85, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[34217, 1179, 186, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[34428, 1193, 623, 13, 212, "Input"],
Cell[35054, 1208, 162, 3, 88, "Output"],
Cell[35219, 1213, 168, 2, 114, "Output"],
Cell[35390, 1217, 62, 1, 88, "Output"],
Cell[35455, 1220, 124, 2, 71, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35616, 1227, 478, 12, 150, "Input"],
Cell[36097, 1241, 162, 2, 88, "Output"],
Cell[36262, 1245, 206, 3, 108, "Output"],
Cell[36471, 1250, 199, 3, 85, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[36719, 1259, 186, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[36930, 1273, 623, 13, 212, "Input"],
Cell[37556, 1288, 170, 2, 116, "Output"],
Cell[37729, 1292, 181, 3, 104, "Output"],
Cell[37913, 1297, 65, 1, 88, "Output"],
Cell[37981, 1300, 124, 2, 71, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38142, 1307, 487, 11, 182, "Input"],
Cell[38632, 1320, 165, 2, 88, "Output"],
Cell[38800, 1324, 210, 4, 112, "Output"],
Cell[39013, 1330, 177, 3, 85, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[39239, 1339, 186, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[39450, 1353, 623, 13, 212, "Input"],
Cell[40076, 1368, 161, 2, 106, "Output"],
Cell[40240, 1372, 169, 2, 104, "Output"],
Cell[40412, 1376, 66, 1, 88, "Output"],
Cell[40481, 1379, 140, 2, 71, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[40658, 1386, 505, 12, 170, "Input"],
Cell[41166, 1400, 156, 2, 88, "Output"],
Cell[41325, 1404, 262, 5, 85, "Output"],
Cell[41590, 1411, 201, 3, 87, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[41840, 1420, 186, 10, 89, "Subsection"],

Cell[CellGroupData[{
Cell[42051, 1434, 623, 13, 212, "Input"],
Cell[42677, 1449, 191, 3, 106, "Output"],
Cell[42871, 1454, 190, 3, 104, "Output"],
Cell[43064, 1459, 73, 1, 88, "Output"],
Cell[43140, 1462, 144, 2, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43321, 1469, 521, 12, 173, "Input"],
Cell[43845, 1483, 186, 3, 98, "Output"],
Cell[44034, 1488, 297, 6, 108, "Output"],
Cell[44334, 1496, 207, 3, 92, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[44602, 1506, 153, 5, 85, "Section"],
Cell[44758, 1513, 162, 5, 56, "Text"],
Cell[44923, 1520, 7007, 138, 2179, "Input"],
Cell[51933, 1660, 16, 0, 56, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

