(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     30040,        704]*)
(*NotebookOutlinePosition[     30769,        729]*)
(*  CellTagsIndexPosition[     30725,        725]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Part ",
    FontWeight->"Bold"],
  StyleBox["2. Quantum Isotropic Oscillator",
    FontWeight->"Bold"],
  "\n2.2. Two-Dimensional Isotropic Quantum Oscillator"
}], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
2.2.4. Normalized Wave Functions and Probability Densities of the \
Two-Dimensional Quantum Oscillator\
\>", "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
1. Normalized radial and angular wave functions of the two-dimensional \
quantum oscillator\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Consider some states of the two-dimensional quantum oscillator defined by \
quantum numbers:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  Cell[BoxData[
      \(n\_rad = 0, 1, 2, 3\)]],
  ",\n",
  Cell[BoxData[
      \(m\_azm = 0, 1, 2, 3\)]]
}], "NumberedEquation"],

Cell["\<\
Normalized radial wave functions and radial probability densities of the \
two-dimensional quantum oscillator for given quantum numbers are:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(R\_Oscl[0, 0, \[Lambda], 
          r] = \@2\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \@\
\[Lambda];\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[0, 0, \[Lambda], r] = 
        2\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \[Lambda];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[0, 1, \[Lambda], 
          r] = \@2\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\ \
\[Lambda];\)\), "\[IndentingNewLine]", 
    \(\(RR\_Oscl[0, 1, \[Lambda], r] = 
        2\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \[Lambda];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[0, 2, \[Lambda], 
          r] = \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^2\ \
\[Lambda]\^\(3/2\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[0, 2, \[Lambda], 
          r] = \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^5\ \[Lambda]\^3;\
\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[0, 3, \[Lambda], 
          r] = \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^3\ \
\[Lambda]\^2\)\/\@3;\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[0, 3, \[Lambda], r] = 
        1\/3\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^7\ \
\[Lambda]\^4;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[1, 0, \[Lambda], 
          r] = \@2\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \@\
\[Lambda]\ \((1 - r\^2\ \[Lambda])\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[1, 0, \[Lambda], r] = 
        2\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \[Lambda]\ \((1 - \
r\^2\ \[Lambda])\)\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[1, 1, \[Lambda], 
          r] = \(-\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\)\ r\ \
\[Lambda]\ \((\(-2\) + r\^2\ \[Lambda])\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[1, 1, \[Lambda], 
          r] = \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^3\ \[Lambda]\^2\ \
\((\(-2\) + r\^2\ \[Lambda])\)\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[1, 2, \[Lambda], 
          r] = \(-\(\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^2\ \
\[Lambda]\^\(3/2\)\ \((\(-3\) + 
                    r\^2\ \[Lambda])\)\)\/\@3\)\);\)\), \
"\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[1, 2, \[Lambda], r] = 
        1\/3\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^5\ \[Lambda]\^3\ \
\((\(-3\) + r\^2\ \[Lambda])\)\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[1, 3, \[Lambda], 
          r] = \(-\(\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^3\ \
\[Lambda]\^2\ \((\(-4\) + 
                    r\^2\ \[Lambda])\)\)\/\(2\ \@3\)\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[1, 3, \[Lambda], r] = 
        1\/12\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^7\ \[Lambda]\^4\ \
\((\(-4\) + r\^2\ \[Lambda])\)\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[2, 0, \[Lambda], 
          r] = \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
\@\[Lambda]\ \((2 + r\^2\ \[Lambda]\ \((\(-4\) + r\^2\ \
\[Lambda])\))\)\)\/\@2;\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[2, 0, \[Lambda], r] = 
        1\/2\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \[Lambda]\ \((2 + \
r\^2\ \[Lambda]\ \((\(-4\) + r\^2\ \[Lambda])\))\)\^2;\)\(\[IndentingNewLine]\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[2, 1, \[Lambda], 
          r] = \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\ \
\[Lambda]\ \((6 + r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \
\[Lambda])\))\)\)\/\@6;\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[2, 1, \[Lambda], r] = 
        1\/6\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^3\ \[Lambda]\^2\ \
\((6 + r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \[Lambda])\))\)\^2;\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[2, 2, \[Lambda], 
          r] = \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^2\ \
\[Lambda]\^\(3/2\)\ \((\(-6\) + r\^2\ \[Lambda])\)\ \((\(-2\) + r\^2\ \
\[Lambda])\)\)\/\(2\ \@6\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[2, 2, \[Lambda], r] = 
        1\/24\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^5\ \[Lambda]\^3\ \
\((\(-6\) + r\^2\ \[Lambda])\)\^2\ \((\(-2\) + r\^2\ \[Lambda])\)\^2;\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[2, 3, \[Lambda], 
          r] = \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^3\ \
\[Lambda]\^2\ \((20 + r\^2\ \[Lambda]\ \((\(-10\) + r\^2\ \[Lambda])\))\)\)\/\
\(2\ \@30\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[2, 3, \[Lambda], r] = 
        1\/120\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^7\ \[Lambda]\^4\
\ \((20 + r\^2\ \[Lambda]\ \((\(-10\) + r\^2\ \[Lambda])\))\)\^2;\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[3, 0, \[Lambda], 
          r] = \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
\@\[Lambda]\ \((6 - r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \[Lambda])\)\ \
\((\(-3\) + r\^2\ \[Lambda])\))\)\)\/\(3\ \@2\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[3, 0, \[Lambda], r] = 
        1\/18\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \[Lambda]\ \((6 \
- r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \[Lambda])\)\ \((\(-3\) + r\^2\ \
\[Lambda])\))\)\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[3, 1, \[Lambda], 
          r] = \(-\(\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\ \
\[Lambda]\ \((\(-24\) + 
                    r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \[Lambda])\)\^2)\)\)\/\
\(6\ \@2\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[3, 1, \[Lambda], r] = 
        1\/72\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^3\ \[Lambda]\^2\ \
\((\(-24\) + r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \[Lambda])\)\^2)\)\^2;\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[3, 2, \[Lambda], 
          r] = \@10\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^2\ \
\[Lambda]\^\(3/2\)\ \((1 - 
              1\/60\ r\^2\ \[Lambda]\ \((60 + 
                    r\^2\ \[Lambda]\ \((\(-15\) + 
                          r\^2\ \[Lambda])\))\))\);\)\), \
"\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[3, 2, \[Lambda], r] = 
        10\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^5\ \[Lambda]\^3\ \
\((1 - 1\/60\ r\^2\ \[Lambda]\ \((60 + r\^2\ \[Lambda]\ \((\(-15\) + r\^2\ \
\[Lambda])\))\))\)\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[3, 3, \[Lambda], 
          r] = \(-\(1\/\(12\ \@15\)\)\) \((\[ExponentialE]\^\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\)\ r\^3\ \[Lambda]\^2\ \((\(-120\) + 
                  r\^2\ \[Lambda]\ \((90 + 
                        r\^2\ \[Lambda]\ \((\(-18\) + 
                              r\^2\ \[Lambda])\))\))\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(RR\_Oscl[3, 3, \[Lambda], 
          r] = \(1\/2160\) \((\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^7\
\ \[Lambda]\^4\ \((\(-120\) + r\^2\ \[Lambda]\ \((90 + r\^2\ \[Lambda]\ \
\((\(-18\) + r\^2\ \[Lambda])\))\))\)\^2)\);\)\)}], "Input"],

Cell[TextData[{
  "Normalized angular wave functions and angular probability densities of the \
two-dimensional quantum oscillator for all ",
  Cell[BoxData[
      \(TraditionalForm\`m\_azm\)]],
  " quantum numbers are:"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell[BoxData[{
    \(S[m\_azm, \[CurlyPhi]] = \(\@\(1\/\(2\ \[Pi]\)\)\) \
\[ExponentialE]\^\(\(\[ImaginaryI]\)\(\ \)\(m\_azm\)\(\ \)\(\[CurlyPhi]\)\(\ \
\)\)\), "\[IndentingNewLine]", 
    \(SS[m\_azm, \[CurlyPhi]] = 
      ComplexExpand[
        S[m\_azm, \[CurlyPhi]]*Conjugate[S[m\_azm, \[CurlyPhi]]]]\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi]\ m\_azm\)\/\@\(2\ \[Pi]\)\
\)], "Output"],

Cell[BoxData[
    \(1\/\(2\ \[Pi]\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2. Normalized wave functions of the two-dimensional quantum oscillator\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Define wave functions and probability densities of the two-dimensional \
quantum oscillator for given quantum numbers:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[Psi]\_Oscl[n\_rad, m\_azm, \[Lambda], r, \[CurlyPhi]] = 
      R\_Oscl[n\_rad, m\_azm, \[Lambda], r]\ S[
          m\_azm, \[CurlyPhi]]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[n\_rad, m\_azm, \[Lambda], r, \[CurlyPhi]] = 
      RR\_Oscl[n\_rad, m\_azm, \[Lambda], r]\ SS[
          m\_azm, \[CurlyPhi]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi]\ m\_azm\)\ \
R\_Oscl[n\_rad, m\_azm, \[Lambda], r]\)\/\@\(2\ \[Pi]\)\)], "Output"],

Cell[BoxData[
    \(RR\_Oscl[n\_rad, m\_azm, \[Lambda], r]\/\(2\ \[Pi]\)\)], "Output"]
}, Open  ]],

Cell["\<\
So normalized wave functions and probability densities of the two-dimensional \
quantum oscillator for given quantum numbers are:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[Psi]\_Oscl[0, 0, \[Lambda], r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\_Oscl[n\_rad, m\_azm, \[Lambda], 
          r, \[CurlyPhi]], {n\_rad \[Rule] 0, 
          m\_azm \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_Oscl[0, 0, \[Lambda], r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, m\_azm, \[Lambda], 
          r, \[CurlyPhi]], {n\_rad \[Rule] 0, 
          m\_azm \[Rule] 0}]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[0, 1, \[Lambda], r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\_Oscl[n\_rad, m\_azm, \[Lambda], 
          r, \[CurlyPhi]], {n\_rad \[Rule] 0, 
          m\_azm \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_Oscl[0, 1, \[Lambda], r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, m\_azm, \[Lambda], 
          r, \[CurlyPhi]], {n\_rad \[Rule] 0, 
          m\_azm \[Rule] 1}]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[0, 2, \[Lambda], r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\_Oscl[n\_rad, m\_azm, \[Lambda], 
          r, \[CurlyPhi]], {n\_rad \[Rule] 0, 
          m\_azm \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_Oscl[0, 2, \[Lambda], r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, m\_azm, \[Lambda], 
          r, \[CurlyPhi]], {n\_rad \[Rule] 0, 
          m\_azm \[Rule] 2}]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[0, 3, \[Lambda], r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\_Oscl[n\_rad, m\_azm, \[Lambda], 
          r, \[CurlyPhi]], {n\_rad \[Rule] 0, 
          m\_azm \[Rule] 3}]\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_Oscl[0, 3, \[Lambda], r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, m\_azm, \[Lambda], 
          r, \[CurlyPhi]], {n\_rad \[Rule] 0, 
          m\_azm \[Rule] 
            3}]\)\(\[IndentingNewLine]\)\(\[IndentingNewLine]\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[1, 0, \[Lambda], r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\_Oscl[n\_rad, m\_azm, \[Lambda], 
          r, \[CurlyPhi]], {n\_rad \[Rule] 1, 
          m\_azm \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_Oscl[1, 0, \[Lambda], r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, m\_azm, \[Lambda], 
          r, \[CurlyPhi]], {n\_rad \[Rule] 1, 
          m\_azm \[Rule] 0}]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[1, 1, \[Lambda], r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\_Oscl[n\_rad, m\_azm, \[Lambda], 
          r, \[CurlyPhi]], {n\_rad \[Rule] 1, 
          m\_azm \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_Oscl[1, 1, \[Lambda], r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, m\_azm, \[Lambda], 
          r, \[CurlyPhi]], {n\_rad \[Rule] 1, 
          m\_azm \[Rule] 1}]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[1, 2, \[Lambda], r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\_Oscl[n\_rad, m\_azm, \[Lambda], 
          r, \[CurlyPhi]], {n\_rad \[Rule] 1, 
          m\_azm \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_Oscl[1, 2, \[Lambda], r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, m\_azm, \[Lambda], 
          r, \[CurlyPhi]], {n\_rad \[Rule] 1, 
          m\_azm \[Rule] 2}]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[1, 3, \[Lambda], r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\_Oscl[n\_rad, m\_azm, \[Lambda], 
          r, \[CurlyPhi]], {n\_rad \[Rule] 1, 
          m\_azm \[Rule] 3}]\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_Oscl[1, 3, \[Lambda], r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, m\_azm, \[Lambda], 
          r, \[CurlyPhi]], {n\_rad \[Rule] 1, 
          m\_azm \[Rule] 
            3}]\)\(\[IndentingNewLine]\)\(\[IndentingNewLine]\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[2, 0, \[Lambda], r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\_Oscl[n\_rad, m\_azm, \[Lambda], 
          r, \[CurlyPhi]], {n\_rad \[Rule] 2, 
          m\_azm \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_Oscl[2, 0, \[Lambda], r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, m\_azm, \[Lambda], 
          r, \[CurlyPhi]], {n\_rad \[Rule] 2, 
          m\_azm \[Rule] 0}]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[2, 1, \[Lambda], r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\_Oscl[n\_rad, m\_azm, \[Lambda], 
          r, \[CurlyPhi]], {n\_rad \[Rule] 2, 
          m\_azm \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_Oscl[2, 1, \[Lambda], r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, m\_azm, \[Lambda], 
          r, \[CurlyPhi]], {n\_rad \[Rule] 2, 
          m\_azm \[Rule] 1}]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[2, 2, \[Lambda], r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\_Oscl[n\_rad, m\_azm, \[Lambda], 
          r, \[CurlyPhi]], {n\_rad \[Rule] 2, 
          m\_azm \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_Oscl[2, 2, \[Lambda], r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, m\_azm, \[Lambda], 
          r, \[CurlyPhi]], {n\_rad \[Rule] 2, 
          m\_azm \[Rule] 2}]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[2, 3, \[Lambda], r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\_Oscl[n\_rad, m\_azm, \[Lambda], 
          r, \[CurlyPhi]], {n\_rad \[Rule] 2, 
          m\_azm \[Rule] 3}]\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_Oscl[2, 3, \[Lambda], r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, m\_azm, \[Lambda], 
          r, \[CurlyPhi]], {n\_rad \[Rule] 2, 
          m\_azm \[Rule] 3}]\)\(\[IndentingNewLine]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[3, 0, \[Lambda], r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\_Oscl[n\_rad, m\_azm, \[Lambda], 
          r, \[CurlyPhi]], {n\_rad \[Rule] 3, 
          m\_azm \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_Oscl[3, 0, \[Lambda], r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, m\_azm, \[Lambda], 
          r, \[CurlyPhi]], {n\_rad \[Rule] 3, 
          m\_azm \[Rule] 0}]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[3, 1, \[Lambda], r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\_Oscl[n\_rad, m\_azm, \[Lambda], 
          r, \[CurlyPhi]], {n\_rad \[Rule] 3, 
          m\_azm \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_Oscl[3, 1, \[Lambda], r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, m\_azm, \[Lambda], 
          r, \[CurlyPhi]], {n\_rad \[Rule] 3, 
          m\_azm \[Rule] 1}]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[3, 2, \[Lambda], r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\_Oscl[n\_rad, m\_azm, \[Lambda], 
          r, \[CurlyPhi]], {n\_rad \[Rule] 3, 
          m\_azm \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_Oscl[3, 2, \[Lambda], r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, m\_azm, \[Lambda], 
          r, \[CurlyPhi]], {n\_rad \[Rule] 3, 
          m\_azm \[Rule] 2}]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[3, 3, \[Lambda], r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\_Oscl[n\_rad, m\_azm, \[Lambda], 
          r, \[CurlyPhi]], {n\_rad \[Rule] 3, 
          m\_azm \[Rule] 3}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[3, 3, \[Lambda], r, \[CurlyPhi]] = 
      ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, m\_azm, \[Lambda], 
          r, \[CurlyPhi]], {n\_rad \[Rule] 3, m\_azm \[Rule] 3}]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \@\[Lambda]\)\/\@\
\[Pi]\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \[Lambda]\)\/\[Pi]\)], \
"Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\(\(r\^2\ \[Lambda]\)\/2\)\) + \[ImaginaryI]\ \
\[CurlyPhi]\)\ r\ \[Lambda]\)\/\@\[Pi]\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \[Lambda]\)\/\[Pi]\)], \
"Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\(\(r\^2\ \[Lambda]\)\/2\)\) + 2\ \[ImaginaryI]\
\ \[CurlyPhi]\)\ r\^2\ \[Lambda]\^\(3/2\)\)\/\@\(2\ \[Pi]\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^5\ \[Lambda]\^3\)\/\(2\ \
\[Pi]\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\(\(r\^2\ \[Lambda]\)\/2\)\) + 3\ \[ImaginaryI]\
\ \[CurlyPhi]\)\ r\^3\ \[Lambda]\^2\)\/\@\(6\ \[Pi]\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^7\ \[Lambda]\^4\)\/\(6\ \
\[Pi]\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \@\[Lambda]\ \((1 - \
r\^2\ \[Lambda])\)\)\/\@\[Pi]\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \[Lambda]\ \((1 - r\^2\ \
\[Lambda])\)\^2\)\/\[Pi]\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\(-\(\(r\^2\ \[Lambda]\)\/2\)\) + \
\[ImaginaryI]\ \[CurlyPhi]\)\ r\ \[Lambda]\ \((\(-2\) + 
                r\^2\ \[Lambda])\)\)\/\@\(2\ \[Pi]\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^3\ \[Lambda]\^2\ \
\((\(-2\) + r\^2\ \[Lambda])\)\^2\)\/\(2\ \[Pi]\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\(-\(\(r\^2\ \[Lambda]\)\/2\)\) + 2\ \
\[ImaginaryI]\ \[CurlyPhi]\)\ r\^2\ \[Lambda]\^\(3/2\)\ \((\(-3\) + 
                r\^2\ \[Lambda])\)\)\/\@\(6\ \[Pi]\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^5\ \[Lambda]\^3\ \
\((\(-3\) + r\^2\ \[Lambda])\)\^2\)\/\(6\ \[Pi]\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\(-\(\(r\^2\ \[Lambda]\)\/2\)\) + 3\ \
\[ImaginaryI]\ \[CurlyPhi]\)\ r\^3\ \[Lambda]\^2\ \((\(-4\) + 
                r\^2\ \[Lambda])\)\)\/\(2\ \@\(6\ \[Pi]\)\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^7\ \[Lambda]\^4\ \
\((\(-4\) + r\^2\ \[Lambda])\)\^2\)\/\(24\ \[Pi]\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \@\[Lambda]\ \((2 + \
r\^2\ \[Lambda]\ \((\(-4\) + r\^2\ \[Lambda])\))\)\)\/\(2\ \@\[Pi]\)\)], \
"Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \[Lambda]\ \((2 + r\^2\ \
\[Lambda]\ \((\(-4\) + r\^2\ \[Lambda])\))\)\^2\)\/\(4\ \[Pi]\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\(\(r\^2\ \[Lambda]\)\/2\)\) + \[ImaginaryI]\ \
\[CurlyPhi]\)\ r\ \[Lambda]\ \((6 + r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \
\[Lambda])\))\)\)\/\(2\ \@\(3\ \[Pi]\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^3\ \[Lambda]\^2\ \((6 + \
r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \[Lambda])\))\)\^2\)\/\(12\ \[Pi]\)\)], \
"Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\(\(r\^2\ \[Lambda]\)\/2\)\) + 2\ \[ImaginaryI]\
\ \[CurlyPhi]\)\ r\^2\ \[Lambda]\^\(3/2\)\ \((\(-6\) + r\^2\ \[Lambda])\)\ \
\((\(-2\) + r\^2\ \[Lambda])\)\)\/\(4\ \@\(3\ \[Pi]\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^5\ \[Lambda]\^3\ \
\((\(-6\) + r\^2\ \[Lambda])\)\^2\ \((\(-2\) + r\^2\ \[Lambda])\)\^2\)\/\(48\ \
\[Pi]\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\(\(r\^2\ \[Lambda]\)\/2\)\) + 3\ \[ImaginaryI]\
\ \[CurlyPhi]\)\ r\^3\ \[Lambda]\^2\ \((20 + r\^2\ \[Lambda]\ \((\(-10\) + \
r\^2\ \[Lambda])\))\)\)\/\(4\ \@\(15\ \[Pi]\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^7\ \[Lambda]\^4\ \((20 \
+ r\^2\ \[Lambda]\ \((\(-10\) + r\^2\ \[Lambda])\))\)\^2\)\/\(240\ \
\[Pi]\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \@\[Lambda]\ \((6 - \
r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \[Lambda])\)\ \((\(-3\) + r\^2\ \[Lambda])\
\))\)\)\/\(6\ \@\[Pi]\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \[Lambda]\ \((6 - r\^2\ \
\[Lambda]\ \((\(-6\) + r\^2\ \[Lambda])\)\ \((\(-3\) + r\^2\ \
\[Lambda])\))\)\^2\)\/\(36\ \[Pi]\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\(-\(\(r\^2\ \[Lambda]\)\/2\)\) + \
\[ImaginaryI]\ \[CurlyPhi]\)\ r\ \[Lambda]\ \((\(-24\) + 
                r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \[Lambda])\)\^2)\)\)\/\(12\
\ \@\[Pi]\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^3\ \[Lambda]\^2\ \
\((\(-24\) + r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \
\[Lambda])\)\^2)\)\^2\)\/\(144\ \[Pi]\)\)], "Output"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(-\(\(r\^2\ \[Lambda]\)\/2\)\) + 2\ \[ImaginaryI]\ \
\[CurlyPhi]\)\ \@\(5\/\[Pi]\)\ r\^2\ \[Lambda]\^\(3/2\)\ \((1 - 
          1\/60\ r\^2\ \[Lambda]\ \((60 + 
                r\^2\ \[Lambda]\ \((\(-15\) + 
                      r\^2\ \[Lambda])\))\))\)\)], "Output"],

Cell[BoxData[
    \(\(5\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^5\ \[Lambda]\^3\ \
\((1 - 1\/60\ r\^2\ \[Lambda]\ \((60 + r\^2\ \[Lambda]\ \((\(-15\) + r\^2\ \
\[Lambda])\))\))\)\^2\)\/\[Pi]\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\(-\(\(r\^2\ \[Lambda]\)\/2\)\) + 3\ \
\[ImaginaryI]\ \[CurlyPhi]\)\ r\^3\ \[Lambda]\^2\ \((\(-120\) + 
                r\^2\ \[Lambda]\ \((90 + 
                      r\^2\ \[Lambda]\ \((\(-18\) + 
                            r\^2\ \[Lambda])\))\))\)\)\/\(12\ \@\(30\ \[Pi]\)\
\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^7\ \[Lambda]\^4\ \
\((\(-120\) + r\^2\ \[Lambda]\ \((90 + r\^2\ \[Lambda]\ \((\(-18\) + r\^2\ \
\[Lambda])\))\))\)\^2\)\/\(4320\ \[Pi]\)\)], "Output"]
}, Open  ]],

Cell["\<\
Thus probability densities of the two-dimensional quantum oscillator for \
given quantum numbers are:\
\>", "Text"],

Cell[BoxData[{
    \(\(\[Psi]\[Psi]\_Oscl[0, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \
\[Lambda]\)\/\[Pi];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[0, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \
\[Lambda]\)\/\[Pi];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[0, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^5\ \
\[Lambda]\^3\)\/\(2\ \[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_Oscl[0, 
          3, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^7\ \
\[Lambda]\^4\)\/\(6\ \[Pi]\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[1, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \
\[Lambda]\ \((1 - r\^2\ \[Lambda])\)\^2\)\/\[Pi];\)\), "\[IndentingNewLine]", \

    \(\(\[Psi]\[Psi]\_Oscl[1, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^3\ \
\[Lambda]\^2\ \((\(-2\) + r\^2\ \[Lambda])\)\^2\)\/\(2\ \[Pi]\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[1, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^5\ \
\[Lambda]\^3\ \((\(-3\) + r\^2\ \[Lambda])\)\^2\)\/\(6\ \[Pi]\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_Oscl[1, 
          3, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^7\ \
\[Lambda]\^4\ \((\(-4\) + r\^2\ \[Lambda])\)\^2\)\/\(24\ \[Pi]\);\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[2, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \
\[Lambda]\ \((2 + r\^2\ \[Lambda]\ \((\(-4\) + r\^2\ \
\[Lambda])\))\)\^2\)\/\(4\ \[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[2, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^3\ \
\[Lambda]\^2\ \((6 + r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \
\[Lambda])\))\)\^2\)\/\(12\ \[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[2, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^5\ \
\[Lambda]\^3\ \((\(-6\) + r\^2\ \[Lambda])\)\^2\ \((\(-2\) + r\^2\ \[Lambda])\
\)\^2\)\/\(48\ \[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_Oscl[2, 
          3, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^7\ \
\[Lambda]\^4\ \((20 + r\^2\ \[Lambda]\ \((\(-10\) + r\^2\ \
\[Lambda])\))\)\^2\)\/\(240\ \[Pi]\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[3, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \
\[Lambda]\ \((6 - r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \[Lambda])\)\ \((\(-3\) \
+ r\^2\ \[Lambda])\))\)\^2\)\/\(36\ \[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[3, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^3\ \
\[Lambda]\^2\ \((\(-24\) + r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \
\[Lambda])\)\^2)\)\^2\)\/\(144\ \[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[3, 
          2, \[Lambda]] = \(1\/\[Pi]\) \((5\ \[ExponentialE]\^\(\(-r\^2\)\ \
\[Lambda]\)\ r\^5\ \[Lambda]\^3\ \((1 - 1\/60\ r\^2\ \[Lambda]\ \((60 + r\^2\ \
\[Lambda]\ \((\(-15\) + r\^2\ \[Lambda])\))\))\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[3, 
          3, \[Lambda]] = \(1\/\(4320\ \[Pi]\)\) \
\((\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^7\ \[Lambda]\^4\ \((\(-120\) \
+ r\^2\ \[Lambda]\ \((90 + r\^2\ \[Lambda]\ \((\(-18\) + r\^2\ \
\[Lambda])\))\))\)\^2)\);\)\)}], "Input"],

Cell["", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1016, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.25,
StyleDefinitions -> "Classroom1.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 252, 8, 93, "Subtitle"],
Cell[2525, 82, 182, 5, 124, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2732, 91, 165, 5, 85, "Section"],
Cell[2900, 98, 163, 5, 56, "Text"],
Cell[3066, 105, 145, 6, 72, "NumberedEquation"],
Cell[3214, 113, 211, 5, 80, "Text"],
Cell[3428, 120, 7105, 137, 2179, "Input"],
Cell[10536, 259, 279, 8, 80, "Text"],

Cell[CellGroupData[{
Cell[10840, 271, 318, 6, 126, "Input"],
Cell[11161, 279, 107, 2, 99, "Output"],
Cell[11271, 283, 49, 1, 85, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[11369, 290, 144, 4, 85, "Section"],
Cell[11516, 296, 142, 3, 56, "Text"],

Cell[CellGroupData[{
Cell[11683, 303, 351, 6, 88, "Input"],
Cell[12037, 311, 150, 2, 99, "Output"],
Cell[12190, 315, 86, 1, 85, "Output"]
}, Open  ]],
Cell[12291, 319, 200, 5, 56, "Text"],

Cell[CellGroupData[{
Cell[12516, 328, 7779, 146, 1338, "Input"],
Cell[20298, 476, 110, 2, 108, "Output"],
Cell[20411, 480, 102, 2, 92, "Output"],
Cell[20516, 484, 144, 2, 108, "Output"],
Cell[20663, 488, 102, 2, 92, "Output"],
Cell[20768, 492, 166, 2, 108, "Output"],
Cell[20937, 496, 115, 2, 92, "Output"],
Cell[21055, 500, 160, 2, 108, "Output"],
Cell[21218, 504, 115, 2, 92, "Output"],
Cell[21336, 508, 137, 2, 108, "Output"],
Cell[21476, 512, 132, 2, 92, "Output"],
Cell[21611, 516, 209, 3, 108, "Output"],
Cell[21823, 521, 150, 2, 92, "Output"],
Cell[21976, 525, 224, 3, 108, "Output"],
Cell[22203, 530, 150, 2, 92, "Output"],
Cell[22356, 534, 225, 3, 108, "Output"],
Cell[22584, 539, 151, 2, 92, "Output"],
Cell[22738, 543, 178, 3, 108, "Output"],
Cell[22919, 548, 171, 2, 92, "Output"],
Cell[23093, 552, 219, 3, 108, "Output"],
Cell[23315, 557, 180, 3, 92, "Output"],
Cell[23498, 562, 239, 3, 108, "Output"],
Cell[23740, 567, 188, 3, 92, "Output"],
Cell[23931, 572, 231, 3, 108, "Output"],
Cell[24165, 577, 183, 3, 92, "Output"],
Cell[24351, 582, 210, 3, 108, "Output"],
Cell[24564, 587, 206, 3, 92, "Output"],
Cell[24773, 592, 248, 4, 112, "Output"],
Cell[25024, 598, 190, 3, 96, "Output"],
Cell[25217, 603, 308, 5, 98, "Output"],
Cell[25528, 610, 211, 3, 98, "Output"],
Cell[25742, 615, 344, 6, 108, "Output"],
Cell[26089, 623, 218, 3, 92, "Output"]
}, Open  ]],
Cell[26322, 629, 125, 3, 56, "Text"],
Cell[26450, 634, 3555, 65, 1059, "Input"],
Cell[30008, 701, 16, 0, 56, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

