(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     25887,        840]*)
(*NotebookOutlinePosition[     26616,        865]*)
(*  CellTagsIndexPosition[     26572,        861]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Part ",
    FontWeight->"Bold"],
  StyleBox["2. Quantum Isotropic Oscillator",
    FontWeight->"Bold"],
  "\n2.3. Two-Dimensional Isotropic Quantum Oscillator"
}], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
2.3.2. Radial Equation of the Three-Dimensional Quantum Oscillator: General \
Solutions, Radial Wave Functions and Energy Levels\
\>", "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
1. Radial equation of the three-dimensional quantum oscillator\
\>", "Section"],

Cell[TextData[{
  "Consider radial equation (",
  StyleBox["RadDifEqnQntOsc",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  ") of ",
  "the three-dimensional quantum oscillator"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"RadDifEqnQntOsc", "=", 
      RowBox[{
        RowBox[{\(D[R[r], {r, 2}]\), "+", \(\((2/r)\)*D[R[r], r]\), "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"2", "*", 
                SubscriptBox["m", 
                  StyleBox["0",
                    "TI"]], "*", \(En/\[HBar]^2\)}], ")"}], "*", \(R[r]\)}], 
          "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{\(-2\), "*", 
                SubscriptBox["m", 
                  StyleBox["0",
                    "TI"]], "*", \(V[r]/\[HBar]^2\)}], ")"}], "*", \(R[r]\)}],
           "-", \(\((\(l\_orb\) \((l\_orb + 1)\)/r^2)\)*R[r]\)}], "\[Equal]", 
        "0"}]}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(-\(\(R[r]\ l\_orb\ \((1 + l\_orb)\)\)\/r\^2\)\), 
        "+", \(\(2\ En\ R[r]\ m\_0\)\/\[HBar]\^2\), 
        "-", \(\(2\ R[r]\ m\_0\ V[r]\)\/\[HBar]\^2\), "+", 
        FractionBox[
          RowBox[{"2", " ", 
            RowBox[{
              SuperscriptBox["R", "\[Prime]",
                MultilineFunction->None], "[", "r", "]"}]}], "r"], "+", 
        RowBox[{
          SuperscriptBox["R", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}], "==", 
      "0"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "where ",
  StyleBox["V",
    FontSlant->"Italic"],
  "[",
  StyleBox["r",
    FontSlant->"Italic"],
  "] is potential energy of oscillator:"
}], "Text"],

Cell[BoxData[
    \(\(\(V[r] = 1\/2\ r\^2\ \[Omega]\^2\ m\_0\)\(,\)\)\)], "NumberedEquation"],

Cell[TextData[{
  Cell[BoxData[
      \(m\_0\)],
    FontSlant->"Italic"],
  " is mass of oscillating particle, \[Omega] is frequency of oscillations, \
",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " is orbital quantum number, ",
  StyleBox["En",
    FontSlant->"Italic"],
  " is total energy of oscillator, ",
  StyleBox["R",
    FontSlant->"Italic"],
  "[",
  StyleBox["r",
    FontSlant->"Italic"],
  "] is radial part of wave function of oscillator."
}], "Text"],

Cell[TextData[{
  "Substitute expression for potential energy ",
  StyleBox["V",
    FontSlant->"Italic"],
  "[",
  StyleBox["r",
    FontSlant->"Italic"],
  "] to radial equation (",
  StyleBox["RadDifEqnQntOsc",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  ") and use extra denotations:"
}], "Text"],

Cell[BoxData[
    \(k = \@\(2\ \(m\_0\) En\)\/\[HBar], \ \[Lambda] = \(\(\ \)\(\(m\_0\) \
\[Omega]\)\)\/\[HBar]\)], "NumberedEquation",
  TextAlignment->Center],

Cell["and we will have", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RadDifEqnQntOsc1 = 
      Simplify[ReplaceAll[
          RadDifEqnQntOsc, {V[r] \[Rule] 1\/2\ r\^2\ \[Omega]\^2\ m\_0, 
            En \[Rule] \(k\^2\ \[HBar]\^2\)\/\(2\ m\_0\), 
            m\_0 \[Rule] \(\[Lambda]\ \[HBar]\)\/\[Omega]}]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(\(k\^2\ \[Lambda]\ \[HBar]\ R[r]\)\/\(\[Omega]\ m\_0\)\), "+",
         
        FractionBox[
          RowBox[{"2", " ", 
            RowBox[{
              SuperscriptBox["R", "\[Prime]",
                MultilineFunction->None], "[", "r", "]"}]}], "r"], "+", 
        RowBox[{
          SuperscriptBox["R", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}], 
      "==", \(\(R[
              r]\ \((l\_orb + 
                l\_orb\%2 + \(r\^4\ \[Lambda]\ \[Omega]\ m\_0\)\/\[HBar])\)\)\
\/r\^2\)}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RadDifEqnQntOsc2 = 
      Simplify[ReplaceAll[
          RadDifEqnQntOsc1, {m\_0 \[Rule] \(\[Lambda]\ \[HBar]\)\/\[Omega]}]]\
\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(k\^2\ R[r]\), "+", 
        FractionBox[
          RowBox[{"2", " ", 
            RowBox[{
              SuperscriptBox["R", "\[Prime]",
                MultilineFunction->None], "[", "r", "]"}]}], "r"], "+", 
        RowBox[{
          SuperscriptBox["R", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}], 
      "==", \(\(R[
              r]\ \((r\^4\ \[Lambda]\^2 + l\_orb + 
                l\_orb\%2)\)\)\/r\^2\)}]], "Output"]
}, Open  ]],

Cell["\<\
These transformation give dimensionless form of the radial equation.
We will seek solution of radial equation using the substitution:\
\>", "Text"],

Cell[BoxData[
    \(R[r] = \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^l\_orb\ v[
          r]\)], "NumberedEquation",
  TextAlignment->Center],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[r] = \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^l\_orb\ v[
          r]\), "\[IndentingNewLine]", 
    \(RadDifEqnQntOsc3 = 
      Simplify[\(-\(\(R[
                      r]\ \((r\^4\ \[Lambda]\^2 + l\_orb + 
                        l\_orb\%2)\)\)\/r\^2\)\) + 
            k\^2\ R[r] + \(2\ D[R[r], r]\)\/r + D[R[r], {r, 2}]] \[Equal] 
        0\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^l\_orb\ v[
        r]\)], "Output"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\), 
        " ", \(r\^\(\(-1\) + l\_orb\)\), " ", 
        RowBox[{"(", 
          
          RowBox[{\(r\ \((k\^2 - 3\ \[Lambda] - 2\ \[Lambda]\ l\_orb)\)\ v[
                r]\), "+", 
            RowBox[{\((2 - 2\ r\^2\ \[Lambda] + 2\ l\_orb)\), " ", 
              RowBox[{
                SuperscriptBox["v", "\[Prime]",
                  MultilineFunction->None], "[", "r", "]"}]}], "+", 
            RowBox[{"r", " ", 
              RowBox[{
                SuperscriptBox["v", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], "==",
       "0"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "and will solve with \"",
  StyleBox["DSolve",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  "\" tool:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DSolve[RadDifEqnQntOsc3, v[r], r]\)], "Input"],

Cell[BoxData[
    \({{v[
            r] \[Rule] \[ImaginaryI]\^\(\(-1\) - 2\ l\_orb\)\ r\^\(\(-1\) - 2\
\ l\_orb\)\ \[Lambda]\^\(1\/2\ \((\(-1\) - 2\ l\_orb)\)\)\ C[
                2]\ Hypergeometric1F1[
                1\/4 - k\^2\/\(4\ \[Lambda]\) - l\_orb\/2, 1\/2 - l\_orb, 
                r\^2\ \[Lambda]] + 
            C[1]\ Hypergeometric1F1[
                3\/4 - k\^2\/\(4\ \[Lambda]\) + l\_orb\/2, 3\/2 + l\_orb, 
                r\^2\ \[Lambda]]}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "General solution for ",
  StyleBox["v",
    FontSlant->"Italic"],
  "[",
  StyleBox["r",
    FontSlant->"Italic"],
  "] is superposition of two independent fundamental solutions:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(v2[r] = \[ImaginaryI]\^\(\(-1\) - 2\ l\_orb\)\ r\^\(\(-1\) - 2\ \
l\_orb\)\ \[Lambda]\^\(1\/2\ \((\(-1\) - 2\ l\_orb)\)\)\ C[
          2]\ Hypergeometric1F1[1\/4 - k\^2\/\(4\ \[Lambda]\) - l\_orb\/2, 
          1\/2 - l\_orb, r\^2\ \[Lambda]]\), "\[IndentingNewLine]", 
    \(v1[r] = 
      C[1]\ Hypergeometric1F1[3\/4 - k\^2\/\(4\ \[Lambda]\) + l\_orb\/2, 
          3\/2 + l\_orb, r\^2\ \[Lambda]]\)}], "Input",
  TextAlignment->Center],

Cell[BoxData[
    \(\[ImaginaryI]\^\(\(-1\) - 2\ l\_orb\)\ r\^\(\(-1\) - 2\ l\_orb\)\ \
\[Lambda]\^\(1\/2\ \((\(-1\) - 2\ l\_orb)\)\)\ C[2]\ Hypergeometric1F1[
        1\/4 - k\^2\/\(4\ \[Lambda]\) - l\_orb\/2, 1\/2 - l\_orb, 
        r\^2\ \[Lambda]]\)], "Output"],

Cell[BoxData[
    \(C[1]\ Hypergeometric1F1[3\/4 - k\^2\/\(4\ \[Lambda]\) + l\_orb\/2, 
        3\/2 + l\_orb, r\^2\ \[Lambda]]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "where Hypergeometric1F1[...] are the Kummer confluent hypergeometric \
functions ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Null]\_1\) \(\(F\_1\)(a; b; z)\)\)], 
    "InlineFormula"],
  " and C[2] and C[1] are constants.\nAs a result we have solution of the \
radial equation in the form:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(R[r] = \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \(r\^l\_orb\) \
\((v2[r] + v1[r])\)\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^l\_orb\ \((\
\[ImaginaryI]\^\(\(-1\) - 2\ l\_orb\)\ r\^\(\(-1\) - 2\ l\_orb\)\ \[Lambda]\^\
\(1\/2\ \((\(-1\) - 2\ l\_orb)\)\)\ C[2]\ Hypergeometric1F1[
              1\/4 - k\^2\/\(4\ \[Lambda]\) - l\_orb\/2, 1\/2 - l\_orb, 
              r\^2\ \[Lambda]] + 
          C[1]\ Hypergeometric1F1[3\/4 - k\^2\/\(4\ \[Lambda]\) + l\_orb\/2, 
              3\/2 + l\_orb, r\^2\ \[Lambda]])\)\)], "Output"]
}, Open  ]],

Cell["or as superposition of two components:", "Text"],

Cell[BoxData[
    \(R[r] = R2[r] + R1[r]\)], "NumberedEquation",
  TextAlignment->Center],

Cell["where", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R2[r] = \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^l\_orb\
\ \ \[ImaginaryI]\^\(\(-1\) - 2\ l\_orb\)\ r\^\(\(-1\) - 2\ l\_orb\)\ \
\[Lambda]\^\(1\/2\ \((\(-1\) - 2\ l\_orb)\)\)\ C[2]\ Hypergeometric1F1[
          1\/4 - k\^2\/\(4\ \[Lambda]\) - l\_orb\/2, 1\/2 - l\_orb, 
          r\^2\ \[Lambda]]\), "\[IndentingNewLine]", 
    \(R1[r] = \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^l\_orb\ C[
          1]\ Hypergeometric1F1[3\/4 - k\^2\/\(4\ \[Lambda]\) + l\_orb\/2, 
          3\/2 + l\_orb, r\^2\ \[Lambda]]\)}], "Input"],

Cell[BoxData[
    \(\[ImaginaryI]\^\(\(-1\) - 2\ l\_orb\)\ \[ExponentialE]\^\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\)\ r\^\(\(-1\) - l\_orb\)\ \[Lambda]\^\(1\/2\ \((\(-1\) - 2\ \
l\_orb)\)\)\ C[2]\ Hypergeometric1F1[
        1\/4 - k\^2\/\(4\ \[Lambda]\) - l\_orb\/2, 1\/2 - l\_orb, 
        r\^2\ \[Lambda]]\)], "Output"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^l\_orb\ C[
        1]\ Hypergeometric1F1[3\/4 - k\^2\/\(4\ \[Lambda]\) + l\_orb\/2, 
        3\/2 + l\_orb, r\^2\ \[Lambda]]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Now we analyze behavior of functions ",
  StyleBox["R2",
    FontSlant->"Italic"],
  "[",
  StyleBox["r",
    FontSlant->"Italic"],
  "] and ",
  StyleBox["R1",
    FontSlant->"Italic"],
  "[",
  StyleBox["r",
    FontSlant->"Italic"],
  "] near zero.\nTake Taylor series of hypergeometric functions near zero:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{
      RowBox[{
        StyleBox[
          RowBox[{
            StyleBox["HG2",
              FontSlant->"Italic"], "Taylor2"}]], "[", 
        StyleBox["r",
          FontSlant->"Italic"], "]"}], 
      "=", \(Series[
        Hypergeometric1F1[1\/4 - k\^2\/\(4\ \[Lambda]\) - l\_orb\/2, 
          1\/2 - l\_orb, r\^2\ \[Lambda]], {r, \ 0, \ 
          2}]\)}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox[
          RowBox[{
            StyleBox["HG1",
              FontSlant->"Italic"], "Taylor2"}]], "[", 
        StyleBox["r",
          FontSlant->"Italic"], "]"}], 
      "=", \(Series[
        Hypergeometric1F1[3\/4 - k\^2\/\(4\ \[Lambda]\) + l\_orb\/2, 
          3\/2 + l\_orb, r\^2\ \[Lambda]], {r, \ 0, \ 2}]\)}]}], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      "1", "+", \(\(\[Lambda]\ \((1\/4 - k\^2\/\(4\ \[Lambda]\) - 
                  l\_orb\/2)\)\ r\^2\)\/\(1\/2 - l\_orb\)\), "+", 
        InterpretationBox[\(O[r]\^3\),
          SeriesData[ r, 0, {}, 0, 3, 1]]}],
      SeriesData[ r, 0, {1, 0, 
        Times[ \[Lambda], 
          Power[ 
            Plus[ 
              Rational[ 1, 2], 
              Times[ -1, 
                Subscript[ l, orb]]], -1], 
          Plus[ 
            Rational[ 1, 4], 
            Times[ 
              Rational[ -1, 4], 
              Power[ k, 2], 
              Power[ \[Lambda], -1]], 
            Times[ 
              Rational[ -1, 2], 
              Subscript[ l, orb]]]]}, 0, 3, 1]]], "Output"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      "1", "+", \(\(\[Lambda]\ \((3\/4 - k\^2\/\(4\ \[Lambda]\) + 
                  l\_orb\/2)\)\ r\^2\)\/\(3\/2 + l\_orb\)\), "+", 
        InterpretationBox[\(O[r]\^3\),
          SeriesData[ r, 0, {}, 0, 3, 1]]}],
      SeriesData[ r, 0, {1, 0, 
        Times[ \[Lambda], 
          Plus[ 
            Rational[ 3, 4], 
            Times[ 
              Rational[ -1, 4], 
              Power[ k, 2], 
              Power[ \[Lambda], -1]], 
            Times[ 
              Rational[ 1, 2], 
              Subscript[ l, orb]]], 
          Power[ 
            Plus[ 
              Rational[ 3, 2], 
              Subscript[ l, orb]], -1]]}, 0, 3, 1]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "and take Taylor series of radial functions ",
  StyleBox["R2",
    FontSlant->"Italic"],
  "[",
  StyleBox["r",
    FontSlant->"Italic"],
  "] and ",
  StyleBox["R1",
    FontSlant->"Italic"],
  "[",
  StyleBox["r",
    FontSlant->"Italic"],
  "] near zero:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{\(R2Taylor2[r]\), "=", 
      RowBox[{"Simplify", "[", 
        RowBox[{\(\[ImaginaryI]\^\(\(-1\) - 2\ l\_orb\)\), 
          " ", \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\), 
          " ", \(r\^\(\(-1\) - l\_orb\)\), 
          " ", \(\[Lambda]\^\(1\/2\ \((\(-1\) - 2\ l\_orb)\)\)\), 
          " ", \(C[2]\), " ", 
          RowBox[{
            StyleBox[
              RowBox[{
                StyleBox["HG2",
                  FontSlant->"Italic"], "Taylor2"}]], "[", 
            StyleBox["r",
              FontSlant->"Italic"], "]"}]}], "]"}]}], "\[IndentingNewLine]", 
    RowBox[{\(R1Taylor1[r]\), "=", 
      RowBox[{"Simplify", "[", 
        RowBox[{\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\), 
          " ", \(r\^l\_orb\), " ", \(C[1]\), "  ", 
          RowBox[{
            StyleBox[
              RowBox[{
                StyleBox["HG1",
                  FontSlant->"Italic"], "Taylor2"}]], "[", 
            StyleBox["r",
              FontSlant->"Italic"], "]"}]}], "]"}]}]}], "Input"],

Cell[BoxData[
    RowBox[{\(r\^\(-l\_orb\)\), " ", 
      RowBox[{"(", 
        InterpretationBox[
          
          RowBox[{\(-\(\(\[ImaginaryI]\ \[ImaginaryI]\^\(\(-2\)\ l\_orb\)\ \
\[Lambda]\^\(\(-\(1\/2\)\) - l\_orb\)\ C[2]\)\/r\)\), 
            "+", \(\(\[ImaginaryI]\ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \
\[Pi]\ l\_orb\)\ k\^2\ \[Lambda]\^\(\(-\(1\/2\)\) - l\_orb\)\ C[
                    2]\ r\)\/\(2 - 4\ l\_orb\)\), "+", 
            InterpretationBox[\(O[r]\^2\),
              SeriesData[ r, 0, {}, -1, 2, 1]]}],
          SeriesData[ r, 0, {
            Times[ 
              Complex[ 0, -1], 
              Power[ 
                Complex[ 0, 1], 
                Times[ -2, 
                  Subscript[ l, orb]]], 
              Power[ \[Lambda], 
                Plus[ 
                  Rational[ -1, 2], 
                  Times[ -1, 
                    Subscript[ l, orb]]]], 
              C[ 2]], 0, 
            Times[ 
              Complex[ 0, 1], 
              Power[ E, 
                Times[ 
                  Complex[ 0, -1], Pi, 
                  Subscript[ l, orb]]], 
              Power[ k, 2], 
              Power[ \[Lambda], 
                Plus[ 
                  Rational[ -1, 2], 
                  Times[ -1, 
                    Subscript[ l, orb]]]], 
              C[ 2], 
              Power[ 
                Plus[ 2, 
                  Times[ -4, 
                    Subscript[ l, orb]]], -1]]}, -1, 2, 1]], 
        ")"}]}]], "Output"],

Cell[BoxData[
    RowBox[{\(r\^l\_orb\), " ", 
      RowBox[{"(", 
        InterpretationBox[
          
          RowBox[{\(C[1]\), 
            "+", \(\(k\^2\ C[1]\ r\^2\)\/\(\(-6\) - 4\ l\_orb\)\), "+", 
            InterpretationBox[\(O[r]\^3\),
              SeriesData[ r, 0, {}, 0, 3, 1]]}],
          SeriesData[ r, 0, {
            C[ 1], 0, 
            Times[ 
              Power[ k, 2], 
              C[ 1], 
              Power[ 
                Plus[ -6, 
                  Times[ -4, 
                    Subscript[ l, orb]]], -1]]}, 0, 3, 1]], ")"}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["R2",
    FontSlant->"Italic"],
  "[",
  StyleBox["r",
    FontSlant->"Italic"],
  "] is divergent function near zero and ",
  StyleBox["R1",
    FontSlant->"Italic"],
  "[",
  StyleBox["r",
    FontSlant->"Italic"],
  "] tends to zero.\nFiniteness of the wave function results us to \
condition:"
}], "Text"],

Cell[BoxData[
    \(C[2] = 0\)], "NumberedEquation",
  TextAlignment->Center],

Cell["\<\
Therefore radial wave function is:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(R[r] = \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^l\_orb\ C[
          1]\ Hypergeometric1F1[3\/4 - k\^2\/\(4\ \[Lambda]\) + l\_orb\/2, 
          3\/2 + l\_orb, r\^2\ \[Lambda]]\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^l\_orb\ C[
        1]\ Hypergeometric1F1[3\/4 - k\^2\/\(4\ \[Lambda]\) + l\_orb\/2, 
        3\/2 + l\_orb, r\^2\ \[Lambda]]\)], "Output"]
}, Open  ]],

Cell["\<\
Finiteness of the wave function give the second condition for radial \
function:\
\>", "Text"],

Cell[BoxData[{
    \(3\/4 + l\/2 - 
        k\^2\/\(4\ \[Lambda]\) = \(-n\_r\)\), "\[IndentingNewLine]", 
    \(n\_r = \ 0, 1, 2, 3,  ... \)}], "NumberedEquation",
  TextAlignment->Center],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(n\_r\)],
    FontSlant->"Italic"],
  " is the radial ",
  "quantum number."
}], "Text"],

Cell["\<\
This implies that hypergeometric functions has to be polynomial.
Thus we have:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(R[n\_r, l, \[Lambda], 
        r] = \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^l\_orb\ C[
          1]\ Hypergeometric1F1[\(-n\_rad\), 3\/2 + l\_orb, 
          r\^2\ \[Lambda]]\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^l\_orb\ C[
        1]\ Hypergeometric1F1[\(-n\_rad\), 3\/2 + l\_orb, 
        r\^2\ \[Lambda]]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. Energy levels of the two-dimensional quantum oscillator", "Section"],

Cell[TextData[{
  "Condition (6) give us possibility to obtain energy levels of the \
two-dimensional quantum oscillator.\nTo obtain energy levels we will use \
expressions (2) and \"",
  StyleBox["Solve",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  "\" Tool:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[Lambda] = \((m\_0*\[Omega])\)/\[HBar];\)\), "\n", 
    \(Solve[{3\/4 - k\^2\/\(4\ \[Lambda]\) + l\_orb\/2 == \(-n\_rad\), 
        En == \(k\^2\ \[HBar]\^2\)\/\(2\ m\_0\)}, {En, k}]\)}], "Input"],

Cell[BoxData[
    \({{En \[Rule] 1\/2\ \[Omega]\ \[HBar]\ \((3 + 2\ l\_orb + 4\ n\_rad)\), 
        k \[Rule] \(-\(\(\@\[Omega]\ \@m\_0\ \@\(3 + 2\ l\_orb + 4\ \
n\_rad\)\)\/\@\[HBar]\)\)}, {En \[Rule] 
          1\/2\ \[Omega]\ \[HBar]\ \((3 + 2\ l\_orb + 4\ n\_rad)\), 
        k \[Rule] \(\@\[Omega]\ \@m\_0\ \@\(3 + 2\ l\_orb + 4\ n\_rad\)\)\/\@\
\[HBar]}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "As a result we have quantified energy levels depending on quantum numbers \
",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " and ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(En[n\_rad, l\_orb] = 
      1\/2\ \[Omega]\ \[HBar]\ \((3 + 2\ l\_orb + 4\ n\_rad)\)\)], "Input"],

Cell[BoxData[
    \(1\/2\ \[Omega]\ \[HBar]\ \((3 + 2\ l\_orb + 4\ n\_rad)\)\)], "Output"]
}, Open  ]],

Cell["or", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(En[n, l\_orb] = 
      Simplify[ReplaceAll[
          1\/2\ \[Omega]\ \[HBar]\ \((3 + 2\ l\_orb + 4\ n\_rad)\), 
          n\_rad \[Rule] \((n - l\_orb)\)/2]]\)], "Input"],

Cell[BoxData[
    \(1\/2\ \((3 + 2\ n)\)\ \[Omega]\ \[HBar]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(n\)],
    FontSlant->"Italic"],
  " is total quantum number:"
}], "Text"],

Cell[BoxData[{
    \(n = 2  n\_rad + l\_orb\), "\n", 
    \(n = \ 0, 1, 2, 3,  ... \)}], "NumberedEquation",
  TextAlignment->Center],

Cell["Thus we can write down the radial function in the forms:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(R[\[Omega], r] = \((r^l\_orb)\)*Exp[\(-\((\[Lambda]*r^2)\)\)/2]*
        C[1]\ Hypergeometric1F1[\(-n\_rad\), 3\/2 + l\_orb, 
          r\^2\ \[Lambda]]\), "\[IndentingNewLine]", 
    \(R[\[Omega], r] = \((r^l\_orb)\)*Exp[\(-\((\[Lambda]*r^2)\)\)/2]*
        C[1]\ Hypergeometric1F1[\((n - l\_orb)\)/2, 3\/2 + l\_orb, 
          r\^2\ \[Lambda]]\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\(r\^2\ \[Omega]\ m\_0\)\/\(2\ \[HBar]\)\)\)\ \
r\^l\_orb\ C[1]\ Hypergeometric1F1[\(-n\_rad\), 
        3\/2 + l\_orb, \(r\^2\ \[Omega]\ m\_0\)\/\[HBar]]\)], "Output"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\(r\^2\ \[Omega]\ m\_0\)\/\(2\ \[HBar]\)\)\)\ \
r\^l\_orb\ C[1]\ Hypergeometric1F1[1\/2\ \((n - l\_orb)\), 
        3\/2 + l\_orb, \(r\^2\ \[Omega]\ m\_0\)\/\[HBar]]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Clear[\[Lambda]]\), "\[IndentingNewLine]", 
    \(\[Psi][n\_rad, \[Lambda], r] = 
      C[1] \((r^l)\)*Exp[\(-\((\[Lambda]*r^2)\)\)/2] 
        Hypergeometric1F1[\(-n\_rad\), 3\/2 + l\_orb, 
          r\^2\ \[Lambda]]\), "\n", 
    \(\[Psi][n, \[Lambda], r] = 
      C[1] \((r^l)\)*Exp[\(-\((\[Lambda]*r^2)\)\)/2] 
        Hypergeometric1F1[\(n - l\_orb\)\/2, 3\/2 + l\_orb, 
          r\^2\ \[Lambda]]\), "\[IndentingNewLine]", 
    \(\[Psi][n\_rad, \[Omega], r] = 
      Simplify[ReplaceAll[\[Psi][n\_rad, \[Lambda], 
            r], {\[Lambda] \[Rule] \(\[Omega]\ m\_0\)\/\[HBar]}]]\), "\
\[IndentingNewLine]", 
    \(\[Psi][n, \[Omega], r] = 
      Simplify[ReplaceAll[\[Psi][n, \[Lambda], 
            r], {\[Lambda] \[Rule] \(\[Omega]\ m\_0\)\/\[HBar]}]]\)}], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^l\ C[
        1]\ Hypergeometric1F1[\(-n\_rad\), 3\/2 + l\_orb, 
        r\^2\ \[Lambda]]\)], "Output"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^l\ C[
        1]\ Hypergeometric1F1[1\/2\ \((n - l\_orb)\), 3\/2 + l\_orb, 
        r\^2\ \[Lambda]]\)], "Output"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\(r\^2\ \[Omega]\ m\_0\)\/\(2\ \[HBar]\)\)\)\ \
r\^l\ C[1]\ Hypergeometric1F1[\(-n\_rad\), 
        3\/2 + l\_orb, \(r\^2\ \[Omega]\ m\_0\)\/\[HBar]]\)], "Output"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\(r\^2\ \[Omega]\ m\_0\)\/\(2\ \[HBar]\)\)\)\ \
r\^l\ C[1]\ Hypergeometric1F1[1\/2\ \((n - l\_orb)\), 
        3\/2 + l\_orb, \(r\^2\ \[Omega]\ m\_0\)\/\[HBar]]\)], "Output"]
}, Open  ]],

Cell["", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1016, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.25,
StyleDefinitions -> "Classroom1.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 252, 8, 93, "Subtitle"],
Cell[2525, 82, 208, 5, 124, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2758, 91, 89, 2, 85, "Section"],
Cell[2850, 95, 243, 8, 57, "Text"],

Cell[CellGroupData[{
Cell[3118, 107, 711, 18, 113, "Input"],
Cell[3832, 127, 550, 13, 85, "Output"]
}, Open  ]],
Cell[4397, 143, 171, 8, 56, "Text"],
Cell[4571, 153, 93, 1, 68, "NumberedEquation"],
Cell[4667, 156, 487, 19, 80, "Text"],
Cell[5157, 177, 356, 13, 57, "Text"],
Cell[5516, 192, 160, 3, 75, "NumberedEquation"],
Cell[5679, 197, 32, 0, 56, "Text"],

Cell[CellGroupData[{
Cell[5736, 201, 272, 5, 119, "Input"],
Cell[6011, 208, 582, 15, 106, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6630, 228, 159, 4, 85, "Input"],
Cell[6792, 234, 501, 13, 89, "Output"]
}, Open  ]],
Cell[7308, 250, 157, 3, 92, "Text"],
Cell[7468, 255, 152, 3, 64, "NumberedEquation"],

Cell[CellGroupData[{
Cell[7645, 262, 393, 8, 153, "Input"],
Cell[8041, 272, 108, 2, 73, "Output"],
Cell[8152, 276, 702, 16, 73, "Output"]
}, Open  ]],
Cell[8869, 295, 187, 7, 57, "Text"],

Cell[CellGroupData[{
Cell[9081, 306, 66, 1, 63, "Input"],
Cell[9150, 309, 476, 9, 174, "Output"]
}, Open  ]],
Cell[9641, 321, 210, 8, 56, "Text"],

Cell[CellGroupData[{
Cell[9876, 333, 461, 8, 178, "Input"],
Cell[10340, 343, 265, 4, 88, "Output"],
Cell[10608, 349, 141, 2, 88, "Output"]
}, Open  ]],
Cell[10764, 354, 325, 8, 92, "Text"],

Cell[CellGroupData[{
Cell[11114, 366, 125, 2, 73, "Input"],
Cell[11242, 370, 473, 7, 183, "Output"]
}, Open  ]],
Cell[11730, 380, 54, 0, 56, "Text"],
Cell[11787, 382, 89, 2, 53, "NumberedEquation"],
Cell[11879, 386, 68, 2, 56, "Text"],

Cell[CellGroupData[{
Cell[11972, 392, 566, 8, 183, "Input"],
Cell[12541, 402, 314, 5, 88, "Output"],
Cell[12858, 409, 211, 3, 88, "Output"]
}, Open  ]],
Cell[13084, 415, 342, 14, 92, "Text"],

Cell[CellGroupData[{
Cell[13451, 433, 790, 23, 171, "Input"],
Cell[14244, 458, 748, 22, 113, "Output"],
Cell[14995, 482, 718, 21, 113, "Output"]
}, Open  ]],
Cell[15728, 506, 289, 14, 56, "Text"],

Cell[CellGroupData[{
Cell[16042, 524, 1052, 25, 114, "Input"],
Cell[17097, 551, 1498, 42, 102, "Output"],
Cell[18598, 595, 581, 17, 91, "Output"]
}, Open  ]],
Cell[19194, 615, 336, 14, 92, "Text"],
Cell[19533, 631, 77, 2, 53, "NumberedEquation"],
Cell[19613, 635, 58, 2, 56, "Text"],

Cell[CellGroupData[{
Cell[19696, 641, 221, 3, 88, "Input"],
Cell[19920, 646, 211, 3, 88, "Output"]
}, Open  ]],
Cell[20146, 652, 104, 3, 56, "Text"],
Cell[20253, 657, 188, 4, 98, "NumberedEquation"],
Cell[20444, 663, 139, 7, 56, "Text"],
Cell[20586, 672, 102, 3, 92, "Text"],

Cell[CellGroupData[{
Cell[20713, 679, 220, 4, 85, "Input"],
Cell[20936, 685, 181, 3, 85, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[21166, 694, 77, 0, 85, "Section"],
Cell[21246, 696, 328, 9, 93, "Text"],

Cell[CellGroupData[{
Cell[21599, 709, 220, 3, 119, "Input"],
Cell[21822, 714, 374, 6, 180, "Output"]
}, Open  ]],
Cell[22211, 723, 248, 11, 56, "Text"],

Cell[CellGroupData[{
Cell[22484, 738, 117, 2, 85, "Input"],
Cell[22604, 742, 90, 1, 85, "Output"]
}, Open  ]],
Cell[22709, 746, 18, 0, 56, "Text"],

Cell[CellGroupData[{
Cell[22752, 750, 191, 4, 85, "Input"],
Cell[22946, 756, 73, 1, 85, "Output"]
}, Open  ]],
Cell[23034, 760, 125, 6, 56, "Text"],
Cell[23162, 768, 133, 3, 78, "NumberedEquation"],
Cell[23298, 773, 72, 0, 56, "Text"],

Cell[CellGroupData[{
Cell[23395, 777, 380, 6, 161, "Input"],
Cell[23778, 785, 210, 3, 88, "Output"],
Cell[23991, 790, 221, 3, 88, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24249, 798, 795, 16, 309, "Input"],
Cell[25047, 816, 176, 3, 85, "Output"],
Cell[25226, 821, 187, 3, 85, "Output"],
Cell[25416, 826, 205, 3, 88, "Output"],
Cell[25624, 831, 216, 3, 88, "Output"]
}, Open  ]],
Cell[25855, 837, 16, 0, 56, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

