(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    142139,       3082]*)
(*NotebookOutlinePosition[    142868,       3107]*)
(*  CellTagsIndexPosition[    142824,       3103]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Part ",
    FontWeight->"Bold"],
  StyleBox["2. Quantum Isotropic Oscillator",
    FontWeight->"Bold"],
  "\n2.3. Three-Dimensional Isotropic Quantum Oscillator"
}], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
2.3.6. Probability Densities of the Three-Dimensional Quantum Oscillator\
\>", "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
1. Normalized radial and angular wave functions and probability densities of \
the three-dimensional quantum oscillator\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Consider some states of the quantum oscillator defined by quantum numbers:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  Cell[BoxData[
      \(n\_rad = 0, 1, 2, 3\)],
    FontSlant->"Italic"],
  " ,\n",
  Cell[BoxData[
      \(l\_orb = 0, 1, 2, 3\)],
    FontSlant->"Italic"],
  " ,\n",
  Cell[BoxData[
      \(m\_azm = 0, 1, 2, 3\)]],
  ","
}], "NumberedEquation"],

Cell["\<\
Wave functions and probability densities of the quantum oscillator is\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(\[Psi]\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda]] = 
      R\_Oscl[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\)], "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      StyleBox[\(R\_Oscl[n\_rad, l\_orb, \[Lambda]]\),
        FontSlant->"Italic"]]],
  " is the radial wave function and ",
  Cell[BoxData[
      StyleBox[\(Y[l\_orb, m\_azm]\),
        FontSlant->"Italic"]]],
  " is the angular wave function."
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Normalized radial wave functions and radial probability densities of the \
quantum oscillator for quantum numbers are:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(R\_Oscl[0, 
          0, \[Lambda]] = \(2\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\
\)\ \[Lambda]\^\(3/4\)\)\/\[Pi]\^\(1/4\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[0, 0, \[Lambda]] = 
        R\_Oscl[0, 0, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[0, 
          1, \[Lambda]] = \(2\ \@\(2\/3\)\ \[ExponentialE]\^\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\)\ r\ \[Lambda]\^\(5/4\)\)\/\[Pi]\^\(1/4\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[0, 1, \[Lambda]] = 
        R\_Oscl[0, 1, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[0, 
          2, \[Lambda]] = \(4\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\
\)\ r\^2\ \[Lambda]\^\(7/4\)\)\/\(\@15\ \[Pi]\^\(1/4\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[0, 2, \[Lambda]] = 
        R\_Oscl[0, 2, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[0, 
          3, \[Lambda]] = \(4\ \@\(2\/105\)\ \[ExponentialE]\^\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\)\ r\^3\ \[Lambda]\^\(9/4\)\)\/\[Pi]\^\(1/4\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[0, 3, \[Lambda]] = 
        R\_Oscl[0, 3, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[1, 
          0, \[Lambda]] = \(\@6\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\
\)\)\ \[Lambda]\^\(3/4\)\ \((1 - \(2\ r\^2\ \[Lambda]\)\/3)\)\)\/\[Pi]\^\(1/4\
\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[1, 0, \[Lambda]] = 
        R\_Oscl[1, 0, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[1, 
          1, \[Lambda]] = \(-\(\(2\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\
\/2\)\)\ r\ \[Lambda]\^\(5/4\)\ \((\(-5\) + 
                    2\ r\^2\ \[Lambda])\)\)\/\(\@15\ \
\[Pi]\^\(1/4\)\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[1, 1, \[Lambda]] = 
        R\_Oscl[1, 1, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[1, 
          2, \[Lambda]] = \(-\(\(2\ \@\(2\/105\)\ \
\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^2\ \[Lambda]\^\(7/4\)\ \
\((\(-7\) + 
                    2\ r\^2\ \[Lambda])\)\)\/\[Pi]\^\(1/4\)\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[1, 2, \[Lambda]] = 
        R\_Oscl[1, 2, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[1, 
          3, \[Lambda]] = \(4\ \@\(3\/35\)\ \[ExponentialE]\^\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\)\ r\^3\ \[Lambda]\^\(9/4\)\ \((1 - \(2\ r\^2\ \
\[Lambda]\)\/9)\)\)\/\[Pi]\^\(1/4\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[1, 3, \[Lambda]] = 
        R\_Oscl[1, 3, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[2, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
\[Lambda]\^\(3/4\)\ \((15 + 4\ r\^2\ \[Lambda]\ \((\(-5\) + r\^2\ \
\[Lambda])\))\)\)\/\(\@30\ \[Pi]\^\(1/4\)\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[2, 0, \[Lambda]] = 
        R\_Oscl[2, 0, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[2, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
r\ \[Lambda]\^\(5/4\)\ \((35 + 4\ r\^2\ \[Lambda]\ \((\(-7\) + r\^2\ \
\[Lambda])\))\)\)\/\(\@105\ \[Pi]\^\(1/4\)\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[2, 1, \[Lambda]] = 
        R\_Oscl[2, 1, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[2, 
          2, \[Lambda]] = \(1\/\(3\ \[Pi]\^\(1/4\)\)\) \((\@\(2\/105\)\ \
\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^2\ \[Lambda]\^\(7/4\)\ \
\((63 + 4\ r\^2\ \[Lambda]\ \((\(-9\) + 
                        r\^2\ \[Lambda])\))\))\);\)\), "\[IndentingNewLine]", \

    \(\(\(RR\_Oscl[2, 2, \[Lambda]] = 
        R\_Oscl[2, 2, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[2, 
          3, \[Lambda]] = \((2\ \[ExponentialE]\^\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\)\ r\^3\ \[Lambda]\^\(9/4\)\ \((99 + 
                  4\ r\^2\ \[Lambda]\ \((\(-11\) + 
                        r\^2\ \[Lambda])\))\))\)/\((3\ \@1155\ \
\[Pi]\^\(1/4\))\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[2, 3, \[Lambda]] = 
        R\_Oscl[2, 3, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[3, 
          0, \[Lambda]] = \(1\/\(2\ \[Pi]\^\(1/4\)\)\) \((\@35\ \
\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \[Lambda]\^\(3/4\)\ \((1 - 
                  2\ r\^2\ \[Lambda] + \(4\ r\^4\ \[Lambda]\^2\)\/5 - \(8\ \
r\^6\ \[Lambda]\^3\)\/105)\))\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[3, 0, \[Lambda]] = 
        R\_Oscl[3, 0, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[3, 
          1, \[Lambda]] = \(-\(\(1\/\(9\ \@70\ \[Pi]\^\(1/4\)\)\) \((\
\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\ \[Lambda]\^\(5/4\)\ \
\((\(-315\) + 2\ r\^2\ \[Lambda]\ \((189 - 54\ r\^2\ \[Lambda] + 
                          4\ r\^4\ \[Lambda]\^2)\))\))\)\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[3, 1, \[Lambda]] = 
        R\_Oscl[3, 1, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[3, 
          2, \[Lambda]] = \(1\/\[Pi]\^\(1/4\)\) \((\@\(77\/5\)\ \
\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^2\ \[Lambda]\^\(7/4\)\ \
\((1 - 2\/693\ r\^2\ \[Lambda]\ \((297 - 66\ r\^2\ \[Lambda] + 
                        4\ r\^4\ \[Lambda]\^2)\))\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[3, 2, \[Lambda]] = 
        R\_Oscl[3, 2, \[Lambda]]\^2\ r\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[3, 
          3, \[Lambda]] = \(1\/\[Pi]\^\(1/4\)\) \((\@\(286\/35\)\ \
\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^3\ \[Lambda]\^\(9/4\)\ \
\((1 - \(2\ r\^2\ \[Lambda]\ \((429 - 78\ r\^2\ \[Lambda] + 4\ r\^4\ \
\[Lambda]\^2)\)\)\/1287)\))\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_Oscl[3, 3, \[Lambda]] = 
        R\_Oscl[3, 3, \[Lambda]]\^2\ r\^2;\)\)}], "Input"],

Cell["\<\
Normalized angular wave functions (spherical harmonics) and angular \
probability densities of the three-dimensional quantum oscillator for given \
quantum numbers are:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(Y[0, 0] = 1\/\(2\ \@\[Pi]\);\)\), "\n", 
    \(\(\(YY[0, 0] = 1\/\(4\ \[Pi]\);\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(Y[1, 0] = 1\/2\ \@\(3\/\[Pi]\)\ Cos[\[Theta]];\)\), "\n", 
    \(\(\(YY[1, 
          0] = \(3\ Cos[\[Theta]]\^2\)\/\(4\ \
\[Pi]\);\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(Y[1, 
          1] = \(-\(1\/2\)\)\ \[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi]\)\
\ \@\(3\/\(2\ \[Pi]\)\)\ Sin[\[Theta]];\)\), "\n", 
    \(\(\(YY[1, 
          1] = \(3\ Sin[\[Theta]]\^2\)\/\(8\ \
\[Pi]\);\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(Y[2, 0] = 
        1\/4\ \@\(5\/\[Pi]\)\ \((\(-1\) + 3\ Cos[\[Theta]]\^2)\);\)\), "\n", 
    \(\(\(YY[2, 
          0] = \(5\ \((1 + 3\ Cos[2\ \[Theta]])\)\^2\)\/\(64\ \[Pi]\);\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(Y[2, 
          1] = \(-\(1\/2\)\)\ \[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi]\)\
\ \@\(15\/\(2\ \[Pi]\)\)\ Cos[\[Theta]]\ Sin[\[Theta]];\)\), "\n", 
    \(\(\(YY[2, 
          1] = \(15\ Cos[\[Theta]]\^2\ Sin[\[Theta]]\^2\)\/\(8\ \[Pi]\);\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(Y[2, 2] = 
        1\/4\ \[ExponentialE]\^\(2\ \[ImaginaryI]\ \[CurlyPhi]\)\ \@\(15\/\(2\
\ \[Pi]\)\)\ Sin[\[Theta]]\^2;\)\), "\n", 
    \(\(\(YY[2, 
          2] = \(15\ Sin[\[Theta]]\^4\)\/\(32\ \
\[Pi]\);\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(Y[3, 0] = 
        1\/4\ \@\(7\/\[Pi]\)\ \((\(-3\)\ Cos[\[Theta]] + 
              5\ Cos[\[Theta]]\^3)\);\)\), "\n", 
    \(\(\(YY[3, 
          0] = \(7\ \((3\ Cos[\[Theta]] + 5\ Cos[3\ \[Theta]])\)\^2\)\/\(256\ \
\[Pi]\);\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(Y[3, 
          1] = \(-\(1\/8\)\)\ \[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi]\)\
\ \@\(21\/\[Pi]\)\ \((\(-1\) + 
              5\ Cos[\[Theta]]\^2)\)\ Sin[\[Theta]];\)\), "\n", 
    \(\(\(YY[3, 
          1] = \(21\ \((Sin[\[Theta]] + 5\ Sin[3\ \[Theta]])\)\^2\)\/\(1024\ \
\[Pi]\);\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(Y[3, 2] = 
        1\/4\ \[ExponentialE]\^\(2\ \[ImaginaryI]\ \[CurlyPhi]\)\ \
\@\(105\/\(2\ \[Pi]\)\)\ Cos[\[Theta]]\ Sin[\[Theta]]\^2;\)\), "\n", 
    \(\(\(YY[3, 
          2] = \(105\ Cos[\[Theta]]\^2\ Sin[\[Theta]]\^4\)\/\(32\ \
\[Pi]\);\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(Y[3, 
          3] = \(-\(1\/8\)\)\ \[ExponentialE]\^\(3\ \[ImaginaryI]\ \
\[CurlyPhi]\)\ \@\(35\/\[Pi]\)\ Sin[\[Theta]]\^3;\)\), "\n", 
    \(\(YY[3, 3] = \(35\ Sin[\[Theta]]\^6\)\/\(64\ \[Pi]\);\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2. Calculation of wave functions and probability densities of the \
three-dimensional quantum oscillator for given quantum numbers\
\>", "Section"],

Cell["\<\
Normalized wave functions and probability densities of the three-dimensional \
quantum oscillator for given quantum numbers are:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[Psi]\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda]] = 
      R\_Oscl[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda]] = 
      RR\_Oscl[n\_rad, l\_orb, \[Lambda]]\ YY[l\_orb, m\_azm]\)}], "Input"],

Cell[BoxData[
    \(Y[l\_orb, m\_azm]\ R\_Oscl[n\_rad, l\_orb, \[Lambda]]\)], "Output"],

Cell[BoxData[
    \(YY[l\_orb, m\_azm]\ RR\_Oscl[n\_rad, l\_orb, \[Lambda]]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Psi]\_Oscl[0, 0, 
        0, \[Lambda]] = \(\(R\_Oscl[n\_rad, l\_orb, \[Lambda]]\)\(\ \)\(Y[
          l\_orb, m\_azm]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(Y[l\_orb, m\_azm]\ R\_Oscl[n\_rad, l\_orb, \[Lambda]]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "1) ",
  Cell[BoxData[
      \(n\_rad = 0\)],
    FontSlant->"Italic"]
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[0, 0, 0, \[Lambda]] = 
      R\_Oscl[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[0, 0, 0, \[Lambda]] = 
      RR\_Oscl[n\_rad, l\_orb, \[Lambda]]\ YY[l\_orb, m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
\[Lambda]\^\(3/4\)\)\/\[Pi]\^\(3/4\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^2\ \[Lambda]\^\(3/2\)\)\
\/\[Pi]\^\(3/2\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[0, 1, 0, \[Lambda]] = 
      R\_Oscl[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[0, 1, 0, \[Lambda]] = 
      RR\_Oscl[n\_rad, l\_orb, \[Lambda]]\ YY[l\_orb, m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\@2\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\ \[Lambda]\^\
\(5/4\)\ Cos[\[Theta]]\)\/\[Pi]\^\(3/4\)\)], "Output"],

Cell[BoxData[
    \(\(2\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^4\ \
\[Lambda]\^\(5/2\)\ Cos[\[Theta]]\^2\)\/\[Pi]\^\(3/2\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[0, 1, 1, \[Lambda]] = 
      R\_Oscl[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[0, 1, 1, \[Lambda]] = 
      RR\_Oscl[n\_rad, l\_orb, \[Lambda]]\ YY[l\_orb, m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\(-\(\(r\^2\ \[Lambda]\)\/2\)\) + \
\[ImaginaryI]\ \[CurlyPhi]\)\ r\ \[Lambda]\^\(5/4\)\ Sin[\[Theta]]\)\/\[Pi]\^\
\(3/4\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^4\ \[Lambda]\^\(5/2\)\ \
Sin[\[Theta]]\^2\)\/\[Pi]\^\(3/2\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[0, 2, 0, \[Lambda]] = 
      R\_Oscl[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[0, 2, 0, \[Lambda]] = 
      RR\_Oscl[n\_rad, l\_orb, \[Lambda]]\ YY[l\_orb, m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^2\ \
\[Lambda]\^\(7/4\)\ \((\(-1\) + 3\ Cos[\[Theta]]\^2)\)\)\/\(\@3\ \[Pi]\^\(3/4\
\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^6\ \[Lambda]\^\(7/2\)\ \
\((1 + 3\ Cos[2\ \[Theta]])\)\^2\)\/\(12\ \[Pi]\^\(3/2\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[0, 2, 1, \[Lambda]] = 
      R\_Oscl[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[0, 2, 1, \[Lambda]] = 
      RR\_Oscl[n\_rad, l\_orb, \[Lambda]]\ YY[l\_orb, m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(\@2\ \[ExponentialE]\^\(\(-\(\(r\^2\ \[Lambda]\)\/2\)\) + \
\[ImaginaryI]\ \[CurlyPhi]\)\ r\^2\ \[Lambda]\^\(7/4\)\ Cos[\[Theta]]\ Sin[\
\[Theta]]\)\/\[Pi]\^\(3/4\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(2\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^6\ \
\[Lambda]\^\(7/2\)\ Cos[\[Theta]]\^2\ Sin[\[Theta]]\^2\)\/\[Pi]\^\(3/2\)\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 2;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[0, 2, 2, \[Lambda]] = 
      R\_Oscl[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[0, 2, 2, \[Lambda]] = 
      RR\_Oscl[n\_rad, l\_orb, \[Lambda]]\ YY[l\_orb, m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\(\(r\^2\ \[Lambda]\)\/2\)\) + 2\ \[ImaginaryI]\
\ \[CurlyPhi]\)\ r\^2\ \[Lambda]\^\(7/4\)\ Sin[\[Theta]]\^2\)\/\(\@2\ \[Pi]\^\
\(3/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^6\ \[Lambda]\^\(7/2\)\ \
Sin[\[Theta]]\^4\)\/\(2\ \[Pi]\^\(3/2\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[0, 3, 0, \[Lambda]] = 
      R\_Oscl[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[0, 3, 0, \[Lambda]] = 
      RR\_Oscl[n\_rad, l\_orb, \[Lambda]]\ YY[l\_orb, m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\@\(2\/15\)\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^3\ \
\[Lambda]\^\(9/4\)\ \((\(-3\)\ Cos[\[Theta]] + 5\ \
Cos[\[Theta]]\^3)\)\)\/\[Pi]\^\(3/4\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^8\ \[Lambda]\^\(9/2\)\ \
\((3\ Cos[\[Theta]] + 5\ Cos[3\ \[Theta]])\)\^2\)\/\(120\ \
\[Pi]\^\(3/2\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[0, 3, 1, \[Lambda]] = 
      R\_Oscl[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[0, 3, 1, \[Lambda]] = 
      RR\_Oscl[n\_rad, l\_orb, \[Lambda]]\ YY[l\_orb, m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\(-\(\(r\^2\ \[Lambda]\)\/2\)\) + \
\[ImaginaryI]\ \[CurlyPhi]\)\ r\^3\ \[Lambda]\^\(9/4\)\ \((\(-1\) + 
                5\ Cos[\[Theta]]\^2)\)\ Sin[\[Theta]]\)\/\(\@10\ \[Pi]\^\(3/4\
\)\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^8\ \[Lambda]\^\(9/2\)\ \
\((Sin[\[Theta]] + 5\ Sin[3\ \[Theta]])\)\^2\)\/\(160\ \[Pi]\^\(3/2\)\)\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 2;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[0, 3, 2, \[Lambda]] = 
      R\_Oscl[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[0, 3, 2, \[Lambda]] = 
      RR\_Oscl[n\_rad, l\_orb, \[Lambda]]\ YY[l\_orb, m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\(\(r\^2\ \[Lambda]\)\/2\)\) + 2\ \[ImaginaryI]\
\ \[CurlyPhi]\)\ r\^3\ \[Lambda]\^\(9/4\)\ Cos[\[Theta]]\ \
Sin[\[Theta]]\^2\)\/\[Pi]\^\(3/4\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^8\ \[Lambda]\^\(9/2\)\ \
Cos[\[Theta]]\^2\ Sin[\[Theta]]\^4\)\/\[Pi]\^\(3/2\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\n", 
    \(\(l\_orb = 3;\)\), "\n", 
    \(\(m\_azm = 3;\)\), "\n", 
    \(\[Psi]\_Oscl[0, 3, 3, \[Lambda]] = 
      R\_Oscl[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[0, 3, 3, \[Lambda]] = 
      RR\_Oscl[n\_rad, l\_orb, \[Lambda]]\ YY[l\_orb, m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\(-\(\(r\^2\ \[Lambda]\)\/2\)\) + 3\ \
\[ImaginaryI]\ \[CurlyPhi]\)\ r\^3\ \[Lambda]\^\(9/4\)\ \
Sin[\[Theta]]\^3\)\/\(\@6\ \[Pi]\^\(3/4\)\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^8\ \[Lambda]\^\(9/2\)\ \
Sin[\[Theta]]\^6\)\/\(6\ \[Pi]\^\(3/2\)\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "2) ",
  Cell[BoxData[
      \(n\_rad = 1\)],
    FontSlant->"Italic"]
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[1, 0, 0, \[Lambda]] = 
      R\_Oscl[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[1, 0, 0, \[Lambda]] = 
      RR\_Oscl[n\_rad, l\_orb, \[Lambda]]\ YY[l\_orb, m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\@\(3\/2\)\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
\[Lambda]\^\(3/4\)\ \((1 - \(2\ r\^2\ \[Lambda]\)\/3)\)\)\/\[Pi]\^\(3/4\)\)], \
"Output"],

Cell[BoxData[
    \(\(3\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^2\ \
\[Lambda]\^\(3/2\)\ \((1 - \(2\ r\^2\ \[Lambda]\)\/3)\)\^2\)\/\(2\ \
\[Pi]\^\(3/2\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[1, 1, 0, \[Lambda]] = 
      R\_Oscl[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[1, 1, 0, \[Lambda]] = 
      RR\_Oscl[n\_rad, l\_orb, \[Lambda]]\ YY[l\_orb, m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\ \[Lambda]\^\
\(5/4\)\ \((\(-5\) + 
                2\ r\^2\ \[Lambda])\)\ Cos[\[Theta]]\)\/\(\@5\ \[Pi]\^\(3/4\)\
\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^4\ \[Lambda]\^\(5/2\)\ \
\((\(-5\) + 2\ r\^2\ \[Lambda])\)\^2\ Cos[\[Theta]]\^2\)\/\(5\ \[Pi]\^\(3/2\)\
\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[1, 1, 1, \[Lambda]] = 
      R\_Oscl[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[1, 1, 1, \[Lambda]] = 
      RR\_Oscl[n\_rad, l\_orb, \[Lambda]]\ YY[l\_orb, m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\(\(r\^2\ \[Lambda]\)\/2\)\) + \[ImaginaryI]\ \
\[CurlyPhi]\)\ r\ \[Lambda]\^\(5/4\)\ \((\(-5\) + 2\ r\^2\ \[Lambda])\)\ Sin[\
\[Theta]]\)\/\(\@10\ \[Pi]\^\(3/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^4\ \[Lambda]\^\(5/2\)\ \
\((\(-5\) + 2\ r\^2\ \[Lambda])\)\^2\ Sin[\[Theta]]\^2\)\/\(10\ \
\[Pi]\^\(3/2\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[1, 2, 0, \[Lambda]] = 
      R\_Oscl[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[1, 2, 0, \[Lambda]] = 
      RR\_Oscl[n\_rad, l\_orb, \[Lambda]]\ YY[l\_orb, m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^2\ \
\[Lambda]\^\(7/4\)\ \((\(-7\) + 2\ r\^2\ \[Lambda])\)\ \((\(-1\) + 
                3\ Cos[\[Theta]]\^2)\)\)\/\(\@42\ \[Pi]\^\(3/4\)\)\)\)\)], \
"Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^6\ \[Lambda]\^\(7/2\)\ \
\((\(-7\) + 2\ r\^2\ \[Lambda])\)\^2\ \((1 + 3\ Cos[2\ \
\[Theta]])\)\^2\)\/\(168\ \[Pi]\^\(3/2\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[1, 2, 1, \[Lambda]] = 
      R\_Oscl[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[1, 2, 1, \[Lambda]] = 
      RR\_Oscl[n\_rad, l\_orb, \[Lambda]]\ YY[l\_orb, m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\(\(r\^2\ \[Lambda]\)\/2\)\) + \[ImaginaryI]\ \
\[CurlyPhi]\)\ r\^2\ \[Lambda]\^\(7/4\)\ \((\(-7\) + 2\ r\^2\ \[Lambda])\)\ \
Cos[\[Theta]]\ Sin[\[Theta]]\)\/\(\@7\ \[Pi]\^\(3/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^6\ \[Lambda]\^\(7/2\)\ \
\((\(-7\) + 2\ r\^2\ \[Lambda])\)\^2\ Cos[\[Theta]]\^2\ \
Sin[\[Theta]]\^2\)\/\(7\ \[Pi]\^\(3/2\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 2;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[1, 2, 2, \[Lambda]] = 
      R\_Oscl[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[1, 2, 2, \[Lambda]] = 
      RR\_Oscl[n\_rad, l\_orb, \[Lambda]]\ YY[l\_orb, m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\(-\(\(r\^2\ \[Lambda]\)\/2\)\) + 2\ \
\[ImaginaryI]\ \[CurlyPhi]\)\ r\^2\ \[Lambda]\^\(7/4\)\ \((\(-7\) + 
                2\ r\^2\ \[Lambda])\)\ Sin[\[Theta]]\^2\)\/\(2\ \@7\ \
\[Pi]\^\(3/4\)\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^6\ \[Lambda]\^\(7/2\)\ \
\((\(-7\) + 2\ r\^2\ \[Lambda])\)\^2\ Sin[\[Theta]]\^4\)\/\(28\ \
\[Pi]\^\(3/2\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[1, 3, 0, \[Lambda]] = 
      R\_Oscl[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[1, 3, 0, \[Lambda]] = 
      RR\_Oscl[n\_rad, l\_orb, \[Lambda]]\ YY[l\_orb, m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\@\(3\/5\)\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^3\ \
\[Lambda]\^\(9/4\)\ \((1 - \(2\ r\^2\ \[Lambda]\)\/9)\)\ \((\(-3\)\ Cos[\
\[Theta]] + 5\ Cos[\[Theta]]\^3)\)\)\/\[Pi]\^\(3/4\)\)], "Output"],

Cell[BoxData[
    \(\(3\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^8\ \
\[Lambda]\^\(9/2\)\ \((1 - \(2\ r\^2\ \[Lambda]\)\/9)\)\^2\ \((3\ \
Cos[\[Theta]] + 5\ Cos[3\ \[Theta]])\)\^2\)\/\(80\ \[Pi]\^\(3/2\)\)\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[1, 3, 1, \[Lambda]] = 
      R\_Oscl[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[1, 3, 1, \[Lambda]] = 
      RR\_Oscl[n\_rad, l\_orb, \[Lambda]]\ YY[l\_orb, m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(3\ \[ExponentialE]\^\(\(-\(\(r\^2\ \[Lambda]\)\/2\)\) + \
\[ImaginaryI]\ \[CurlyPhi]\)\ r\^3\ \[Lambda]\^\(9/4\)\ \((1 - \(2\ r\^2\ \
\[Lambda]\)\/9)\)\ \((\(-1\) + 
                5\ Cos[\[Theta]]\^2)\)\ Sin[\[Theta]]\)\/\(2\ \@5\ \
\[Pi]\^\(3/4\)\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(9\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^8\ \
\[Lambda]\^\(9/2\)\ \((1 - \(2\ r\^2\ \[Lambda]\)\/9)\)\^2\ \((Sin[\[Theta]] \
+ 5\ Sin[3\ \[Theta]])\)\^2\)\/\(320\ \[Pi]\^\(3/2\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 2;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[1, 3, 2, \[Lambda]] = 
      R\_Oscl[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[1, 3, 2, \[Lambda]] = 
      RR\_Oscl[n\_rad, l\_orb, \[Lambda]]\ YY[l\_orb, m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(3\ \[ExponentialE]\^\(\(-\(\(r\^2\ \[Lambda]\)\/2\)\) + 2\ \
\[ImaginaryI]\ \[CurlyPhi]\)\ r\^3\ \[Lambda]\^\(9/4\)\ \((1 - \(2\ r\^2\ \
\[Lambda]\)\/9)\)\ Cos[\[Theta]]\ Sin[\[Theta]]\^2\)\/\(\@2\ \[Pi]\^\(3/4\)\)\
\)], "Output"],

Cell[BoxData[
    \(\(9\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^8\ \
\[Lambda]\^\(9/2\)\ \((1 - \(2\ r\^2\ \[Lambda]\)\/9)\)\^2\ Cos[\[Theta]]\^2\ \
Sin[\[Theta]]\^4\)\/\(2\ \[Pi]\^\(3/2\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\n", 
    \(\(l\_orb = 3;\)\), "\n", 
    \(\(m\_azm = 3;\)\), "\n", 
    \(\[Psi]\_Oscl[1, 3, 3, \[Lambda]] = 
      R\_Oscl[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[1, 3, 3, \[Lambda]] = 
      RR\_Oscl[n\_rad, l\_orb, \[Lambda]]\ YY[l\_orb, m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(\@3\ \[ExponentialE]\^\(\(-\(\(r\^2\ \[Lambda]\)\/2\)\) + 3\ \
\[ImaginaryI]\ \[CurlyPhi]\)\ r\^3\ \[Lambda]\^\(9/4\)\ \((1 - \(2\ r\^2\ \
\[Lambda]\)\/9)\)\ Sin[\[Theta]]\^3\)\/\(2\ \[Pi]\^\(3/4\)\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(3\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^8\ \
\[Lambda]\^\(9/2\)\ \((1 - \(2\ r\^2\ \[Lambda]\)\/9)\)\^2\ \
Sin[\[Theta]]\^6\)\/\(4\ \[Pi]\^\(3/2\)\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "3) ",
  Cell[BoxData[
      \(n\_rad = 2\)],
    FontSlant->"Italic"]
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[2, 0, 0, \[Lambda]] = 
      R\_Oscl[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[2, 0, 0, \[Lambda]] = 
      RR\_Oscl[n\_rad, l\_orb, \[Lambda]]\ YY[l\_orb, m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \[Lambda]\^\(3/4\)\ \
\((15 + 4\ r\^2\ \[Lambda]\ \((\(-5\) + r\^2\ \[Lambda])\))\)\)\/\(2\ \@30\ \
\[Pi]\^\(3/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^2\ \[Lambda]\^\(3/2\)\ \
\((15 + 4\ r\^2\ \[Lambda]\ \((\(-5\) + r\^2\ \[Lambda])\))\)\^2\)\/\(120\ \
\[Pi]\^\(3/2\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[2, 1, 0, \[Lambda]] = 
      R\_Oscl[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[2, 1, 0, \[Lambda]] = 
      RR\_Oscl[n\_rad, l\_orb, \[Lambda]]\ YY[l\_orb, m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\ \[Lambda]\^\(5/4\
\)\ \((35 + 4\ r\^2\ \[Lambda]\ \((\(-7\) + r\^2\ \[Lambda])\))\)\ Cos[\
\[Theta]]\)\/\(2\ \@35\ \[Pi]\^\(3/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^4\ \[Lambda]\^\(5/2\)\ \
\((35 + 4\ r\^2\ \[Lambda]\ \((\(-7\) + r\^2\ \[Lambda])\))\)\^2\ \
Cos[\[Theta]]\^2\)\/\(140\ \[Pi]\^\(3/2\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[2, 1, 1, \[Lambda]] = 
      R\_Oscl[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[2, 1, 1, \[Lambda]] = 
      RR\_Oscl[n\_rad, l\_orb, \[Lambda]]\ YY[l\_orb, m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\(-\(\(r\^2\ \[Lambda]\)\/2\)\) + \
\[ImaginaryI]\ \[CurlyPhi]\)\ r\ \[Lambda]\^\(5/4\)\ \((35 + 
                4\ r\^2\ \[Lambda]\ \((\(-7\) + 
                      r\^2\ \[Lambda])\))\)\ Sin[\[Theta]]\)\/\(2\ \@70\ \
\[Pi]\^\(3/4\)\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^4\ \[Lambda]\^\(5/2\)\ \
\((35 + 4\ r\^2\ \[Lambda]\ \((\(-7\) + r\^2\ \[Lambda])\))\)\^2\ \
Sin[\[Theta]]\^2\)\/\(280\ \[Pi]\^\(3/2\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[2, 2, 0, \[Lambda]] = 
      R\_Oscl[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[2, 2, 0, \[Lambda]] = 
      RR\_Oscl[n\_rad, l\_orb, \[Lambda]]\ YY[l\_orb, m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^2\ \
\[Lambda]\^\(7/4\)\ \((63 + 4\ r\^2\ \[Lambda]\ \((\(-9\) + r\^2\ \
\[Lambda])\))\)\ \((\(-1\) + 3\ Cos[\[Theta]]\^2)\)\)\/\(6\ \@42\ \
\[Pi]\^\(3/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^6\ \[Lambda]\^\(7/2\)\ \
\((63 + 4\ r\^2\ \[Lambda]\ \((\(-9\) + r\^2\ \[Lambda])\))\)\^2\ \((1 + 3\ \
Cos[2\ \[Theta]])\)\^2\)\/\(6048\ \[Pi]\^\(3/2\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[2, 2, 1, \[Lambda]] = 
      R\_Oscl[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[2, 2, 1, \[Lambda]] = 
      RR\_Oscl[n\_rad, l\_orb, \[Lambda]]\ YY[l\_orb, m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\(-\(\(r\^2\ \[Lambda]\)\/2\)\) + \
\[ImaginaryI]\ \[CurlyPhi]\)\ r\^2\ \[Lambda]\^\(7/4\)\ \((63 + 
                4\ r\^2\ \[Lambda]\ \((\(-9\) + 
                      r\^2\ \[Lambda])\))\)\ Cos[\[Theta]]\ Sin[\[Theta]]\)\/\
\(6\ \@7\ \[Pi]\^\(3/4\)\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^6\ \[Lambda]\^\(7/2\)\ \
\((63 + 4\ r\^2\ \[Lambda]\ \((\(-9\) + r\^2\ \[Lambda])\))\)\^2\ \
Cos[\[Theta]]\^2\ Sin[\[Theta]]\^2\)\/\(252\ \[Pi]\^\(3/2\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 2;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[2, 2, 2, \[Lambda]] = 
      R\_Oscl[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[2, 2, 2, \[Lambda]] = 
      RR\_Oscl[n\_rad, l\_orb, \[Lambda]]\ YY[l\_orb, m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\(\(r\^2\ \[Lambda]\)\/2\)\) + 2\ \[ImaginaryI]\
\ \[CurlyPhi]\)\ r\^2\ \[Lambda]\^\(7/4\)\ \((63 + 4\ r\^2\ \[Lambda]\ \
\((\(-9\) + r\^2\ \[Lambda])\))\)\ Sin[\[Theta]]\^2\)\/\(12\ \@7\ \
\[Pi]\^\(3/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^6\ \[Lambda]\^\(7/2\)\ \
\((63 + 4\ r\^2\ \[Lambda]\ \((\(-9\) + r\^2\ \[Lambda])\))\)\^2\ \
Sin[\[Theta]]\^4\)\/\(1008\ \[Pi]\^\(3/2\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[2, 3, 0, \[Lambda]] = 
      R\_Oscl[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[2, 3, 0, \[Lambda]] = 
      RR\_Oscl[n\_rad, l\_orb, \[Lambda]]\ YY[l\_orb, m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^3\ \
\[Lambda]\^\(9/4\)\ \((99 + 4\ r\^2\ \[Lambda]\ \((\(-11\) + r\^2\ \[Lambda])\
\))\)\ \((\(-3\)\ Cos[\[Theta]] + 5\ Cos[\[Theta]]\^3)\)\)\/\(6\ \@165\ \[Pi]\
\^\(3/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^8\ \[Lambda]\^\(9/2\)\ \
\((99 + 4\ r\^2\ \[Lambda]\ \((\(-11\) + r\^2\ \[Lambda])\))\)\^2\ \((3\ Cos[\
\[Theta]] + 5\ Cos[3\ \[Theta]])\)\^2\)\/\(95040\ \[Pi]\^\(3/2\)\)\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[2, 3, 1, \[Lambda]] = 
      R\_Oscl[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[2, 3, 1, \[Lambda]] = 
      RR\_Oscl[n\_rad, l\_orb, \[Lambda]]\ YY[l\_orb, m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\(-\(\(r\^2\ \[Lambda]\)\/2\)\) + \
\[ImaginaryI]\ \[CurlyPhi]\)\ r\^3\ \[Lambda]\^\(9/4\)\ \((99 + 
                4\ r\^2\ \[Lambda]\ \((\(-11\) + 
                      r\^2\ \[Lambda])\))\)\ \((\(-1\) + 
                5\ Cos[\[Theta]]\^2)\)\ Sin[\[Theta]]\)\/\(12\ \@55\ \
\[Pi]\^\(3/4\)\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^8\ \[Lambda]\^\(9/2\)\ \
\((99 + 4\ r\^2\ \[Lambda]\ \((\(-11\) + r\^2\ \[Lambda])\))\)\^2\ \((Sin[\
\[Theta]] + 5\ Sin[3\ \[Theta]])\)\^2\)\/\(126720\ \[Pi]\^\(3/2\)\)\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 2;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[2, 3, 2, \[Lambda]] = 
      R\_Oscl[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[2, 3, 2, \[Lambda]] = 
      RR\_Oscl[n\_rad, l\_orb, \[Lambda]]\ YY[l\_orb, m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\(\(r\^2\ \[Lambda]\)\/2\)\) + 2\ \[ImaginaryI]\
\ \[CurlyPhi]\)\ r\^3\ \[Lambda]\^\(9/4\)\ \((99 + 4\ r\^2\ \[Lambda]\ \
\((\(-11\) + r\^2\ \[Lambda])\))\)\ Cos[\[Theta]]\ Sin[\[Theta]]\^2\)\/\(6\ \
\@22\ \[Pi]\^\(3/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^8\ \[Lambda]\^\(9/2\)\ \
\((99 + 4\ r\^2\ \[Lambda]\ \((\(-11\) + r\^2\ \[Lambda])\))\)\^2\ Cos[\
\[Theta]]\^2\ Sin[\[Theta]]\^4\)\/\(792\ \[Pi]\^\(3/2\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\n", 
    \(\(l\_orb = 3;\)\), "\n", 
    \(\(m\_azm = 3;\)\), "\n", 
    \(\[Psi]\_Oscl[2, 3, 3, \[Lambda]] = 
      R\_Oscl[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[2, 3, 3, \[Lambda]] = 
      RR\_Oscl[n\_rad, l\_orb, \[Lambda]]\ YY[l\_orb, m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\(-\(\(r\^2\ \[Lambda]\)\/2\)\) + 3\ \
\[ImaginaryI]\ \[CurlyPhi]\)\ r\^3\ \[Lambda]\^\(9/4\)\ \((99 + 
                4\ r\^2\ \[Lambda]\ \((\(-11\) + 
                      r\^2\ \[Lambda])\))\)\ Sin[\[Theta]]\^3\)\/\(12\ \@33\ \
\[Pi]\^\(3/4\)\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^8\ \[Lambda]\^\(9/2\)\ \
\((99 + 4\ r\^2\ \[Lambda]\ \((\(-11\) + r\^2\ \[Lambda])\))\)\^2\ Sin[\
\[Theta]]\^6\)\/\(4752\ \[Pi]\^\(3/2\)\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "4) ",
  Cell[BoxData[
      \(n\_rad = 3\)],
    FontSlant->"Italic"]
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[3, 0, 0, \[Lambda]] = 
      R\_Oscl[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[3, 0, 0, \[Lambda]] = 
      RR\_Oscl[n\_rad, l\_orb, \[Lambda]]\ YY[l\_orb, m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\@35\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
\[Lambda]\^\(3/4\)\ \((1 - 2\ r\^2\ \[Lambda] + \(4\ r\^4\ \[Lambda]\^2\)\/5 \
- \(8\ r\^6\ \[Lambda]\^3\)\/105)\)\)\/\(4\ \[Pi]\^\(3/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(35\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^2\ \[Lambda]\^\(3/2\
\)\ \((1 - 2\ r\^2\ \[Lambda] + \(4\ r\^4\ \[Lambda]\^2\)\/5 - \(8\ r\^6\ \
\[Lambda]\^3\)\/105)\)\^2\)\/\(16\ \[Pi]\^\(3/2\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[3, 1, 0, \[Lambda]] = 
      R\_Oscl[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[3, 1, 0, \[Lambda]] = 
      RR\_Oscl[n\_rad, l\_orb, \[Lambda]]\ YY[l\_orb, m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\ \[Lambda]\^\
\(5/4\)\ \((\(-315\) + 
                2\ r\^2\ \[Lambda]\ \((189 - 54\ r\^2\ \[Lambda] + 
                      4\ r\^4\ \[Lambda]\^2)\))\)\ Cos[\[Theta]]\)\/\(6\ \
\@210\ \[Pi]\^\(3/4\)\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^4\ \[Lambda]\^\(5/2\)\ \
\((\(-315\) + 2\ r\^2\ \[Lambda]\ \((189 - 54\ r\^2\ \[Lambda] + 4\ r\^4\ \
\[Lambda]\^2)\))\)\^2\ Cos[\[Theta]]\^2\)\/\(7560\ \[Pi]\^\(3/2\)\)\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[3, 1, 1, \[Lambda]] = 
      R\_Oscl[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[3, 1, 1, \[Lambda]] = 
      RR\_Oscl[n\_rad, l\_orb, \[Lambda]]\ YY[l\_orb, m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\(\(r\^2\ \[Lambda]\)\/2\)\) + \[ImaginaryI]\ \
\[CurlyPhi]\)\ r\ \[Lambda]\^\(5/4\)\ \((\(-315\) + 2\ r\^2\ \[Lambda]\ \
\((189 - 54\ r\^2\ \[Lambda] + 4\ r\^4\ \[Lambda]\^2)\))\)\ Sin[\[Theta]]\)\/\
\(12\ \@105\ \[Pi]\^\(3/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^4\ \[Lambda]\^\(5/2\)\ \
\((\(-315\) + 2\ r\^2\ \[Lambda]\ \((189 - 54\ r\^2\ \[Lambda] + 4\ r\^4\ \
\[Lambda]\^2)\))\)\^2\ Sin[\[Theta]]\^2\)\/\(15120\ \[Pi]\^\(3/2\)\)\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[3, 2, 0, \[Lambda]] = 
      R\_Oscl[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[3, 2, 0, \[Lambda]] = 
      RR\_Oscl[n\_rad, l\_orb, \[Lambda]]\ YY[l\_orb, m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\@77\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^2\ \
\[Lambda]\^\(7/4\)\ \((1 - 2\/693\ r\^2\ \[Lambda]\ \((297 - 66\ r\^2\ \
\[Lambda] + 4\ r\^4\ \[Lambda]\^2)\))\)\ \((\(-1\) + 3\ Cos[\[Theta]]\^2)\)\)\
\/\(4\ \[Pi]\^\(3/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(77\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^6\ \[Lambda]\^\(7/2\
\)\ \((1 - 2\/693\ r\^2\ \[Lambda]\ \((297 - 66\ r\^2\ \[Lambda] + 4\ r\^4\ \
\[Lambda]\^2)\))\)\^2\ \((1 + 3\ Cos[2\ \[Theta]])\)\^2\)\/\(64\ \[Pi]\^\(3/2\
\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[3, 2, 1, \[Lambda]] = 
      R\_Oscl[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[3, 2, 1, \[Lambda]] = 
      RR\_Oscl[n\_rad, l\_orb, \[Lambda]]\ YY[l\_orb, m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(\@\(231\/2\)\ \[ExponentialE]\^\(\(-\(\(r\^2\ \[Lambda]\)\/2\)\) \
+ \[ImaginaryI]\ \[CurlyPhi]\)\ r\^2\ \[Lambda]\^\(7/4\)\ \((1 - 
                2\/693\ r\^2\ \[Lambda]\ \((297 - 66\ r\^2\ \[Lambda] + 
                      4\ r\^4\ \[Lambda]\^2)\))\)\ Cos[\[Theta]]\ \
Sin[\[Theta]]\)\/\(2\ \[Pi]\^\(3/4\)\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(231\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^6\ \
\[Lambda]\^\(7/2\)\ \((1 - 2\/693\ r\^2\ \[Lambda]\ \((297 - 66\ r\^2\ \
\[Lambda] + 4\ r\^4\ \[Lambda]\^2)\))\)\^2\ Cos[\[Theta]]\^2\ \
Sin[\[Theta]]\^2\)\/\(8\ \[Pi]\^\(3/2\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 2;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[3, 2, 2, \[Lambda]] = 
      R\_Oscl[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[3, 2, 2, \[Lambda]] = 
      RR\_Oscl[n\_rad, l\_orb, \[Lambda]]\ YY[l\_orb, m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\@\(231\/2\)\ \[ExponentialE]\^\(\(-\(\(r\^2\ \[Lambda]\)\/2\)\) + 2\ \
\[ImaginaryI]\ \[CurlyPhi]\)\ r\^2\ \[Lambda]\^\(7/4\)\ \((1 - 2\/693\ r\^2\ \
\[Lambda]\ \((297 - 66\ r\^2\ \[Lambda] + 4\ r\^4\ \[Lambda]\^2)\))\)\ Sin[\
\[Theta]]\^2\)\/\(4\ \[Pi]\^\(3/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(231\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^6\ \
\[Lambda]\^\(7/2\)\ \((1 - 2\/693\ r\^2\ \[Lambda]\ \((297 - 66\ r\^2\ \
\[Lambda] + 4\ r\^4\ \[Lambda]\^2)\))\)\^2\ Sin[\[Theta]]\^4\)\/\(32\ \[Pi]\^\
\(3/2\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[3, 3, 0, \[Lambda]] = 
      R\_Oscl[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[3, 3, 0, \[Lambda]] = 
      RR\_Oscl[n\_rad, l\_orb, \[Lambda]]\ YY[l\_orb, m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\@\(143\/10\)\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^3\
\ \[Lambda]\^\(9/4\)\ \((1 - \(2\ r\^2\ \[Lambda]\ \((429 - 78\ r\^2\ \
\[Lambda] + 4\ r\^4\ \[Lambda]\^2)\)\)\/1287)\)\ \((\(-3\)\ Cos[\[Theta]] + 5\
\ Cos[\[Theta]]\^3)\)\)\/\(2\ \[Pi]\^\(3/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(143\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^8\ \
\[Lambda]\^\(9/2\)\ \((1 - \(2\ r\^2\ \[Lambda]\ \((429 - 78\ r\^2\ \[Lambda] \
+ 4\ r\^4\ \[Lambda]\^2)\)\)\/1287)\)\^2\ \((3\ Cos[\[Theta]] + 5\ Cos[3\ \
\[Theta]])\)\^2\)\/\(640\ \[Pi]\^\(3/2\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[3, 3, 1, \[Lambda]] = 
      R\_Oscl[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[3, 3, 1, \[Lambda]] = 
      RR\_Oscl[n\_rad, l\_orb, \[Lambda]]\ YY[l\_orb, m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(\@\(429\/10\)\ \[ExponentialE]\^\(\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\) + \[ImaginaryI]\ \[CurlyPhi]\)\ r\^3\ \[Lambda]\^\(9/4\)\ \
\((1 - \(2\ r\^2\ \[Lambda]\ \((429 - 78\ r\^2\ \[Lambda] + 4\ r\^4\ \
\[Lambda]\^2)\)\)\/1287)\)\ \((\(-1\) + 
                5\ Cos[\[Theta]]\^2)\)\ Sin[\[Theta]]\)\/\(4\ \
\[Pi]\^\(3/4\)\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(429\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^8\ \
\[Lambda]\^\(9/2\)\ \((1 - \(2\ r\^2\ \[Lambda]\ \((429 - 78\ r\^2\ \[Lambda] \
+ 4\ r\^4\ \[Lambda]\^2)\)\)\/1287)\)\^2\ \((Sin[\[Theta]] + 5\ Sin[3\ \
\[Theta]])\)\^2\)\/\(2560\ \[Pi]\^\(3/2\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 2;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_Oscl[3, 3, 2, \[Lambda]] = 
      R\_Oscl[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[3, 3, 2, \[Lambda]] = 
      RR\_Oscl[n\_rad, l\_orb, \[Lambda]]\ YY[l\_orb, m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(\@429\ \[ExponentialE]\^\(\(-\(\(r\^2\ \[Lambda]\)\/2\)\) + 2\ \
\[ImaginaryI]\ \[CurlyPhi]\)\ r\^3\ \[Lambda]\^\(9/4\)\ \((1 - \(2\ r\^2\ \
\[Lambda]\ \((429 - 78\ r\^2\ \[Lambda] + 4\ r\^4\ \[Lambda]\^2)\)\)\/1287)\)\
\ Cos[\[Theta]]\ Sin[\[Theta]]\^2\)\/\(4\ \[Pi]\^\(3/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(429\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^8\ \
\[Lambda]\^\(9/2\)\ \((1 - \(2\ r\^2\ \[Lambda]\ \((429 - 78\ r\^2\ \[Lambda] \
+ 4\ r\^4\ \[Lambda]\^2)\)\)\/1287)\)\^2\ Cos[\[Theta]]\^2\ \
Sin[\[Theta]]\^4\)\/\(16\ \[Pi]\^\(3/2\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\n", 
    \(\(l\_orb = 3;\)\), "\n", 
    \(\(m\_azm = 3;\)\), "\n", 
    \(\[Psi]\_Oscl[3, 3, 3, \[Lambda]] = 
      R\_Oscl[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_Oscl[3, 3, 3, \[Lambda]] = 
      RR\_Oscl[n\_rad, l\_orb, \[Lambda]]\ YY[l\_orb, m\_azm]\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(\@\(143\/2\)\ \[ExponentialE]\^\(\(-\(\(r\^2\ \[Lambda]\)\/2\)\) \
+ 3\ \[ImaginaryI]\ \[CurlyPhi]\)\ r\^3\ \[Lambda]\^\(9/4\)\ \((1 - \(2\ r\^2\
\ \[Lambda]\ \((429 - 78\ r\^2\ \[Lambda] + 4\ r\^4\ \[Lambda]\^2)\)\)\/1287)\
\)\ Sin[\[Theta]]\^3\)\/\(4\ \[Pi]\^\(3/4\)\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(143\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^8\ \
\[Lambda]\^\(9/2\)\ \((1 - \(2\ r\^2\ \[Lambda]\ \((429 - 78\ r\^2\ \[Lambda] \
+ 4\ r\^4\ \[Lambda]\^2)\)\)\/1287)\)\^2\ Sin[\[Theta]]\^6\)\/\(32\ \
\[Pi]\^\(3/2\)\)\)], "Output"]
}, Open  ]],

Cell["\<\
List of wave functions and probability densities of the three-dimensional \
quantum oscillator for given quantum numbers in the spherical coordinates:\
\>", "Text"],

Cell["Wave functions", "Text"],

Cell[BoxData[{
    \(\(\[Psi]\_Oscl[0, 0, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
\[Lambda]\^\(3/4\)\)\/\[Pi]\^\(3/4\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_Oscl[0, 1, 
          0, \[Lambda]] = \(\@2\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\
\)\)\ r\ \[Lambda]\^\(5/4\)\ Cos[\[Theta]]\)\/\[Pi]\^\(3/4\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\_Oscl[0, 1, 
          1, \[Lambda]] = \(-\(\(\[ExponentialE]\^\(\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\) + \[ImaginaryI]\ \[CurlyPhi]\)\ r\ \[Lambda]\^\(5/4\)\ \
Sin[\[Theta]]\)\/\[Pi]\^\(3/4\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_Oscl[0, 2, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
r\^2\ \[Lambda]\^\(7/4\)\ \((\(-1\) + 3\ Cos[\[Theta]]\^2)\)\)\/\(\@3\ \
\[Pi]\^\(3/4\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_Oscl[0, 2, 
          1, \[Lambda]] = \(-\(\(\@2\ \[ExponentialE]\^\(\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\) + \[ImaginaryI]\ \[CurlyPhi]\)\ r\^2\ \[Lambda]\^\(7/4\)\ \
Cos[\[Theta]]\ Sin[\[Theta]]\)\/\[Pi]\^\(3/4\)\)\);\)\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\_Oscl[0, 2, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\) + 2\ \[ImaginaryI]\ \[CurlyPhi]\)\ r\^2\ \
\[Lambda]\^\(7/4\)\ Sin[\[Theta]]\^2\)\/\(\@2\ \[Pi]\^\(3/4\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\_Oscl[0, 3, 
          0, \[Lambda]] = \(\@\(2\/15\)\ \[ExponentialE]\^\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\)\ r\^3\ \[Lambda]\^\(9/4\)\ \((\(-3\)\ Cos[\[Theta]] + 5\ \
Cos[\[Theta]]\^3)\)\)\/\[Pi]\^\(3/4\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_Oscl[0, 3, 
          1, \[Lambda]] = \(-\(\(\[ExponentialE]\^\(\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\) + \[ImaginaryI]\ \[CurlyPhi]\)\ r\^3\ \[Lambda]\^\(9/4\)\ \
\((\(-1\) + 
                    5\ Cos[\[Theta]]\^2)\)\ Sin[\[Theta]]\)\/\(\@10\ \
\[Pi]\^\(3/4\)\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_Oscl[0, 3, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\) + 2\ \[ImaginaryI]\ \[CurlyPhi]\)\ r\^3\ \
\[Lambda]\^\(9/4\)\ Cos[\[Theta]]\ Sin[\[Theta]]\^2\)\/\[Pi]\^\(3/4\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\_Oscl[0, 3, 
          3, \[Lambda]] = \(-\(\(\[ExponentialE]\^\(\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\) + 3\ \[ImaginaryI]\ \[CurlyPhi]\)\ r\^3\ \
\[Lambda]\^\(9/4\)\ Sin[\[Theta]]\^3\)\/\(\@6\ \[Pi]\^\(3/4\)\)\)\);\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_Oscl[1, 0, 
          0, \[Lambda]] = \(\@\(3\/2\)\ \[ExponentialE]\^\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\)\ \[Lambda]\^\(3/4\)\ \((1 - \(2\ r\^2\ \[Lambda]\)\/3)\)\)\
\/\[Pi]\^\(3/4\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_Oscl[1, 1, 
          0, \[Lambda]] = \(-\(\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\
\)\)\ r\ \[Lambda]\^\(5/4\)\ \((\(-5\) + 
                    2\ r\^2\ \[Lambda])\)\ Cos[\[Theta]]\)\/\(\@5\ \
\[Pi]\^\(3/4\)\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_Oscl[1, 1, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\) + \[ImaginaryI]\ \[CurlyPhi]\)\ r\ \[Lambda]\^\(5/4\)\ \((\
\(-5\) + 2\ r\^2\ \[Lambda])\)\ Sin[\[Theta]]\)\/\(\@10\ \
\[Pi]\^\(3/4\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_Oscl[1, 2, 
          0, \[Lambda]] = \(-\(\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\
\)\)\ r\^2\ \[Lambda]\^\(7/4\)\ \((\(-7\) + 
                    2\ r\^2\ \[Lambda])\)\ \((\(-1\) + 
                    3\ Cos[\[Theta]]\^2)\)\)\/\(\@42\ \[Pi]\^\(3/4\)\)\)\);\)\
\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_Oscl[1, 2, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\) + \[ImaginaryI]\ \[CurlyPhi]\)\ r\^2\ \[Lambda]\^\(7/4\)\ \
\((\(-7\) + 2\ r\^2\ \[Lambda])\)\ Cos[\[Theta]]\ Sin[\[Theta]]\)\/\(\@7\ \
\[Pi]\^\(3/4\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_Oscl[1, 2, 
          2, \[Lambda]] = \(-\(\(\[ExponentialE]\^\(\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\) + 2\ \[ImaginaryI]\ \[CurlyPhi]\)\ r\^2\ \
\[Lambda]\^\(7/4\)\ \((\(-7\) + 
                    2\ r\^2\ \[Lambda])\)\ Sin[\[Theta]]\^2\)\/\(2\ \@7\ \
\[Pi]\^\(3/4\)\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_Oscl[1, 3, 
          0, \[Lambda]] = \(\@\(3\/5\)\ \[ExponentialE]\^\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\)\ r\^3\ \[Lambda]\^\(9/4\)\ \((1 - \(2\ r\^2\ \
\[Lambda]\)\/9)\)\ \((\(-3\)\ Cos[\[Theta]] + 5\ Cos[\[Theta]]\^3)\)\)\/\[Pi]\
\^\(3/4\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_Oscl[1, 3, 
          1, \[Lambda]] = \(-\(\(3\ \[ExponentialE]\^\(\(-\(\(r\^2\ \[Lambda]\
\)\/2\)\) + \[ImaginaryI]\ \[CurlyPhi]\)\ r\^3\ \[Lambda]\^\(9/4\)\ \((1 - \
\(2\ r\^2\ \[Lambda]\)\/9)\)\ \((\(-1\) + 
                    5\ Cos[\[Theta]]\^2)\)\ Sin[\[Theta]]\)\/\(2\ \@5\ \
\[Pi]\^\(3/4\)\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_Oscl[1, 3, 
          2, \[Lambda]] = \(3\ \[ExponentialE]\^\(\(-\(\(r\^2\ \[Lambda]\)\/2\
\)\) + 2\ \[ImaginaryI]\ \[CurlyPhi]\)\ r\^3\ \[Lambda]\^\(9/4\)\ \((1 - \(2\ \
r\^2\ \[Lambda]\)\/9)\)\ Cos[\[Theta]]\ Sin[\[Theta]]\^2\)\/\(\@2\ \
\[Pi]\^\(3/4\)\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\_Oscl[1, 3, 
          3, \[Lambda]] = \(-\(\(\@3\ \[ExponentialE]\^\(\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\) + 3\ \[ImaginaryI]\ \[CurlyPhi]\)\ r\^3\ \
\[Lambda]\^\(9/4\)\ \((1 - \(2\ r\^2\ \[Lambda]\)\/9)\)\ Sin[\[Theta]]\^3\)\/\
\(2\ \[Pi]\^\(3/4\)\)\)\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_Oscl[2, 0, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
\[Lambda]\^\(3/4\)\ \((15 + 4\ r\^2\ \[Lambda]\ \((\(-5\) + r\^2\ \
\[Lambda])\))\)\)\/\(2\ \@30\ \[Pi]\^\(3/4\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_Oscl[2, 1, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
r\ \[Lambda]\^\(5/4\)\ \((35 + 4\ r\^2\ \[Lambda]\ \((\(-7\) + r\^2\ \
\[Lambda])\))\)\ Cos[\[Theta]]\)\/\(2\ \@35\ \[Pi]\^\(3/4\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\_Oscl[2, 1, 
          1, \[Lambda]] = \(-\(\(\[ExponentialE]\^\(\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\) + \[ImaginaryI]\ \[CurlyPhi]\)\ r\ \[Lambda]\^\(5/4\)\ \
\((35 + 4\ r\^2\ \[Lambda]\ \((\(-7\) + 
                          r\^2\ \[Lambda])\))\)\ Sin[\[Theta]]\)\/\(2\ \@70\ \
\[Pi]\^\(3/4\)\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_Oscl[2, 2, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
r\^2\ \[Lambda]\^\(7/4\)\ \((63 + 4\ r\^2\ \[Lambda]\ \((\(-9\) + r\^2\ \
\[Lambda])\))\)\ \((\(-1\) + 3\ Cos[\[Theta]]\^2)\)\)\/\(6\ \@42\ \
\[Pi]\^\(3/4\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_Oscl[2, 2, 
          1, \[Lambda]] = \(-\(\(\[ExponentialE]\^\(\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\) + \[ImaginaryI]\ \[CurlyPhi]\)\ r\^2\ \[Lambda]\^\(7/4\)\ \
\((63 + 4\ r\^2\ \[Lambda]\ \((\(-9\) + 
                          r\^2\ \[Lambda])\))\)\ Cos[\[Theta]]\ Sin[\[Theta]]\
\)\/\(6\ \@7\ \[Pi]\^\(3/4\)\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_Oscl[2, 2, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\) + 2\ \[ImaginaryI]\ \[CurlyPhi]\)\ r\^2\ \
\[Lambda]\^\(7/4\)\ \((63 + 4\ r\^2\ \[Lambda]\ \((\(-9\) + r\^2\ \
\[Lambda])\))\)\ Sin[\[Theta]]\^2\)\/\(12\ \@7\ \[Pi]\^\(3/4\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\_Oscl[2, 3, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
r\^3\ \[Lambda]\^\(9/4\)\ \((99 + 4\ r\^2\ \[Lambda]\ \((\(-11\) + r\^2\ \
\[Lambda])\))\)\ \((\(-3\)\ Cos[\[Theta]] + 5\ Cos[\[Theta]]\^3)\)\)\/\(6\ \
\@165\ \[Pi]\^\(3/4\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_Oscl[2, 3, 
          1, \[Lambda]] = \(-\(\(\[ExponentialE]\^\(\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\) + \[ImaginaryI]\ \[CurlyPhi]\)\ r\^3\ \[Lambda]\^\(9/4\)\ \
\((99 + 4\ r\^2\ \[Lambda]\ \((\(-11\) + r\^2\ \[Lambda])\))\)\ \((\(-1\) + 
                    5\ Cos[\[Theta]]\^2)\)\ Sin[\[Theta]]\)\/\(12\ \@55\ \
\[Pi]\^\(3/4\)\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_Oscl[2, 3, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\) + 2\ \[ImaginaryI]\ \[CurlyPhi]\)\ r\^3\ \
\[Lambda]\^\(9/4\)\ \((99 + 4\ r\^2\ \[Lambda]\ \((\(-11\) + r\^2\ \[Lambda])\
\))\)\ Cos[\[Theta]]\ Sin[\[Theta]]\^2\)\/\(6\ \@22\ \[Pi]\^\(3/4\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\_Oscl[2, 3, 
          3, \[Lambda]] = \(-\(\(\[ExponentialE]\^\(\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\) + 3\ \[ImaginaryI]\ \[CurlyPhi]\)\ r\^3\ \
\[Lambda]\^\(9/4\)\ \((99 + 
                    4\ r\^2\ \[Lambda]\ \((\(-11\) + 
                          r\^2\ \[Lambda])\))\)\ Sin[\[Theta]]\^3\)\/\(12\ \
\@33\ \[Pi]\^\(3/4\)\)\)\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_Oscl[3, 0, 
          0, \[Lambda]] = \(\@35\ \[ExponentialE]\^\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\)\ \[Lambda]\^\(3/4\)\ \((1 - 2\ r\^2\ \[Lambda] + \(4\ r\^4\
\ \[Lambda]\^2\)\/5 - \(8\ r\^6\ \[Lambda]\^3\)\/105)\)\)\/\(4\ \
\[Pi]\^\(3/4\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_Oscl[3, 1, 
          0, \[Lambda]] = \(-\(\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\
\)\)\ r\ \[Lambda]\^\(5/4\)\ \((\(-315\) + 
                    2\ r\^2\ \[Lambda]\ \((189 - 54\ r\^2\ \[Lambda] + 
                          4\ r\^4\ \[Lambda]\^2)\))\)\ Cos[\[Theta]]\)\/\(6\ \
\@210\ \[Pi]\^\(3/4\)\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_Oscl[3, 1, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\) + \[ImaginaryI]\ \[CurlyPhi]\)\ r\ \[Lambda]\^\(5/4\)\ \((\
\(-315\) + 2\ r\^2\ \[Lambda]\ \((189 - 54\ r\^2\ \[Lambda] + 4\ r\^4\ \
\[Lambda]\^2)\))\)\ Sin[\[Theta]]\)\/\(12\ \@105\ \[Pi]\^\(3/4\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\_Oscl[3, 2, 
          0, \[Lambda]] = \(\@77\ \[ExponentialE]\^\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\)\ r\^2\ \[Lambda]\^\(7/4\)\ \((1 - 2\/693\ r\^2\ \[Lambda]\ \
\((297 - 66\ r\^2\ \[Lambda] + 4\ r\^4\ \[Lambda]\^2)\))\)\ \((\(-1\) + 3\ \
Cos[\[Theta]]\^2)\)\)\/\(4\ \[Pi]\^\(3/4\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_Oscl[3, 2, 
          1, \[Lambda]] = \(-\(\(\@\(231\/2\)\ \[ExponentialE]\^\(\(-\(\(r\^2\
\ \[Lambda]\)\/2\)\) + \[ImaginaryI]\ \[CurlyPhi]\)\ r\^2\ \[Lambda]\^\(7/4\)\
\ \((1 - 2\/693\ r\^2\ \[Lambda]\ \((297 - 66\ r\^2\ \[Lambda] + 
                          
                          4\ r\^4\ \[Lambda]\^2)\))\)\ Cos[\[Theta]]\ Sin[\
\[Theta]]\)\/\(2\ \[Pi]\^\(3/4\)\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_Oscl[3, 2, 
          2, \[Lambda]] = \(\@\(231\/2\)\ \[ExponentialE]\^\(\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\) + 2\ \[ImaginaryI]\ \[CurlyPhi]\)\ r\^2\ \
\[Lambda]\^\(7/4\)\ \((1 - 2\/693\ r\^2\ \[Lambda]\ \((297 - 66\ r\^2\ \
\[Lambda] + 4\ r\^4\ \[Lambda]\^2)\))\)\ Sin[\[Theta]]\^2\)\/\(4\ \
\[Pi]\^\(3/4\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_Oscl[3, 3, 
          0, \[Lambda]] = \(\@\(143\/10\)\ \[ExponentialE]\^\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\)\ r\^3\ \[Lambda]\^\(9/4\)\ \((1 - \(2\ r\^2\ \[Lambda]\ \
\((429 - 78\ r\^2\ \[Lambda] + 4\ r\^4\ \[Lambda]\^2)\)\)\/1287)\)\ \((\(-3\)\
\ Cos[\[Theta]] + 5\ Cos[\[Theta]]\^3)\)\)\/\(2\ \[Pi]\^\(3/4\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\_Oscl[3, 3, 
          1, \[Lambda]] = \(-\(\(\@\(429\/10\)\ \
\[ExponentialE]\^\(\(-\(\(r\^2\ \[Lambda]\)\/2\)\) + \[ImaginaryI]\ \
\[CurlyPhi]\)\ r\^3\ \[Lambda]\^\(9/4\)\ \((1 - \(2\ r\^2\ \[Lambda]\ \((429 \
- 78\ r\^2\ \[Lambda] + 4\ r\^4\ \[Lambda]\^2)\)\)\/1287)\)\ \((\(-1\) + 
                    5\ Cos[\[Theta]]\^2)\)\ Sin[\[Theta]]\)\/\(4\ \
\[Pi]\^\(3/4\)\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_Oscl[3, 3, 
          2, \[Lambda]] = \(\@429\ \[ExponentialE]\^\(\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\) + 2\ \[ImaginaryI]\ \[CurlyPhi]\)\ r\^3\ \
\[Lambda]\^\(9/4\)\ \((1 - \(2\ r\^2\ \[Lambda]\ \((429 - 78\ r\^2\ \[Lambda] \
+ 4\ r\^4\ \[Lambda]\^2)\)\)\/1287)\)\ Cos[\[Theta]]\ Sin[\[Theta]]\^2\)\/\(4\
\ \[Pi]\^\(3/4\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_Oscl[3, 3, 
          3, \[Lambda]] = \(-\(\(\@\(143\/2\)\ \[ExponentialE]\^\(\(-\(\(r\^2\
\ \[Lambda]\)\/2\)\) + 3\ \[ImaginaryI]\ \[CurlyPhi]\)\ r\^3\ \
\[Lambda]\^\(9/4\)\ \((1 - \(2\ r\^2\ \[Lambda]\ \((429 - 78\ r\^2\ \[Lambda] \
+ 4\ r\^4\ \[Lambda]\^2)\)\)\/1287)\)\ Sin[\[Theta]]\^3\)\/\(4\ \
\[Pi]\^\(3/4\)\)\)\);\)\)}], "Input"],

Cell["Probability densities:", "Text"],

Cell[BoxData[{
    \(\(\[Psi]\[Psi]\_Oscl[0, 0, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^2\ \
\[Lambda]\^\(3/2\)\)\/\[Pi]\^\(3/2\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[0, 1, 
          0, \[Lambda]] = \(2\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ \
r\^4\ \[Lambda]\^\(5/2\)\ Cos[\[Theta]]\^2\)\/\[Pi]\^\(3/2\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[0, 1, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^4\ \
\[Lambda]\^\(5/2\)\ Sin[\[Theta]]\^2\)\/\[Pi]\^\(3/2\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[0, 2, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^6\ \
\[Lambda]\^\(7/2\)\ \((1 + 3\ Cos[2\ \[Theta]])\)\^2\)\/\(12\ \
\[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[0, 2, 
          1, \[Lambda]] = \(2\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ \
r\^6\ \[Lambda]\^\(7/2\)\ Cos[\[Theta]]\^2\ \
Sin[\[Theta]]\^2\)\/\[Pi]\^\(3/2\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[0, 2, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^6\ \
\[Lambda]\^\(7/2\)\ Sin[\[Theta]]\^4\)\/\(2\ \[Pi]\^\(3/2\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[0, 3, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^8\ \
\[Lambda]\^\(9/2\)\ \((3\ Cos[\[Theta]] + 5\ Cos[3\ \[Theta]])\)\^2\)\/\(120\ \
\[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[0, 3, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^8\ \
\[Lambda]\^\(9/2\)\ \((Sin[\[Theta]] + 5\ Sin[3\ \[Theta]])\)\^2\)\/\(160\ \
\[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[0, 3, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^8\ \
\[Lambda]\^\(9/2\)\ Cos[\[Theta]]\^2\ \
Sin[\[Theta]]\^4\)\/\[Pi]\^\(3/2\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_Oscl[0, 3, 
          3, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^8\ \
\[Lambda]\^\(9/2\)\ Sin[\[Theta]]\^6\)\/\(6\ \[Pi]\^\(3/2\)\);\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[1, 0, 
          0, \[Lambda]] = \(3\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ \
r\^2\ \[Lambda]\^\(3/2\)\ \((1 - \(2\ r\^2\ \[Lambda]\)\/3)\)\^2\)\/\(2\ \
\[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[1, 1, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^4\ \
\[Lambda]\^\(5/2\)\ \((\(-5\) + 2\ r\^2\ \[Lambda])\)\^2\ \
Cos[\[Theta]]\^2\)\/\(5\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[1, 1, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^4\ \
\[Lambda]\^\(5/2\)\ \((\(-5\) + 2\ r\^2\ \[Lambda])\)\^2\ \
Sin[\[Theta]]\^2\)\/\(10\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[1, 2, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^6\ \
\[Lambda]\^\(7/2\)\ \((\(-7\) + 2\ r\^2\ \[Lambda])\)\^2\ \((1 + 3\ Cos[2\ \
\[Theta]])\)\^2\)\/\(168\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[1, 2, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^6\ \
\[Lambda]\^\(7/2\)\ \((\(-7\) + 2\ r\^2\ \[Lambda])\)\^2\ Cos[\[Theta]]\^2\ \
Sin[\[Theta]]\^2\)\/\(7\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[1, 2, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^6\ \
\[Lambda]\^\(7/2\)\ \((\(-7\) + 2\ r\^2\ \[Lambda])\)\^2\ \
Sin[\[Theta]]\^4\)\/\(28\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[1, 3, 
          0, \[Lambda]] = \(3\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ \
r\^8\ \[Lambda]\^\(9/2\)\ \((1 - \(2\ r\^2\ \[Lambda]\)\/9)\)\^2\ \((3\ Cos[\
\[Theta]] + 5\ Cos[3\ \[Theta]])\)\^2\)\/\(80\ \[Pi]\^\(3/2\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[1, 3, 
          1, \[Lambda]] = \(9\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ \
r\^8\ \[Lambda]\^\(9/2\)\ \((1 - \(2\ r\^2\ \[Lambda]\)\/9)\)\^2\ \((Sin[\
\[Theta]] + 5\ Sin[3\ \[Theta]])\)\^2\)\/\(320\ \[Pi]\^\(3/2\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[1, 3, 
          2, \[Lambda]] = \(9\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ \
r\^8\ \[Lambda]\^\(9/2\)\ \((1 - \(2\ r\^2\ \[Lambda]\)\/9)\)\^2\ \
Cos[\[Theta]]\^2\ Sin[\[Theta]]\^4\)\/\(2\ \[Pi]\^\(3/2\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_Oscl[1, 3, 
          3, \[Lambda]] = \(3\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ \
r\^8\ \[Lambda]\^\(9/2\)\ \((1 - \(2\ r\^2\ \[Lambda]\)\/9)\)\^2\ \
Sin[\[Theta]]\^6\)\/\(4\ \[Pi]\^\(3/2\)\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[2, 0, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^2\ \
\[Lambda]\^\(3/2\)\ \((15 + 4\ r\^2\ \[Lambda]\ \((\(-5\) + r\^2\ \
\[Lambda])\))\)\^2\)\/\(120\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[2, 1, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^4\ \
\[Lambda]\^\(5/2\)\ \((35 + 4\ r\^2\ \[Lambda]\ \((\(-7\) + r\^2\ \
\[Lambda])\))\)\^2\ Cos[\[Theta]]\^2\)\/\(140\ \[Pi]\^\(3/2\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[2, 1, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^4\ \
\[Lambda]\^\(5/2\)\ \((35 + 4\ r\^2\ \[Lambda]\ \((\(-7\) + r\^2\ \
\[Lambda])\))\)\^2\ Sin[\[Theta]]\^2\)\/\(280\ \[Pi]\^\(3/2\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[2, 2, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^6\ \
\[Lambda]\^\(7/2\)\ \((63 + 4\ r\^2\ \[Lambda]\ \((\(-9\) + r\^2\ \
\[Lambda])\))\)\^2\ \((1 + 3\ Cos[2\ \[Theta]])\)\^2\)\/\(6048\ \
\[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[2, 2, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^6\ \
\[Lambda]\^\(7/2\)\ \((63 + 4\ r\^2\ \[Lambda]\ \((\(-9\) + r\^2\ \
\[Lambda])\))\)\^2\ Cos[\[Theta]]\^2\ Sin[\[Theta]]\^2\)\/\(252\ \[Pi]\^\(3/2\
\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[2, 2, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^6\ \
\[Lambda]\^\(7/2\)\ \((63 + 4\ r\^2\ \[Lambda]\ \((\(-9\) + r\^2\ \
\[Lambda])\))\)\^2\ Sin[\[Theta]]\^4\)\/\(1008\ \[Pi]\^\(3/2\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[2, 3, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^8\ \
\[Lambda]\^\(9/2\)\ \((99 + 4\ r\^2\ \[Lambda]\ \((\(-11\) + r\^2\ \[Lambda])\
\))\)\^2\ \((3\ Cos[\[Theta]] + 5\ Cos[3\ \[Theta]])\)\^2\)\/\(95040\ \[Pi]\^\
\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[2, 3, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^8\ \
\[Lambda]\^\(9/2\)\ \((99 + 4\ r\^2\ \[Lambda]\ \((\(-11\) + r\^2\ \[Lambda])\
\))\)\^2\ \((Sin[\[Theta]] + 5\ Sin[3\ \[Theta]])\)\^2\)\/\(126720\ \
\[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[2, 3, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^8\ \
\[Lambda]\^\(9/2\)\ \((99 + 4\ r\^2\ \[Lambda]\ \((\(-11\) + r\^2\ \[Lambda])\
\))\)\^2\ Cos[\[Theta]]\^2\ Sin[\[Theta]]\^4\)\/\(792\ \[Pi]\^\(3/2\)\);\)\), \
"\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_Oscl[2, 3, 
          3, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^8\ \
\[Lambda]\^\(9/2\)\ \((99 + 4\ r\^2\ \[Lambda]\ \((\(-11\) + r\^2\ \[Lambda])\
\))\)\^2\ Sin[\[Theta]]\^6\)\/\(4752\ \
\[Pi]\^\(3/2\)\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[3, 0, 
          0, \[Lambda]] = \(35\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ \
r\^2\ \[Lambda]\^\(3/2\)\ \((1 - 2\ r\^2\ \[Lambda] + \(4\ r\^4\ \[Lambda]\^2\
\)\/5 - \(8\ r\^6\ \[Lambda]\^3\)\/105)\)\^2\)\/\(16\ \[Pi]\^\(3/2\)\);\)\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[3, 1, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^4\ \
\[Lambda]\^\(5/2\)\ \((\(-315\) + 2\ r\^2\ \[Lambda]\ \((189 - 54\ r\^2\ \
\[Lambda] + 4\ r\^4\ \[Lambda]\^2)\))\)\^2\ Cos[\[Theta]]\^2\)\/\(7560\ \[Pi]\
\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[3, 1, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^4\ \
\[Lambda]\^\(5/2\)\ \((\(-315\) + 2\ r\^2\ \[Lambda]\ \((189 - 54\ r\^2\ \
\[Lambda] + 4\ r\^4\ \[Lambda]\^2)\))\)\^2\ Sin[\[Theta]]\^2\)\/\(15120\ \
\[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[3, 2, 
          0, \[Lambda]] = \(77\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ \
r\^6\ \[Lambda]\^\(7/2\)\ \((1 - 2\/693\ r\^2\ \[Lambda]\ \((297 - 66\ r\^2\ \
\[Lambda] + 4\ r\^4\ \[Lambda]\^2)\))\)\^2\ \((1 + 3\ Cos[2\ \
\[Theta]])\)\^2\)\/\(64\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[3, 2, 
          1, \[Lambda]] = \(231\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\
\^6\ \[Lambda]\^\(7/2\)\ \((1 - 2\/693\ r\^2\ \[Lambda]\ \((297 - 66\ r\^2\ \
\[Lambda] + 4\ r\^4\ \[Lambda]\^2)\))\)\^2\ Cos[\[Theta]]\^2\ \
Sin[\[Theta]]\^2\)\/\(8\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[3, 2, 
          2, \[Lambda]] = \(231\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\
\^6\ \[Lambda]\^\(7/2\)\ \((1 - 2\/693\ r\^2\ \[Lambda]\ \((297 - 66\ r\^2\ \
\[Lambda] + 4\ r\^4\ \[Lambda]\^2)\))\)\^2\ Sin[\[Theta]]\^4\)\/\(32\ \[Pi]\^\
\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[3, 3, 
          0, \[Lambda]] = \(143\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\
\^8\ \[Lambda]\^\(9/2\)\ \((1 - \(2\ r\^2\ \[Lambda]\ \((429 - 78\ r\^2\ \
\[Lambda] + 4\ r\^4\ \[Lambda]\^2)\)\)\/1287)\)\^2\ \((3\ Cos[\[Theta]] + 5\ \
Cos[3\ \[Theta]])\)\^2\)\/\(640\ \[Pi]\^\(3/2\)\);\)\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[3, 3, 
          1, \[Lambda]] = \(429\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\
\^8\ \[Lambda]\^\(9/2\)\ \((1 - \(2\ r\^2\ \[Lambda]\ \((429 - 78\ r\^2\ \
\[Lambda] + 4\ r\^4\ \[Lambda]\^2)\)\)\/1287)\)\^2\ \((Sin[\[Theta]] + 5\ \
Sin[3\ \[Theta]])\)\^2\)\/\(2560\ \[Pi]\^\(3/2\)\);\)\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[3, 3, 
          2, \[Lambda]] = \(429\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\
\^8\ \[Lambda]\^\(9/2\)\ \((1 - \(2\ r\^2\ \[Lambda]\ \((429 - 78\ r\^2\ \
\[Lambda] + 4\ r\^4\ \[Lambda]\^2)\)\)\/1287)\)\^2\ Cos[\[Theta]]\^2\ Sin[\
\[Theta]]\^4\)\/\(16\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[3, 3, 
          3, \[Lambda]] = \(143\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\
\^8\ \[Lambda]\^\(9/2\)\ \((1 - \(2\ r\^2\ \[Lambda]\ \((429 - 78\ r\^2\ \
\[Lambda] + 4\ r\^4\ \[Lambda]\^2)\)\)\/1287)\)\^2\ Sin[\[Theta]]\^6\)\/\(32\ \
\[Pi]\^\(3/2\)\);\)\)}], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
3. Normalized wave functions and radial probability densities of the quantum \
oscillator in the Cartesian rectangular coordinates\
\>", "Section"],

Cell[TextData[{
  "To obtain spherical  harmonic ",
  Cell[BoxData[
      \(Y\_Cart[l\_orb, m\_azm]\)],
    FontSlant->"Italic"],
  " and angular densities ",
  Cell[BoxData[
      \(YY\_Cart[l\_orb, m\_azm]\)],
    FontSlant->"Italic"],
  " in the Cartesian rectangular coordinates we will use coordinate \
transformations:"
}], "Text"],

Cell[BoxData[{
    \(\(\[Theta] = 
        ArcCos[z/\@\(x^2 + y^2 + z^2\)];\)\), "\[IndentingNewLine]", 
    \(\(\[CurlyPhi] = ArcCos[x/\@\(x^2 + y^2\)];\)\), "\[IndentingNewLine]", 
    \(\(r = \@\(x^2 + y^2 + z^2\);\)\)}], "Input"],

Cell[BoxData[{
    \(n\_rad =. \), "\n", 
    \(l\_orb =. \), "\[IndentingNewLine]", 
    \(m\_azm =. \)}], "Input"],

Cell["Wave functions", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(FullSimplify[\[Psi]\_Oscl[0, 0, 
        0, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\_Oscl[0, 1, 
        0, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\_Oscl[0, 1, 
        1, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\_Oscl[0, 2, 
        0, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\_Oscl[0, 2, 
        1, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\_Oscl[0, 2, 
        2, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\_Oscl[0, 3, 
        0, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\_Oscl[0, 3, 
        1, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\_Oscl[0, 3, 
        2, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(\(\(FullSimplify[\[Psi]\_Oscl[0, 3, 
        3, \[Lambda]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\_Oscl[1, 0, 
        0, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\_Oscl[1, 1, 
        0, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\_Oscl[1, 1, 
        1, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\_Oscl[1, 2, 
        0, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\_Oscl[1, 2, 
        1, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\_Oscl[1, 2, 
        2, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\_Oscl[1, 3, 
        0, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\_Oscl[1, 3, 
        1, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\_Oscl[1, 3, 
        2, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(\(\(FullSimplify[\[Psi]\_Oscl[1, 3, 
        3, \[Lambda]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\_Oscl[2, 0, 
        0, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\_Oscl[2, 1, 
        0, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\_Oscl[2, 1, 
        1, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\_Oscl[2, 2, 
        0, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\_Oscl[2, 2, 
        1, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\_Oscl[2, 2, 
        2, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\_Oscl[2, 3, 
        0, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\_Oscl[2, 3, 
        1, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\_Oscl[2, 3, 
        2, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(\(\(FullSimplify[\[Psi]\_Oscl[2, 3, 
        3, \[Lambda]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\_Oscl[3, 0, 
        0, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\_Oscl[3, 1, 
        0, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\_Oscl[3, 1, 
        1, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\_Oscl[3, 2, 
        0, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\_Oscl[3, 2, 
        1, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\_Oscl[3, 2, 
        2, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\_Oscl[3, 3, 
        0, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\_Oscl[3, 3, 
        1, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\_Oscl[3, 3, 
        2, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\_Oscl[3, 3, 3, \[Lambda]]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\
\)\ \[Lambda]\^\(3/4\)\)\/\[Pi]\^\(3/4\)\)], "Output"],

Cell[BoxData[
    \(\(\@2\ \[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\)\ z\ \[Lambda]\^\(5/4\)\)\/\[Pi]\^\(3/4\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda] + \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \@\(\(x\^2 + \
y\^2\)\/\(x\^2 + y\^2 + z\^2\)\)\ \@\(x\^2 + y\^2 + z\^2\)\ \
\[Lambda]\^\(5/4\)\)\/\[Pi]\^\(3/4\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2 - 
                2\ z\^2)\)\ \[Lambda]\^\(7/4\)\)\/\(\@3\ \[Pi]\^\(3/4\)\)\)\)\
\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\@2\ \[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda] + \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ z\ \@\(\(x\^2 + \
y\^2\)\/\(x\^2 + y\^2 + z\^2\)\)\ \@\(x\^2 + y\^2 + z\^2\)\ \
\[Lambda]\^\(7/4\)\)\/\[Pi]\^\(3/4\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda] \
+ 2\ \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \((x\^2 + y\^2)\)\ \
\[Lambda]\^\(7/4\)\)\/\(\@2\ \[Pi]\^\(3/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(\@\(2\/15\)\ \[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\
\)\ \[Lambda]\)\ z\ \((\(-3\)\ \((x\^2 + y\^2)\) + 2\ z\^2)\)\ \
\[Lambda]\^\(9/4\)\)\/\[Pi]\^\(3/4\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda] \
+ \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\ \
\@\(\(x\^2 + y\^2\)\/\(x\^2 + y\^2 + z\^2\)\)\ \@\(x\^2 + y\^2 + z\^2\)\ \
\[Lambda]\^\(9/4\)\)\/\(\@10\ \[Pi]\^\(3/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda] \
+ 2\ \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \((x\^2 + y\^2)\)\ z\ \
\[Lambda]\^\(9/4\)\)\/\[Pi]\^\(3/4\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda] + 3\ \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \((\(x\^2 + \
y\^2\)\/\(x\^2 + y\^2 + z\^2\))\)\^\(3/2\)\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\
\ \[Lambda]\^\(9/4\)\)\/\(\@6\ \[Pi]\^\(3/4\)\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\
\)\ \[Lambda]\^\(3/4\)\ \((3 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\)\)\/\(\@6\ \[Pi]\^\(3/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\
\)\ z\ \[Lambda]\^\(5/4\)\ \((5 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\)\
\/\(\@5\ \[Pi]\^\(3/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda] \
+ \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \@\(\(x\^2 + y\^2\)\/\(x\^2 \
+ y\^2 + z\^2\)\)\ \@\(x\^2 + y\^2 + z\^2\)\ \[Lambda]\^\(5/4\)\ \((\(-5\) + \
2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\)\/\(\@10\ \[Pi]\^\(3/4\)\)\)], \
"Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\
\)\ \((x\^2 + y\^2 - 2\ z\^2)\)\ \[Lambda]\^\(7/4\)\ \((\(-7\) + 2\ \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda])\)\)\/\(\@42\ \[Pi]\^\(3/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda] \
+ \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ z\ \@\(\(x\^2 + \
y\^2\)\/\(x\^2 + y\^2 + z\^2\)\)\ \@\(x\^2 + y\^2 + z\^2\)\ \
\[Lambda]\^\(7/4\)\ \((\(-7\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\)\/\
\(\@7\ \[Pi]\^\(3/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda] + 2\ \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \((x\^2 + 
                y\^2)\)\ \[Lambda]\^\(7/4\)\ \((\(-7\) + 
                2\ \((x\^2 + y\^2 + 
                      z\^2)\)\ \[Lambda])\)\)\/\(2\ \@7\ \[Pi]\^\(3/4\)\)\)\)\
\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\)\ z\ \((\(-3\)\ \((x\^2 + y\^2)\) + 
                2\ z\^2)\)\ \[Lambda]\^\(9/4\)\ \((\(-9\) + 
                2\ \((x\^2 + y\^2 + 
                      z\^2)\)\ \[Lambda])\)\)\/\(3\ \@15\ \
\[Pi]\^\(3/4\)\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(1\/\(6\ \@5\ \[Pi]\^\(3/4\)\)\)\((\[ExponentialE]\^\(\(-\(1\/2\)\
\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda] + \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + \
y\^2\)]\)\ \((x\^2 + y\^2 - 
              4\ z\^2)\)\ \@\(\(x\^2 + y\^2\)\/\(x\^2 + y\^2 + z\^2\)\)\ \
\@\(x\^2 + y\^2 + z\^2\)\ \[Lambda]\^\(9/4\)\ \((\(-9\) + 
              2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda] + 2\ \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \((x\^2 + 
                y\^2)\)\ z\ \[Lambda]\^\(9/4\)\ \((\(-9\) + 
                2\ \((x\^2 + y\^2 + 
                      z\^2)\)\ \[Lambda])\)\)\/\(3\ \@2\ \[Pi]\^\(3/4\)\)\)\)\
\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda] \
+ 3\ \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \((\(x\^2 + \
y\^2\)\/\(x\^2 + y\^2 + z\^2\))\)\^\(3/2\)\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\
\ \[Lambda]\^\(9/4\)\ \((\(-9\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\)\
\/\(6\ \@3\ \[Pi]\^\(3/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\
\)\ \[Lambda]\^\(3/4\)\ \((15 + 4\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((\(-5\) + \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\)\/\(2\ \@30\ \
\[Pi]\^\(3/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\
\)\ z\ \[Lambda]\^\(5/4\)\ \((35 + 4\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((\(-7\) + \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\)\/\(2\ \@35\ \
\[Pi]\^\(3/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(1\/\(2\ \@70\ \
\[Pi]\^\(3/4\)\)\)\((\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\
\)\ \[Lambda] + \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \@\(\(x\^2 + y\
\^2\)\/\(x\^2 + y\^2 + z\^2\)\)\ \@\(x\^2 + y\^2 + z\^2\)\ \[Lambda]\^\(5/4\)\
\ \((35 + 4\ \((x\^2 + y\^2 + 
                    z\^2)\)\ \[Lambda]\ \((\(-7\) + \((x\^2 + y\^2 + 
                          z\^2)\)\ \[Lambda])\))\))\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2 - 2\ z\^2)\)\ \[Lambda]\^\(7/4\)\ \((63 + 
                4\ \((x\^2 + y\^2 + 
                      z\^2)\)\ \[Lambda]\ \((\(-9\) + \((x\^2 + y\^2 + 
                            z\^2)\)\ \[Lambda])\))\)\)\/\(6\ \@42\ \
\[Pi]\^\(3/4\)\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(1\/\(6\ \@7\ \[Pi]\^\(3/4\)\)\)\((\[ExponentialE]\^\(\(-\(1\/2\)\
\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda] + \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + \
y\^2\)]\)\ z\ \@\(\(x\^2 + y\^2\)\/\(x\^2 + y\^2 + z\^2\)\)\ \@\(x\^2 + y\^2 \
+ z\^2\)\ \[Lambda]\^\(7/4\)\ \((63 + 
              4\ \((x\^2 + y\^2 + 
                    z\^2)\)\ \[Lambda]\ \((\(-9\) + \((x\^2 + y\^2 + 
                          z\^2)\)\ \[Lambda])\))\))\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda] \
+ 2\ \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \((x\^2 + y\^2)\)\ \
\[Lambda]\^\(7/4\)\ \((63 + 4\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-9\) \
+ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\)\/\(12\ \@7\ \
\[Pi]\^\(3/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\
\)\ z\ \((\(-3\)\ \((x\^2 + y\^2)\) + 2\ z\^2)\)\ \[Lambda]\^\(9/4\)\ \((99 + \
4\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-11\) + \((x\^2 + y\^2 + z\^2)\)\
\ \[Lambda])\))\)\)\/\(6\ \@165\ \[Pi]\^\(3/4\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(12\ \@55\ \
\[Pi]\^\(3/4\)\)\)\((\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\
\)\ \[Lambda] + \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \((x\^2 + 
            y\^2 - 4\ z\^2)\)\ \@\(\(x\^2 + y\^2\)\/\(x\^2 + y\^2 + z\^2\)\)\ \
\@\(x\^2 + y\^2 + z\^2\)\ \[Lambda]\^\(9/4\)\ \((99 + 
            4\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\ \((\(-11\) + \((x\^2 + y\^2 + 
                        z\^2)\)\ \[Lambda])\))\))\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(6\ \@22\ \[Pi]\^\(3/4\)\)\)\((\[ExponentialE]\^\(\(-\(1\/2\)\)\
\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda] + 2\ \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 \
+ y\^2\)]\)\ \((x\^2 + y\^2)\)\ z\ \[Lambda]\^\(9/4\)\ \((99 + 
            4\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\ \((\(-11\) + \((x\^2 + y\^2 + 
                        z\^2)\)\ \[Lambda])\))\))\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(1\/\(12\ \@33\ \[Pi]\^\(3/4\)\)\)\((\[ExponentialE]\^\(\(-\(1\/2\
\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda] + 3\ \[ImaginaryI]\ ArcCos[x\/\@\(x\
\^2 + y\^2\)]\)\ \((\(x\^2 + y\^2\)\/\(x\^2 + y\^2 + z\^2\))\)\^\(3/2\)\ \((x\
\^2 + y\^2 + z\^2)\)\^\(3/2\)\ \[Lambda]\^\(9/4\)\ \((99 + 
              4\ \((x\^2 + y\^2 + 
                    z\^2)\)\ \[Lambda]\ \((\(-11\) + \((x\^2 + y\^2 + 
                          z\^2)\)\ \[Lambda])\))\))\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(4\ \[Pi]\^\(3/4\)\)\)\((\@35\ \[ExponentialE]\^\(\(-\(1\/2\)\)\
\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\)\ \[Lambda]\^\(3/4\)\ \((1 + 
            2\/105\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-105\) + 
                  2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((21 - 
                        2\ \((x\^2 + y\^2 + 
                              z\^2)\)\ \[Lambda])\))\))\))\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(1\/\(6\ \@210\ \[Pi]\^\(3/4\)\)\)\((\[ExponentialE]\^\(\(-\(1\/2\
\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\)\ z\ \[Lambda]\^\(5/4\)\ \((\(-315\
\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((189 + 
                    2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-27\) + 
                          2\ \((x\^2 + y\^2 + 
                                z\^2)\)\ \[Lambda])\))\))\))\)\)\)\)], \
"Output"],

Cell[BoxData[
    \(\(\(1\/\(12\ \@105\ \[Pi]\^\(3/4\)\)\)\((\[ExponentialE]\^\(\(-\(1\/2\)\
\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda] + \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + \
y\^2\)]\)\ \@\(\(x\^2 + y\^2\)\/\(x\^2 + y\^2 + z\^2\)\)\ \@\(x\^2 + y\^2 + z\
\^2\)\ \[Lambda]\^\(5/4\)\ \((\(-315\) + 
            2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((189 + 
                  2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-27\) + 
                        2\ \((x\^2 + y\^2 + 
                              z\^2)\)\ \[Lambda])\))\))\))\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(4\ \[Pi]\^\(3/4\)\)\)\((\@77\ \[ExponentialE]\^\(\(-\(1\/2\)\)\
\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\)\ \((x\^2 + y\^2 + 
            z\^2)\)\ \((\(-1\) + \(3\ z\^2\)\/\(x\^2 + y\^2 + z\^2\))\)\ \
\[Lambda]\^\(7/4\)\ \((1 + 
            2\/693\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-297\) + 
                  2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((33 - 
                        2\ \((x\^2 + y\^2 + 
                              z\^2)\)\ \[Lambda])\))\))\))\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(6\ \@462\ \
\[Pi]\^\(3/4\)\)\)\((\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\
\)\ \[Lambda] + \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ z\ \@\(\(x\^2 \
+ y\^2\)\/\(x\^2 + y\^2 + z\^2\)\)\ \@\(x\^2 + y\^2 + z\^2\)\ \
\[Lambda]\^\(7/4\)\ \((\(-693\) + 
            2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((297 + 
                  2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-33\) + 
                        2\ \((x\^2 + y\^2 + 
                              z\^2)\)\ \[Lambda])\))\))\))\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(4\ \[Pi]\^\(3/4\)\)\)\((\@\(231\/2\)\ \
\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda] + 2\ \
\[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \((x\^2 + 
            y\^2)\)\ \[Lambda]\^\(7/4\)\ \((1 + 
            2\/693\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-297\) + 
                  2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((33 - 
                        2\ \((x\^2 + y\^2 + 
                              z\^2)\)\ \[Lambda])\))\))\))\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(2\ \[Pi]\^\(3/4\)\)\)\((\@\(143\/10\)\ \
\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\)\ \
\((\(-3\)\ \((x\^2 + y\^2)\)\ z + 
            2\ z\^3)\)\ \[Lambda]\^\(9/4\)\ \((1 + \(2\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-429\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((39 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\)\/1287)\))\)\)\)], \
"Output"],

Cell[BoxData[
    \(\(-\(\(1\/\(12\ \@4290\ \
\[Pi]\^\(3/4\)\)\)\((\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\
\)\ \[Lambda] + \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \((x\^2 + 
              y\^2 - 4\ z\^2)\)\ \@\(\(x\^2 + y\^2\)\/\(x\^2 + y\^2 + \
z\^2\)\)\ \@\(x\^2 + y\^2 + z\^2\)\ \[Lambda]\^\(9/4\)\ \((\(-1287\) + 
              2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((429 + 
                    2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-39\) + 
                          2\ \((x\^2 + y\^2 + 
                                z\^2)\)\ \[Lambda])\))\))\))\)\)\)\)], \
"Output"],

Cell[BoxData[
    \(\(\(1\/\(4\ \[Pi]\^\(3/4\)\)\)\((\@429\ \
\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda] + 2\ \
\[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \((x\^2 + 
            y\^2)\)\ z\ \[Lambda]\^\(9/4\)\ \((1 + \(2\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-429\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((39 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\)\/1287)\))\)\)\)], \
"Output"],

Cell[BoxData[
    \(\(\(1\/\(4\ \[Pi]\^\(3/4\)\)\)\((\@\(143\/2\)\ \
\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda] + 3\ \
\[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \((\(x\^2 + y\^2\)\/\(x\^2 + y\
\^2 + z\^2\))\)\^\(3/2\)\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ \[Lambda]\^\(9/4\
\)\ \((\(-1\) + \(2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((429 + 2\ \((x\^2 \
+ y\^2 + z\^2)\)\ \[Lambda]\ \((\(-39\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\)\/1287)\))\)\)\)], "Output"]
}, Open  ]],

Cell["Probability densities:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(FullSimplify[\[Psi]\[Psi]\_Oscl[0, 0, 
        0, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\[Psi]\_Oscl[0, 1, 
        0, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\[Psi]\_Oscl[0, 1, 
        1, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\[Psi]\_Oscl[0, 2, 
        0, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\[Psi]\_Oscl[0, 2, 
        1, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\[Psi]\_Oscl[0, 2, 
        2, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\[Psi]\_Oscl[0, 3, 
        0, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\[Psi]\_Oscl[0, 3, 
        1, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\[Psi]\_Oscl[0, 3, 
        2, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(\(\(FullSimplify[\[Psi]\[Psi]\_Oscl[0, 3, 
        3, \[Lambda]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\[Psi]\_Oscl[1, 0, 
        0, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\[Psi]\_Oscl[1, 1, 
        0, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\[Psi]\_Oscl[1, 1, 
        1, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\[Psi]\_Oscl[1, 2, 
        0, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\[Psi]\_Oscl[1, 2, 
        1, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\[Psi]\_Oscl[1, 2, 
        2, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\[Psi]\_Oscl[1, 3, 
        0, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\[Psi]\_Oscl[1, 3, 
        1, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\[Psi]\_Oscl[1, 3, 
        2, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(\(\(FullSimplify[\[Psi]\[Psi]\_Oscl[1, 3, 
        3, \[Lambda]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\[Psi]\_Oscl[2, 0, 
        0, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\[Psi]\_Oscl[2, 1, 
        0, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\[Psi]\_Oscl[2, 1, 
        1, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\[Psi]\_Oscl[2, 2, 
        0, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\[Psi]\_Oscl[2, 2, 
        1, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\[Psi]\_Oscl[2, 2, 
        2, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\[Psi]\_Oscl[2, 3, 
        0, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\[Psi]\_Oscl[2, 3, 
        1, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\[Psi]\_Oscl[2, 3, 
        2, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(\(\(FullSimplify[\[Psi]\[Psi]\_Oscl[2, 3, 
        3, \[Lambda]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\[Psi]\_Oscl[3, 0, 
        0, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\[Psi]\_Oscl[3, 1, 
        0, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\[Psi]\_Oscl[3, 1, 
        1, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\[Psi]\_Oscl[3, 2, 
        0, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\[Psi]\_Oscl[3, 2, 
        1, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\[Psi]\_Oscl[3, 2, 
        2, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\[Psi]\_Oscl[3, 3, 
        0, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\[Psi]\_Oscl[3, 3, 
        1, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\[Psi]\_Oscl[3, 3, 
        2, \[Lambda]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[\[Psi]\[Psi]\_Oscl[3, 3, 3, \[Lambda]]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(3/2\)\)\/\[Pi]\^\(3/2\)\)], "Output"],

Cell[BoxData[
    \(\(2\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \
z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(5/2\)\)\/\[Pi]\^\(3/2\)\)], \
"Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \
\((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(5/2\)\)\/\[Pi]\^\(3/2\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \
\((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(7/2\)\)\/\(3\ \[Pi]\^\(3/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(2\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \
\((x\^2 + y\^2)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(7/2\)\)\/\[Pi]\^\(3/2\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \
\((x\^2 + y\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(7/2\)\)\/\(2\ \
\[Pi]\^\(3/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(2\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \
\((x\^2 + y\^2 + z\^2)\)\ \((3\ \((x\^2 + y\^2)\)\ z - 2\ z\^3)\)\^2\ \
\[Lambda]\^\(9/2\)\)\/\(15\ \[Pi]\^\(3/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \
\((x\^2 + y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(9/2\)\)\/\(10\ \[Pi]\^\(3/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \
\((x\^2 + y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(9/2\)\)\/\
\[Pi]\^\(3/2\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \
\((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(9/2\)\)\/\(6\ \
\[Pi]\^\(3/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(3/2\)\ \((3 - 2\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda])\)\^2\)\/\(6\ \[Pi]\^\(3/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ z\^2\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(5/2\)\ \((5 - 2\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda])\)\^2\)\/\(5\ \[Pi]\^\(3/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \
\((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(5/2\)\ \((5 - 2\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\^2\)\/\(10\ \[Pi]\^\(3/2\)\)\)], \
"Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \
\((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(7/2\)\ \
\((7 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\^2\)\/\(42\ \[Pi]\^\(3/2\)\)\
\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \
\((x\^2 + y\^2)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(7/2\)\ \((7 - \
2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\^2\)\/\(7\ \[Pi]\^\(3/2\)\)\)], \
"Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \
\((x\^2 + y\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(7/2\)\ \((7 - 2\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\^2\)\/\(28\ \[Pi]\^\(3/2\)\)\)], \
"Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ z\^2\ \
\((3\ \((x\^2 + y\^2)\) - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(9/2\)\ \((9 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\)\^2\)\/\(135\ \[Pi]\^\(3/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \
\((x\^2 + y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(9/2\)\ \((9 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\)\^2\)\/\(180\ \[Pi]\^\(3/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \
\((x\^2 + y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(9/2\)\ \
\((9 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\^2\)\/\(18\ \[Pi]\^\(3/2\)\)\
\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \
\((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(9/2\)\ \((9 - 2\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\^2\)\/\(108\ \[Pi]\^\(3/2\)\)\)], \
"Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(3/2\)\ \((15 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-5\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\^2\)\/\(120\ \[Pi]\^\(3/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ z\^2\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(5/2\)\ \((35 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-7\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\^2\)\/\(140\ \[Pi]\^\(3/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \
\((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(5/2\)\ \((35 + 4\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-7\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\^2\)\/\(280\ \[Pi]\^\(3/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(1512\ \[Pi]\^\(3/2\)\)\)\((\[ExponentialE]\^\(\(-\((x\^2 + \
y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((x\^2 + 
            y\^2 + z\^2)\)\ \[Lambda]\^\(7/2\)\ \((63 + 4\ \((x\^2 + y\^2 + z\
\^2)\)\ \[Lambda]\ \((\(-9\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \
\((x\^2 + y\^2)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(7/2\)\ \((63 \
+ 4\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-9\) + \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda])\))\)\^2\)\/\(252\ \[Pi]\^\(3/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \
\((x\^2 + y\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(7/2\)\ \((63 + 4\
\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-9\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\^2\)\/\(1008\ \[Pi]\^\(3/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(5940\ \[Pi]\^\(3/2\)\)\)\((\[ExponentialE]\^\(\(-\((x\^2 + \
y\^2 + z\^2)\)\)\ \[Lambda]\)\ z\^2\ \((3\ \((x\^2 + y\^2)\) - 2\ z\^2)\)\^2\ \
\((x\^2 + y\^2 + 
            z\^2)\)\ \[Lambda]\^\(9/2\)\ \((99 + 4\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\ \((\(-11\) + \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\^2)\)\)\)], \
"Output"],

Cell[BoxData[
    \(\(\(1\/\(7920\ \[Pi]\^\(3/2\)\)\)\((\[ExponentialE]\^\(\(-\((x\^2 + \
y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + 
            y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
            z\^2)\)\ \[Lambda]\^\(9/2\)\ \((99 + 4\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\ \((\(-11\) + \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\^2)\)\)\)], \
"Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \
\((x\^2 + y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(9/2\)\ \
\((99 + 4\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-11\) + \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda])\))\)\^2\)\/\(792\ \[Pi]\^\(3/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \
\((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(9/2\)\ \((99 + 4\
\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-11\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\^2\)\/\(4752\ \[Pi]\^\(3/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(16\ \[Pi]\^\(3/2\)\)\)\((35\ \[ExponentialE]\^\(\(-\((x\^2 + y\
\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2 + 
            z\^2)\)\ \[Lambda]\^\(3/2\)\ \((1 + 2\/105\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-105\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((21 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(7560\ \[Pi]\^\(3/2\)\)\)\((\[ExponentialE]\^\(\(-\((x\^2 + \
y\^2 + z\^2)\)\)\ \[Lambda]\)\ z\^2\ \((x\^2 + y\^2 + 
            z\^2)\)\ \[Lambda]\^\(5/2\)\ \((315 - 2\ \((x\^2 + y\^2 + z\^2)\)\
\ \[Lambda]\ \((189 + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-27\) + 2\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(15120\ \[Pi]\^\(3/2\)\)\)\((\[ExponentialE]\^\(\(-\((x\^2 + \
y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + 
            z\^2)\)\ \[Lambda]\^\(5/2\)\ \((315 - 2\ \((x\^2 + y\^2 + z\^2)\)\
\ \[Lambda]\ \((189 + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-27\) + 2\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(64\ \[Pi]\^\(3/2\)\)\)\((77\ \[ExponentialE]\^\(\(-\((x\^2 + y\
\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\^3\ \((2 - \(6\ z\^2\)\
\/\(x\^2 + y\^2 + z\^2\))\)\^2\ \[Lambda]\^\(7/2\)\ \((1 + 2\/693\ \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda]\ \((\(-297\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\ \((33 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\))\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(8\ \[Pi]\^\(3/2\)\)\)\((231\ \[ExponentialE]\^\(\(-\((x\^2 + y\
\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2)\)\ z\^2\ \((x\^2 + y\^2 + 
            z\^2)\)\ \[Lambda]\^\(7/2\)\ \((1 + 2\/693\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-297\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((33 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(32\ \[Pi]\^\(3/2\)\)\)\((231\ \[ExponentialE]\^\(\(-\((x\^2 + \
y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2)\)\^2\ \((x\^2 + y\^2 + 
            z\^2)\)\ \[Lambda]\^\(7/2\)\ \((1 + 2\/693\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-297\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((33 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(40\ \[Pi]\^\(3/2\)\)\)\((143\ \[ExponentialE]\^\(\(-\((x\^2 + \
y\^2 + z\^2)\)\)\ \[Lambda]\)\ z\^2\ \((3\ \((x\^2 + y\^2)\) - 2\ z\^2)\)\^2\ \
\((x\^2 + y\^2 + 
            z\^2)\)\ \[Lambda]\^\(9/2\)\ \((1 + \(2\ \((x\^2 + y\^2 + z\^2)\)\
\ \[Lambda]\ \((\(-429\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((39 - 2\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\)\/1287)\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(160\ \[Pi]\^\(3/2\)\)\)\((429\ \[ExponentialE]\^\(\(-\((x\^2 + \
y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + 
            y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
            z\^2)\)\ \[Lambda]\^\(9/2\)\ \((1 + \(2\ \((x\^2 + y\^2 + z\^2)\)\
\ \[Lambda]\ \((\(-429\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((39 - 2\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\)\/1287)\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(16\ \[Pi]\^\(3/2\)\)\)\((429\ \[ExponentialE]\^\(\(-\((x\^2 + \
y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + 
            z\^2)\)\ \[Lambda]\^\(9/2\)\ \((1 + \(2\ \((x\^2 + y\^2 + z\^2)\)\
\ \[Lambda]\ \((\(-429\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((39 - 2\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\)\/1287)\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(32\ \[Pi]\^\(3/2\)\)\)\((143\ \[ExponentialE]\^\(\(-\((x\^2 + \
y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + 
            z\^2)\)\ \[Lambda]\^\(9/2\)\ \((1 + \(2\ \((x\^2 + y\^2 + z\^2)\)\
\ \[Lambda]\ \((\(-429\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((39 - 2\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\)\/1287)\)\^2)\)\)\)], "Output"]
}, Open  ]],

Cell["Wave functions", "Text"],

Cell[BoxData[{
    \(\(\[Psi]\_\(Oscl, Cart\)[0, 0, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 \
+ z\^2)\)\ \[Lambda]\)\ \[Lambda]\^\(3/4\)\)\/\[Pi]\^\(3/4\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\_\(Oscl, Cart\)[0, 1, 
          0, \[Lambda]] = \(\@2\ \[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda]\)\ z\ \[Lambda]\^\(5/4\)\)\/\[Pi]\^\(3/4\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\_\(Oscl, Cart\)[0, 1, 
          1, \[Lambda]] = \(-\(\(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda] + \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \@\
\(\(x\^2 + y\^2\)\/\(x\^2 + y\^2 + z\^2\)\)\ \@\(x\^2 + y\^2 + z\^2\)\ \
\[Lambda]\^\(5/4\)\)\/\[Pi]\^\(3/4\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_\(Oscl, Cart\)[0, 2, 
          0, \[Lambda]] = \(-\(\(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda]\)\ \((x\^2 + y\^2 - 
                    2\ z\^2)\)\ \[Lambda]\^\(7/4\)\)\/\(\@3\ \[Pi]\^\(3/4\)\)\
\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_\(Oscl, Cart\)[0, 2, 
          1, \[Lambda]] = \(-\(\(\@2\ \[ExponentialE]\^\(\(-\(1\/2\)\)\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda] + \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + \
y\^2\)]\)\ z\ \@\(\(x\^2 + y\^2\)\/\(x\^2 + y\^2 + z\^2\)\)\ \@\(x\^2 + y\^2 \
+ z\^2\)\ \[Lambda]\^\(7/4\)\)\/\[Pi]\^\(3/4\)\)\);\)\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\_\(Oscl, Cart\)[0, 2, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 \
+ z\^2)\)\ \[Lambda] + 2\ \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \((x\
\^2 + y\^2)\)\ \[Lambda]\^\(7/4\)\)\/\(\@2\ \[Pi]\^\(3/4\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\_\(Oscl, Cart\)[0, 3, 
          0, \[Lambda]] = \(\@\(2\/15\)\ \[ExponentialE]\^\(\(-\(1\/2\)\)\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\)\ z\ \((\(-3\)\ \((x\^2 + y\^2)\) + 2\ z\
\^2)\)\ \[Lambda]\^\(9/4\)\)\/\[Pi]\^\(3/4\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_\(Oscl, Cart\)[0, 3, 
          
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 \
+ z\^2)\)\ \[Lambda] + \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \((x\^2 \
+ y\^2 - 4\ z\^2)\)\ \@\(\(x\^2 + y\^2\)\/\(x\^2 + y\^2 + z\^2\)\)\ \@\(x\^2 \
+ y\^2 + z\^2\)\ \[Lambda]\^\(9/4\)\)\/\(\@10\ \[Pi]\^\(3/4\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\_\(Oscl, Cart\)[0, 3, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 \
+ z\^2)\)\ \[Lambda] + 2\ \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \((x\
\^2 + y\^2)\)\ z\ \[Lambda]\^\(9/4\)\)\/\[Pi]\^\(3/4\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\_\(Oscl, Cart\)[0, 3, 
          3, \[Lambda]] = \(-\(\(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda] + 3\ \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \
\((\(x\^2 + y\^2\)\/\(x\^2 + y\^2 + z\^2\))\)\^\(3/2\)\ \((x\^2 + y\^2 + \
z\^2)\)\^\(3/2\)\ \[Lambda]\^\(9/4\)\)\/\(\@6\ \[Pi]\^\(3/4\)\)\)\);\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_\(Oscl, Cart\)[1, 0, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 \
+ z\^2)\)\ \[Lambda]\)\ \[Lambda]\^\(3/4\)\ \((3 - 2\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda])\)\)\/\(\@6\ \[Pi]\^\(3/4\)\);\)\), "\[IndentingNewLine]", \

    \(\(\[Psi]\_\(Oscl, Cart\)[1, 1, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 \
+ z\^2)\)\ \[Lambda]\)\ z\ \[Lambda]\^\(5/4\)\ \((5 - 2\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda])\)\)\/\(\@5\ \[Pi]\^\(3/4\)\);\)\), "\[IndentingNewLine]", \

    \(\(\[Psi]\_\(Oscl, Cart\)[1, 1, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 \
+ z\^2)\)\ \[Lambda] + \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \@\(\(x\
\^2 + y\^2\)\/\(x\^2 + y\^2 + z\^2\)\)\ \@\(x\^2 + y\^2 + z\^2\)\ \[Lambda]\^\
\(5/4\)\ \((\(-5\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\)\/\(\@10\ \
\[Pi]\^\(3/4\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_\(Oscl, Cart\)[1, 2, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 \
+ z\^2)\)\ \[Lambda]\)\ \((x\^2 + y\^2 - 2\ z\^2)\)\ \[Lambda]\^\(7/4\)\ \
\((\(-7\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\)\/\(\@42\ \[Pi]\^\(3/4\
\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_\(Oscl, Cart\)[1, 2, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 \
+ z\^2)\)\ \[Lambda] + \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ z\ \@\(\
\(x\^2 + y\^2\)\/\(x\^2 + y\^2 + z\^2\)\)\ \@\(x\^2 + y\^2 + z\^2\)\ \
\[Lambda]\^\(7/4\)\ \((\(-7\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\)\/\
\(\@7\ \[Pi]\^\(3/4\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_\(Oscl, Cart\)[1, 2, 
          2, \[Lambda]] = \(-\(\(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda] + 2\ \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \
\((x\^2 + y\^2)\)\ \[Lambda]\^\(7/4\)\ \((\(-7\) + 
                    2\ \((x\^2 + y\^2 + 
                          z\^2)\)\ \[Lambda])\)\)\/\(2\ \@7\ \[Pi]\^\(3/4\)\)\
\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_\(Oscl, Cart\)[1, 3, 
          0, \[Lambda]] = \(-\(\(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda]\)\ z\ \((\(-3\)\ \((x\^2 + y\^2)\) + 
                    2\ z\^2)\)\ \[Lambda]\^\(9/4\)\ \((\(-9\) + 
                    2\ \((x\^2 + y\^2 + 
                          z\^2)\)\ \[Lambda])\)\)\/\(3\ \@15\ \
\[Pi]\^\(3/4\)\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_\(Oscl, Cart\)[1, 3, 
          1, \[Lambda]] = \(-\(1\/\(6\ \@5\ \[Pi]\^\(3/4\)\)\)\) \((\
\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda] + \
\[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \((x\^2 + y\^2 - 
                  4\ z\^2)\)\ \@\(\(x\^2 + y\^2\)\/\(x\^2 + y\^2 + z\^2\)\)\ \
\@\(x\^2 + y\^2 + z\^2\)\ \[Lambda]\^\(9/4\)\ \((\(-9\) + 
                  2\ \((x\^2 + y\^2 + 
                        z\^2)\)\ \[Lambda])\))\);\)\), "\[IndentingNewLine]", \

    \(\(\[Psi]\_\(Oscl, Cart\)[1, 3, 
          2, \[Lambda]] = \(-\(\(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda] + 2\ \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \
\((x\^2 + y\^2)\)\ z\ \[Lambda]\^\(9/4\)\ \((\(-9\) + 
                    2\ \((x\^2 + y\^2 + 
                          z\^2)\)\ \[Lambda])\)\)\/\(3\ \@2\ \[Pi]\^\(3/4\)\)\
\)\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\_\(Oscl, Cart\)[1, 3, 
          3, \[Lambda]] = \(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 \
+ z\^2)\)\ \[Lambda] + 3\ \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \
\((\(x\^2 + y\^2\)\/\(x\^2 + y\^2 + z\^2\))\)\^\(3/2\)\ \((x\^2 + y\^2 + \
z\^2)\)\^\(3/2\)\ \[Lambda]\^\(9/4\)\ \((\(-9\) + 2\ \((x\^2 + y\^2 + z\^2)\)\
\ \[Lambda])\)\)\/\(6\ \@3\ \[Pi]\^\(3/4\)\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_\(Oscl, Cart\)[2, 0, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 \
+ z\^2)\)\ \[Lambda]\)\ \[Lambda]\^\(3/4\)\ \((15 + 4\ \((x\^2 + y\^2 + z\^2)\
\)\ \[Lambda]\ \((\(-5\) + \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\)\/\(2\ \
\@30\ \[Pi]\^\(3/4\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_\(Oscl, Cart\)[2, 1, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 \
+ z\^2)\)\ \[Lambda]\)\ z\ \[Lambda]\^\(5/4\)\ \((35 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-7\) + \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\)\/\
\(2\ \@35\ \[Pi]\^\(3/4\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_\(Oscl, Cart\)[2, 1, 
          1, \[Lambda]] = \(-\(1\/\(2\ \@70\ \[Pi]\^\(3/4\)\)\)\) \((\
\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda] + \
\[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \@\(\(x\^2 + y\^2\)\/\(x\^2 + \
y\^2 + z\^2\)\)\ \@\(x\^2 + y\^2 + z\^2\)\ \[Lambda]\^\(5/4\)\ \((35 + 
                  4\ \((x\^2 + y\^2 + 
                        z\^2)\)\ \[Lambda]\ \((\(-7\) + \((x\^2 + y\^2 + 
                              z\^2)\)\ \[Lambda])\))\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\_\(Oscl, Cart\)[2, 2, 
          0, \[Lambda]] = \(-\(\(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda]\)\ \((x\^2 + y\^2 - 
                    2\ z\^2)\)\ \[Lambda]\^\(7/4\)\ \((63 + 
                    4\ \((x\^2 + y\^2 + 
                          z\^2)\)\ \[Lambda]\ \((\(-9\) + \((x\^2 + y\^2 + 
                                z\^2)\)\ \[Lambda])\))\)\)\/\(6\ \@42\ \
\[Pi]\^\(3/4\)\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_\(Oscl, Cart\)[2, 2, 
          1, \[Lambda]] = \(-\(1\/\(6\ \@7\ \[Pi]\^\(3/4\)\)\)\) \((\
\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda] + \
\[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ z\ \@\(\(x\^2 + y\^2\)\/\(x\^2 \
+ y\^2 + z\^2\)\)\ \@\(x\^2 + y\^2 + z\^2\)\ \[Lambda]\^\(7/4\)\ \((63 + 
                  4\ \((x\^2 + y\^2 + 
                        z\^2)\)\ \[Lambda]\ \((\(-9\) + \((x\^2 + y\^2 + 
                              z\^2)\)\ \[Lambda])\))\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\_\(Oscl, Cart\)[2, 2, 
          2, \[Lambda]] = \(1\/\(12\ \@7\ \[Pi]\^\(3/4\)\)\) \((\
\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda] + 2\ \
\[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \((x\^2 + 
                  y\^2)\)\ \[Lambda]\^\(7/4\)\ \((63 + 
                  4\ \((x\^2 + y\^2 + 
                        z\^2)\)\ \[Lambda]\ \((\(-9\) + \((x\^2 + y\^2 + 
                              z\^2)\)\ \[Lambda])\))\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\_\(Oscl, Cart\)[2, 3, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 \
+ z\^2)\)\ \[Lambda]\)\ z\ \((\(-3\)\ \((x\^2 + y\^2)\) + 2\ z\^2)\)\ \
\[Lambda]\^\(9/4\)\ \((99 + 4\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((\(-11\) + \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\)\/\(6\ \@165\ \[Pi]\^\
\(3/4\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_\(Oscl, Cart\)[2, 3, 
          1, \[Lambda]] = \(1\/\(12\ \@55\ \[Pi]\^\(3/4\)\)\) \((\
\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda] + \
\[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \((x\^2 + y\^2 - 
                  4\ z\^2)\)\ \@\(\(x\^2 + y\^2\)\/\(x\^2 + y\^2 + z\^2\)\)\ \
\@\(x\^2 + y\^2 + z\^2\)\ \[Lambda]\^\(9/4\)\ \((99 + 
                  4\ \((x\^2 + y\^2 + 
                        z\^2)\)\ \[Lambda]\ \((\(-11\) + \((x\^2 + y\^2 + 
                              z\^2)\)\ \[Lambda])\))\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\_\(Oscl, Cart\)[2, 3, 
          2, \[Lambda]] = \(1\/\(6\ \@22\ \[Pi]\^\(3/4\)\)\) \((\
\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda] + 2\ \
\[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \((x\^2 + 
                  y\^2)\)\ z\ \[Lambda]\^\(9/4\)\ \((99 + 
                  4\ \((x\^2 + y\^2 + 
                        z\^2)\)\ \[Lambda]\ \((\(-11\) + \((x\^2 + y\^2 + 
                              z\^2)\)\ \[Lambda])\))\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\_\(Oscl, Cart\)[2, 3, 
          3, \[Lambda]] = \(-\(1\/\(12\ \@33\ \[Pi]\^\(3/4\)\)\)\) \((\
\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda] + 3\ \
\[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \((\(x\^2 + y\^2\)\/\(x\^2 + y\
\^2 + z\^2\))\)\^\(3/2\)\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ \[Lambda]\^\(9/4\
\)\ \((99 + 4\ \((x\^2 + y\^2 + 
                        z\^2)\)\ \[Lambda]\ \((\(-11\) + \((x\^2 + y\^2 + 
                              z\^2)\)\ \[Lambda])\))\))\);\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_\(Oscl, Cart\)[3, 0, 
          0, \[Lambda]] = \(1\/\(4\ \[Pi]\^\(3/4\)\)\) \((\@35\ \
\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\)\ \
\[Lambda]\^\(3/4\)\ \((1 + 
                  2\/105\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-105\) + 
                        2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((21 - 
                              2\ \((x\^2 + y\^2 + 
                                    z\^2)\)\ \[Lambda])\))\))\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\_\(Oscl, Cart\)[3, 1, 
          0, \[Lambda]] = \(-\(1\/\(6\ \@210\ \[Pi]\^\(3/4\)\)\)\) \((\
\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\)\ z\ \
\[Lambda]\^\(5/4\)\ \((\(-315\) + 
                  2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((189 + 
                        2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-27\) + 
                              2\ \((x\^2 + y\^2 + 
                                    z\^2)\)\ \[Lambda])\))\))\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\_\(Oscl, Cart\)[3, 1, 
          1, \[Lambda]] = \(1\/\(12\ \@105\ \[Pi]\^\(3/4\)\)\) \((\
\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda] + \
\[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \@\(\(x\^2 + y\^2\)\/\(x\^2 + \
y\^2 + z\^2\)\)\ \@\(x\^2 + y\^2 + z\^2\)\ \[Lambda]\^\(5/4\)\ \((\(-315\) + 
                  2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((189 + 
                        2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-27\) + 
                              2\ \((x\^2 + y\^2 + 
                                    z\^2)\)\ \[Lambda])\))\))\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\_\(Oscl, Cart\)[3, 2, 
          0, \[Lambda]] = \(1\/\(4\ \[Pi]\^\(3/4\)\)\) \((\@77\ \
\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\)\ \((x\
\^2 + y\^2 + 
                  z\^2)\)\ \((\(-1\) + \(3\ z\^2\)\/\(x\^2 + y\^2 + z\^2\))\)\
\ \[Lambda]\^\(7/4\)\ \((1 + 
                  2\/693\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-297\) + 
                        2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((33 - 
                              2\ \((x\^2 + y\^2 + 
                                    z\^2)\)\ \[Lambda])\))\))\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\_\(Oscl, Cart\)[3, 2, 
          1, \[Lambda]] = \(1\/\(6\ \@462\ \[Pi]\^\(3/4\)\)\) \((\
\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda] + \
\[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ z\ \@\(\(x\^2 + y\^2\)\/\(x\^2 \
+ y\^2 + z\^2\)\)\ \@\(x\^2 + y\^2 + z\^2\)\ \[Lambda]\^\(7/4\)\ \((\(-693\) \
+ 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((297 + 
                        2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-33\) + 
                              2\ \((x\^2 + y\^2 + 
                                    z\^2)\)\ \[Lambda])\))\))\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\_\(Oscl, Cart\)[3, 2, 
          2, \[Lambda]] = \(1\/\(4\ \[Pi]\^\(3/4\)\)\) \((\@\(231\/2\)\ \
\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda] + 2\ \
\[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \((x\^2 + 
                  y\^2)\)\ \[Lambda]\^\(7/4\)\ \((1 + 
                  2\/693\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-297\) + 
                        2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((33 - 
                              2\ \((x\^2 + y\^2 + 
                                    z\^2)\)\ \[Lambda])\))\))\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\_\(Oscl, Cart\)[3, 3, 
          0, \[Lambda]] = \(1\/\(2\ \[Pi]\^\(3/4\)\)\) \((\@\(143\/10\)\ \
\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\)\ \
\((\(-3\)\ \((x\^2 + y\^2)\)\ z + 
                  2\ z\^3)\)\ \[Lambda]\^\(9/4\)\ \((1 + \(2\ \((x\^2 + y\^2 \
+ z\^2)\)\ \[Lambda]\ \((\(-429\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((39 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\)\/1287)\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\_\(Oscl, Cart\)[3, 3, 
          1, \[Lambda]] = \(-\(1\/\(12\ \@4290\ \[Pi]\^\(3/4\)\)\)\) \((\
\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda] + \
\[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \((x\^2 + y\^2 - 
                  4\ z\^2)\)\ \@\(\(x\^2 + y\^2\)\/\(x\^2 + y\^2 + z\^2\)\)\ \
\@\(x\^2 + y\^2 + z\^2\)\ \[Lambda]\^\(9/4\)\ \((\(-1287\) + 
                  2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((429 + 
                        2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-39\) + 
                              2\ \((x\^2 + y\^2 + 
                                    z\^2)\)\ \[Lambda])\))\))\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\_\(Oscl, Cart\)[3, 3, 
          2, \[Lambda]] = \(1\/\(4\ \[Pi]\^\(3/4\)\)\) \((\@429\ \
\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda] + 2\ \
\[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \((x\^2 + 
                  y\^2)\)\ z\ \[Lambda]\^\(9/4\)\ \((1 + \(2\ \((x\^2 + y\^2 \
+ z\^2)\)\ \[Lambda]\ \((\(-429\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((39 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\)\/1287)\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\_\(Oscl, Cart\)[3, 3, 
          3, \[Lambda]] = \(1\/\(4\ \[Pi]\^\(3/4\)\)\) \((\@\(143\/2\)\ \
\[ExponentialE]\^\(\(-\(1\/2\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda] + 3\ \
\[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)]\)\ \((\(x\^2 + y\^2\)\/\(x\^2 + y\
\^2 + z\^2\))\)\^\(3/2\)\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ \[Lambda]\^\(9/4\
\)\ \((\(-1\) + \(2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((429 + 2\ \((x\^2 \
+ y\^2 + z\^2)\)\ \[Lambda]\ \((\(-39\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\)\/1287)\))\);\)\)}], "Input"],

Cell["Probability densities:", "Text"],

Cell[BoxData[{
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 0, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(3/2\)\)\/\[Pi]\^\(3/2\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 1, 
          0, \[Lambda]] = \(2\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\
\)\ \[Lambda]\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(5/2\)\)\/\[Pi]\^\(3/2\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 1, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(5/2\)\)\/\[Pi]\^\(3/2\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 2, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(7/2\)\)\/\(3\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 2, 
          1, \[Lambda]] = \(2\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\
\)\ \[Lambda]\)\ \((x\^2 + y\^2)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\
\^\(7/2\)\)\/\[Pi]\^\(3/2\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 2, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(7/2\
\)\)\/\(2\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 3, 
          0, \[Lambda]] = \(2\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\
\)\ \[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\ \((3\ \((x\^2 + y\^2)\)\ z - 2\ \
z\^3)\)\^2\ \[Lambda]\^\(9/2\)\)\/\(15\ \[Pi]\^\(3/2\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 3, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda]\^\(9/2\)\)\/\(10\ \[Pi]\^\(3/2\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 3, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(9/2\)\)\/\[Pi]\^\(3/2\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 3, 
          3, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(9/2\
\)\)\/\(6\ \[Pi]\^\(3/2\)\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 0, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(3/2\)\ \((3 - 2\ \((x\^2 \
+ y\^2 + z\^2)\)\ \[Lambda])\)\^2\)\/\(6\ \[Pi]\^\(3/2\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 1, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(5/2\)\ \((5 - 2\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\^2\)\/\(5\ \[Pi]\^\(3/2\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 1, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(5/2\)\ \
\((5 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\^2\)\/\(10\ \
\[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 2, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(7/2\)\ \((7 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\)\^2\)\/\(42\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 2, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(7/2\)\ \((7 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\)\^2\)\/\(7\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 2, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(7/2\
\)\ \((7 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\^2\)\/\(28\ \[Pi]\^\(3/2\
\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 3, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ z\^2\ \((3\ \((x\^2 + y\^2)\) - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\^\(9/2\)\ \((9 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\
\^2\)\/\(135\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 3, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda]\^\(9/2\)\ \((9 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\)\^2\)\/\(180\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 3, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(9/2\)\ \((9 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\)\^2\)\/\(18\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 3, 
          3, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(9/2\
\)\ \((9 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\^2\)\/\(108\ \
\[Pi]\^\(3/2\)\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 0, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(3/2\)\ \((15 + 4\ \((x\^2 \
+ y\^2 + z\^2)\)\ \[Lambda]\ \((\(-5\) + \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\
\))\)\^2\)\/\(120\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 1, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(5/2\)\ \((35 + 4\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-7\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\^2\)\/\(140\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 1, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(5/2\)\ \
\((35 + 4\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-7\) + \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda])\))\)\^2\)\/\(280\ \[Pi]\^\(3/2\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 2, 
          0, \[Lambda]] = \(1\/\(1512\ \[Pi]\^\(3/2\)\)\) \
\((\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\
\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(7/2\)\ \((63 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-9\) + \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\^2)\
\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 2, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(7/2\)\ \((63 + 4\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-9\) \
+ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\^2\)\/\(252\ \
\[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 2, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(7/2\
\)\ \((63 + 4\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-9\) + \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda])\))\)\^2\)\/\(1008\ \[Pi]\^\(3/2\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 3, 
          0, \[Lambda]] = \(1\/\(5940\ \[Pi]\^\(3/2\)\)\) \
\((\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ z\^2\ \((3\ \
\((x\^2 + y\^2)\) - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((99 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-11\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 3, 
          1, \[Lambda]] = \(1\/\(7920\ \[Pi]\^\(3/2\)\)\) \
\((\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + 
                  y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((99 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-11\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 3, 
          2, \[Lambda]] = \(1\/\(792\ \[Pi]\^\(3/2\)\)\) \((\[ExponentialE]\^\
\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2)\)\^2\ z\^2\ \
\((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((99 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-11\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 3, 
          3, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(9/2\
\)\ \((99 + 4\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-11\) + \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda])\))\)\^2\)\/\(4752\ \[Pi]\^\(3/2\)\);\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 0, 
          0, \[Lambda]] = \(1\/\(16\ \[Pi]\^\(3/2\)\)\) \((35\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + 
                  y\^2 + z\^2)\)\ \[Lambda]\^\(3/2\)\ \((1 + 2\/105\ \((x\^2 \
+ y\^2 + z\^2)\)\ \[Lambda]\ \((\(-105\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\ \((21 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 1, 
          0, \[Lambda]] = \(1\/\(7560\ \[Pi]\^\(3/2\)\)\) \
\((\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ z\^2\ \
\((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(5/2\)\ \((315 - 2\ \((x\^2 + y\^2 + z\
\^2)\)\ \[Lambda]\ \((189 + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((\(-27\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 1, 
          1, \[Lambda]] = \(1\/\(15120\ \[Pi]\^\(3/2\)\)\) \((\[ExponentialE]\
\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2)\)\ \((x\^2 + 
                  y\^2 + z\^2)\)\ \[Lambda]\^\(5/2\)\ \((315 - 2\ \((x\^2 + y\
\^2 + z\^2)\)\ \[Lambda]\ \((189 + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((\(-27\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 2, 
          0, \[Lambda]] = \(1\/\(64\ \[Pi]\^\(3/2\)\)\) \((77\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2 \
+ z\^2)\)\^3\ \((2 - \(6\ z\^2\)\/\(x\^2 + y\^2 + z\^2\))\)\^2\ \
\[Lambda]\^\(7/2\)\ \((1 + 2\/693\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((\(-297\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((33 - 2\ \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 2, 
          1, \[Lambda]] = \(1\/\(8\ \[Pi]\^\(3/2\)\)\) \((231\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + 
                  y\^2)\)\ z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(7/2\)\ \((1 + 2\/693\ \((x\^2 + y\^2 \
+ z\^2)\)\ \[Lambda]\ \((\(-297\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((33 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 2, 
          2, \[Lambda]] = \(1\/\(32\ \[Pi]\^\(3/2\)\)\) \((231\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + \
y\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(7/2\)\ \((1 + 2\/693\ \((x\^2 + y\^2 \
+ z\^2)\)\ \[Lambda]\ \((\(-297\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((33 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 3, 
          0, \[Lambda]] = \(1\/\(40\ \[Pi]\^\(3/2\)\)\) \((143\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ z\^2\ \((3\ \
\((x\^2 + y\^2)\) - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((1 + \(2\ \((x\^2 + y\^2 + z\
\^2)\)\ \[Lambda]\ \((\(-429\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((39 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\)\/1287)\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 3, 
          1, \[Lambda]] = \(1\/\(160\ \[Pi]\^\(3/2\)\)\) \((429\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + 
                  y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((1 + \(2\ \((x\^2 + y\^2 + z\
\^2)\)\ \[Lambda]\ \((\(-429\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((39 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\)\/1287)\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 3, 
          2, \[Lambda]] = \(1\/\(16\ \[Pi]\^\(3/2\)\)\) \((429\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + \
y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((1 + \(2\ \((x\^2 + y\^2 + z\
\^2)\)\ \[Lambda]\ \((\(-429\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((39 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\)\/1287)\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 3, 
          3, \[Lambda]] = \(1\/\(32\ \[Pi]\^\(3/2\)\)\) \((143\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + \
y\^2)\)\^3\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((1 + \(2\ \((x\^2 + y\^2 + z\
\^2)\)\ \[Lambda]\ \((\(-429\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((39 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\)\/1287)\)\^2)\);\)\)}], \
"Input"],

Cell["", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1016, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.25,
StyleDefinitions -> "Classroom1.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 254, 8, 93, "Subtitle"],
Cell[2527, 82, 152, 4, 97, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2704, 90, 193, 5, 119, "Section"],
Cell[2900, 97, 145, 4, 56, "Text"],
Cell[3048, 103, 262, 12, 96, "NumberedEquation"],
Cell[3313, 117, 140, 4, 56, "Text"],
Cell[3456, 123, 165, 3, 53, "NumberedEquation"],
Cell[3624, 128, 349, 12, 56, "Text"],
Cell[3976, 142, 189, 5, 56, "Text"],
Cell[4168, 149, 6236, 123, 2077, "Input"],
Cell[10407, 274, 239, 6, 80, "Text"],
Cell[10649, 282, 2493, 61, 1479, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13179, 348, 157, 3, 119, "Section"],
Cell[13339, 353, 152, 3, 56, "Text"],

Cell[CellGroupData[{
Cell[13516, 360, 308, 5, 88, "Input"],
Cell[13827, 367, 87, 1, 63, "Output"],
Cell[13917, 370, 89, 1, 63, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14043, 376, 163, 3, 63, "Input"],
Cell[14209, 381, 87, 1, 63, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14333, 387, 106, 5, 89, "Subsection"],

Cell[CellGroupData[{
Cell[14464, 396, 425, 8, 163, "Input"],
Cell[14892, 406, 124, 2, 98, "Output"],
Cell[15019, 410, 123, 2, 92, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15179, 417, 425, 8, 163, "Input"],
Cell[15607, 427, 147, 2, 98, "Output"],
Cell[15757, 431, 144, 2, 92, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15938, 438, 425, 8, 163, "Input"],
Cell[16366, 448, 186, 3, 98, "Output"],
Cell[16555, 453, 141, 2, 92, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16733, 460, 425, 8, 163, "Input"],
Cell[17161, 470, 177, 3, 108, "Output"],
Cell[17341, 475, 165, 2, 92, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17543, 482, 425, 8, 163, "Input"],
Cell[17971, 492, 209, 3, 98, "Output"],
Cell[18183, 497, 164, 3, 92, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18384, 505, 425, 8, 163, "Input"],
Cell[18812, 515, 195, 3, 108, "Output"],
Cell[19010, 520, 148, 2, 92, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19195, 527, 425, 8, 163, "Input"],
Cell[19623, 537, 196, 3, 124, "Output"],
Cell[19822, 542, 183, 3, 92, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20042, 550, 425, 8, 163, "Input"],
Cell[20470, 560, 252, 4, 108, "Output"],
Cell[20725, 566, 180, 3, 92, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20942, 574, 425, 8, 163, "Input"],
Cell[21370, 584, 201, 3, 98, "Output"],
Cell[21574, 589, 159, 2, 92, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21770, 596, 374, 8, 163, "Input"],
Cell[22147, 606, 204, 3, 108, "Output"],
Cell[22354, 611, 148, 2, 92, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[22551, 619, 106, 5, 89, "Subsection"],

Cell[CellGroupData[{
Cell[22682, 628, 425, 8, 163, "Input"],
Cell[23110, 638, 175, 3, 124, "Output"],
Cell[23288, 643, 175, 3, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23500, 651, 425, 8, 163, "Input"],
Cell[23928, 661, 214, 4, 108, "Output"],
Cell[24145, 667, 188, 3, 92, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24370, 675, 425, 8, 163, "Input"],
Cell[24798, 685, 222, 3, 108, "Output"],
Cell[25023, 690, 189, 3, 92, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25249, 698, 425, 8, 163, "Input"],
Cell[25677, 708, 239, 4, 108, "Output"],
Cell[25919, 714, 206, 3, 92, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26162, 722, 425, 8, 163, "Input"],
Cell[26590, 732, 239, 3, 108, "Output"],
Cell[26832, 737, 206, 3, 92, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27075, 745, 425, 8, 163, "Input"],
Cell[27503, 755, 259, 4, 108, "Output"],
Cell[27765, 761, 189, 3, 92, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27991, 769, 425, 8, 163, "Input"],
Cell[28419, 779, 232, 3, 124, "Output"],
Cell[28654, 784, 227, 4, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28918, 793, 425, 8, 163, "Input"],
Cell[29346, 803, 296, 5, 114, "Output"],
Cell[29645, 810, 223, 3, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29905, 818, 425, 8, 163, "Input"],
Cell[30333, 828, 252, 4, 114, "Output"],
Cell[30588, 834, 211, 3, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30836, 842, 374, 8, 163, "Input"],
Cell[31213, 852, 244, 3, 104, "Output"],
Cell[31460, 857, 193, 3, 102, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[31702, 866, 106, 5, 89, "Subsection"],

Cell[CellGroupData[{
Cell[31833, 875, 425, 8, 163, "Input"],
Cell[32261, 885, 202, 3, 108, "Output"],
Cell[32466, 890, 200, 3, 92, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32703, 898, 425, 8, 163, "Input"],
Cell[33131, 908, 220, 3, 108, "Output"],
Cell[33354, 913, 218, 3, 92, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33609, 921, 425, 8, 163, "Input"],
Cell[34037, 931, 302, 5, 108, "Output"],
Cell[34342, 938, 218, 3, 92, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[34597, 946, 425, 8, 163, "Input"],
Cell[35025, 956, 246, 4, 108, "Output"],
Cell[35274, 962, 235, 3, 92, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35546, 970, 425, 8, 163, "Input"],
Cell[35974, 980, 319, 5, 108, "Output"],
Cell[36296, 987, 236, 3, 92, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36569, 995, 425, 8, 163, "Input"],
Cell[36997, 1005, 264, 4, 108, "Output"],
Cell[37264, 1011, 219, 3, 92, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37520, 1019, 425, 8, 163, "Input"],
Cell[37948, 1029, 263, 4, 108, "Output"],
Cell[38214, 1035, 254, 4, 92, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38505, 1044, 425, 8, 163, "Input"],
Cell[38933, 1054, 360, 6, 108, "Output"],
Cell[39296, 1062, 252, 4, 92, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[39585, 1071, 425, 8, 163, "Input"],
Cell[40013, 1081, 280, 4, 108, "Output"],
Cell[40296, 1087, 237, 3, 92, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[40570, 1095, 374, 8, 163, "Input"],
Cell[40947, 1105, 313, 5, 108, "Output"],
Cell[41263, 1112, 220, 3, 92, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[41532, 1121, 106, 5, 89, "Subsection"],

Cell[CellGroupData[{
Cell[41663, 1130, 425, 8, 163, "Input"],
Cell[42091, 1140, 233, 3, 104, "Output"],
Cell[42327, 1145, 234, 3, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[42598, 1153, 425, 8, 163, "Input"],
Cell[43026, 1163, 301, 5, 108, "Output"],
Cell[43330, 1170, 252, 4, 92, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43619, 1179, 425, 8, 163, "Input"],
Cell[44047, 1189, 288, 4, 108, "Output"],
Cell[44338, 1195, 253, 4, 92, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[44628, 1204, 425, 8, 163, "Input"],
Cell[45056, 1214, 275, 4, 104, "Output"],
Cell[45334, 1220, 268, 4, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[45639, 1229, 425, 8, 163, "Input"],
Cell[46067, 1239, 357, 5, 124, "Output"],
Cell[46427, 1246, 270, 4, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[46734, 1255, 425, 8, 163, "Input"],
Cell[47162, 1265, 301, 4, 124, "Output"],
Cell[47466, 1271, 253, 4, 98, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47756, 1280, 425, 8, 163, "Input"],
Cell[48184, 1290, 304, 4, 124, "Output"],
Cell[48491, 1296, 290, 4, 107, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[48818, 1305, 425, 8, 163, "Input"],
Cell[49246, 1315, 365, 6, 124, "Output"],
Cell[49614, 1323, 288, 4, 107, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49939, 1332, 425, 8, 163, "Input"],
Cell[50367, 1342, 314, 4, 106, "Output"],
Cell[50684, 1348, 276, 4, 107, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[50997, 1357, 374, 8, 163, "Input"],
Cell[51374, 1367, 315, 4, 124, "Output"],
Cell[51692, 1373, 258, 4, 107, "Output"]
}, Open  ]],
Cell[51965, 1380, 174, 3, 80, "Text"],
Cell[52142, 1385, 30, 0, 56, "Text"],
Cell[52175, 1387, 12285, 216, 3510, "Input"],
Cell[64463, 1605, 38, 0, 56, "Text"],
Cell[64504, 1607, 10906, 186, 2734, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[75459, 1799, 157, 3, 119, "Section"],
Cell[75619, 1804, 337, 11, 80, "Text"],
Cell[75959, 1817, 233, 4, 138, "Input"],
Cell[76195, 1823, 116, 3, 113, "Input"],
Cell[76314, 1828, 30, 0, 56, "Text"],

Cell[CellGroupData[{
Cell[76369, 1832, 3660, 82, 1113, "Input"],
Cell[80032, 1916, 147, 2, 94, "Output"],
Cell[80182, 1920, 155, 2, 94, "Output"],
Cell[80340, 1924, 279, 4, 124, "Output"],
Cell[80622, 1930, 213, 4, 104, "Output"],
Cell[80838, 1936, 287, 4, 124, "Output"],
Cell[81128, 1942, 226, 3, 116, "Output"],
Cell[81357, 1947, 208, 3, 124, "Output"],
Cell[81568, 1952, 309, 4, 134, "Output"],
Cell[81880, 1958, 220, 3, 106, "Output"],
Cell[82103, 1963, 309, 4, 124, "Output"],
Cell[82415, 1969, 208, 3, 104, "Output"],
Cell[82626, 1974, 211, 3, 104, "Output"],
Cell[82840, 1979, 337, 5, 134, "Output"],
Cell[83180, 1986, 243, 3, 104, "Output"],
Cell[83426, 1991, 339, 5, 134, "Output"],
Cell[83768, 1998, 350, 6, 116, "Output"],
Cell[84121, 2006, 329, 6, 104, "Output"],
Cell[84453, 2014, 412, 6, 177, "Output"],
Cell[84868, 2022, 353, 6, 116, "Output"],
Cell[85224, 2030, 360, 5, 124, "Output"],
Cell[85587, 2037, 267, 4, 104, "Output"],
Cell[85857, 2043, 270, 4, 104, "Output"],
Cell[86130, 2049, 452, 7, 178, "Output"],
Cell[86585, 2058, 372, 6, 104, "Output"],
Cell[86960, 2066, 467, 7, 178, "Output"],
Cell[87430, 2075, 337, 5, 116, "Output"],
Cell[87770, 2082, 315, 4, 104, "Output"],
Cell[88088, 2088, 498, 8, 178, "Output"],
Cell[88589, 2098, 405, 6, 169, "Output"],
Cell[88997, 2106, 488, 7, 169, "Output"],
Cell[89488, 2115, 422, 6, 136, "Output"],
Cell[89913, 2123, 430, 7, 126, "Output"],
Cell[90346, 2132, 549, 8, 178, "Output"],
Cell[90898, 2142, 515, 8, 145, "Output"],
Cell[91416, 2152, 553, 9, 178, "Output"],
Cell[91972, 2163, 513, 8, 177, "Output"],
Cell[92488, 2173, 415, 7, 177, "Output"],
Cell[92906, 2182, 610, 10, 242, "Output"],
Cell[93519, 2194, 432, 7, 166, "Output"],
Cell[93954, 2203, 502, 7, 177, "Output"]
}, Open  ]],
Cell[94471, 2213, 38, 0, 56, "Text"],

Cell[CellGroupData[{
Cell[94534, 2217, 3900, 82, 1113, "Input"],
Cell[98437, 2301, 163, 2, 93, "Output"],
Cell[98603, 2305, 174, 3, 93, "Output"],
Cell[98780, 2310, 184, 3, 93, "Output"],
Cell[98967, 2315, 204, 3, 93, "Output"],
Cell[99174, 2320, 193, 3, 93, "Output"],
Cell[99370, 2325, 194, 3, 93, "Output"],
Cell[99567, 2330, 220, 3, 93, "Output"],
Cell[99790, 2335, 224, 3, 93, "Output"],
Cell[100017, 2340, 193, 3, 93, "Output"],
Cell[100213, 2345, 194, 3, 93, "Output"],
Cell[100410, 2350, 225, 3, 93, "Output"],
Cell[100638, 2355, 231, 3, 93, "Output"],
Cell[100872, 2360, 247, 4, 93, "Output"],
Cell[101122, 2366, 260, 4, 93, "Output"],
Cell[101385, 2372, 252, 4, 93, "Output"],
Cell[101640, 2378, 250, 4, 93, "Output"],
Cell[101893, 2384, 276, 4, 93, "Output"],
Cell[102172, 2390, 280, 4, 93, "Output"],
Cell[102455, 2396, 256, 4, 93, "Output"],
Cell[102714, 2402, 251, 4, 93, "Output"],
Cell[102968, 2408, 282, 4, 93, "Output"],
Cell[103253, 2414, 288, 4, 93, "Output"],
Cell[103544, 2420, 301, 4, 93, "Output"],
Cell[103848, 2426, 339, 5, 117, "Output"],
Cell[104190, 2433, 307, 4, 93, "Output"],
Cell[104500, 2439, 305, 4, 93, "Output"],
Cell[104808, 2445, 357, 6, 117, "Output"],
Cell[105168, 2453, 372, 6, 117, "Output"],
Cell[105543, 2461, 311, 4, 93, "Output"],
Cell[105857, 2467, 306, 4, 93, "Output"],
Cell[106166, 2473, 369, 5, 139, "Output"],
Cell[106538, 2480, 370, 5, 117, "Output"],
Cell[106911, 2487, 384, 5, 117, "Output"],
Cell[107298, 2494, 413, 6, 162, "Output"],
Cell[107714, 2502, 394, 5, 139, "Output"],
Cell[108111, 2509, 392, 5, 139, "Output"],
Cell[108506, 2516, 424, 6, 162, "Output"],
Cell[108933, 2524, 440, 6, 162, "Output"],
Cell[109376, 2532, 403, 5, 162, "Output"],
Cell[109782, 2539, 397, 5, 162, "Output"]
}, Open  ]],
Cell[110194, 2547, 30, 0, 56, "Text"],
Cell[110227, 2549, 17292, 290, 5666, "Input"],
Cell[127522, 2841, 38, 0, 56, "Text"],
Cell[127563, 2843, 14541, 234, 3926, "Input"],
Cell[142107, 3079, 16, 0, 56, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

