(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    380472,       6715]*)
(*NotebookOutlinePosition[    381228,       6741]*)
(*  CellTagsIndexPosition[    381184,       6737]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Part ",
    FontWeight->"Bold"],
  StyleBox["2. Quantum Isotropic Oscillator",
    FontWeight->"Bold"],
  "\n2.3. Three-Dimensional Isotropic Quantum Oscillator"
}], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "2.3.8. Visualization of the Wave Functions and Probability Densities of \
the Three-Dimensional Quantum Oscillator (",
  StyleBox["ending",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  StyleBox[")",
    FontWeight->"Plain"]
}], "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
1. Normalized radial wave functions and radial probability densities of the \
three-dimensional quantum oscillator\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Consider some states of the three-dimensional quantum oscillator defined by \
quantum numbers:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  Cell[BoxData[
      \(n\_rad = 0, 1, 2, 3\)],
    FontSlant->"Italic"],
  ", \n",
  Cell[BoxData[
      \(l\_orb = 0, 1, 2, 3\)],
    FontSlant->"Italic"]
}], "NumberedEquation"],

Cell["In this file we present states for radial quantum numbers:", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  Cell[BoxData[
      \(n\_rad = 3, 4. \)],
    FontSlant->"Italic"],
  " "
}], "NumberedEquation"],

Cell["\<\
and previous file presents states for radial quantum numbers:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[Cell[BoxData[
    \(n\_rad = 1, 2\)],
  FontSlant->"Italic"]], "NumberedEquation"],

Cell["\<\
Determine parameter \[Lambda] of the three-dimensional quantum oscillator:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(\(\(\[Lambda] = 1;\)\(\ \)\)\)], "Input"],

Cell["\<\
Normalized radial wave functions and radial probability densities of the \
three-dimensional quantum oscillator for given quantum numbers in the \
Cartesian rectangular coordinates are:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->1],

Cell["Radial probability densities:", "Text"],

Cell[BoxData[{
    \(\(RR\_\(Oscl, Cart\)[2, 
          0, \[Lambda]] = \(1\/\(30\ \@\[Pi]\)\) \
\((\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + 
                  y\^2 + z\^2)\)\ \[Lambda]\^\(3/2\)\ \((15 + 4\ \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda]\ \((\(-5\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(Oscl, Cart\)[2, 
          1, \[Lambda]] = \(1\/\(105\ \@\[Pi]\)\) \
\((\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\
\^2 + z\^2)\)\^2\ \[Lambda]\^\(5/2\)\ \((35 + 4\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\ \((\(-7\) + \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\^2)\);\)\), \
"\[IndentingNewLine]", 
    \(\(RR\_\(Oscl, Cart\)[2, 
          2, \[Lambda]] = \(1\/\(945\ \@\[Pi]\)\) \((2\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2 \
+ z\^2)\)\^3\ \[Lambda]\^\(7/2\)\ \((63 + 4\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\ \((\(-9\) + \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\^2)\);\)\), \
"\[IndentingNewLine]", 
    \(\(\(RR\_\(Oscl, Cart\)[2, 
          3, \[Lambda]] = \(1\/\(10395\ \@\[Pi]\)\) \((4\ \[ExponentialE]\^\(\
\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\^4\ \
\[Lambda]\^\(9/2\)\ \((99 + 4\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((\(-11\) + \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\^2)\);\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RR\_\(Oscl, Cart\)[3, 
          0, \[Lambda]] = \(1\/\(1260\ \@\[Pi]\)\) \
\((\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + 
                  y\^2 + z\^2)\)\ \[Lambda]\^\(3/2\)\ \((105 - 2\ \((x\^2 + y\
\^2 + z\^2)\)\ \[Lambda]\ \((105 + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((\(-21\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(RR\_\(Oscl, Cart\)[3, 
          1, \[Lambda]] = \(1\/\(5670\ \@\[Pi]\)\) \
\((\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\
\^2 + z\^2)\)\^2\ \[Lambda]\^\(5/2\)\ \((315 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\ \((189 + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-27\) + 2\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\);\)\), \
"\[IndentingNewLine]", 
    \(\(RR\_\(Oscl, Cart\)[3, 
          2, \[Lambda]] = \(1\/\(31185\ \@\[Pi]\)\) \((\[ExponentialE]\^\(\(-\
\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\^3\ \
\[Lambda]\^\(7/2\)\ \((693 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((297 + \
2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-33\) + 2\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda])\))\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_\(Oscl, Cart\)[3, 
          3, \[Lambda]] = \(1\/\(405405\ \@\[Pi]\)\) \((2\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2 \
+ z\^2)\)\^4\ \[Lambda]\^\(9/2\)\ \((1287 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\ \((429 + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-39\) + 2\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\);\)\)}], "Input"],

Cell["Angular probability densities:", "Text"],

Cell[BoxData[{
    \(\(YY[0, 0] = 1\/\(4\ \[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(YY[1, 
          0] = \(3\ Cos[\[Theta]]\^2\)\/\(4\ \[Pi]\);\)\), "\
\[IndentingNewLine]", 
    \(\(YY[1, 
          1] = \(3\ Sin[\[Theta]]\^2\)\/\(8\ \[Pi]\);\)\), "\
\[IndentingNewLine]", 
    \(\(YY[2, 
          0] = \(5\ \((1 + 3\ Cos[2\ \[Theta]])\)\^2\)\/\(64\ \[Pi]\);\)\), "\
\[IndentingNewLine]", 
    \(\(YY[2, 
          1] = \(15\ Cos[\[Theta]]\^2\ Sin[\[Theta]]\^2\)\/\(8\ \[Pi]\);\)\), \
"\[IndentingNewLine]", 
    \(\(YY[2, 
          2] = \(15\ Sin[\[Theta]]\^4\)\/\(32\ \[Pi]\);\)\), "\
\[IndentingNewLine]", 
    \(\(YY[3, 
          0] = \(7\ \((3\ Cos[\[Theta]] + 5\ Cos[3\ \[Theta]])\)\^2\)\/\(256\ \
\[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(YY[3, 
          1] = \(21\ \((Sin[\[Theta]] + 5\ Sin[3\ \[Theta]])\)\^2\)\/\(1024\ \
\[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(YY[3, 
          2] = \(105\ Cos[\[Theta]]\^2\ Sin[\[Theta]]\^4\)\/\(32\ \
\[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(YY[3, 3] = \(35\ Sin[\[Theta]]\^6\)\/\(64\ \[Pi]\);\)\)}], "Input"],

Cell["Probability densities:", "Text"],

Cell[BoxData[{
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 0, 
          0, \[Lambda]] = \(1\/\(120\ \[Pi]\^\(3/2\)\)\) \((\[ExponentialE]\^\
\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(3/2\)\ \((15 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-5\) + \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\^2)\
\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 1, 
          0, \[Lambda]] = \(1\/\(140\ \[Pi]\^\(3/2\)\)\) \((\[ExponentialE]\^\
\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(5/2\)\ \((35 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-7\) + \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\^2)\
\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 1, 
          1, \[Lambda]] = \(1\/\(280\ \[Pi]\^\(3/2\)\)\) \((\[ExponentialE]\^\
\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2)\)\ \((x\^2 + 
                  y\^2 + z\^2)\)\ \[Lambda]\^\(5/2\)\ \((35 + 4\ \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda]\ \((\(-7\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 2, 
          0, \[Lambda]] = \(1\/\(1512\ \[Pi]\^\(3/2\)\)\) \
\((\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\
\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(7/2\)\ \((63 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-9\) + \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\^2)\
\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 2, 
          1, \[Lambda]] = \(1\/\(252\ \[Pi]\^\(3/2\)\)\) \((\[ExponentialE]\^\
\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + 
                  y\^2)\)\ z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(7/2\)\ \((63 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-9\) + \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\^2)\
\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 2, 
          2, \[Lambda]] = \(1\/\(1008\ \[Pi]\^\(3/2\)\)\) \
\((\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\
\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(7/2\)\ \((63 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-9\) + \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\^2)\
\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 3, 
          0, \[Lambda]] = \(1\/\(5940\ \[Pi]\^\(3/2\)\)\) \
\((\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ z\^2\ \((3\ \
\((x\^2 + y\^2)\) - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((99 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-11\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 3, 
          1, \[Lambda]] = \(1\/\(7920\ \[Pi]\^\(3/2\)\)\) \
\((\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + 
                  y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((99 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-11\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 3, 
          2, \[Lambda]] = \(1\/\(792\ \[Pi]\^\(3/2\)\)\) \((\[ExponentialE]\^\
\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2)\)\^2\ z\^2\ \
\((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((99 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-11\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 3, 
          3, \[Lambda]] = \(1\/\(4752\ \[Pi]\^\(3/2\)\)\) \
\((\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\
\^2)\)\^3\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((99 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-11\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\^2)\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 0, 
          
          0, \[Lambda]] = \(1\/\(16\ \[Pi]\^\(3/2\)\)\) \((35\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + 
                  y\^2 + z\^2)\)\ \[Lambda]\^\(3/2\)\ \((1 + 2\/105\ \((x\^2 \
+ y\^2 + z\^2)\)\ \[Lambda]\ \((\(-105\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\ \((21 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 1, 
          0, \[Lambda]] = \(1\/\(7560\ \[Pi]\^\(3/2\)\)\) \
\((\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ z\^2\ \
\((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(5/2\)\ \((315 - 2\ \((x\^2 + y\^2 + z\
\^2)\)\ \[Lambda]\ \((189 + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((\(-27\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 1, 
          1, \[Lambda]] = \(1\/\(15120\ \[Pi]\^\(3/2\)\)\) \((\[ExponentialE]\
\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2)\)\ \((x\^2 + 
                  y\^2 + z\^2)\)\ \[Lambda]\^\(5/2\)\ \((315 - 2\ \((x\^2 + y\
\^2 + z\^2)\)\ \[Lambda]\ \((189 + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((\(-27\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 2, 
          0, \[Lambda]] = \(1\/\(64\ \[Pi]\^\(3/2\)\)\) \((77\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2 \
+ z\^2)\)\^3\ \((2 - \(6\ z\^2\)\/\(x\^2 + y\^2 + z\^2\))\)\^2\ \
\[Lambda]\^\(7/2\)\ \((1 + 2\/693\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((\(-297\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((33 - 2\ \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 2, 
          1, \[Lambda]] = \(1\/\(8\ \[Pi]\^\(3/2\)\)\) \((231\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + 
                  y\^2)\)\ z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(7/2\)\ \((1 + 2\/693\ \((x\^2 + y\^2 \
+ z\^2)\)\ \[Lambda]\ \((\(-297\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((33 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 2, 
          2, \[Lambda]] = \(1\/\(32\ \[Pi]\^\(3/2\)\)\) \((231\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + \
y\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(7/2\)\ \((1 + 2\/693\ \((x\^2 + y\^2 \
+ z\^2)\)\ \[Lambda]\ \((\(-297\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((33 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 3, 
          0, \[Lambda]] = \(1\/\(40\ \[Pi]\^\(3/2\)\)\) \((143\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ z\^2\ \((3\ \
\((x\^2 + y\^2)\) - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((1 + \(1\/1287\) \((2\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-429\) + 2\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((39 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\))\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 3, 
          1, \[Lambda]] = \(1\/\(160\ \[Pi]\^\(3/2\)\)\) \((429\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + 
                  y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((1 + \(1\/1287\) \((2\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-429\) + 2\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((39 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\))\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 3, 
          2, \[Lambda]] = \(1\/\(16\ \[Pi]\^\(3/2\)\)\) \((429\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + \
y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((1 + \(1\/1287\) \((2\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-429\) + 2\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((39 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\))\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 3, 
          3, \[Lambda]] = \(1\/\(32\ \[Pi]\^\(3/2\)\)\) \((143\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + \
y\^2)\)\^3\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((1 + \(1\/1287\) \((2\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-429\) + 2\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((39 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\))\))\)\^2)\);\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2. Visualization of the radial probability densities, angular probability \
densities and probability densities of the three-dimensional quantum \
oscillator\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "Now we present visualizations of the radial wave functions, radial \
probability densities and probability densities of the two-dimensional \
quantum rotator.\nWe will obtain three-dimensional plots for radial and \
angular probability densities (product of these functions gives probability \
density), three-dimensional plots for probability densities (surface and \
density plots) for four cross-sectional profiles (defined by coordinate \
planes ",
  StyleBox["y0",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y3",
    FontSlant->"Italic"],
  ") of the three-dimensional quantum rotator.\nIn this file we will present \
visualizations in individual scales for states defined by given quantum \
numbers."
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox["Parameters of Plots:",
    FontWeight->"Bold"],
  "\n",
  StyleBox["2d Plots",
    FontWeight->"Bold"],
  "\n\t\tVariable Range: {x2dMin, x2dMax}\n\t\tPlot Range for 2d Plots: \
{PR2dMin, PR2dMax}\n\t\tImage Size for 2d Plots: {IS2dHorz, IS2dVert}\n\n",
  StyleBox["3d Plots",
    FontWeight->"Bold"],
  "\n\t\tVariable Range: {x3dMin, x3dMax, y3dMin, y3dMax}\n\t\tPlot Range for \
3d Plots: {PR3dMin, PR3dMax}\n\t\tPlot Points for 3d Plots: {N3d}\n\t\tImage \
Size for 3d Plots: {IS3DHorz, IS3DVert}\n\t\tViewPoint for 3d Plots: {VP1, \
VP2, VP3} or {WP1, WP2, WP3}"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(N3d = 100;\)\[IndentingNewLine]\), "\n", 
    \(\(ISAll3dHorz = 700;\)\), "\[IndentingNewLine]", 
    \(\(ISAll3dVert = 550;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(ISProf3dHorz = 700;\)\), "\[IndentingNewLine]", 
    \(\(ISProf3dVert = 550;\)\)}], "Input"],

Cell[CellGroupData[{

Cell[TextData[{
  "21) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 0\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\), "\[IndentingNewLine]", 
    \(\(y1 = \(-1\);\)\), "\[IndentingNewLine]", 
    \(\(y2 = \(-2\);\)\), "\[IndentingNewLine]", 
    \(\(y3 = \(-3\);\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.0525;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-4\);\)\), "\[IndentingNewLine]", 
    \(\(\(z3dMax = 4;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, \[Lambda]] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.09\), 
                0.09}, {\(-0.09\), 0.09}, {\(-0.09\), 
                0.09}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[0,0,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        ReplaceAll[
          RR\_\(Oscl, Cart\)[n\_rad, 
            l\_orb, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        If[z < 0, 0, 
          RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Oscl[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[2,0]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][2,0,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,0,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][2,0,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,0,0], y=0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], Anglar3dPlot[l\_orb, m\_azm, \[Lambda]], 
            Radial3dhf\_Oscl[n\_rad, l\_orb, y0]}, {WFunktion3d\_Oscl[n\_rad, 
              l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][2,0,0], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,0,0], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,0,0], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,0,0], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,0,0], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,0,0], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,0,0], y=-2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,0,0], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,0,0], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,0,0], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][2,0,0], y=0, -1, -2, -3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "22) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\), "\[IndentingNewLine]", 
    \(\(y1 = \(-1\);\)\), "\[IndentingNewLine]", 
    \(\(y2 = \(-2\);\)\), "\[IndentingNewLine]", 
    \(\(y3 = \(-3\);\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.65;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.155;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4.25\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4.25;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-4.25\);\)\), "\[IndentingNewLine]", 
    \(\(\(z3dMax = 4.25;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, \[Lambda]] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.13\), 
                0.13}, {\(-0.13\), 0.13}, {\(-0.25\), 
                0.25}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[1,0,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        ReplaceAll[
          RR\_\(Oscl, Cart\)[n\_rad, 
            l\_orb, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        If[z < 0, 0, 
          RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Oscl[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[2,1]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][2,1,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,1,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][2,1,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,1,0], y=0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], Anglar3dPlot[l\_orb, m\_azm, \[Lambda]], 
            Radial3dhf\_Oscl[n\_rad, l\_orb, y0]}, {WFunktion3d\_Oscl[n\_rad, 
              l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][2,1,0], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,1,0], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,1,0], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,1,0], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,1,0], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,1,0], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,1,0], y=-2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,1,0], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,1,0], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,1,0], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][2,1,0], y=0, -1, -2, -3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "23) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\), "\[IndentingNewLine]", 
    \(\(y1 = \(-1\);\)\), "\[IndentingNewLine]", 
    \(\(y2 = \(-2\);\)\), "\[IndentingNewLine]", 
    \(\(y3 = \(-3\);\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.075;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4.25\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4.25;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-4.25\);\)\), "\[IndentingNewLine]", 
    \(\(\(z3dMax = 4.25;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, \[Lambda]] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.125\), 
                0.125}, {\(-0.125\), 0.125}, {\(-0.125\), 
                0.125}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[1,1,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        ReplaceAll[
          RR\_\(Oscl, Cart\)[n\_rad, 
            l\_orb, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        If[z < 0, 0, 
          RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Oscl[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[2,1]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][2,1,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,1,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][2,1,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,1,1], y=0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], Anglar3dPlot[l\_orb, m\_azm, \[Lambda]], 
            Radial3dhf\_Oscl[n\_rad, l\_orb, y0]}, {WFunktion3d\_Oscl[n\_rad, 
              l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][2,1,1], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,1,1], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,1,1], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,1,1], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,1,1], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,1,1], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,1,1], y=-2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,1,1], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,1,1], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,1,1], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][2,1,1], y=0, -1, -2, -3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "24) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\), "\[IndentingNewLine]", 
    \(\(y1 = \(-1\);\)\), "\[IndentingNewLine]", 
    \(\(y2 = \(-2\);\)\), "\[IndentingNewLine]", 
    \(\(y3 = \(-3\);\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.25;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4.5\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4.5;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-4.5\);\)\), "\[IndentingNewLine]", 
    \(\(\(z3dMax = 4.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, \[Lambda]] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.2\), 
                0.2}, {\(-0.2\), 0.2}, {\(-0.4\), 
                0.4}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[2,0,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        ReplaceAll[
          RR\_\(Oscl, Cart\)[n\_rad, 
            l\_orb, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        If[z < 0, 0, 
          RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Oscl[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[2,2]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][2,2,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,2,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][2,2,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,2,0], y=0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], Anglar3dPlot[l\_orb, m\_azm, \[Lambda]], 
            Radial3dhf\_Oscl[n\_rad, l\_orb, y0]}, {WFunktion3d\_Oscl[n\_rad, 
              l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][2,2,0], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,2,0], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,2,0], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,2,0], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,2,0], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,2,0], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,2,0], y=-2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,2,0], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,2,0], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,2,0], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][2,2,0], y=0, -1, -2, -3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "25) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\), "\[IndentingNewLine]", 
    \(\(y1 = \(-1\);\)\), "\[IndentingNewLine]", 
    \(\(y2 = \(-2\);\)\), "\[IndentingNewLine]", 
    \(\(y3 = \(-3\);\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.09;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4.5\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4.5;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-4.5\);\)\), "\[IndentingNewLine]", 
    \(\(\(z3dMax = 4.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, \[Lambda]] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {40, 
              40}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.115\), 
                0.115}, {\(-0.115\), 0.115}, {\(-0.115\), 
                0.115}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[2,1,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        ReplaceAll[
          RR\_\(Oscl, Cart\)[n\_rad, 
            l\_orb, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        If[z < 0, 0, 
          RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Oscl[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[2,2]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][2,2,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,2,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][2,2,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,2,1], y=0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], Anglar3dPlot[l\_orb, m\_azm, \[Lambda]], 
            Radial3dhf\_Oscl[n\_rad, l\_orb, y0]}, {WFunktion3d\_Oscl[n\_rad, 
              l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][2,2,1], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,2,1], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,2,1], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,2,1], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,2,1], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,2,1], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,2,1], y=-2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,2,1], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,2,1], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,2,1], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][2,2,1], y=0, -1, -2, -3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "26) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 2;\)\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\), "\[IndentingNewLine]", 
    \(\(y1 = \(-1\);\)\), "\[IndentingNewLine]", 
    \(\(y2 = \(-2\);\)\), "\[IndentingNewLine]", 
    \(\(y3 = \(-3\);\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.09;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4.5\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4.5;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-4.5\);\)\), "\[IndentingNewLine]", 
    \(\(\(z3dMax = 4.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, \[Lambda]] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {40, 
              40}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.155\), 
                0.155}, {\(-0.155\), 0.155}, {\(-0.155\), 
                0.155}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[2,2,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        ReplaceAll[
          RR\_\(Oscl, Cart\)[n\_rad, 
            l\_orb, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        If[z < 0, 0, 
          RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Oscl[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[2,2]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][2,2,2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,2,2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][2,2,2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,2,2], y=0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], Anglar3dPlot[l\_orb, m\_azm, \[Lambda]], 
            Radial3dhf\_Oscl[n\_rad, l\_orb, y0]}, {WFunktion3d\_Oscl[n\_rad, 
              l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][2,2,2], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,2,2], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,2,2], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,2,2], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,2,2], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,2,2], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,2,2], y=-2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,2,2], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,2,2], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,2,2], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][2,2,2], y=0, -1, -2, -3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "27) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\), "\[IndentingNewLine]", 
    \(\(y1 = \(-1\);\)\), "\[IndentingNewLine]", 
    \(\(y2 = \(-2\);\)\), "\[IndentingNewLine]", 
    \(\(y3 = \(-3\);\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.345;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4.75\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4.75;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-4.75\);\)\), "\[IndentingNewLine]", 
    \(\(\(z3dMax = 4.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, \[Lambda]] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {36, 
              36}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.175\), 
                0.175}, {\(-0.175\), 0.175}, {\(-0.575\), 
                0.575}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[3,0,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        ReplaceAll[
          RR\_\(Oscl, Cart\)[n\_rad, 
            l\_orb, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        If[z < 0, 0, 
          RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Oscl[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[2,3]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][2,3,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,3,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][2,3,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,3,0], y=0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], Anglar3dPlot[l\_orb, m\_azm, \[Lambda]], 
            Radial3dhf\_Oscl[n\_rad, l\_orb, y0]}, {WFunktion3d\_Oscl[n\_rad, 
              l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][2,3,0], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,3,0], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,3,0], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,3,0], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,3,0], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,3,0], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,3,0], y=-2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,3,0], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,3,0], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,3,0], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][2,3,0], y=0, -1, -2, -3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "28) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\), "\[IndentingNewLine]", 
    \(\(y1 = \(-1\);\)\), "\[IndentingNewLine]", 
    \(\(y2 = \(-2\);\)\), "\[IndentingNewLine]", 
    \(\(y3 = \(-3\);\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.825;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.125;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4.75\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4.75;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-4.75\);\)\), "\[IndentingNewLine]", 
    \(\(\(z3dMax = 4.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, \[Lambda]] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {40, 
              40}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.185\), 
                0.185}, {\(-0.185\), 0.185}, {\(-0.185\), 
                0.185}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[3,1,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        ReplaceAll[
          RR\_\(Oscl, Cart\)[n\_rad, 
            l\_orb, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        If[z < 0, 0, 
          RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Oscl[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[2,3]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][2,3,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,3,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][2,3,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,3,1], y=0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], Anglar3dPlot[l\_orb, m\_azm, \[Lambda]], 
            Radial3dhf\_Oscl[n\_rad, l\_orb, y0]}, {WFunktion3d\_Oscl[n\_rad, 
              l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][2,3,1], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,3,1], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,3,1], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,3,1], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,3,1], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,3,1], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,3,1], y=-2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,3,1], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,3,1], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,3,1], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][2,3,1], y=0, -1, -2, -3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "29) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 2;\)\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\), "\[IndentingNewLine]", 
    \(\(y1 = \(-1\);\)\), "\[IndentingNewLine]", 
    \(\(y2 = \(-2\);\)\), "\[IndentingNewLine]", 
    \(\(y3 = \(-3\);\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.825;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.095;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4.75\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4.75;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-4.75\);\)\), "\[IndentingNewLine]", 
    \(\(\(z3dMax = 4.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, \[Lambda]] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {36, 
              36}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.14\), 
                0.14}, {\(-0.14\), 0.14}, {\(-0.14\), 
                0.14}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[3,2,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        ReplaceAll[
          RR\_\(Oscl, Cart\)[n\_rad, 
            l\_orb, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        If[z < 0, 0, 
          RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Oscl[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[2,3]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][2,3,2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,3,2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][2,3,2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,3,2], y=0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], Anglar3dPlot[l\_orb, m\_azm, \[Lambda]], 
            Radial3dhf\_Oscl[n\_rad, l\_orb, y0]}, {WFunktion3d\_Oscl[n\_rad, 
              l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][2,3,2], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,3,2], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,3,2], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,3,2], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,3,2], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,3,2], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,3,2], y=-2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,3,2], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,3,2], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,3,2], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][2,3,2], y=0, -1, -2, -3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "30) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 3\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 3;\)\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\), "\[IndentingNewLine]", 
    \(\(y1 = \(-1\);\)\), "\[IndentingNewLine]", 
    \(\(y2 = \(-2\);\)\), "\[IndentingNewLine]", 
    \(\(y3 = \(-3\);\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.825;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.11;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4.75\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4.75;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-4.75\);\)\), "\[IndentingNewLine]", 
    \(\(\(z3dMax = 4.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, \[Lambda]] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {36, 
              36}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.183\), 
                0.183}, {\(-0.183\), 0.183}, {\(-0.183\), 
                0.183}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[3,3,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        ReplaceAll[
          RR\_\(Oscl, Cart\)[n\_rad, 
            l\_orb, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        If[z < 0, 0, 
          RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Oscl[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[2,3]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][2,3,3], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,3,3], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][2,3,3], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,3,3], y=0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], Anglar3dPlot[l\_orb, m\_azm, \[Lambda]], 
            Radial3dhf\_Oscl[n\_rad, l\_orb, y0]}, {WFunktion3d\_Oscl[n\_rad, 
              l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][2,3,3], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,3,3], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,3,3], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,3,3], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,3,3], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,3,3], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,3,3], y=-2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,3,3], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,3,3], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][2,3,3], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][2,3,3], y=0, -1, -2, -3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "31) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 0\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\), "\[IndentingNewLine]", 
    \(\(y1 = \(-1\);\)\), "\[IndentingNewLine]", 
    \(\(y2 = \(-2\);\)\), "\[IndentingNewLine]", 
    \(\(y3 = \(-3\);\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.0475;\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4.75\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4.75;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-4.75\);\)\), "\[IndentingNewLine]", 
    \(\(\(z3dMax = 4.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, \[Lambda]] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.09\), 
                0.09}, {\(-0.09\), 0.09}, {\(-0.09\), 
                0.09}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[0,0,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        ReplaceAll[
          RR\_\(Oscl, Cart\)[n\_rad, 
            l\_orb, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        If[z < 0, 0, 
          RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Oscl[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[3,0]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][3,0,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,0,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][3,0,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,0,0], y=0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], Anglar3dPlot[l\_orb, m\_azm, \[Lambda]], 
            Radial3dhf\_Oscl[n\_rad, l\_orb, y0]}, {WFunktion3d\_Oscl[n\_rad, 
              l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][3,0,0], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,0,0], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,0,0], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,0,0], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,0,0], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,0,0], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,0,0], y=-2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,0,0], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,0,0], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,0,0], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][3,0,0], y=0, -1, -2, -3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "32) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\), "\[IndentingNewLine]", 
    \(\(y1 = \(-1\);\)\), "\[IndentingNewLine]", 
    \(\(y2 = \(-2\);\)\), "\[IndentingNewLine]", 
    \(\(y3 = \(-3\);\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.65;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.145;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4.75\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4.75;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-4.75\);\)\), "\[IndentingNewLine]", 
    \(\(\(z3dMax = 4.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, \[Lambda]] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.13\), 
                0.13}, {\(-0.13\), 0.13}, {\(-0.25\), 
                0.25}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[1,0,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        ReplaceAll[
          RR\_\(Oscl, Cart\)[n\_rad, 
            l\_orb, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        If[z < 0, 0, 
          RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Oscl[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[3,1]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][3,1,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,1,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][3,1,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,1,0], y=0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], Anglar3dPlot[l\_orb, m\_azm, \[Lambda]], 
            Radial3dhf\_Oscl[n\_rad, l\_orb, y0]}, {WFunktion3d\_Oscl[n\_rad, 
              l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][3,1,0], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,1,0], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,1,0], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,1,0], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,1,0], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,1,0], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,1,0], y=-2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,1,0], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,1,0], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,1,0], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][3,1,0], y=0, -1, -2, -3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "33) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\), "\[IndentingNewLine]", 
    \(\(y1 = \(-1\);\)\), "\[IndentingNewLine]", 
    \(\(y2 = \(-2\);\)\), "\[IndentingNewLine]", 
    \(\(y3 = \(-3\);\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.0685;\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-5\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 5;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-5\);\)\), "\[IndentingNewLine]", 
    \(\(\(z3dMax = 5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, \[Lambda]] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.125\), 
                0.125}, {\(-0.125\), 0.125}, {\(-0.125\), 
                0.125}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[1,1,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        ReplaceAll[
          RR\_\(Oscl, Cart\)[n\_rad, 
            l\_orb, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        If[z < 0, 0, 
          RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Oscl[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[3,1]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][3,1,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,1,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][3,1,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,1,1], y=0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], Anglar3dPlot[l\_orb, m\_azm, \[Lambda]], 
            Radial3dhf\_Oscl[n\_rad, l\_orb, y0]}, {WFunktion3d\_Oscl[n\_rad, 
              l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][3,1,1], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,1,1], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,1,1], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,1,1], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,1,1], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,1,1], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,1,1], y=-2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,1,1], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,1,1], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,1,1], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][3,1,1], y=0, -1, -2, -3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "34) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\), "\[IndentingNewLine]", 
    \(\(y1 = \(-1\);\)\), "\[IndentingNewLine]", 
    \(\(y2 = \(-2\);\)\), "\[IndentingNewLine]", 
    \(\(y3 = \(-3\);\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.235;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-5\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 5;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-5\);\)\), "\[IndentingNewLine]", 
    \(\(\(z3dMax = 5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, \[Lambda]] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.2\), 
                0.2}, {\(-0.2\), 0.2}, {\(-0.4\), 
                0.4}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[2,0,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        ReplaceAll[
          RR\_\(Oscl, Cart\)[n\_rad, 
            l\_orb, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        If[z < 0, 0, 
          RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Oscl[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[3,2]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][3,2,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,2,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][3,2,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,2,0], y=0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], Anglar3dPlot[l\_orb, m\_azm, \[Lambda]], 
            Radial3dhf\_Oscl[n\_rad, l\_orb, y0]}, {WFunktion3d\_Oscl[n\_rad, 
              l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][3,2,0], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,2,0], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,2,0], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,2,0], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,2,0], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,2,0], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,2,0], y=-2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,2,0], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,2,0], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,2,0], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][3,2,0], y=0, -1, -2, -3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "35) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\), "\[IndentingNewLine]", 
    \(\(y1 = \(-1\);\)\), "\[IndentingNewLine]", 
    \(\(y2 = \(-2\);\)\), "\[IndentingNewLine]", 
    \(\(y3 = \(-3\);\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.0875;\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-5\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 5;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-5\);\)\), "\[IndentingNewLine]", 
    \(\(\(z3dMax = 5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, \[Lambda]] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {40, 
              40}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.115\), 
                0.115}, {\(-0.115\), 0.115}, {\(-0.115\), 
                0.115}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[2,1,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        ReplaceAll[
          RR\_\(Oscl, Cart\)[n\_rad, 
            l\_orb, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        If[z < 0, 0, 
          RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Oscl[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[3,2]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][3,2,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,2,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][3,2,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,2,1], y=0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], Anglar3dPlot[l\_orb, m\_azm, \[Lambda]], 
            Radial3dhf\_Oscl[n\_rad, l\_orb, y0]}, {WFunktion3d\_Oscl[n\_rad, 
              l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][3,2,1], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,2,1], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,2,1], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,2,1], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,2,1], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,2,1], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,2,1], y=-2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,2,1], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,2,1], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,2,1], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][3,2,1], y=0, -1, -2, -3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "36) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 2;\)\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\), "\[IndentingNewLine]", 
    \(\(y1 = \(-1\);\)\), "\[IndentingNewLine]", 
    \(\(y2 = \(-2\);\)\), "\[IndentingNewLine]", 
    \(\(y3 = \(-3\);\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.0865;\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-5\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 5;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-5\);\)\), "\[IndentingNewLine]", 
    \(\(\(z3dMax = 5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, \[Lambda]] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {40, 
              40}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.155\), 
                0.155}, {\(-0.155\), 0.155}, {\(-0.155\), 
                0.155}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[2,2,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        ReplaceAll[
          RR\_\(Oscl, Cart\)[n\_rad, 
            l\_orb, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        If[z < 0, 0, 
          RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Oscl[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[3,2]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][3,2,2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,2,2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][3,2,2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,2,2], y=0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], Anglar3dPlot[l\_orb, m\_azm, \[Lambda]], 
            Radial3dhf\_Oscl[n\_rad, l\_orb, y0]}, {WFunktion3d\_Oscl[n\_rad, 
              l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][3,2,2], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,2,2], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][2,2,2], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,2,2], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,2,2], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,2,2], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,2,2], y=-2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,2,2], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,2,2], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,2,2], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][3,2,2], y=0, -1, -2, -3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "37) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\), "\[IndentingNewLine]", 
    \(\(y1 = \(-1\);\)\), "\[IndentingNewLine]", 
    \(\(y2 = \(-2\);\)\), "\[IndentingNewLine]", 
    \(\(y3 = \(-3\);\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.75;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.315;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-5.25\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 5.25;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-5.25\);\)\), "\[IndentingNewLine]", 
    \(\(\(z3dMax = 5.25;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, \[Lambda]] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {36, 
              36}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.175\), 
                0.175}, {\(-0.175\), 0.175}, {\(-0.575\), 
                0.575}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[3,0,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        ReplaceAll[
          RR\_\(Oscl, Cart\)[n\_rad, 
            l\_orb, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        If[z < 0, 0, 
          RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Oscl[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[3,3]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][3,3,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,3,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][3,3,0], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,3,0], y=0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], Anglar3dPlot[l\_orb, m\_azm, \[Lambda]], 
            Radial3dhf\_Oscl[n\_rad, l\_orb, y0]}, {WFunktion3d\_Oscl[n\_rad, 
              l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][3,3,0], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,3,0], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,3,0], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,3,0], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,3,0], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,3,0], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,3,0], y=-2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,3,0], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,3,0], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,3,0], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][3,3,0], y=0, -1, -2, -3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "38) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\), "\[IndentingNewLine]", 
    \(\(y1 = \(-1\);\)\), "\[IndentingNewLine]", 
    \(\(y2 = \(-2\);\)\), "\[IndentingNewLine]", 
    \(\(y3 = \(-3\);\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.825;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.115;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-5\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 5;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-5\);\)\), "\[IndentingNewLine]", 
    \(\(\(z3dMax = 5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, \[Lambda]] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {40, 
              40}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.185\), 
                0.185}, {\(-0.185\), 0.185}, {\(-0.185\), 
                0.185}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[3,1,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        ReplaceAll[
          RR\_\(Oscl, Cart\)[n\_rad, 
            l\_orb, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        If[z < 0, 0, 
          RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Oscl[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[3,3]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][3,3,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,3,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][3,3,1], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,3,1], y=0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], Anglar3dPlot[l\_orb, m\_azm, \[Lambda]], 
            Radial3dhf\_Oscl[n\_rad, l\_orb, y0]}, {WFunktion3d\_Oscl[n\_rad, 
              l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][3,3,1], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,3,1], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,3,1], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,3,1], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,3,1], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,3,1], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,3,1], y=-2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,3,1], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,3,1], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,3,1], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][3,3,1], y=0, -1, -2, -3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "39) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 2;\)\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\), "\[IndentingNewLine]", 
    \(\(y1 = \(-1\);\)\), "\[IndentingNewLine]", 
    \(\(y2 = \(-2\);\)\), "\[IndentingNewLine]", 
    \(\(y3 = \(-3\);\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.825;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.09;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-5\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 5;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-5\);\)\), "\[IndentingNewLine]", 
    \(\(\(z3dMax = 5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, \[Lambda]] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {36, 
              36}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.14\), 
                0.14}, {\(-0.14\), 0.14}, {\(-0.14\), 
                0.14}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[3,2,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        ReplaceAll[
          RR\_\(Oscl, Cart\)[n\_rad, 
            l\_orb, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        If[z < 0, 0, 
          RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Oscl[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[3,3]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][3,3,2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,3,2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][3,3,2], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,3,2], y=0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], Anglar3dPlot[l\_orb, m\_azm, \[Lambda]], 
            Radial3dhf\_Oscl[n\_rad, l\_orb, y0]}, {WFunktion3d\_Oscl[n\_rad, 
              l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][3,3,2], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,3,2], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,3,2], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,3,2], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,3,2], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,3,2], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,3,2], y=-2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,3,2], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,3,2], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,3,2], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][3,3,2], y=0, -1, -2, -3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "40) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 3\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 3;\)\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\), "\[IndentingNewLine]", 
    \(\(y1 = \(-1\);\)\), "\[IndentingNewLine]", 
    \(\(y2 = \(-2\);\)\), "\[IndentingNewLine]", 
    \(\(y3 = \(-3\);\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(PR2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.825;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(PR3dMax = 
        0.1;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-5.25\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 5.25;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-5.25\);\)\), "\[IndentingNewLine]", 
    \(\(\(z3dMax = 5.25;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Anglar3dPlot[l\_orb, m\_azm, \[Lambda]] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]] YY[l\_orb, m\_azm], 
            Cos[\[Theta]] YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0/2, Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {36, 
              36}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.183\), 
                0.183}, {\(-0.183\), 0.183}, {\(-0.183\), 
                0.183}}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Angular density \
|Y[3,3,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        ReplaceAll[
          RR\_\(Oscl, Cart\)[n\_rad, 
            l\_orb, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], y0] = 
        If[z < 0, 0, 
          RRy\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Radial3dhf\_Oscl[n\_rad, l\_orb, y0] = 
        Plot3D[RRhf\_\(Oscl, Cart\)[n\_rad, l\_orb, \[Lambda], 
            y0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {z, z3dMin, 
            z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.87, 0.87], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ \(-1.825\), \ 
              1.25}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \
radial density RR[3,3]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface profile of \
\[Psi]\[Psi][3,3,3], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,3,3], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y0] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \[Psi]\
\[Psi][3,3,3], y=0\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,3,3], y=0\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], Anglar3dPlot[l\_orb, m\_azm, \[Lambda]], 
            Radial3dhf\_Oscl[n\_rad, l\_orb, y0]}, {WFunktion3d\_Oscl[n\_rad, 
              l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dVW\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y0], 
            WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0]}}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Set of functions \
composing wave function \[Psi]\[Psi][3,3,3], y=0\>"]\)\(\[IndentingNewLine]\)\
\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y1}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,3,3], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.45] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,3,3], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y1] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y1]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y1], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,3,3], y=-1\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y2}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,3,3], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.6] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,3,3], y=-2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y2] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y2]];\)\), "\[IndentingNewLine]", 
    \(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y2], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,3,3], y=-2\>"];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y3}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, \ 
              4}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,3,3], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        DensityPlot[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.75] &)\), \[IndentingNewLine]PlotLabel \[Rule] "\<Density of \
\[Psi]\[Psi][3,3,3], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
          y3] = If[x < 0, 
          0, \[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], 
            y3]];\)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y3] = 
        Plot3D[\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda], y3], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background -> 
            RGBColor[1, 0.9, 0.7], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {\(-1.75\), \ \(-1.5\), \ 
              3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Surface of \[Psi]\
\[Psi][3,3,3], y=-3\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y1], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], y2], 
            WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}, {WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y0], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y1], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y2], WFunktion3dhf\_Oscl[n\_rad, l\_orb, m\_azm, \[Lambda], 
              y3]}}], \[IndentingNewLine]ImageSize \[Rule] {ISProf3dHorz, 
          ISProf3dVert}, 
      PlotLabel \[Rule] "\<Set of profiles of wave function \
\[Psi]\[Psi][3,3,3], y=0, -1, -2, -3\>", 
      Background \[Rule] RGBColor[0.0, 0.75, 0.0]]\)}], "Input"],

Cell["", "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1016, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
CellLabelAutoDelete->True,
Magnification->1.25,
StyleDefinitions -> "Classroom1.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 254, 8, 93, "Subtitle"],
Cell[2527, 82, 318, 10, 125, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2870, 96, 188, 5, 119, "Section"],
Cell[3061, 103, 165, 5, 56, "Text"],
Cell[3229, 110, 196, 8, 72, "NumberedEquation"],
Cell[3428, 120, 121, 2, 56, "Text"],
Cell[3552, 124, 115, 5, 52, "NumberedEquation"],
Cell[3670, 131, 132, 4, 56, "Text"],
Cell[3805, 137, 96, 2, 50, "NumberedEquation"],
Cell[3904, 141, 145, 4, 56, "Text"],
Cell[4052, 147, 61, 1, 63, "Input"],
Cell[4116, 150, 256, 6, 80, "Text"],
Cell[4375, 158, 45, 0, 56, "Text"],
Cell[4423, 160, 3048, 51, 1092, "Input"],
Cell[7474, 213, 46, 0, 56, "Text"],
Cell[7523, 215, 1079, 26, 588, "Input"],
Cell[8605, 243, 38, 0, 56, "Text"],
Cell[8646, 245, 8876, 146, 2686, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17559, 396, 231, 6, 119, "Section"],
Cell[17793, 404, 842, 22, 200, "Text"],
Cell[18638, 428, 666, 17, 452, "Text"],
Cell[19307, 447, 296, 5, 213, "Input"],

Cell[CellGroupData[{
Cell[19628, 456, 203, 11, 89, "Subsection"],
Cell[19834, 469, 17774, 294, 6086, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37645, 768, 203, 11, 89, "Subsection"],
Cell[37851, 781, 17802, 295, 6111, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[55690, 1081, 203, 11, 89, "Subsection"],
Cell[55896, 1094, 17808, 295, 6111, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[73741, 1394, 203, 11, 89, "Subsection"],
Cell[73947, 1407, 17791, 295, 6111, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[91775, 1707, 203, 11, 89, "Subsection"],
Cell[91981, 1720, 17786, 294, 6086, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[109804, 2019, 203, 11, 89, "Subsection"],
Cell[110010, 2032, 17803, 295, 6111, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[127850, 2332, 203, 11, 89, "Subsection"],
Cell[128056, 2345, 17808, 295, 6111, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[145901, 2645, 203, 11, 89, "Subsection"],
Cell[146107, 2658, 17809, 295, 6111, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[163953, 2958, 203, 11, 89, "Subsection"],
Cell[164159, 2971, 17803, 295, 6111, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[181999, 3271, 203, 11, 89, "Subsection"],
Cell[182205, 3284, 17808, 295, 6111, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[200050, 3584, 203, 11, 89, "Subsection"],
Cell[200256, 3597, 17803, 295, 6111, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[218096, 3897, 203, 11, 89, "Subsection"],
Cell[218302, 3910, 17802, 295, 6111, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[236141, 4210, 203, 11, 89, "Subsection"],
Cell[236347, 4223, 17797, 295, 6111, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[254181, 4523, 203, 11, 89, "Subsection"],
Cell[254387, 4536, 17784, 295, 6111, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[272208, 4836, 203, 11, 89, "Subsection"],
Cell[272414, 4849, 17797, 295, 6111, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[290248, 5149, 203, 11, 89, "Subsection"],
Cell[290454, 5162, 17797, 295, 6111, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[308288, 5462, 203, 11, 89, "Subsection"],
Cell[308494, 5475, 17808, 295, 6111, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[326339, 5775, 203, 11, 89, "Subsection"],
Cell[326545, 5788, 17797, 295, 6111, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[344379, 6088, 203, 11, 89, "Subsection"],
Cell[344585, 6101, 17790, 295, 6111, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[362412, 6401, 203, 11, 89, "Subsection"],
Cell[362618, 6414, 17807, 295, 6111, "Input"],
Cell[380428, 6711, 16, 0, 56, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

