(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    187152,       3856]*)
(*NotebookOutlinePosition[    187881,       3881]*)
(*  CellTagsIndexPosition[    187837,       3877]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Part ",
    FontWeight->"Bold"],
  StyleBox["2. Quantum Isotropic Oscillator",
    FontWeight->"Bold"],
  "\n2.3. Three-Dimensional Isotropic Quantum Oscillator"
}], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
2.3.10. Comparative visualization of the Probability Densities of the \
Three-Dimensional Quantum Oscillator for Different Values of Oscillator \
Parameter\
\>", "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
1. Probability densities of the three-dimensional quantum oscillator for \
different values of oscillator parameter\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Now we can compare quantum states of the three-dimensional quantum oscillator \
for different values of oscillator parameter \[Lambda] characterizing \
oscillator frequency and mass:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(\[Lambda] = \(\(\ \)\(\(m\_0\) \[Omega]\)\)\/\[HBar]\)], \
"NumberedEquation",
  TextAlignment->Center],

Cell[TextData[{
  "Determine two ",
  "different values",
  " parameters ",
  StyleBox["\[Lambda]",
    FontSlant->"Italic"],
  " and ",
  StyleBox["\[CapitalLambda]",
    FontSlant->"Italic"],
  " of the three-dimensional quantum oscillator:"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(\[Lambda] = 1;\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalLambda] = 3/2;\)\ \)}], "Input"],

Cell["\<\
Consider some states of the three-dimensional quantum oscillator defined by \
quantum numbers:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  Cell[BoxData[
      \(n\_rad = 0, 1, 2, 3\)],
    FontSlant->"Italic"],
  ",\n",
  Cell[BoxData[
      \(l\_orb = 0, 1, 2, 3\)],
    FontSlant->"Italic"]
}], "NumberedEquation"],

Cell["<< Graphics`FilledPlot`", "Input"],

Cell[TextData[{
  "Probability densities of the three-dimensional quantum oscillator for \
quantum numbers (1) and oscillator parameter ",
  StyleBox["\[Lambda]",
    FontSlant->"Italic"],
  " are:"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 0, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(3/2\)\)\/\[Pi]\^\(3/2\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 1, 
          0, \[Lambda]] = \(2\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\
\)\ \[Lambda]\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(5/2\)\)\/\[Pi]\^\(3/2\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 1, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(5/2\)\)\/\[Pi]\^\(3/2\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 2, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(7/2\)\)\/\(3\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 2, 
          1, \[Lambda]] = \(2\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\
\)\ \[Lambda]\)\ \((x\^2 + y\^2)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\
\^\(7/2\)\)\/\[Pi]\^\(3/2\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 2, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(7/2\
\)\)\/\(2\ \[Pi]\^\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 3, 
          0, \[Lambda]] = \(2\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\
\)\ \[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\ \((3\ \((x\^2 + y\^2)\)\ z - 2\ \
z\^3)\)\^2\ \[Lambda]\^\(9/2\)\)\/\(15\ \[Pi]\^\(3/2\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 3, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda]\^\(9/2\)\)\/\(10\ \[Pi]\^\(3/2\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 3, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda]\^\(9/2\)\)\/\[Pi]\^\(3/2\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[0, 3, 
          3, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(9/2\
\)\)\/\(6\ \[Pi]\^\(3/2\)\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 0, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(3/2\)\ \((3 - 2\ \((x\^2 \
+ y\^2 + z\^2)\)\ \[Lambda])\)\^2\)\/\(6\ \[Pi]\^\(3/2\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 1, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
\[Lambda]\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\^\(5/2\)\ \((5 - 2\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\)\^2\)\/\(5\ \[Pi]\^\(3/2\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 1, 
          1, \[Lambda]] = \(1\/\(10\ \[Pi]\^\(3/2\)\)\) \
\((\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + 
                  y\^2)\)\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(5/2\)\ \((5 - 2\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 2, 
          0, \[Lambda]] = \(1\/\(42\ \[Pi]\^\(3/2\)\)\) \
\((\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\
\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(7/2\)\ \((7 - 2\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 2, 
          1, \[Lambda]] = \(1\/\(7\ \[Pi]\^\(3/2\)\)\) \((\[ExponentialE]\^\(\
\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + 
                  y\^2)\)\ z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(7/2\)\ \((7 - 2\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 2, 
          2, \[Lambda]] = \(1\/\(28\ \[Pi]\^\(3/2\)\)\) \
\((\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\
\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(7/2\)\ \((7 - 2\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 3, 
          0, \[Lambda]] = \(1\/\(135\ \[Pi]\^\(3/2\)\)\) \((\[ExponentialE]\^\
\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ z\^2\ \((3\ \((x\^2 + y\^2)\) - \
2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((9 - 2\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 3, 
          1, \[Lambda]] = \(1\/\(180\ \[Pi]\^\(3/2\)\)\) \((\[ExponentialE]\^\
\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + 
                  y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((9 - 2\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 3, 
          2, \[Lambda]] = \(1\/\(18\ \[Pi]\^\(3/2\)\)\) \
\((\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\
\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((9 - 2\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda])\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[1, 3, 
          3, \[Lambda]] = \(1\/\(108\ \[Pi]\^\(3/2\)\)\) \((\[ExponentialE]\^\
\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2)\)\^3\ \((x\^2 + 
                  y\^2 + z\^2)\)\ \[Lambda]\^\(9/2\)\ \((9 - 2\ \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda])\)\^2)\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 0, 
          
          0, \[Lambda]] = \(1\/\(120\ \[Pi]\^\(3/2\)\)\) \((\[ExponentialE]\^\
\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(3/2\)\ \((15 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-5\) + \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\^2)\
\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 1, 
          0, \[Lambda]] = \(1\/\(140\ \[Pi]\^\(3/2\)\)\) \((\[ExponentialE]\^\
\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(5/2\)\ \((35 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-7\) + \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\^2)\
\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 1, 
          1, \[Lambda]] = \(1\/\(280\ \[Pi]\^\(3/2\)\)\) \((\[ExponentialE]\^\
\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2)\)\ \((x\^2 + 
                  y\^2 + z\^2)\)\ \[Lambda]\^\(5/2\)\ \((35 + 4\ \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda]\ \((\(-7\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 2, 
          0, \[Lambda]] = \(1\/\(1512\ \[Pi]\^\(3/2\)\)\) \
\((\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\
\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(7/2\)\ \((63 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-9\) + \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\^2)\
\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 2, 
          1, \[Lambda]] = \(1\/\(252\ \[Pi]\^\(3/2\)\)\) \((\[ExponentialE]\^\
\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + 
                  y\^2)\)\ z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(7/2\)\ \((63 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-9\) + \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\^2)\
\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 2, 
          2, \[Lambda]] = \(1\/\(1008\ \[Pi]\^\(3/2\)\)\) \
\((\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\
\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(7/2\)\ \((63 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-9\) + \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\)\^2)\
\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 3, 
          0, \[Lambda]] = \(1\/\(5940\ \[Pi]\^\(3/2\)\)\) \
\((\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ z\^2\ \((3\ \
\((x\^2 + y\^2)\) - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((99 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-11\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 3, 
          1, \[Lambda]] = \(1\/\(7920\ \[Pi]\^\(3/2\)\)\) \
\((\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + 
                  y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((99 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-11\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 3, 
          2, \[Lambda]] = \(1\/\(792\ \[Pi]\^\(3/2\)\)\) \((\[ExponentialE]\^\
\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2)\)\^2\ z\^2\ \
\((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((99 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-11\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[2, 3, 
          3, \[Lambda]] = \(1\/\(4752\ \[Pi]\^\(3/2\)\)\) \
\((\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\
\^2)\)\^3\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((99 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((\(-11\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\)\^2)\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 0, 
          0, \[Lambda]] = \(1\/\(16\ \[Pi]\^\(3/2\)\)\) \((35\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + 
                  y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(3/2\)\ \((1 + 2\/105\ \((x\^2 + y\^2 \
+ z\^2)\)\ \[Lambda]\ \((\(-105\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((21 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 1, 
          0, \[Lambda]] = \(1\/\(7560\ \[Pi]\^\(3/2\)\)\) \
\((\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ z\^2\ \
\((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(5/2\)\ \((315 - 2\ \((x\^2 + y\^2 + z\
\^2)\)\ \[Lambda]\ \((189 + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((\(-27\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 1, 
          1, \[Lambda]] = \(1\/\(15120\ \[Pi]\^\(3/2\)\)\) \((\[ExponentialE]\
\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2)\)\ \((x\^2 + 
                  y\^2 + z\^2)\)\ \[Lambda]\^\(5/2\)\ \((315 - 2\ \((x\^2 + y\
\^2 + z\^2)\)\ \[Lambda]\ \((189 + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((\(-27\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 2, 
          0, \[Lambda]] = \(1\/\(64\ \[Pi]\^\(3/2\)\)\) \((77\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + y\^2 \
+ z\^2)\)\^3\ \((2 - \(6\ z\^2\)\/\(x\^2 + y\^2 + z\^2\))\)\^2\ \
\[Lambda]\^\(7/2\)\ \((1 + 2\/693\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((\(-297\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((33 - 2\ \((x\^2 + \
y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 2, 
          1, \[Lambda]] = \(1\/\(8\ \[Pi]\^\(3/2\)\)\) \((231\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + 
                  y\^2)\)\ z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(7/2\)\ \((1 + 2\/693\ \((x\^2 + y\^2 \
+ z\^2)\)\ \[Lambda]\ \((\(-297\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((33 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 2, 
          2, \[Lambda]] = \(1\/\(32\ \[Pi]\^\(3/2\)\)\) \((231\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + \
y\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(7/2\)\ \((1 + 2\/693\ \((x\^2 + y\^2 \
+ z\^2)\)\ \[Lambda]\ \((\(-297\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \
\((33 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[Lambda])\))\))\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 3, 
          0, \[Lambda]] = \(1\/\(40\ \[Pi]\^\(3/2\)\)\) \((143\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ z\^2\ \((3\ \
\((x\^2 + y\^2)\) - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((1 + \(1\/1287\) \((2\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-429\) + 2\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((39 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\))\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 3, 
          1, \[Lambda]] = \(1\/\(160\ \[Pi]\^\(3/2\)\)\) \((429\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + 
                  y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((1 + \(1\/1287\) \((2\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-429\) + 2\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((39 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\))\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 3, 
          2, \[Lambda]] = \(1\/\(16\ \[Pi]\^\(3/2\)\)\) \((429\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + \
y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((1 + \(1\/1287\) \((2\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-429\) + 2\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((39 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\))\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[3, 3, 
          3, \[Lambda]] = \(1\/\(32\ \[Pi]\^\(3/2\)\)\) \((143\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[Lambda]\)\ \((x\^2 + \
y\^2)\)\^3\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[Lambda]\^\(9/2\)\ \((1 + \(1\/1287\) \((2\ \
\((x\^2 + y\^2 + z\^2)\)\ \[Lambda]\ \((\(-429\) + 2\ \((x\^2 + y\^2 + \
z\^2)\)\ \[Lambda]\ \((39 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[Lambda])\))\))\))\)\^2)\);\)\)}], "Input"],

Cell[TextData[{
  "Probability densities of the three-dimensional quantum oscillator for \
quantum numbers (1) and oscillator parameter ",
  StyleBox["\[CapitalLambda]",
    FontSlant->"Italic"],
  " are:"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[0, 0, 
          0, \[CapitalLambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + \
z\^2)\)\)\ \[CapitalLambda]\)\ \((x\^2 + y\^2 + z\^2)\)\ \
\[CapitalLambda]\^\(3/2\)\)\/\[Pi]\^\(3/2\);\)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[0, 1, 
          0, \[CapitalLambda]] = \(2\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + \
z\^2)\)\)\ \[CapitalLambda]\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[CapitalLambda]\^\(5/2\)\)\/\[Pi]\^\(3/2\);\)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[0, 1, 
          1, \[CapitalLambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + \
z\^2)\)\)\ \[CapitalLambda]\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\ \
\[CapitalLambda]\^\(5/2\)\)\/\[Pi]\^\(3/2\);\)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[0, 2, 
          0, \[CapitalLambda]] = \(1\/\(3\ \[Pi]\^\(3/2\)\)\) \((\
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[CapitalLambda]\)\ \((x\^2 \
+ y\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[CapitalLambda]\^\(7/2\))\);\)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[0, 2, 
          1, \[CapitalLambda]] = \(2\ \[ExponentialE]\^\(\(-\((x\^2 + y\^2 + \
z\^2)\)\)\ \[CapitalLambda]\)\ \((x\^2 + y\^2)\)\ z\^2\ \((x\^2 + y\^2 + \
z\^2)\)\ \[CapitalLambda]\^\(7/2\)\)\/\[Pi]\^\(3/2\);\)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[0, 2, 
          2, \[CapitalLambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + \
z\^2)\)\)\ \[CapitalLambda]\)\ \((x\^2 + y\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\
\ \[CapitalLambda]\^\(7/2\)\)\/\(2\ \[Pi]\^\(3/2\)\);\)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[0, 3, 
          0, \[CapitalLambda]] = \(1\/\(15\ \[Pi]\^\(3/2\)\)\) \((2\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[CapitalLambda]\)\ \((x\^2 \
+ y\^2 + z\^2)\)\ \((3\ \((x\^2 + y\^2)\)\ z - 2\ z\^3)\)\^2\ \
\[CapitalLambda]\^\(9/2\))\);\)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[0, 3, 
          1, \[CapitalLambda]] = \(1\/\(10\ \[Pi]\^\(3/2\)\)\) \((\
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[CapitalLambda]\)\ \((x\^2 \
+ y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[CapitalLambda]\^\(9/2\))\);\)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[0, 3, 
          2, \[CapitalLambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + \
z\^2)\)\)\ \[CapitalLambda]\)\ \((x\^2 + y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + z\
\^2)\)\ \[CapitalLambda]\^\(9/2\)\)\/\[Pi]\^\(3/2\);\)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[0, 3, 
          3, \[CapitalLambda]] = \(\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + \
z\^2)\)\)\ \[CapitalLambda]\)\ \((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + z\^2)\)\
\ \[CapitalLambda]\^\(9/2\)\)\/\(6\ \
\[Pi]\^\(3/2\)\);\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[1, 0, 
          0, \[CapitalLambda]] = \(1\/\(6\ \[Pi]\^\(3/2\)\)\) \((\
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[CapitalLambda]\)\ \((x\^2 \
+ y\^2 + z\^2)\)\ \[CapitalLambda]\^\(3/2\)\ \((3 - 2\ \((x\^2 + y\^2 + z\^2)\
\)\ \[CapitalLambda])\)\^2)\);\)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[1, 1, 
          0, \[CapitalLambda]] = \(1\/\(5\ \[Pi]\^\(3/2\)\)\) \((\
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[CapitalLambda]\)\ z\^2\ \
\((x\^2 + y\^2 + 
                  z\^2)\)\ \[CapitalLambda]\^\(5/2\)\ \((5 - 2\ \((x\^2 + \
y\^2 + z\^2)\)\ \[CapitalLambda])\)\^2)\);\)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[1, 1, 
          1, \[CapitalLambda]] = \(1\/\(10\ \[Pi]\^\(3/2\)\)\) \((\
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[CapitalLambda]\)\ \((x\^2 \
+ y\^2)\)\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[CapitalLambda]\^\(5/2\)\ \((5 - 2\ \((x\^2 + \
y\^2 + z\^2)\)\ \[CapitalLambda])\)\^2)\);\)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[1, 2, 
          
          0, \[CapitalLambda]] = \(1\/\(42\ \[Pi]\^\(3/2\)\)\) \((\
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[CapitalLambda]\)\ \((x\^2 \
+ y\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[CapitalLambda]\^\(7/2\)\ \((7 - 2\ \((x\^2 + \
y\^2 + z\^2)\)\ \[CapitalLambda])\)\^2)\);\)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[1, 2, 
          1, \[CapitalLambda]] = \(1\/\(7\ \[Pi]\^\(3/2\)\)\) \((\
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[CapitalLambda]\)\ \((x\^2 \
+ y\^2)\)\ z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[CapitalLambda]\^\(7/2\)\ \((7 - 2\ \((x\^2 + \
y\^2 + z\^2)\)\ \[CapitalLambda])\)\^2)\);\)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[1, 2, 
          2, \[CapitalLambda]] = \(1\/\(28\ \[Pi]\^\(3/2\)\)\) \((\
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[CapitalLambda]\)\ \((x\^2 \
+ y\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[CapitalLambda]\^\(7/2\)\ \((7 - 2\ \((x\^2 + \
y\^2 + z\^2)\)\ \[CapitalLambda])\)\^2)\);\)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[1, 3, 
          0, \[CapitalLambda]] = \(1\/\(135\ \[Pi]\^\(3/2\)\)\) \((\
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[CapitalLambda]\)\ z\^2\ \
\((3\ \((x\^2 + y\^2)\) - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[CapitalLambda]\^\(9/2\)\ \((9 - 2\ \((x\^2 + \
y\^2 + z\^2)\)\ \[CapitalLambda])\)\^2)\);\)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[1, 3, 
          1, \[CapitalLambda]] = \(1\/\(180\ \[Pi]\^\(3/2\)\)\) \((\
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[CapitalLambda]\)\ \((x\^2 \
+ y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[CapitalLambda]\^\(9/2\)\ \((9 - 2\ \((x\^2 + \
y\^2 + z\^2)\)\ \[CapitalLambda])\)\^2)\);\)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[1, 3, 
          2, \[CapitalLambda]] = \(1\/\(18\ \[Pi]\^\(3/2\)\)\) \((\
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[CapitalLambda]\)\ \((x\^2 \
+ y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[CapitalLambda]\^\(9/2\)\ \((9 - 2\ \((x\^2 + \
y\^2 + z\^2)\)\ \[CapitalLambda])\)\^2)\);\)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[1, 3, 
          3, \[CapitalLambda]] = \(1\/\(108\ \[Pi]\^\(3/2\)\)\) \((\
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[CapitalLambda]\)\ \((x\^2 \
+ y\^2)\)\^3\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[CapitalLambda]\^\(9/2\)\ \((9 - 2\ \((x\^2 + \
y\^2 + z\^2)\)\ \[CapitalLambda])\)\^2)\);\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[2, 0, 
          0, \[CapitalLambda]] = \(1\/\(120\ \[Pi]\^\(3/2\)\)\) \((\
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[CapitalLambda]\)\ \((x\^2 \
+ y\^2 + z\^2)\)\ \[CapitalLambda]\^\(3/2\)\ \((15 + 4\ \((x\^2 + y\^2 + \
z\^2)\)\ \[CapitalLambda]\ \((\(-5\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[CapitalLambda])\))\)\^2)\);\)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[2, 1, 
          0, \[CapitalLambda]] = \(1\/\(140\ \[Pi]\^\(3/2\)\)\) \((\
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[CapitalLambda]\)\ z\^2\ \
\((x\^2 + y\^2 + 
                  z\^2)\)\ \[CapitalLambda]\^\(5/2\)\ \((35 + 4\ \((x\^2 + \
y\^2 + z\^2)\)\ \[CapitalLambda]\ \((\(-7\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[CapitalLambda])\))\)\^2)\);\)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[2, 1, 
          1, \[CapitalLambda]] = \(1\/\(280\ \[Pi]\^\(3/2\)\)\) \((\
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[CapitalLambda]\)\ \((x\^2 \
+ y\^2)\)\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[CapitalLambda]\^\(5/2\)\ \((35 + 4\ \((x\^2 + \
y\^2 + z\^2)\)\ \[CapitalLambda]\ \((\(-7\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[CapitalLambda])\))\)\^2)\);\)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[2, 2, 
          0, \[CapitalLambda]] = \(1\/\(1512\ \[Pi]\^\(3/2\)\)\) \((\
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[CapitalLambda]\)\ \((x\^2 \
+ y\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[CapitalLambda]\^\(7/2\)\ \((63 + 4\ \((x\^2 + \
y\^2 + z\^2)\)\ \[CapitalLambda]\ \((\(-9\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[CapitalLambda])\))\)\^2)\);\)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[2, 2, 
          1, \[CapitalLambda]] = \(1\/\(252\ \[Pi]\^\(3/2\)\)\) \((\
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[CapitalLambda]\)\ \((x\^2 \
+ y\^2)\)\ z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[CapitalLambda]\^\(7/2\)\ \((63 + 4\ \((x\^2 + \
y\^2 + z\^2)\)\ \[CapitalLambda]\ \((\(-9\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[CapitalLambda])\))\)\^2)\);\)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[2, 2, 
          2, \[CapitalLambda]] = \(1\/\(1008\ \[Pi]\^\(3/2\)\)\) \((\
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[CapitalLambda]\)\ \((x\^2 \
+ y\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[CapitalLambda]\^\(7/2\)\ \((63 + 4\ \((x\^2 + \
y\^2 + z\^2)\)\ \[CapitalLambda]\ \((\(-9\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[CapitalLambda])\))\)\^2)\);\)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[2, 3, 
          0, \[CapitalLambda]] = \(1\/\(5940\ \[Pi]\^\(3/2\)\)\) \((\
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[CapitalLambda]\)\ z\^2\ \
\((3\ \((x\^2 + y\^2)\) - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[CapitalLambda]\^\(9/2\)\ \((99 + 4\ \((x\^2 + \
y\^2 + z\^2)\)\ \[CapitalLambda]\ \((\(-11\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[CapitalLambda])\))\)\^2)\);\)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[2, 3, 
          1, \[CapitalLambda]] = \(1\/\(7920\ \[Pi]\^\(3/2\)\)\) \((\
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[CapitalLambda]\)\ \((x\^2 \
+ y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[CapitalLambda]\^\(9/2\)\ \((99 + 4\ \((x\^2 + \
y\^2 + z\^2)\)\ \[CapitalLambda]\ \((\(-11\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[CapitalLambda])\))\)\^2)\);\)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[2, 3, 
          2, \[CapitalLambda]] = \(1\/\(792\ \[Pi]\^\(3/2\)\)\) \((\
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[CapitalLambda]\)\ \((x\^2 \
+ y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[CapitalLambda]\^\(9/2\)\ \((99 + 4\ \((x\^2 + \
y\^2 + z\^2)\)\ \[CapitalLambda]\ \((\(-11\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[CapitalLambda])\))\)\^2)\);\)\), "\n", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[2, 3, 
          3, \[CapitalLambda]] = \(1\/\(4752\ \[Pi]\^\(3/2\)\)\) \((\
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[CapitalLambda]\)\ \((x\^2 \
+ y\^2)\)\^3\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[CapitalLambda]\^\(9/2\)\ \((99 + 4\ \((x\^2 + \
y\^2 + z\^2)\)\ \[CapitalLambda]\ \((\(-11\) + \((x\^2 + y\^2 + z\^2)\)\ \
\[CapitalLambda])\))\)\^2)\);\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[3, 0, 
          0, \[CapitalLambda]] = \(1\/\(16\ \[Pi]\^\(3/2\)\)\) \((35\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[CapitalLambda]\)\ \((x\^2 \
+ y\^2 + z\^2)\)\ \[CapitalLambda]\^\(3/2\)\ \((1 + 2\/105\ \((x\^2 + y\^2 + \
z\^2)\)\ \[CapitalLambda]\ \((\(-105\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[CapitalLambda]\ \((21 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[CapitalLambda])\))\))\)\^2)\);\)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[3, 1, 
          0, \[CapitalLambda]] = \(1\/\(7560\ \[Pi]\^\(3/2\)\)\) \((\
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[CapitalLambda]\)\ z\^2\ \
\((x\^2 + y\^2 + 
                  z\^2)\)\ \[CapitalLambda]\^\(5/2\)\ \((315 - 2\ \((x\^2 + y\
\^2 + z\^2)\)\ \[CapitalLambda]\ \((189 + 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[CapitalLambda]\ \((\(-27\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[CapitalLambda])\
\))\))\)\^2)\);\)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[3, 1, 
          1, \[CapitalLambda]] = \(1\/\(15120\ \[Pi]\^\(3/2\)\)\) \((\
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[CapitalLambda]\)\ \((x\^2 \
+ y\^2)\)\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[CapitalLambda]\^\(5/2\)\ \((315 - 2\ \((x\^2 + y\
\^2 + z\^2)\)\ \[CapitalLambda]\ \((189 + 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[CapitalLambda]\ \((\(-27\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[CapitalLambda])\
\))\))\)\^2)\);\)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[3, 2, 
          0, \[CapitalLambda]] = \(1\/\(64\ \[Pi]\^\(3/2\)\)\) \((77\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[CapitalLambda]\)\ \((x\^2 \
+ y\^2 + z\^2)\)\^3\ \((2 - \(6\ z\^2\)\/\(x\^2 + y\^2 + z\^2\))\)\^2\ \
\[CapitalLambda]\^\(7/2\)\ \((1 + 2\/693\ \((x\^2 + y\^2 + z\^2)\)\ \
\[CapitalLambda]\ \((\(-297\) + 2\ \((x\^2 + y\^2 + z\^2)\)\ \[CapitalLambda]\
\ \((33 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[CapitalLambda])\))\))\)\^2)\);\)\), \
"\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[3, 2, 
          1, \[CapitalLambda]] = \(1\/\(8\ \[Pi]\^\(3/2\)\)\) \((231\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[CapitalLambda]\)\ \((x\^2 \
+ y\^2)\)\ z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[CapitalLambda]\^\(7/2\)\ \((1 + 2\/693\ \((x\^2 \
+ y\^2 + z\^2)\)\ \[CapitalLambda]\ \((\(-297\) + 2\ \((x\^2 + y\^2 + z\^2)\)\
\ \[CapitalLambda]\ \((33 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[CapitalLambda])\))\
\))\)\^2)\);\)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[3, 2, 
          2, \[CapitalLambda]] = \(1\/\(32\ \[Pi]\^\(3/2\)\)\) \((231\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[CapitalLambda]\)\ \((x\^2 \
+ y\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[CapitalLambda]\^\(7/2\)\ \((1 + 2\/693\ \((x\^2 \
+ y\^2 + z\^2)\)\ \[CapitalLambda]\ \((\(-297\) + 2\ \((x\^2 + y\^2 + z\^2)\)\
\ \[CapitalLambda]\ \((33 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \[CapitalLambda])\))\
\))\)\^2)\);\)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[3, 3, 
          0, \[CapitalLambda]] = \(1\/\(40\ \[Pi]\^\(3/2\)\)\) \((143\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[CapitalLambda]\)\ z\^2\ \
\((3\ \((x\^2 + y\^2)\) - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[CapitalLambda]\^\(9/2\)\ \((1 + \(1\/1287\) \((2\
\ \((x\^2 + y\^2 + z\^2)\)\ \[CapitalLambda]\ \((\(-429\) + 2\ \((x\^2 + y\^2 \
+ z\^2)\)\ \[CapitalLambda]\ \((39 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[CapitalLambda])\))\))\))\)\^2)\);\)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[3, 3, 
          1, \[CapitalLambda]] = \(1\/\(160\ \[Pi]\^\(3/2\)\)\) \((429\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[CapitalLambda]\)\ \((x\^2 \
+ y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[CapitalLambda]\^\(9/2\)\ \((1 + \(1\/1287\) \((2\
\ \((x\^2 + y\^2 + z\^2)\)\ \[CapitalLambda]\ \((\(-429\) + 2\ \((x\^2 + y\^2 \
+ z\^2)\)\ \[CapitalLambda]\ \((39 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[CapitalLambda])\))\))\))\)\^2)\);\)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[3, 3, 
          2, \[CapitalLambda]] = \(1\/\(16\ \[Pi]\^\(3/2\)\)\) \((429\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[CapitalLambda]\)\ \((x\^2 \
+ y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[CapitalLambda]\^\(9/2\)\ \((1 + \(1\/1287\) \((2\
\ \((x\^2 + y\^2 + z\^2)\)\ \[CapitalLambda]\ \((\(-429\) + 2\ \((x\^2 + y\^2 \
+ z\^2)\)\ \[CapitalLambda]\ \((39 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[CapitalLambda])\))\))\))\)\^2)\);\)\), "\n", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[3, 3, 
          3, \[CapitalLambda]] = \(1\/\(32\ \[Pi]\^\(3/2\)\)\) \((143\ \
\[ExponentialE]\^\(\(-\((x\^2 + y\^2 + z\^2)\)\)\ \[CapitalLambda]\)\ \((x\^2 \
+ y\^2)\)\^3\ \((x\^2 + y\^2 + 
                  z\^2)\)\ \[CapitalLambda]\^\(9/2\)\ \((1 + \(1\/1287\) \((2\
\ \((x\^2 + y\^2 + z\^2)\)\ \[CapitalLambda]\ \((\(-429\) + 2\ \((x\^2 + y\^2 \
+ z\^2)\)\ \[CapitalLambda]\ \((39 - 2\ \((x\^2 + y\^2 + z\^2)\)\ \
\[CapitalLambda])\))\))\))\)\^2)\);\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2. Comparative visualization of the probability densities of the \
three-dimensional quantum oscillator for different values of oscillator \
parameter\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Now we present visualizations of the probability densities of the \
three-dimensional quantum oscillator.
We will obtain density and surface (three-dimensional) plots for probability \
densities of the three-dimensional quantum oscillator for different values of \
oscillator parameter.
In this file we will present visualizations in individual scales for states \
defined by given quantum numbers.\
\>", "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox["Parameters of Plots:",
    FontWeight->"Bold"],
  "\n",
  StyleBox["2d Plots",
    FontWeight->"Bold"],
  "\n\t\tVariable Range: {x2dMin, x2dMax}\n\t\tPlot Range for 2d Plots: \
{PR2dMin, PR2dMax}\n\t\tImage Size for 2d Plots: {IS2dHorz, IS2dVert}\n\n",
  StyleBox["3d Plots",
    FontWeight->"Bold"],
  "\n\t\tVariable Range: {x3dMin, x3dMax, y3dMin, y3dMax}\n\t\tPlot Range for \
3d Plots: {PR3dMin, PR3dMax}\n\t\tPlot Points for 3d Plots: {N3d}\n\t\tImage \
Size for 3d Plots: {IS3DHorz, IS3DVert}\n\t\tViewPoint for 3d Plots: {VP1, \
VP2, VP3} or {WP1, WP2, WP3}"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(N3d = 100;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(y0 = 0;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(IS3dHorz = 300;\)\), "\[IndentingNewLine]", 
    \(\(IS3dVert = 300;\)\n\), "\[IndentingNewLine]", 
    \(\(ISAll3dHorz = 600;\)\), "\[IndentingNewLine]", 
    \(\(ISAll3dVert = 300;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-5\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 5;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-5\);\)\), "\[IndentingNewLine]", 
    \(\(z3dMax = 5;\)\)}], "Input"],

Cell[CellGroupData[{

Cell[TextData[{
  "1) ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 0\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
          m\_azm, \[CapitalLambda], y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda]], {y \[Rule] 
              y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda], y0], \[Psi]\[Psi]\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, \[Lambda], y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,0,0,1], \[CapitalPsi]\[CapitalPsi][0,0,0,1.5], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,0,0,1], \[CapitalPsi]\[CapitalPsi][0,0,0,1.5], y=0\>"];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0], 
          WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][0,0,0,1], \[CapitalPsi]\[CapitalPsi][0,0,0,1.5], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "2",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.25;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
          m\_azm, \[CapitalLambda], y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda]], {y \[Rule] 
              y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda], y0], \[Psi]\[Psi]\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, \[Lambda], y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,1,0,1], \[CapitalPsi]\[CapitalPsi][0,1,0,1.5], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,1,0,1], \[CapitalPsi]\[CapitalPsi][0,1,0,1.5], y=0\>"];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0], 
          WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][0,1,0,1], \[CapitalPsi]\[CapitalPsi][0,1,0,1.5], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "3",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
          m\_azm, \[CapitalLambda], y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda]], {y \[Rule] 
              y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda], y0], \[Psi]\[Psi]\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, \[Lambda], y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,1,1,1], \[CapitalPsi]\[CapitalPsi][0,1,1,1.5], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,1,1,1], \[CapitalPsi]\[CapitalPsi][0,1,1,1.5], y=0\>"];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0], 
          WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][0,1,1,1], \[CapitalPsi]\[CapitalPsi][0,1,1,1.5], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "4",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
          m\_azm, \[CapitalLambda], y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda]], {y \[Rule] 
              y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda], y0], \[Psi]\[Psi]\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, \[Lambda], y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,2,0,1], \[CapitalPsi]\[CapitalPsi][0,2,0,1.5], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,2,0,1], \[CapitalPsi]\[CapitalPsi][0,2,0,1.5], y=0\>"];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0], 
          WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][0,2,0,1], \[CapitalPsi]\[CapitalPsi][0,2,0,1.5], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "5",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.15;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
          m\_azm, \[CapitalLambda], y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda]], {y \[Rule] 
              y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda], y0], \[Psi]\[Psi]\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, \[Lambda], y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,2,1,1], \[CapitalPsi]\[CapitalPsi][0,2,1,1.5], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,2,1,1], \[CapitalPsi]\[CapitalPsi][0,2,1,1.5], y=0\>"];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0], 
          WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][0,2,1,1], \[CapitalPsi]\[CapitalPsi][0,2,1,1.5], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "6",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.15;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
          m\_azm, \[CapitalLambda], y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda]], {y \[Rule] 
              y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda], y0], \[Psi]\[Psi]\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, \[Lambda], y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,2,2,1], \[CapitalPsi]\[CapitalPsi][0,2,2,1.5], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,2,2,1], \[CapitalPsi]\[CapitalPsi][0,2,2,1.5], y=0\>"];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0], 
          WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][0,2,2,1], \[CapitalPsi]\[CapitalPsi][0,2,2,1.5], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "7",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.575;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
          m\_azm, \[CapitalLambda], y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda]], {y \[Rule] 
              y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda], y0], \[Psi]\[Psi]\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, \[Lambda], y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,3,0,1], \[CapitalPsi]\[CapitalPsi][0,3,0,1.5], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,3,0,1], \[CapitalPsi]\[CapitalPsi][0,3,0,1.5], y=0\>"];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0], 
          WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][0,3,0,1], \[CapitalPsi]\[CapitalPsi][0,3,0,1.5], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "8",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.16;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
          m\_azm, \[CapitalLambda], y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda]], {y \[Rule] 
              y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda], y0], \[Psi]\[Psi]\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, \[Lambda], y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,3,1,1], \[CapitalPsi]\[CapitalPsi][0,3,1,1.5], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,3,1,1], \[CapitalPsi]\[CapitalPsi][0,3,1,1.5], y=0\>"];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0], 
          WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][0,3,1,1], \[CapitalPsi]\[CapitalPsi][0,3,1,1.5], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "9",
  ") ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(IS3dHorz = 250;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 265;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
          m\_azm, \[CapitalLambda], y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda]], {y \[Rule] 
              y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda], y0], \[Psi]\[Psi]\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, \[Lambda], y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,3,2,1], \[CapitalPsi]\[CapitalPsi][0,3,2,1.5], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,3,2,1], \[CapitalPsi]\[CapitalPsi][0,3,2,1.5], y=0\>"];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0], 
          WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][0,3,2,1], \[CapitalPsi]\[CapitalPsi][0,3,2,1.5], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "10",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 0\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 3\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.14;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
          m\_azm, \[CapitalLambda], y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda]], {y \[Rule] 
              y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda], y0], \[Psi]\[Psi]\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, \[Lambda], y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,3,3,1], \[CapitalPsi]\[CapitalPsi][0,3,3,1.5], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][0,3,3,1], \[CapitalPsi]\[CapitalPsi][0,3,3,1.5], y=0\>"];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0], 
          WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][0,3,3,1], \[CapitalPsi]\[CapitalPsi][0,3,3,1.5], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "11",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 0\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.0575;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
          m\_azm, \[CapitalLambda], y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda]], {y \[Rule] 
              y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda], y0], \[Psi]\[Psi]\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, \[Lambda], y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,0,0,1], \[CapitalPsi]\[CapitalPsi][1,0,0,1.5], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,0,0,1], \[CapitalPsi]\[CapitalPsi][1,0,0,1.5], y=0\>"];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0], 
          WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,0,0,1], \[CapitalPsi]\[CapitalPsi][1,0,0,1.5], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "12",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.165;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
          m\_azm, \[CapitalLambda], y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda]], {y \[Rule] 
              y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda], y0], \[Psi]\[Psi]\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, \[Lambda], y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,1,0,1], \[CapitalPsi]\[CapitalPsi][1,1,0,1.5], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,1,0,1], \[CapitalPsi]\[CapitalPsi][1,1,0,1.5], y=0\>"];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0], 
          WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,1,0,1], \[CapitalPsi]\[CapitalPsi][1,1,0,1.5], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "13",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.085;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
          m\_azm, \[CapitalLambda], y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda]], {y \[Rule] 
              y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda], y0], \[Psi]\[Psi]\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, \[Lambda], y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,1,1,1], \[CapitalPsi]\[CapitalPsi][1,1,1,1.5], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,1,1,1], \[CapitalPsi]\[CapitalPsi][1,1,1,1.5], y=0\>"];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0], 
          WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,1,1,1], \[CapitalPsi]\[CapitalPsi][1,1,1,1.5], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "14",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.27;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
          m\_azm, \[CapitalLambda], y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda]], {y \[Rule] 
              y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda], y0], \[Psi]\[Psi]\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, \[Lambda], y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,0,1], \[CapitalPsi]\[CapitalPsi][1,2,0,1.5], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,0,1], \[CapitalPsi]\[CapitalPsi][1,2,0,1.5], y=0\>"];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0], 
          WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,2,0,1], \[CapitalPsi]\[CapitalPsi][1,2,0,1.5], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "15",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
          m\_azm, \[CapitalLambda], y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda]], {y \[Rule] 
              y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda], y0], \[Psi]\[Psi]\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, \[Lambda], y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,1,1], \[CapitalPsi]\[CapitalPsi][1,2,1,1.5], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,1,1], \[CapitalPsi]\[CapitalPsi][1,2,1,1.5], y=0\>"];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0], 
          WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,2,1,1], \[CapitalPsi]\[CapitalPsi][1,2,1,1.5], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "16",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
          m\_azm, \[CapitalLambda], y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda]], {y \[Rule] 
              y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda], y0], \[Psi]\[Psi]\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, \[Lambda], y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,2,1], \[CapitalPsi]\[CapitalPsi][1,2,2,1.5], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,2,2,1], \[CapitalPsi]\[CapitalPsi][1,2,2,1.5], y=0\>"];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0], 
          WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,2,2,1], \[CapitalPsi]\[CapitalPsi][1,2,2,1.5], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "17",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.375;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
          m\_azm, \[CapitalLambda], y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda]], {y \[Rule] 
              y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda], y0], \[Psi]\[Psi]\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, \[Lambda], y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,0,1], \[CapitalPsi]\[CapitalPsi][1,3,0,1.5], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,0,1], \[CapitalPsi]\[CapitalPsi][1,3,0,1.5], y=0\>"];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0], 
          WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,3,0,1], \[CapitalPsi]\[CapitalPsi][1,3,0,1.5], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "18",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.15;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
          m\_azm, \[CapitalLambda], y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda]], {y \[Rule] 
              y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda], y0], \[Psi]\[Psi]\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, \[Lambda], y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,1,1], \[CapitalPsi]\[CapitalPsi][1,3,1,1.5], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,1,1], \[CapitalPsi]\[CapitalPsi][1,3,1,1.5], y=0\>"];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0], 
          WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,3,1,1], \[CapitalPsi]\[CapitalPsi][1,3,1,1.5], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "19",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.105;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
          m\_azm, \[CapitalLambda], y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda]], {y \[Rule] 
              y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda], y0], \[Psi]\[Psi]\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, \[Lambda], y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,2,1], \[CapitalPsi]\[CapitalPsi][1,3,2,1.5], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,2,1], \[CapitalPsi]\[CapitalPsi][1,3,2,1.5], y=0\>"];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0], 
          WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,3,2,1], \[CapitalPsi]\[CapitalPsi][1,3,2,1.5], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "20",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 1\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 3\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.115;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
          m\_azm, \[CapitalLambda], y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda]], {y \[Rule] 
              y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda], y0], \[Psi]\[Psi]\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, \[Lambda], y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,3,1], \[CapitalPsi]\[CapitalPsi][1,3,3,1.5], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][1,3,3,1], \[CapitalPsi]\[CapitalPsi][1,3,3,1.5], y=0\>"];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0], 
          WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][1,3,3,1], \[CapitalPsi]\[CapitalPsi][1,3,3,1.5], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "21",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 0\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.0525;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
          m\_azm, \[CapitalLambda], y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda]], {y \[Rule] 
              y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda], y0], \[Psi]\[Psi]\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, \[Lambda], y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,0,0,1], \[CapitalPsi]\[CapitalPsi][2,0,0,1.5], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,0,0,1], \[CapitalPsi]\[CapitalPsi][2,0,0,1.5], y=0\>"];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0], 
          WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,0,0,1], \[CapitalPsi]\[CapitalPsi][2,0,0,1.5], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "22",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.155;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
          m\_azm, \[CapitalLambda], y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda]], {y \[Rule] 
              y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda], y0], \[Psi]\[Psi]\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, \[Lambda], y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,1,0,1], \[CapitalPsi]\[CapitalPsi][2,1,0,1.5], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,1,0,1], \[CapitalPsi]\[CapitalPsi][2,1,0,1.5], y=0\>"];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0], 
          WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,1,0,1], \[CapitalPsi]\[CapitalPsi][2,1,0,1.5], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "23) ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.075;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
          m\_azm, \[CapitalLambda], y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda]], {y \[Rule] 
              y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda], y0], \[Psi]\[Psi]\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, \[Lambda], y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,1,1,1], \[CapitalPsi]\[CapitalPsi][2,1,1,1.5], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,1,1,1], \[CapitalPsi]\[CapitalPsi][2,1,1,1.5], y=0\>"];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0], 
          WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,1,1,1], \[CapitalPsi]\[CapitalPsi][2,1,1,1.5], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "24",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.25;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
          m\_azm, \[CapitalLambda], y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda]], {y \[Rule] 
              y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda], y0], \[Psi]\[Psi]\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, \[Lambda], y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,0,1], \[CapitalPsi]\[CapitalPsi][2,2,0,1.5], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,0,1], \[CapitalPsi]\[CapitalPsi][2,2,0,1.5], y=0\>"];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0], 
          WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,2,0,1], \[CapitalPsi]\[CapitalPsi][2,2,0,1.5], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "25",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.09;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
          m\_azm, \[CapitalLambda], y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda]], {y \[Rule] 
              y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda], y0], \[Psi]\[Psi]\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, \[Lambda], y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,1,1], \[CapitalPsi]\[CapitalPsi][2,2,1,1.5], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,1,1], \[CapitalPsi]\[CapitalPsi][2,2,1,1.5], y=0\>"];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0], 
          WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,2,1,1], \[CapitalPsi]\[CapitalPsi][2,2,1,1.5], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "26",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.09;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
          m\_azm, \[CapitalLambda], y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda]], {y \[Rule] 
              y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda], y0], \[Psi]\[Psi]\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, \[Lambda], y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,2,1], \[CapitalPsi]\[CapitalPsi][2,2,2,1.5], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,2,2,1], \[CapitalPsi]\[CapitalPsi][2,2,2,1.5], y=0\>"];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0], 
          WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,2,2,1], \[CapitalPsi]\[CapitalPsi][2,2,2,1.5], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "27",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.345;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
          m\_azm, \[CapitalLambda], y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda]], {y \[Rule] 
              y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda], y0], \[Psi]\[Psi]\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, \[Lambda], y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,0,1], \[CapitalPsi]\[CapitalPsi][2,3,0,1.5], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,0,1], \[CapitalPsi]\[CapitalPsi][2,3,0,1.5], y=0\>"];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0], 
          WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,3,0,1], \[CapitalPsi]\[CapitalPsi][2,3,0,1.5], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "28",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.125;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
          m\_azm, \[CapitalLambda], y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda]], {y \[Rule] 
              y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda], y0], \[Psi]\[Psi]\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, \[Lambda], y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,1,1], \[CapitalPsi]\[CapitalPsi][2,3,1,1.5], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,1,1], \[CapitalPsi]\[CapitalPsi][2,3,1,1.5], y=0\>"];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0], 
          WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,3,1,1], \[CapitalPsi]\[CapitalPsi][2,3,1,1.5], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "29",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.095;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
          m\_azm, \[CapitalLambda], y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda]], {y \[Rule] 
              y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda], y0], \[Psi]\[Psi]\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, \[Lambda], y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,2,1], \[CapitalPsi]\[CapitalPsi][2,3,2,1.5], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,2,1], \[CapitalPsi]\[CapitalPsi][2,3,2,1.5], y=0\>"];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0], 
          WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,3,2,1], \[CapitalPsi]\[CapitalPsi][2,3,2,1.5], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "30",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 2\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 3\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.11;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
          m\_azm, \[CapitalLambda], y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda]], {y \[Rule] 
              y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda], y0], \[Psi]\[Psi]\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, \[Lambda], y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,3,1], \[CapitalPsi]\[CapitalPsi][2,3,3,1.5], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][2,3,3,1], \[CapitalPsi]\[CapitalPsi][2,3,3,1.5], y=0\>"];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0], 
          WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][2,3,3,1], \[CapitalPsi]\[CapitalPsi][2,3,3,1.5], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "31",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 0\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.0475;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
          m\_azm, \[CapitalLambda], y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda]], {y \[Rule] 
              y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda], y0], \[Psi]\[Psi]\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, \[Lambda], y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,0,0,1], \[CapitalPsi]\[CapitalPsi][3,0,0,1.5], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,0,0,1], \[CapitalPsi]\[CapitalPsi][3,0,0,1.5], y=0\>"];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0], 
          WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,0,0,1], \[CapitalPsi]\[CapitalPsi][3,0,0,1.5], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "32",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.145;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
          m\_azm, \[CapitalLambda], y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda]], {y \[Rule] 
              y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda], y0], \[Psi]\[Psi]\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, \[Lambda], y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,1,0,1], \[CapitalPsi]\[CapitalPsi][3,1,0,1.5], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,1,0,1], \[CapitalPsi]\[CapitalPsi][3,1,0,1.5], y=0\>"];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0], 
          WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,1,0,1], \[CapitalPsi]\[CapitalPsi][3,1,0,1.5], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "33",
  ")",
  " ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.0685;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
          m\_azm, \[CapitalLambda], y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda]], {y \[Rule] 
              y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda], y0], \[Psi]\[Psi]\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, \[Lambda], y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,1,1,1], \[CapitalPsi]\[CapitalPsi][3,1,1,1.5], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,1,1,1], \[CapitalPsi]\[CapitalPsi][3,1,1,1.5], y=0\>"];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0], 
          WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,1,1,1], \[CapitalPsi]\[CapitalPsi][3,1,1,1.5], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "34) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.235;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
          m\_azm, \[CapitalLambda], y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda]], {y \[Rule] 
              y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda], y0], \[Psi]\[Psi]\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, \[Lambda], y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,2,0,1], \[CapitalPsi]\[CapitalPsi][3,2,0,1.5], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,2,0,1], \[CapitalPsi]\[CapitalPsi][3,2,0,1.5], y=0\>"];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0], 
          WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,2,0,1], \[CapitalPsi]\[CapitalPsi][3,2,0,1.5], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "35) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.0875;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
          m\_azm, \[CapitalLambda], y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda]], {y \[Rule] 
              y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda], y0], \[Psi]\[Psi]\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, \[Lambda], y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,2,1,1], \[CapitalPsi]\[CapitalPsi][3,2,1,1.5], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,2,1,1], \[CapitalPsi]\[CapitalPsi][3,2,1,1.5], y=0\>"];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0], 
          WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,2,1,1], \[CapitalPsi]\[CapitalPsi][3,2,1,1.5], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "36) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.0865;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
          m\_azm, \[CapitalLambda], y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda]], {y \[Rule] 
              y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda], y0], \[Psi]\[Psi]\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, \[Lambda], y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,2,2,1], \[CapitalPsi]\[CapitalPsi][3,2,2,1.5], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,2,2,1], \[CapitalPsi]\[CapitalPsi][3,2,2,1.5], y=0\>"];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0], 
          WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,2,2,1], \[CapitalPsi]\[CapitalPsi][3,2,2,1.5], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "37) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.315;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
          m\_azm, \[CapitalLambda], y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda]], {y \[Rule] 
              y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda], y0], \[Psi]\[Psi]\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, \[Lambda], y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,3,0,1], \[CapitalPsi]\[CapitalPsi][3,3,0,1.5], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,3,0,1], \[CapitalPsi]\[CapitalPsi][3,3,0,1.5], y=0\>"];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0], 
          WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,3,0,1], \[CapitalPsi]\[CapitalPsi][3,3,0,1.5], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "38) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.115;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
          m\_azm, \[CapitalLambda], y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda]], {y \[Rule] 
              y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda], y0], \[Psi]\[Psi]\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, \[Lambda], y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,3,1,1], \[CapitalPsi]\[CapitalPsi][3,3,1,1.5], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,3,1,1], \[CapitalPsi]\[CapitalPsi][3,3,1,1.5], y=0\>"];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0], 
          WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,3,1,1], \[CapitalPsi]\[CapitalPsi][3,3,1,1.5], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "39) ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 2\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.09;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
          m\_azm, \[CapitalLambda], y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda]], {y \[Rule] 
              y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda], y0], \[Psi]\[Psi]\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, \[Lambda], y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,3,2,1], \[CapitalPsi]\[CapitalPsi][3,3,2,1.5], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,3,2,1], \[CapitalPsi]\[CapitalPsi][3,3,2,1.5], y=0\>"];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0], 
          WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,3,2,1], \[CapitalPsi]\[CapitalPsi][3,3,2,1.5], y=0\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "40. ",
  Cell[BoxData[
      \(n\_rad = 3\)]],
  ", ",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(m\_azm = 3\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, m\_azm, \[Lambda], y0] = 
        ReplaceAll[\[Psi]\[Psi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[Lambda]], {y \[Rule] y0}];\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
          m\_azm, \[CapitalLambda], y0] = 
        ReplaceAll[\[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda]], {y \[Rule] 
              y0}];\)\), "\[IndentingNewLine]", 
    \(\(\(\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[n\_rad, 
          l\_orb, m\_azm, y0] = 
        If[x > 0, \[CapitalPsi]\[CapitalPsi]\_\(Oscl, Cart\)[n\_rad, l\_orb, 
            m\_azm, \[CapitalLambda], y0], \[Psi]\[Psi]\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, \[Lambda], y0]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        DensityPlot[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[
              0.9], \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.3] &)\), \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,3,3,1], \[CapitalPsi]\[CapitalPsi][3,3,3,1.5], y=0\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, y0] = 
        Plot3D[\[CapitalPsi]\[CapitalPsi]\[Psi]\[Psi]hf\_\(Oscl, Cart\)[
            n\_rad, l\_orb, m\_azm, y0], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {z, z3dMin, z3dMax}, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.5, 0. , 0.35], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {0.000, \ 0.000, 
              4}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<\[Psi]\[Psi][3,3,3,1], \[CapitalPsi]\[CapitalPsi][3,3,3,1.5], y=0\>"];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{WFunktion3dDen\_Oscl[n\_rad, l\_orb, m\_azm, y0], 
          WFunktion3d\_Oscl[n\_rad, l\_orb, m\_azm, 
            y0]}], \[IndentingNewLine]ImageSize \[Rule] {ISAll3dHorz, 
          ISAll3dVert}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave function \[Psi]\
\[Psi][3,3,3,1], \[CapitalPsi]\[CapitalPsi][3,3,3,1.5], y=0\>"]\)}], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
3. Comparison of plots of the probability densities of the three-dimensional \
quantum oscillator for different values of oscillator parameter\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(Show[
      GraphicsArray[{{WFunktion3dDen\_Oscl[0, 0, 0, y0], 
            WFunktion3dDen\_Oscl[1, 0, 0, y0], 
            WFunktion3dDen\_Oscl[2, 0, 0, y0], 
            WFunktion3dDen\_Oscl[3, 0, 0, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
Oscl[0, 1, 0, y0], WFunktion3dDen\_Oscl[1, 1, 0, y0], 
            WFunktion3dDen\_Oscl[2, 1, 0, y0], 
            WFunktion3dDen\_Oscl[3, 1, 0, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
Oscl[0, 1, 1, y0], WFunktion3dDen\_Oscl[1, 1, 1, y0], 
            WFunktion3dDen\_Oscl[2, 1, 1, y0], 
            WFunktion3dDen\_Oscl[3, 1, 1, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
Oscl[0, 2, 0, y0], WFunktion3dDen\_Oscl[1, 2, 0, y0], 
            WFunktion3dDen\_Oscl[2, 2, 0, y0], 
            WFunktion3dDen\_Oscl[3, 2, 0, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
Oscl[0, 2, 1, y0], WFunktion3dDen\_Oscl[1, 2, 1, y0], 
            WFunktion3dDen\_Oscl[2, 2, 1, y0], 
            WFunktion3dDen\_Oscl[3, 2, 1, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
Oscl[0, 2, 2, y0], WFunktion3dDen\_Oscl[1, 2, 2, y0], 
            WFunktion3dDen\_Oscl[2, 2, 2, y0], 
            WFunktion3dDen\_Oscl[3, 2, 2, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
Oscl[0, 3, 0, y0], WFunktion3dDen\_Oscl[1, 3, 0, y0], 
            WFunktion3dDen\_Oscl[2, 3, 0, y0], 
            WFunktion3dDen\_Oscl[3, 3, 0, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
Oscl[0, 3, 1, y0], WFunktion3dDen\_Oscl[1, 3, 1, y0], 
            WFunktion3dDen\_Oscl[2, 3, 1, y0], 
            WFunktion3dDen\_Oscl[3, 3, 1, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
Oscl[0, 3, 2, y0], WFunktion3dDen\_Oscl[1, 3, 2, y0], 
            WFunktion3dDen\_Oscl[2, 3, 2, y0], 
            WFunktion3dDen\_Oscl[3, 3, 2, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3dDen\_\
Oscl[0, 3, 3, y0], WFunktion3dDen\_Oscl[1, 3, 3, y0], 
            WFunktion3dDen\_Oscl[2, 3, 3, y0], 
            WFunktion3dDen\_Oscl[3, 3, 3, y0]}}, 
        ImageSize \[Rule] {850, 2100}, \[IndentingNewLine]Background \[Rule] 
          RGBColor[0.0, 0.75, 
            0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave functions, y=0\
\>"]]\)], "Input"],

Cell["", "Text"],

Cell[BoxData[
    \(Show[
      GraphicsArray[{{WFunktion3d\_Oscl[0, 0, 0, y0], 
            WFunktion3d\_Oscl[1, 0, 0, y0], WFunktion3d\_Oscl[2, 0, 0, y0], 
            WFunktion3d\_Oscl[3, 0, 0, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3d\_Oscl[
              0, 1, 0, y0], WFunktion3d\_Oscl[1, 1, 0, y0], 
            WFunktion3d\_Oscl[2, 1, 0, y0], 
            WFunktion3d\_Oscl[3, 1, 0, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3d\_Oscl[
              0, 1, 1, y0], WFunktion3d\_Oscl[1, 1, 1, y0], 
            WFunktion3d\_Oscl[2, 1, 1, y0], 
            WFunktion3d\_Oscl[3, 1, 1, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3d\_Oscl[
              0, 2, 0, y0], WFunktion3d\_Oscl[1, 2, 0, y0], 
            WFunktion3d\_Oscl[2, 2, 0, y0], 
            WFunktion3d\_Oscl[3, 2, 0, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3d\_Oscl[
              0, 2, 1, y0], WFunktion3d\_Oscl[1, 2, 1, y0], 
            WFunktion3d\_Oscl[2, 2, 1, y0], 
            WFunktion3d\_Oscl[3, 2, 1, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3d\_Oscl[
              0, 2, 2, y0], WFunktion3d\_Oscl[1, 2, 2, y0], 
            WFunktion3d\_Oscl[2, 2, 2, y0], 
            WFunktion3d\_Oscl[3, 2, 2, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3d\_Oscl[
              0, 3, 0, y0], WFunktion3d\_Oscl[1, 3, 0, y0], 
            WFunktion3d\_Oscl[2, 3, 0, y0], 
            WFunktion3d\_Oscl[3, 3, 0, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3d\_Oscl[
              0, 3, 1, y0], WFunktion3d\_Oscl[1, 3, 1, y0], 
            WFunktion3d\_Oscl[2, 3, 1, y0], 
            WFunktion3d\_Oscl[3, 3, 1, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3d\_Oscl[
              0, 3, 2, y0], WFunktion3d\_Oscl[1, 3, 2, y0], 
            WFunktion3d\_Oscl[2, 3, 2, y0], 
            WFunktion3d\_Oscl[3, 3, 2, 
              y0]}, \[IndentingNewLine]\[IndentingNewLine]{WFunktion3d\_Oscl[
              0, 3, 3, y0], WFunktion3d\_Oscl[1, 3, 3, y0], 
            WFunktion3d\_Oscl[2, 3, 3, y0], WFunktion3d\_Oscl[3, 3, 3, y0]}}, 
        ImageSize \[Rule] {850, 2100}, \[IndentingNewLine]Background \[Rule] 
          RGBColor[0.0, 0.75, 
            0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Wave functions, y=0\
\>"]]\)], "Input"],

Cell["", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1016, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.25,
StyleDefinitions -> "Classroom1.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 254, 8, 93, "Subtitle"],
Cell[2527, 82, 235, 6, 124, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2787, 92, 189, 5, 119, "Section"],
Cell[2979, 99, 253, 6, 80, "Text"],
Cell[3235, 107, 123, 3, 65, "NumberedEquation"],
Cell[3361, 112, 302, 12, 56, "Text"],
Cell[3666, 126, 116, 2, 88, "Input"],
Cell[3785, 130, 165, 5, 56, "Text"],
Cell[3953, 137, 195, 8, 72, "NumberedEquation"],
Cell[4151, 147, 40, 0, 62, "Input"],
Cell[4194, 149, 257, 8, 56, "Text"],
Cell[4454, 159, 15045, 248, 4112, "Input"],
Cell[19502, 409, 264, 8, 56, "Text"],
Cell[19769, 419, 16137, 255, 4034, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35943, 679, 224, 6, 119, "Section"],
Cell[36170, 687, 422, 8, 152, "Text"],
Cell[36595, 697, 666, 17, 452, "Text"],
Cell[37264, 716, 577, 10, 388, "Input"],

Cell[CellGroupData[{
Cell[37866, 730, 202, 11, 89, "Subsection"],
Cell[38071, 743, 3350, 56, 1068, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41458, 804, 214, 13, 89, "Subsection"],
Cell[41675, 819, 3351, 56, 1068, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[45063, 880, 214, 13, 89, "Subsection"],
Cell[45280, 895, 3350, 56, 1068, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[48667, 956, 214, 13, 89, "Subsection"],
Cell[48884, 971, 3350, 56, 1068, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52271, 1032, 214, 13, 89, "Subsection"],
Cell[52488, 1047, 3351, 56, 1068, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[55876, 1108, 214, 13, 89, "Subsection"],
Cell[56093, 1123, 3351, 56, 1068, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[59481, 1184, 214, 13, 89, "Subsection"],
Cell[59698, 1199, 3352, 56, 1068, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[63087, 1260, 214, 13, 89, "Subsection"],
Cell[63304, 1275, 3351, 56, 1068, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[66692, 1336, 208, 12, 89, "Subsection"],
Cell[66903, 1350, 3354, 56, 1068, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[70294, 1411, 215, 13, 89, "Subsection"],
Cell[70512, 1426, 3351, 56, 1068, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[73900, 1487, 215, 13, 89, "Subsection"],
Cell[74118, 1502, 3353, 56, 1068, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[77508, 1563, 215, 13, 89, "Subsection"],
Cell[77726, 1578, 3352, 56, 1068, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[81115, 1639, 215, 13, 89, "Subsection"],
Cell[81333, 1654, 3352, 56, 1068, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[84722, 1715, 215, 13, 89, "Subsection"],
Cell[84940, 1730, 3351, 56, 1068, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[88328, 1791, 215, 13, 89, "Subsection"],
Cell[88546, 1806, 3350, 56, 1068, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[91933, 1867, 215, 13, 89, "Subsection"],
Cell[92151, 1882, 3350, 56, 1068, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[95538, 1943, 215, 13, 89, "Subsection"],
Cell[95756, 1958, 3352, 56, 1068, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[99145, 2019, 215, 13, 89, "Subsection"],
Cell[99363, 2034, 3351, 56, 1068, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[102751, 2095, 215, 13, 89, "Subsection"],
Cell[102969, 2110, 3352, 56, 1068, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[106358, 2171, 215, 13, 89, "Subsection"],
Cell[106576, 2186, 3352, 56, 1068, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[109965, 2247, 215, 13, 89, "Subsection"],
Cell[110183, 2262, 3353, 56, 1068, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[113573, 2323, 215, 13, 89, "Subsection"],
Cell[113791, 2338, 3352, 56, 1068, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[117180, 2399, 203, 11, 89, "Subsection"],
Cell[117386, 2412, 3352, 56, 1068, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[120775, 2473, 215, 13, 89, "Subsection"],
Cell[120993, 2488, 3351, 56, 1068, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[124381, 2549, 215, 13, 89, "Subsection"],
Cell[124599, 2564, 3351, 56, 1068, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[127987, 2625, 215, 13, 89, "Subsection"],
Cell[128205, 2640, 3351, 56, 1068, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[131593, 2701, 215, 13, 89, "Subsection"],
Cell[131811, 2716, 3352, 56, 1068, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[135200, 2777, 215, 13, 89, "Subsection"],
Cell[135418, 2792, 3352, 56, 1068, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[138807, 2853, 215, 13, 89, "Subsection"],
Cell[139025, 2868, 3352, 56, 1068, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[142414, 2929, 215, 13, 89, "Subsection"],
Cell[142632, 2944, 3351, 56, 1068, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[146020, 3005, 215, 13, 89, "Subsection"],
Cell[146238, 3020, 3353, 56, 1068, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[149628, 3081, 215, 13, 89, "Subsection"],
Cell[149846, 3096, 3352, 56, 1068, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[153235, 3157, 215, 13, 89, "Subsection"],
Cell[153453, 3172, 3353, 56, 1068, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[156843, 3233, 203, 11, 89, "Subsection"],
Cell[157049, 3246, 3352, 56, 1068, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[160438, 3307, 203, 11, 89, "Subsection"],
Cell[160644, 3320, 3353, 56, 1068, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[164034, 3381, 203, 11, 89, "Subsection"],
Cell[164240, 3394, 3353, 56, 1068, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[167630, 3455, 203, 11, 89, "Subsection"],
Cell[167836, 3468, 3352, 56, 1068, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[171225, 3529, 203, 11, 89, "Subsection"],
Cell[171431, 3542, 3352, 56, 1068, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[174820, 3603, 203, 11, 89, "Subsection"],
Cell[175026, 3616, 3351, 56, 1068, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[178414, 3677, 203, 11, 89, "Subsection"],
Cell[178620, 3690, 3350, 56, 1068, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[182019, 3752, 216, 5, 119, "Section"],
Cell[182238, 3759, 2443, 45, 888, "Input"],
Cell[184684, 3806, 16, 0, 56, "Text"],
Cell[184703, 3808, 2414, 43, 888, "Input"],
Cell[187120, 3853, 16, 0, 56, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

