(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     76850,       1708]*)
(*NotebookOutlinePosition[     77579,       1733]*)
(*  CellTagsIndexPosition[     77535,       1729]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Part ",
    FontWeight->"Bold"],
  StyleBox["3. Hydrogen-Like Atoms",
    FontWeight->"Bold"]
}], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
3.4. Visualization of the Radial Wave Functions and Radial Probability \
Densities of the Hydrogen-like Atoms\
\>", "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
1. Normalized radial wave functions and radial probability densities of the \
Hydrogen-like atoms\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[StyleBox["In this file we will present visualizations in \
individual scales for states defined by given quantum numbers.",
  FontWeight->"Bold"]], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Consider some states of the Hydrogen-like atoms defined by quantum numbers:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  Cell[BoxData[
      \(n\_rad = 0, 1, 2, 3\)],
    FontSlant->"Italic"],
  ",\n",
  Cell[BoxData[
      \(l\_orb = 0, 1, 2, 3\)],
    FontSlant->"Italic"]
}], "NumberedEquation"],

Cell[TextData[{
  "We will use \"",
  StyleBox["Graphics`FilledPlot`",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  "\" tool in this part to give vivid presentation of functions."
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(<< Graphics`FilledPlot`\)], "Input"],

Cell[TextData[{
  "Determine parameter ",
  StyleBox["Z",
    FontSlant->"Italic"],
  " of the Hydrogen-like atoms and the first Borh's radius (in special \
dimensionless units):"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(Z = 1;\)\ \), "\[IndentingNewLine]", 
    \(\(a\_0 = 1;\)\)}], "Input"],

Cell["\<\
Normalized radial wave functions and radial probability densities of the \
Hydrogen-like atoms for quantum numbers (1) are:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["Radial wave functions:", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(R\_HydAt[0, 0, Z] = 
        2\ \[ExponentialE]\^\(-\(\(r\ Z\)\/a\_0\)\)\ \
\((Z\/a\_0)\)\^\(3/2\);\)\), "\[IndentingNewLine]", 
    \(\(R\_HydAt[0, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\ \
\((Z\/a\_0)\)\^\(5/2\)\)\/\(2\ \@6\);\)\), "\[IndentingNewLine]", 
    \(\(R\_HydAt[0, 2, Z] = 
        2\/81\ \@\(2\/15\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ \
r\^2\ \((Z\/a\_0)\)\^\(7/2\);\)\), "\[IndentingNewLine]", 
    \(\(R\_HydAt[0, 3, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(4\ a\_0\)\)\)\ r\^3\ \
\((Z\/a\_0)\)\^\(9/2\)\)\/\(768\ \@35\);\)\), "\[IndentingNewLine]", 
    \(\(R\_HydAt[1, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ \((2 - \(r\ \
Z\)\/a\_0)\)\ \((Z\/a\_0)\)\^\(3/2\)\)\/\(2\ \@2\);\)\), \
"\[IndentingNewLine]", 
    \(\(R\_HydAt[1, 1, 
          Z] = \(-\(2\/27\)\)\ \@\(2\/3\)\ \[ExponentialE]\^\(-\(\(r\ \
Z\)\/\(3\ a\_0\)\)\)\ r\ \((\(-2\) + \(r\ Z\)\/\(3\ a\_0\))\)\ \
\((Z\/a\_0)\)\^\(5/2\);\)\), "\[IndentingNewLine]", 
    \(\(R\_HydAt[1, 2, 
          Z] = \(-\(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(4\ a\_0\)\)\)\ r\^2\ \
\((\(-3\) + \(r\ Z\)\/\(4\ a\_0\))\)\ \((Z\/a\_0)\)\^\(7/2\)\)\/\(192\ \
\@5\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(R\_HydAt[1, 3, 
          Z] = \(-\(\(2\ \@\(2\/35\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(5\ \
a\_0\)\)\)\ r\^3\ \((\(-4\) + \(r\ Z\)\/\(5\ a\_0\))\)\ \
\((Z\/a\_0)\)\^\(9/2\)\)\/9375\)\);\)\), "\[IndentingNewLine]", 
    \(\(R\_HydAt[2, 0, 
          Z] = \(2\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ \((3 + \
\(2\ r\ Z\ \((r\ Z - 9\ a\_0)\)\)\/\(9\ a\_0\%2\))\)\ \
\((Z\/a\_0)\)\^\(3/2\)\)\/\(9\ \@3\);\)\), "\[IndentingNewLine]", 
    \(\(R\_HydAt[2, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(4\ a\_0\)\)\)\ r\ \((5 + \
\(r\ Z\ \((r\ Z - 20\ a\_0)\)\)\/\(16\ a\_0\%2\))\)\ \((Z\/a\_0)\)\^\(5/2\)\)\
\/\(16\ \@15\);\)\), "\[IndentingNewLine]", 
    \(\(R\_HydAt[2, 2, 
          Z] = \(1\/1875\) \((2\ \@\(2\/35\)\ \[ExponentialE]\^\(-\(\(r\ \
Z\)\/\(5\ a\_0\)\)\)\ r\^2\ \((21 + \(2\ r\ Z\ \((r\ Z - 35\ a\_0)\)\)\/\(25\ \
a\_0\%2\))\)\ \((Z\/a\_0)\)\^\(7/2\))\);\)\), "\[IndentingNewLine]", 
    \(\(R\_HydAt[2, 3, 
          Z] = \(-\(1\/\(972\ \@105\)\)\) \((\[ExponentialE]\^\(-\(\(r\ Z\)\/\
\(6\ a\_0\)\)\)\ r\^2\ \((Z\/a\_0)\)\^\(7/2\)\ \((\(-42\) + \(r\ Z\ \((r\^2\ \
Z\^2 + 72\ a\_0\ \((\(-r\)\ Z + 21\ a\_0)\))\)\)\/\(216\ \
a\_0\%3\))\))\);\)\), "\[IndentingNewLine]", 
    \(\(R\_HydAt[3, 0, Z] = 
        1\/12\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(4\ a\_0\)\)\)\ \((3 - \(r\ Z\
\ \((r\ Z - 12\ a\_0)\)\^2\)\/\(64\ a\_0\%3\))\)\ \
\((Z\/a\_0)\)\^\(3/2\);\)\), "\[IndentingNewLine]", 
    \(\(R\_HydAt[3, 1, 
          Z] = \(-\(2\/375\)\)\ \@\(2\/15\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\
\(5\ a\_0\)\)\)\ r\ \((Z\/a\_0)\)\^\(5/2\)\ \((\(-30\) + \(r\ Z\ \((2\ r\^2\ \
Z\^2 + 45\ a\_0\ \((\(-2\)\ r\ Z + 25\ a\_0)\))\)\)\/\(125\ \
a\_0\%3\))\);\)\), "\[IndentingNewLine]", 
    \(\(R\_HydAt[3, 2, 
          Z] = \(-\(1\/\(972\ \@105\)\)\) \((\[ExponentialE]\^\(-\(\(r\ Z\)\/\
\(6\ a\_0\)\)\)\ r\^2\ \((Z\/a\_0)\)\^\(7/2\)\ \((\(-42\) + \(r\ Z\ \((r\^2\ \
Z\^2 + 72\ a\_0\ \((\(-r\)\ Z + 21\ a\_0)\))\)\)\/\(216\ \
a\_0\%3\))\))\);\)\), "\[IndentingNewLine]", 
    \(\(R\_HydAt[3, 3, 
          Z] = \(-\(1\/756315\)\) \((2\ \@\(2\/21\)\ \
\[ExponentialE]\^\(-\(\(r\ Z\)\/\(7\ a\_0\)\)\)\ r\^3\ \((Z\/a\_0)\)\^\(9/2\)\
\ \((\(-180\) + \(r\ Z\ \((2\ r\^2\ Z\^2 + 105\ a\_0\ \((\(-2\)\ r\ Z + 63\ a\
\_0)\))\)\)\/\(343\ a\_0\%3\))\))\);\)\)}], "Input"],

Cell["Radial probability densities:", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(RR\_HydAt[0, 0, 
          Z] = \(4\ \[ExponentialE]\^\(-\(\(2\ r\ Z\)\/a\_0\)\)\ r\^2\ Z\^3\)\
\/a\_0\%3;\)\), "\[IndentingNewLine]", 
    \(\(RR\_HydAt[0, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/a\_0\)\)\ r\^4\ Z\^5\)\/\(24\
\ a\_0\%5\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_HydAt[0, 2, 
          Z] = \(8\ \[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(3\ a\_0\)\)\)\ r\^6\ \
Z\^7\)\/\(98415\ a\_0\%7\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_HydAt[0, 3, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\^8\ \
Z\^9\)\/\(20643840\ a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_HydAt[1, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/a\_0\)\)\ r\^2\ Z\^3\ \((2 - \
\(r\ Z\)\/a\_0)\)\^2\)\/\(8\ a\_0\%3\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_HydAt[1, 1, 
          Z] = \(8\ \[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(3\ a\_0\)\)\)\ r\^4\ \
Z\^5\ \((\(-2\) + \(r\ Z\)\/\(3\ a\_0\))\)\^2\)\/\(2187\ a\_0\%5\);\)\), "\
\[IndentingNewLine]", 
    \(\(RR\_HydAt[1, 2, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\^6\ Z\^7\ \
\((\(-3\) + \(r\ Z\)\/\(4\ a\_0\))\)\^2\)\/\(184320\ a\_0\%7\);\)\), "\
\[IndentingNewLine]", 
    \(\(RR\_HydAt[1, 3, 
          Z] = \(8\ \[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(5\ a\_0\)\)\)\ r\^8\ \
Z\^9\ \((\(-4\) + \(r\ Z\)\/\(5\ a\_0\))\)\^2\)\/\(3076171875\ \
a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_HydAt[2, 0, 
          Z] = \(4\ \[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(3\ a\_0\)\)\)\ r\^2\ \
Z\^3\ \((3 + \(2\ r\ Z\ \((r\ Z - 9\ a\_0)\)\)\/\(9\ a\_0\%2\))\)\^2\)\/\(243\
\ a\_0\%3\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_HydAt[2, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\^4\ Z\^5\ \
\((5 + \(r\ Z\ \((r\ Z - 20\ a\_0)\)\)\/\(16\ a\_0\%2\))\)\^2\)\/\(3840\ a\_0\
\%5\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_HydAt[2, 2, 
          Z] = \(8\ \[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(5\ a\_0\)\)\)\ r\^6\ \
Z\^7\ \((21 + \(2\ r\ Z\ \((r\ Z - 35\ a\_0)\)\)\/\(25\ \
a\_0\%2\))\)\^2\)\/\(123046875\ a\_0\%7\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_HydAt[2, 3, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ r\^6\ Z\^7\ \
\((\(-42\) + \(r\ Z\ \((r\^2\ Z\^2 + 72\ a\_0\ \((\(-r\)\ Z + 21\ \
a\_0)\))\)\)\/\(216\ a\_0\%3\))\)\^2\)\/\(99202320\ a\_0\%7\);\)\), "\
\[IndentingNewLine]", 
    \(\(RR\_HydAt[3, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\^2\ Z\^3\ \
\((3 - \(r\ Z\ \((r\ Z - 12\ a\_0)\)\^2\)\/\(64\ a\_0\%3\))\)\^2\)\/\(144\ \
a\_0\%3\);\)\), "\[IndentingNewLine]", 
    \(\(RR\_HydAt[3, 1, 
          Z] = \(1\/\(2109375\ a\_0\%5\)\) \((8\ \[ExponentialE]\^\(-\(\(2\ r\
\ Z\)\/\(5\ a\_0\)\)\)\ r\^4\ Z\^5\ \((\(-30\) + \(r\ Z\ \((2\ r\^2\ Z\^2 + \
45\ a\_0\ \((\(-2\)\ r\ Z + 25\ a\_0)\))\)\)\/\(125\ a\_0\%3\))\)\^2)\);\)\), \
"\[IndentingNewLine]", 
    \(\(RR\_HydAt[3, 2, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ r\^6\ Z\^7\ \
\((\(-42\) + \(r\ Z\ \((r\^2\ Z\^2 + 72\ a\_0\ \((\(-r\)\ Z + 21\ \
a\_0)\))\)\)\/\(216\ a\_0\%3\))\)\^2\)\/\(99202320\ a\_0\%7\);\)\), "\
\[IndentingNewLine]", 
    \(\(RR\_HydAt[3, 3, 
          Z] = \(8\ \[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(7\ a\_0\)\)\)\ r\^8\ \
Z\^9\)\/\(12012259963725\ a\_0\%9\)\ \((\(-180\) + \(r\ Z\ \((2\ r\^2\ Z\^2 + \
105\ a\_0\ \((\(-2\)\ r\ Z + 63\ a\_0)\))\)\)\/\(343\ a\_0\%3\))\)\^2;\)\)}], \
"Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2. Visualization of the radial wave functions, radial probability densities \
and probability densities of the Hydrogen-like atoms\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Now we present visualizations of the radial wave functions, radial \
probability densities and probability densities of the Hydrogen-like atoms.
We will obtain three-dimensional plots for radial  functions and radial \
probability densities and present density and surface (three-dimensional) \
plots for probability densities of the Hydrogen-like atoms.
In this file we will present visualizations in individual scales for states \
defined by given quantum numbers.\
\>", "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox["Parameters of Plots:",
    FontWeight->"Bold"],
  "\n",
  StyleBox["2d Plots",
    FontWeight->"Bold"],
  "\n\t\tVariable Range: {x2dMin, x2dMax}\n\t\tPlot Range for 2d Plots: \
{PR2dMin, PR2dMax}\n\t\tImage Size for 2d Plots: {IS2dHorz, IS2dVert}\n\n",
  StyleBox["3d Plots",
    FontWeight->"Bold"],
  "\n\t\tVariable Range: {x3dMin, x3dMax, y3dMin, y3dMax}\n\t\tPlot Range for \
3d Plots: {PR3dMin, PR3dMax}\n\t\tPlot Points for 3d Plots: {N3d}\n\t\tImage \
Size for 3d Plots: {IS3DHorz, IS3DVert}\n\t\tViewPoint for 3d Plots: {VP1, \
VP2, VP3} or {WP1, WP2, WP3}"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(IS2dHorz = 350;\)\), "\[IndentingNewLine]", 
    \(\(\(IS2dVert = 250;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(IS3dHorz = 350;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 250;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(N3d = 100;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(VP1 = 0.000;\)\), "\[IndentingNewLine]", 
    \(\(VP2 = \(-1.825\);\)\), "\[IndentingNewLine]", 
    \(\(VP3 = 1.25;\)\)}], "Input"],

Cell[CellGroupData[{

Cell[TextData[{
  "1) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 0, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 0"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.05\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 2.05;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-4.5\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 4.5;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-4.5\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 4.5;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.575;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_HydAt[n\_rad, l\_orb, Z, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_HydAt[n\_rad, l\_orb, Z], 
            RR\_HydAt[n\_rad, l\_orb, Z]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=0,\!\(l\_orb\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_HydAt[n\_rad, l\_orb, Z] = 
        FullSimplify[
          ReplaceAll[
            RR\_HydAt[n\_rad, l\_orb, 
              Z], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_HydAt[n\_rad, l\_orb, Z] = 
        If[y < 0, 0, RRxy\_HydAt[n\_rad, l\_orb, Z]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_HydAt[n\_rad, l\_orb, Z, x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[
          RRxy2\_HydAt[n\_rad, l\_orb, Z], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=0,\!\(l\_orb\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_HydAt[n\_rad, l\_orb, Z, x2dMin, x2dMax, 
              PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_HydAt[n\_rad, 
              l\_orb, Z, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {700, 
          250}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Presentation  of \
Radial function for \!\(n\_rad\)=0,\!\(l\_orb\)=0\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "2) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 0, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 1"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 14;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.005\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.205;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-13\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 13;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-13\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 13;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.205;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_HydAt[n\_rad, l\_orb, Z, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_HydAt[n\_rad, l\_orb, Z], 
            RR\_HydAt[n\_rad, l\_orb, Z]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=0,\!\(l\_orb\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_HydAt[n\_rad, l\_orb, Z] = 
        FullSimplify[
          ReplaceAll[
            RR\_HydAt[n\_rad, l\_orb, 
              Z], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_HydAt[n\_rad, l\_orb, Z] = 
        If[y < 0, 0, RRxy\_HydAt[n\_rad, l\_orb, Z]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_HydAt[n\_rad, l\_orb, Z, x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[
          RRxy2\_HydAt[n\_rad, l\_orb, Z], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=0,\!\(l\_orb\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_HydAt[n\_rad, l\_orb, Z, x2dMin, x2dMax, 
              PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_HydAt[n\_rad, 
              l\_orb, Z, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {700, 
          250}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Presentation  of \
Radial function for \!\(n\_rad\)=0,\!\(l\_orb\)=1\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "3) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 0, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 2"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 25;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.005\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.11;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-23\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 23;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-23\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 23;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.11;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_HydAt[n\_rad, l\_orb, Z, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_HydAt[n\_rad, l\_orb, Z], 
            RR\_HydAt[n\_rad, l\_orb, Z]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=0,\!\(l\_orb\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_HydAt[n\_rad, l\_orb, Z] = 
        FullSimplify[
          ReplaceAll[
            RR\_HydAt[n\_rad, l\_orb, 
              Z], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_HydAt[n\_rad, l\_orb, Z] = 
        If[y < 0, 0, RRxy\_HydAt[n\_rad, l\_orb, Z]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_HydAt[n\_rad, l\_orb, Z, x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[
          RRxy2\_HydAt[n\_rad, l\_orb, Z], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=0,\!\(l\_orb\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_HydAt[n\_rad, l\_orb, Z, x2dMin, x2dMax, 
              PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_HydAt[n\_rad, 
              l\_orb, Z, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {700, 
          250}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Presentation  of \
Radial function for \!\(n\_rad\)=0,\!\(l\_orb\)=2\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "4) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 0, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 40;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.01\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.075;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-40\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 40;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-40\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 40;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.075;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_HydAt[n\_rad, l\_orb, Z, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_HydAt[n\_rad, l\_orb, Z], 
            RR\_HydAt[n\_rad, l\_orb, Z]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=0,\!\(l\_orb\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_HydAt[n\_rad, l\_orb, Z] = 
        FullSimplify[
          ReplaceAll[
            RR\_HydAt[n\_rad, l\_orb, 
              Z], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_HydAt[n\_rad, l\_orb, Z] = 
        If[y < 0, 0, RRxy\_HydAt[n\_rad, l\_orb, Z]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_HydAt[n\_rad, l\_orb, Z, x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[
          RRxy2\_HydAt[n\_rad, l\_orb, Z], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=0,\!\(l\_orb\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_HydAt[n\_rad, l\_orb, Z, x2dMin, x2dMax, 
              PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_HydAt[n\_rad, 
              l\_orb, Z, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {700, 
          250}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Presentation  of \
Radial function for \!\(n\_rad\)=0,\!\(l\_orb\)=3\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "5) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 0"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 13;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.1\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.7;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-13\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 13;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-13\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 13;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_HydAt[n\_rad, l\_orb, Z, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_HydAt[n\_rad, l\_orb, Z], 
            RR\_HydAt[n\_rad, l\_orb, Z]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=1,\!\(l\_orb\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_HydAt[n\_rad, l\_orb, Z] = 
        FullSimplify[
          ReplaceAll[
            RR\_HydAt[n\_rad, l\_orb, 
              Z], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_HydAt[n\_rad, l\_orb, Z] = 
        If[y < 0, 0, RRxy\_HydAt[n\_rad, l\_orb, Z]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_HydAt[n\_rad, l\_orb, Z, x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[
          RRxy2\_HydAt[n\_rad, l\_orb, Z], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=1,\!\(l\_orb\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_HydAt[n\_rad, l\_orb, Z, x2dMin, x2dMax, 
              PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_HydAt[n\_rad, 
              l\_orb, Z, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {700, 
          250}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Presentation  of \
Radial function for \!\(n\_rad\)=1,\!\(l\_orb\)=0\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "6) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 1"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 30;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.03\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.105;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-30\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 30;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-30\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 30;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.12;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_HydAt[n\_rad, l\_orb, Z, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_HydAt[n\_rad, l\_orb, Z], 
            RR\_HydAt[n\_rad, l\_orb, Z]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=1,\!\(l\_orb\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_HydAt[n\_rad, l\_orb, Z] = 
        FullSimplify[
          ReplaceAll[
            RR\_HydAt[n\_rad, l\_orb, 
              Z], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_HydAt[n\_rad, l\_orb, Z] = 
        If[y < 0, 0, RRxy\_HydAt[n\_rad, l\_orb, Z]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_HydAt[n\_rad, l\_orb, Z, x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[
          RRxy2\_HydAt[n\_rad, l\_orb, Z], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=1,\!\(l\_orb\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_HydAt[n\_rad, l\_orb, Z, x2dMin, x2dMax, 
              PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_HydAt[n\_rad, 
              l\_orb, Z, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {700, 
          250}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Presentation  of \
Radial function for \!\(n\_rad\)=1,\!\(l\_orb\)=1\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "7) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 2"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 45;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.015\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.07;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-45\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 45;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-45\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 45;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.07;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_HydAt[n\_rad, l\_orb, Z, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_HydAt[n\_rad, l\_orb, Z], 
            RR\_HydAt[n\_rad, l\_orb, Z]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=1,\!\(l\_orb\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_HydAt[n\_rad, l\_orb, Z] = 
        FullSimplify[
          ReplaceAll[
            RR\_HydAt[n\_rad, l\_orb, 
              Z], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_HydAt[n\_rad, l\_orb, Z] = 
        If[y < 0, 0, RRxy\_HydAt[n\_rad, l\_orb, Z]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_HydAt[n\_rad, l\_orb, Z, x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[
          RRxy2\_HydAt[n\_rad, l\_orb, Z], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=1,\!\(l\_orb\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_HydAt[n\_rad, l\_orb, Z, x2dMin, x2dMax, 
              PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_HydAt[n\_rad, 
              l\_orb, Z, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {700, 
          250}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Presentation  of \
Radial function for \!\(n\_rad\)=1,\!\(l\_orb\)=2\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "8) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 80;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.00775\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.0475;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-65\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 65;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-65\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 65;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.0475;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_HydAt[n\_rad, l\_orb, Z, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_HydAt[n\_rad, l\_orb, Z], 
            RR\_HydAt[n\_rad, l\_orb, Z]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=1,\!\(l\_orb\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_HydAt[n\_rad, l\_orb, Z] = 
        FullSimplify[
          ReplaceAll[
            RR\_HydAt[n\_rad, l\_orb, 
              Z], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_HydAt[n\_rad, l\_orb, Z] = 
        If[y < 0, 0, RRxy\_HydAt[n\_rad, l\_orb, Z]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_HydAt[n\_rad, l\_orb, Z, x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[
          RRxy2\_HydAt[n\_rad, l\_orb, Z], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=1,\!\(l\_orb\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_HydAt[n\_rad, l\_orb, Z, x2dMin, x2dMax, 
              PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_HydAt[n\_rad, 
              l\_orb, Z, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {700, 
          250}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Presentation  of \
Radial function for \!\(n\_rad\)=1,\!\(l\_orb\)=3\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "9) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 2, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 0"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 30;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.0545\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.4;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-30\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 30;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-30\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 30;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.125;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_HydAt[n\_rad, l\_orb, Z, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_HydAt[n\_rad, l\_orb, Z], 
            RR\_HydAt[n\_rad, l\_orb, Z]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=2,\!\(l\_orb\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_HydAt[n\_rad, l\_orb, Z] = 
        FullSimplify[
          ReplaceAll[
            RR\_HydAt[n\_rad, l\_orb, 
              Z], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_HydAt[n\_rad, l\_orb, Z] = 
        If[y < 0, 0, RRxy\_HydAt[n\_rad, l\_orb, Z]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_HydAt[n\_rad, l\_orb, Z, x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[
          RRxy2\_HydAt[n\_rad, l\_orb, Z], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=2,\!\(l\_orb\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_HydAt[n\_rad, l\_orb, Z, x2dMin, x2dMax, 
              PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_HydAt[n\_rad, 
              l\_orb, Z, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {700, 
          250}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Presentation  of \
Radial function for \!\(n\_rad\)=2,\!\(l\_orb\)=0\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "10) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 2, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 1"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 45;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.02\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.0675;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-45\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 45;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-45\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 45;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.0675;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_HydAt[n\_rad, l\_orb, Z, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_HydAt[n\_rad, l\_orb, Z], 
            RR\_HydAt[n\_rad, l\_orb, Z]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=2,\!\(l\_orb\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_HydAt[n\_rad, l\_orb, Z] = 
        FullSimplify[
          ReplaceAll[
            RR\_HydAt[n\_rad, l\_orb, 
              Z], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_HydAt[n\_rad, l\_orb, Z] = 
        If[y < 0, 0, RRxy\_HydAt[n\_rad, l\_orb, Z]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_HydAt[n\_rad, l\_orb, Z, x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[
          RRxy2\_HydAt[n\_rad, l\_orb, Z], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=2,\!\(l\_orb\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_HydAt[n\_rad, l\_orb, Z, x2dMin, x2dMax, 
              PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_HydAt[n\_rad, 
              l\_orb, Z, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {700, 
          250}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Presentation  of \
Radial function for \!\(n\_rad\)=2,\!\(l\_orb\)=1\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "11) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 2, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 2"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 70;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.01\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.0475;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-70\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 70;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-70\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 70;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.0475;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_HydAt[n\_rad, l\_orb, Z, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_HydAt[n\_rad, l\_orb, Z], 
            RR\_HydAt[n\_rad, l\_orb, Z]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=2,\!\(l\_orb\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_HydAt[n\_rad, l\_orb, Z] = 
        FullSimplify[
          ReplaceAll[
            RR\_HydAt[n\_rad, l\_orb, 
              Z], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_HydAt[n\_rad, l\_orb, Z] = 
        If[y < 0, 0, RRxy\_HydAt[n\_rad, l\_orb, Z]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_HydAt[n\_rad, l\_orb, Z, x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[
          RRxy2\_HydAt[n\_rad, l\_orb, Z], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=2,\!\(l\_orb\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_HydAt[n\_rad, l\_orb, Z, x2dMin, x2dMax, 
              PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_HydAt[n\_rad, 
              l\_orb, Z, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {700, 
          250}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Presentation  of \
Radial function for \!\(n\_rad\)=2,\!\(l\_orb\)=2\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "12) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 2, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 93;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.00725\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.035;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-93\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 93;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-93\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 93;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.035;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_HydAt[n\_rad, l\_orb, Z, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_HydAt[n\_rad, l\_orb, Z], 
            RR\_HydAt[n\_rad, l\_orb, Z]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=2,\!\(l\_orb\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_HydAt[n\_rad, l\_orb, Z] = 
        FullSimplify[
          ReplaceAll[
            RR\_HydAt[n\_rad, l\_orb, 
              Z], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_HydAt[n\_rad, l\_orb, Z] = 
        If[y < 0, 0, RRxy\_HydAt[n\_rad, l\_orb, Z]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_HydAt[n\_rad, l\_orb, Z, x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[
          RRxy2\_HydAt[n\_rad, l\_orb, Z], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=2,\!\(l\_orb\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_HydAt[n\_rad, l\_orb, Z, x2dMin, x2dMax, 
              PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_HydAt[n\_rad, 
              l\_orb, Z, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {700, 
          250}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Presentation  of \
Radial function for \!\(n\_rad\)=2,\!\(l\_orb\)=3\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "13) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 3, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 0"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 45;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.05\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.27;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-45\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 45;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-45\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 45;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.0725;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_HydAt[n\_rad, l\_orb, Z, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_HydAt[n\_rad, l\_orb, Z], 
            RR\_HydAt[n\_rad, l\_orb, Z]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=3,\!\(l\_orb\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_HydAt[n\_rad, l\_orb, Z] = 
        FullSimplify[
          ReplaceAll[
            RR\_HydAt[n\_rad, l\_orb, 
              Z], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_HydAt[n\_rad, l\_orb, Z] = 
        If[y < 0, 0, RRxy\_HydAt[n\_rad, l\_orb, Z]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_HydAt[n\_rad, l\_orb, Z, x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[
          RRxy2\_HydAt[n\_rad, l\_orb, Z], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=3,\!\(l\_orb\)=0\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_HydAt[n\_rad, l\_orb, Z, x2dMin, x2dMax, 
              PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_HydAt[n\_rad, 
              l\_orb, Z, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {700, 
          250}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Presentation  of \
Radial function for \!\(n\_rad\)=3,\!\(l\_orb\)=0\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "14) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 3, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 1"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 70;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.014\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.0475;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-70\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 70;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-70\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 70;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.0475;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_HydAt[n\_rad, l\_orb, Z, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_HydAt[n\_rad, l\_orb, Z], 
            RR\_HydAt[n\_rad, l\_orb, Z]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=3,\!\(l\_orb\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_HydAt[n\_rad, l\_orb, Z] = 
        FullSimplify[
          ReplaceAll[
            RR\_HydAt[n\_rad, l\_orb, 
              Z], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_HydAt[n\_rad, l\_orb, Z] = 
        If[y < 0, 0, RRxy\_HydAt[n\_rad, l\_orb, Z]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_HydAt[n\_rad, l\_orb, Z, x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[
          RRxy2\_HydAt[n\_rad, l\_orb, Z], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=3,\!\(l\_orb\)=1\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_HydAt[n\_rad, l\_orb, Z, x2dMin, x2dMax, 
              PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_HydAt[n\_rad, 
              l\_orb, Z, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {700, 
          250}, \[IndentingNewLine]ImageSize \[Rule] {700, 
          250}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Presentation  of \
Radial function for \!\(n\_rad\)=3,\!\(l\_orb\)=1\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "15) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 3, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 2"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 90;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.00775\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.0355;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-90\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 90;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-90\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 90;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.0355;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Grph2dRR\_HydAt[n\_rad, l\_orb, Z, x2dMin, x2dMax, PR2dMin, PR2dMax, 
          IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_HydAt[n\_rad, l\_orb, Z], 
            RR\_HydAt[n\_rad, l\_orb, Z]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=3,\!\(l\_orb\)=2\>\""];\)\[IndentingNewLine]\
\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_HydAt[n\_rad, l\_orb, Z] = 
        FullSimplify[
          ReplaceAll[
            RR\_HydAt[n\_rad, l\_orb, 
              Z], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_HydAt[n\_rad, l\_orb, Z] = 
        If[y < 0, 0, RRxy\_HydAt[n\_rad, l\_orb, Z]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_HydAt[n\_rad, l\_orb, Z, x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[
          RRxy2\_HydAt[n\_rad, l\_orb, Z], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=3,\!\(l\_orb\)=2\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_HydAt[n\_rad, l\_orb, Z, x2dMin, x2dMax, 
              PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_HydAt[n\_rad, 
              l\_orb, Z, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {700, 
          250}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Presentation  of \
Radial function for \!\(n\_rad\)=3,\!\(l\_orb\)=2\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "16) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 3, ",
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(l\_orb = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(x2dMax = 120;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.0045\);\)\), "\[IndentingNewLine]", 
    \(\(\(PR2dMax = 0.0275;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-120\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 120;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-120\);\)\), "\[IndentingNewLine]", 
    \(\(\(y3dMax = 120;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(PR3dMax = 0.0275;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph2dRR\_HydAt[n\_rad, l\_orb, Z, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[{R\_HydAt[n\_rad, l\_orb, Z], 
            RR\_HydAt[n\_rad, l\_orb, Z]}, \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {{{1, Axis}, 
                RGBColor[0, 1, 0]}, {{2, Axis}, 
                RGBColor[1, 0, 0]}}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.00785], Thickness[0.00785]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Radial \
functions for \!\(n\_rad\)=3,\!\(l\_orb\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(RRxy\_HydAt[n\_rad, l\_orb, Z] = 
        FullSimplify[
          ReplaceAll[
            RR\_HydAt[n\_rad, l\_orb, 
              Z], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RRxy2\_HydAt[n\_rad, l\_orb, Z] = 
        If[y < 0, 0, RRxy\_HydAt[n\_rad, l\_orb, Z]];\)\), "\n", 
    \(\(\(Grph3dDenRRxy2\_HydAt[n\_rad, l\_orb, Z, x3dMin, x3dMax, y3dMin, 
          y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
          N3d] = Plot3D[
          RRxy2\_HydAt[n\_rad, l\_orb, Z], \[IndentingNewLine]{x, x3dMin, 
            x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<3D \
vision for \!\(n\_rad\)=3,\!\(l\_orb\)=3\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph2dRR\_HydAt[n\_rad, l\_orb, Z, x2dMin, x2dMax, 
              PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3dDenRRxy2\_HydAt[n\_rad, 
              l\_orb, Z, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {700, 
          250}, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<Presentation  of \
Radial function for \!\(n\_rad\)=3,\!\(l\_orb\)=3\>\""]\)}], "Input"],

Cell["", "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1016, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.25,
StyleDefinitions -> "Classroom1.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 186, 7, 56, "Subtitle"],
Cell[2459, 81, 189, 5, 124, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2673, 90, 171, 5, 85, "Section"],
Cell[2847, 97, 216, 4, 56, "Text"],
Cell[3066, 103, 146, 4, 56, "Text"],
Cell[3215, 109, 195, 8, 72, "NumberedEquation"],
Cell[3413, 119, 293, 9, 57, "Text"],
Cell[3709, 130, 56, 1, 63, "Input"],
Cell[3768, 133, 238, 8, 56, "Text"],
Cell[4009, 143, 94, 2, 88, "Input"],
Cell[4106, 147, 194, 5, 56, "Text"],
Cell[4303, 154, 85, 2, 56, "Text"],
Cell[4391, 158, 3553, 64, 1380, "Input"],
Cell[7947, 224, 92, 2, 56, "Text"],
Cell[8042, 228, 3410, 63, 1352, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11489, 296, 204, 5, 119, "Section"],
Cell[11696, 303, 490, 8, 176, "Text"],
Cell[12189, 313, 666, 17, 452, "Text"],
Cell[12858, 332, 498, 10, 313, "Input"],

Cell[CellGroupData[{
Cell[13381, 346, 185, 10, 89, "Subsection"],
Cell[13569, 358, 3737, 68, 1455, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17343, 431, 185, 10, 89, "Subsection"],
Cell[17531, 443, 3736, 68, 1455, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21304, 516, 185, 10, 89, "Subsection"],
Cell[21492, 528, 3734, 68, 1455, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25263, 601, 185, 10, 89, "Subsection"],
Cell[25451, 613, 3735, 68, 1455, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29223, 686, 185, 10, 89, "Subsection"],
Cell[29411, 698, 3730, 68, 1455, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33178, 771, 185, 10, 89, "Subsection"],
Cell[33366, 783, 3734, 68, 1455, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37137, 856, 185, 10, 89, "Subsection"],
Cell[37325, 868, 3734, 68, 1455, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41096, 941, 185, 10, 89, "Subsection"],
Cell[41284, 953, 3740, 68, 1455, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[45061, 1026, 185, 10, 89, "Subsection"],
Cell[45249, 1038, 3735, 68, 1455, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49021, 1111, 186, 10, 89, "Subsection"],
Cell[49210, 1123, 3737, 68, 1455, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52984, 1196, 186, 10, 89, "Subsection"],
Cell[53173, 1208, 3737, 68, 1455, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[56947, 1281, 186, 10, 89, "Subsection"],
Cell[57136, 1293, 3738, 68, 1455, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[60911, 1366, 186, 10, 89, "Subsection"],
Cell[61100, 1378, 3735, 68, 1455, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[64872, 1451, 186, 10, 89, "Subsection"],
Cell[65061, 1463, 3798, 69, 1480, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[68896, 1537, 186, 10, 89, "Subsection"],
Cell[69085, 1549, 3748, 68, 1480, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[72870, 1622, 186, 10, 89, "Subsection"],
Cell[73059, 1634, 3744, 68, 1455, "Input"],
Cell[76806, 1704, 16, 0, 56, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

