(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    164474,       3699]*)
(*NotebookOutlinePosition[    165203,       3724]*)
(*  CellTagsIndexPosition[    165159,       3720]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Part ",
    FontWeight->"Bold"],
  StyleBox["3. Hydrogen-Like Atoms",
    FontWeight->"Bold"]
}], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
3.6. Wave Functions and Probability Densities of the Hydrogen-Like Atoms in \
the Cartesian Rectangular Coordinates\
\>", "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
1. Radial and angular wave functions and probability densities of the \
Hydrogen-like atoms\
\>", "Section"],

Cell["\<\
Normalized radial wave functions and radial probability densities of the \
Hydrogen-like atoms for quantum numbers are:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell[BoxData[
    \(R\_HydAt[n\_rad, l\_orb, 
        Z] = \(\(\((Z\/\(\((1 + l\_orb + n\_rad)\) a\_0\))\)\^\(3/
              2\)\)\(\ \ \)\(\@\(\(4\ \(n\_rad!\)\)\/\(\(\ \)\(\(\((1 + 
                        2\ l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + 
                      n\_rad)\)\)\)\)\)\(\ \)\(\[ExponentialE]\^\(-\(\(r\ Z\)\
\/\(a\_0\ \((1 + l\_orb + 
                        n\_rad)\)\)\)\)\)\(\ \)\(\((\(2\ r\ Z\)\/\(\((1 + \
l\_orb + n\_rad)\) a\_0\))\)\^l\_orb\)\(\ \)\(LaguerreL[n\_rad, 
          1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\)]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
        1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
\@\(\(n\_rad!\)\/\(\(\((1 + 2\ l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\
\)\)\)\ \((Z\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ \
Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\))\)\^l\_orb\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RR\_HydAt[n\_rad, l\_orb, 
        Z] = \((R\_HydAt[n\_rad, l\_orb, Z]\ r)\)\^2\)], "Input"],

Cell[BoxData[
    \(\((2\^\(2 + 2\ l\_orb\)\ \[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(a\_0\ \
\((1 + l\_orb + n\_rad)\)\)\)\)\ r\^2\ Z\^3\ \(n\_rad!\)\ LaguerreL[n\_rad, 1 \
+ 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\^2\ \((\(r\ \
Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\))\)\^\(2\ l\_orb\))\)/\((\(\((1 + 
                2\ l\_orb + 
                n\_rad)\)!\)\ a\_0\%3\ \((1 + l\_orb + n\_rad)\)\^4)\)\)], \
"Output"]
}, Open  ]],

Cell["\<\
Normalized angular wave functions (spherical harmonics) and angular \
probability densities of the Hydrogen-like atoms for given quantum numbers \
are:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[CellGroupData[{

Cell[BoxData[
    \(Y[l\_orb, m\_azm] = 
      SphericalHarmonicY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]\)], "Input"],

Cell[BoxData[
    \(SphericalHarmonicY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(YY[l\_orb, m\_azm] = 
      FullSimplify[
        ComplexExpand[
          SphericalHarmonicY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]*
            Conjugate[
              SphericalHarmonicY[l\_orb, 
                m\_azm, \[Theta], \[CurlyPhi]]]]]\)], "Input"],

Cell[BoxData[
    \(Abs[SphericalHarmonicY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]]\^2\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Psi]\_HydAt[n\_rad, l\_orb, m\_azm, Z] = 
      R\_HydAt[n\_rad, l\_orb, Z]\ Y[l\_orb, m\_azm]\)], "Input"],

Cell[BoxData[
    \(2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
        1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
SphericalHarmonicY[l\_orb, 
        m\_azm, \[Theta], \[CurlyPhi]]\ \@\(\(n\_rad!\)\/\(\(\((1 + 2\ l\_orb \
+ n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\)\)\)\ \((Z\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\))\)\^l\_orb\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2. Wave functions and probability densities of the Hydrogen-like atoms for \
given quantum numbers\
\>", "Section"],

Cell["\<\
Wave functions and probability densities of the Hydrogen-like atoms defines \
by the formula:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(\[Psi]\_HydAt[n\_rad, l\_orb, m\_azm, Z] = 
      R\_HydAt[n\_rad, l\_orb, \[Lambda]]\ Y[l\_orb, 
          m\_azm]\)], "NumberedEquation"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      StyleBox[\(R\_HydAt[n\_rad, l\_orb, Z]\),
        FontSlant->"Italic"]]],
  " is the radial wave function and ",
  Cell[BoxData[
      StyleBox[\(Y[l\_orb, m\_azm]\),
        FontSlant->"Italic"]]],
  " is the angular wave function."
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Normalized wave functions and probability densities of the Hydrogen-like \
atoms for given quantum numbers are:\
\>", "Text"],

Cell[BoxData[
    \(\[Psi]\_HydAt[n\_rad, l\_orb, m\_azm, Z] = 
      R\_HydAt[n\_rad, l\_orb, Z]\ Y[l\_orb, m\_azm]\)], "Input",
  GeneratedCell->False,
  CellAutoOverwrite->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Psi]\[Psi]\_HydAt[n\_rad, l\_orb, m\_azm, Z] = 
      RR\_HydAt[n\_rad, l\_orb, Z]\ YY[l\_orb, m\_azm]\)], "Input",
  GeneratedCell->False,
  CellAutoOverwrite->False],

Cell[BoxData[
    \(\((2\^\(2 + 2\ l\_orb\)\ \[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(a\_0\ \
\((1 + l\_orb + n\_rad)\)\)\)\)\ r\^2\ Z\^3\ Abs[SphericalHarmonicY[l\_orb, m\
\_azm, \[Theta], \[CurlyPhi]]]\^2\ \(n\_rad!\)\ LaguerreL[n\_rad, 1 + 2\ \
l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\^2\ \((\(r\ \
Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\))\)\^\(2\ l\_orb\))\)/\((\(\((1 + 
                2\ l\_orb + 
                n\_rad)\)!\)\ a\_0\%3\ \((1 + l\_orb + n\_rad)\)\^4)\)\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "1) ",
  Cell[BoxData[
      \(n\_rad = 0\)],
    FontSlant->"Italic"]
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_HydAt[0, 0, 0, Z] = 
      ReplaceAll[
        2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
            1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
SphericalHarmonicY[l\_orb, 
            m\_azm, \[Theta], \[CurlyPhi]]\ \@\(\(n\_rad!\)\/\(\(\((1 + 2\ \
l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\)\)\)\ \((Z\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\))\)\^l\_orb, {n\_rad \[Rule] 0, l\_orb \[Rule] 0, 
          m\_azm \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_HydAt[0, 0, 0, Z] = 
      PowerExpand[
        FullSimplify[
          ComplexExpand[\[Psi]\_HydAt[0, 0, 0, Z]*
              Conjugate[\[Psi]\_HydAt[0, 0, 0, Z]\ r\^2]]]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/a\_0\)\)\ \
\((Z\/a\_0)\)\^\(3/2\)\)\/\@\[Pi]\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/a\_0\)\)\ r\^2\ Z\^3\)\/\(\[Pi]\ a\
\_0\%3\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_HydAt[0, 1, 0, Z] = 
      ReplaceAll[
        2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
            1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
SphericalHarmonicY[l\_orb, 
            m\_azm, \[Theta], \[CurlyPhi]]\ \@\(\(n\_rad!\)\/\(\(\((1 + 2\ \
l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\)\)\)\ \((Z\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\))\)\^l\_orb, {n\_rad \[Rule] 0, l\_orb \[Rule] 1, 
          m\_azm \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_HydAt[0, 1, 0, Z] = 
      PowerExpand[
        FullSimplify[
          ComplexExpand[\[Psi]\_HydAt[0, 1, 0, Z]*
              Conjugate[\[Psi]\_HydAt[0, 1, 0, Z]\ r\^2]]]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\ Z\ Cos[\[Theta]]\ \
\((Z\/a\_0)\)\^\(3/2\)\)\/\(4\ \@\(2\ \[Pi]\)\ a\_0\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/a\_0\)\)\ r\^4\ Z\^5\ \
Cos[\[Theta]]\^2\)\/\(32\ \[Pi]\ a\_0\%5\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_HydAt[0, 1, 1, Z] = 
      ReplaceAll[
        2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
            1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
SphericalHarmonicY[l\_orb, 
            m\_azm, \[Theta], \[CurlyPhi]]\ \@\(\(n\_rad!\)\/\(\(\((1 + 2\ \
l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\)\)\)\ \((Z\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\))\)\^l\_orb, {n\_rad \[Rule] 0, l\_orb \[Rule] 1, 
          m\_azm \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_HydAt[0, 1, 1, Z] = 
      PowerExpand[
        FullSimplify[
          ComplexExpand[\[Psi]\_HydAt[0, 1, 1, Z]*
              Conjugate[\[Psi]\_HydAt[0, 1, 1, Z]\ r\^2]]]]\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(2\ a\
\_0\)\)\ r\ Z\ Sin[\[Theta]]\ \((Z\/a\_0)\)\^\(3/2\)\)\/\(8\ \@\[Pi]\ \
a\_0\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/a\_0\)\)\ r\^4\ Z\^5\ \
Sin[\[Theta]]\^2\)\/\(64\ \[Pi]\ a\_0\%5\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_HydAt[0, 2, 0, Z] = 
      ReplaceAll[
        2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
            1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
SphericalHarmonicY[l\_orb, 
            m\_azm, \[Theta], \[CurlyPhi]]\ \@\(\(n\_rad!\)\/\(\(\((1 + 2\ \
l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\)\)\)\ \((Z\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\))\)\^l\_orb, {n\_rad \[Rule] 0, l\_orb \[Rule] 2, 
          m\_azm \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_HydAt[0, 2, 0, Z] = 
      PowerExpand[
        FullSimplify[
          ComplexExpand[\[Psi]\_HydAt[0, 2, 0, Z]*
              Conjugate[\[Psi]\_HydAt[0, 2, 0, Z]\ r\^2]]]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ r\^2\ Z\^2\ \
\((\(-1\) + 3\ Cos[\[Theta]]\^2)\)\ \((Z\/a\_0)\)\^\(3/2\)\)\/\(81\ \@\(6\ \
\[Pi]\)\ a\_0\%2\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(3\ a\_0\)\)\)\ r\^6\ Z\^7\ \((1 \
+ 3\ Cos[2\ \[Theta]])\)\^2\)\/\(157464\ \[Pi]\ a\_0\%7\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_HydAt[0, 2, 1, Z] = 
      ReplaceAll[
        2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
            1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
SphericalHarmonicY[l\_orb, 
            m\_azm, \[Theta], \[CurlyPhi]]\ \@\(\(n\_rad!\)\/\(\(\((1 + 2\ \
l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\)\)\)\ \((Z\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\))\)\^l\_orb, {n\_rad \[Rule] 0, l\_orb \[Rule] 2, 
          m\_azm \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_HydAt[0, 2, 1, Z] = 
      PowerExpand[
        FullSimplify[
          ComplexExpand[\[Psi]\_HydAt[0, 2, 1, Z]*
              Conjugate[\[Psi]\_HydAt[0, 2, 1, Z]\ r\^2]]]]\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(3\ a\
\_0\)\)\ r\^2\ Z\^2\ Cos[\[Theta]]\ Sin[\[Theta]]\ \((Z\/a\_0)\)\^\(3/2\)\)\/\
\(81\ \@\[Pi]\ a\_0\%2\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(3\ a\_0\)\)\)\ r\^6\ Z\^7\ Cos[\
\[Theta]]\^2\ Sin[\[Theta]]\^2\)\/\(6561\ \[Pi]\ a\_0\%7\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 2;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_HydAt[0, 2, 2, Z] = 
      ReplaceAll[
        2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
            1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
SphericalHarmonicY[l\_orb, 
            m\_azm, \[Theta], \[CurlyPhi]]\ \@\(\(n\_rad!\)\/\(\(\((1 + 2\ \
l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\)\)\)\ \((Z\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\))\)\^l\_orb, {n\_rad \[Rule] 0, l\_orb \[Rule] 2, 
          m\_azm \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_HydAt[0, 2, 2, Z] = 
      PowerExpand[
        FullSimplify[
          ComplexExpand[\[Psi]\_HydAt[0, 2, 2, Z]*
              Conjugate[\[Psi]\_HydAt[0, 2, 2, Z]\ r\^2]]]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(2\ \[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(3\ \
a\_0\)\)\ r\^2\ Z\^2\ Sin[\[Theta]]\^2\ \((Z\/a\_0)\)\^\(3/2\)\)\/\(162\ \@\
\[Pi]\ a\_0\%2\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(3\ a\_0\)\)\)\ r\^6\ Z\^7\ Sin[\
\[Theta]]\^4\)\/\(26244\ \[Pi]\ a\_0\%7\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_HydAt[0, 3, 0, Z] = 
      ReplaceAll[
        2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
            1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
SphericalHarmonicY[l\_orb, 
            m\_azm, \[Theta], \[CurlyPhi]]\ \@\(\(n\_rad!\)\/\(\(\((1 + 2\ \
l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\)\)\)\ \((Z\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\))\)\^l\_orb, {n\_rad \[Rule] 0, l\_orb \[Rule] 3, 
          m\_azm \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_HydAt[0, 3, 0, Z] = 
      PowerExpand[
        FullSimplify[
          ComplexExpand[\[Psi]\_HydAt[0, 3, 0, Z]*
              Conjugate[\[Psi]\_HydAt[0, 3, 0, Z]\ r\^2]]]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(4\ a\_0\)\)\)\ r\^3\ Z\^3\ \
\((\(-3\)\ Cos[\[Theta]] + 5\ Cos[\[Theta]]\^3)\)\ \((Z\/a\_0)\)\^\(3/2\)\)\/\
\(3072\ \@\(5\ \[Pi]\)\ a\_0\%3\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\^8\ Z\^9\ Cos[\
\[Theta]]\^2\ \((1 - 5\ Cos[2\ \[Theta]])\)\^2\)\/\(188743680\ \[Pi]\ a\_0\%9\
\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_HydAt[0, 3, 1, Z] = 
      ReplaceAll[
        2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
            1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
SphericalHarmonicY[l\_orb, 
            m\_azm, \[Theta], \[CurlyPhi]]\ \@\(\(n\_rad!\)\/\(\(\((1 + 2\ \
l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\)\)\)\ \((Z\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\))\)\^l\_orb, {n\_rad \[Rule] 0, l\_orb \[Rule] 3, 
          m\_azm \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_HydAt[0, 3, 1, Z] = 
      PowerExpand[
        FullSimplify[
          ComplexExpand[\[Psi]\_HydAt[0, 3, 1, Z]*
              Conjugate[\[Psi]\_HydAt[0, 3, 1, Z]\ r\^2]]]]\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(4\ a\
\_0\)\)\ r\^3\ Z\^3\ \((\(-1\) + 
                5\ Cos[\[Theta]]\^2)\)\ Sin[\[Theta]]\ \((Z\/a\_0)\)\^\(3/2\)\
\)\/\(2048\ \@\(15\ \[Pi]\)\ a\_0\%3\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\^8\ Z\^9\ \((3 + 5\
\ Cos[2\ \[Theta]])\)\^2\ Sin[\[Theta]]\^2\)\/\(251658240\ \[Pi]\ \
a\_0\%9\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 2;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_HydAt[0, 3, 2, Z] = 
      ReplaceAll[
        2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
            1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
SphericalHarmonicY[l\_orb, 
            m\_azm, \[Theta], \[CurlyPhi]]\ \@\(\(n\_rad!\)\/\(\(\((1 + 2\ \
l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\)\)\)\ \((Z\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\))\)\^l\_orb, {n\_rad \[Rule] 0, l\_orb \[Rule] 3, 
          m\_azm \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_HydAt[0, 3, 2, Z] = 
      PowerExpand[
        FullSimplify[
          ComplexExpand[\[Psi]\_HydAt[0, 3, 2, Z]*
              Conjugate[\[Psi]\_HydAt[0, 3, 2, Z]\ r\^2]]]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(2\ \[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(4\ \
a\_0\)\)\ r\^3\ Z\^3\ Cos[\[Theta]]\ Sin[\[Theta]]\^2\ \((Z\/a\_0)\)\^\(3/2\)\
\)\/\(1024\ \@\(6\ \[Pi]\)\ a\_0\%3\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\^8\ Z\^9\ Cos[\
\[Theta]]\^2\ Sin[\[Theta]]\^4\)\/\(6291456\ \[Pi]\ a\_0\%9\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\n", 
    \(\(l\_orb = 3;\)\), "\n", 
    \(\(m\_azm = 3;\)\), "\n", 
    \(\[Psi]\_HydAt[0, 3, 3, Z] = 
      ReplaceAll[
        2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
            1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
SphericalHarmonicY[l\_orb, 
            m\_azm, \[Theta], \[CurlyPhi]]\ \@\(\(n\_rad!\)\/\(\(\((1 + 2\ \
l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\)\)\)\ \((Z\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\))\)\^l\_orb, {n\_rad \[Rule] 0, l\_orb \[Rule] 3, 
          m\_azm \[Rule] 3}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_HydAt[0, 3, 3, Z] = 
      PowerExpand[
        FullSimplify[
          ComplexExpand[\[Psi]\_HydAt[0, 3, 3, Z]*
              Conjugate[\[Psi]\_HydAt[0, 3, 3, Z]\ r\^2]]]]\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(3\ \[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(4\
\ a\_0\)\)\ r\^3\ Z\^3\ Sin[\[Theta]]\^3\ \((Z\/a\_0)\)\^\(3/2\)\)\/\(6144\ \
\@\[Pi]\ a\_0\%3\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\^8\ Z\^9\ Sin[\
\[Theta]]\^6\)\/\(37748736\ \[Pi]\ a\_0\%9\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "2) ",
  Cell[BoxData[
      \(n\_rad = 1\)],
    FontSlant->"Italic"]
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_HydAt[1, 0, 0, Z] = 
      ReplaceAll[
        2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
            1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
SphericalHarmonicY[l\_orb, 
            m\_azm, \[Theta], \[CurlyPhi]]\ \@\(\(n\_rad!\)\/\(\(\((1 + 2\ \
l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\)\)\)\ \((Z\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\))\)\^l\_orb, {n\_rad \[Rule] 1, l\_orb \[Rule] 0, 
          m\_azm \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_HydAt[1, 0, 0, Z] = 
      PowerExpand[
        FullSimplify[
          ComplexExpand[\[Psi]\_HydAt[1, 0, 0, Z]*
              Conjugate[\[Psi]\_HydAt[1, 0, 0, Z]\ r\^2]]]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ \((2 - \(r\ \
Z\)\/a\_0)\)\ \((Z\/a\_0)\)\^\(3/2\)\)\/\(4\ \@\(2\ \[Pi]\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/a\_0\)\)\ r\^2\ Z\^3\ \((r\ Z - 2\ \
a\_0)\)\^2\)\/\(32\ \[Pi]\ a\_0\%5\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_HydAt[1, 1, 0, Z] = 
      ReplaceAll[
        2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
            1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
SphericalHarmonicY[l\_orb, 
            m\_azm, \[Theta], \[CurlyPhi]]\ \@\(\(n\_rad!\)\/\(\(\((1 + 2\ \
l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\)\)\)\ \((Z\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\))\)\^l\_orb, {n\_rad \[Rule] 1, l\_orb \[Rule] 1, 
          m\_azm \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_HydAt[1, 1, 0, Z] = 
      PowerExpand[
        FullSimplify[
          ComplexExpand[\[Psi]\_HydAt[1, 1, 0, Z]*
              Conjugate[\[Psi]\_HydAt[1, 1, 0, Z]\ r\^2]]]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ r\ Z\ Cos[\[Theta]]\ \
\((4 - \(2\ r\ Z\)\/\(3\ a\_0\))\)\ \((Z\/a\_0)\)\^\(3/2\)\)\/\(27\ \@\(2\ \
\[Pi]\)\ a\_0\)\)], "Output"],

Cell[BoxData[
    \(\(2\ \[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(3\ a\_0\)\)\)\ r\^4\ Z\^5\ \
Cos[\[Theta]]\^2\ \((r\ Z - 6\ a\_0)\)\^2\)\/\(6561\ \[Pi]\ a\_0\%7\)\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_HydAt[1, 1, 1, Z] = 
      ReplaceAll[
        2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
            1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
SphericalHarmonicY[l\_orb, 
            m\_azm, \[Theta], \[CurlyPhi]]\ \@\(\(n\_rad!\)\/\(\(\((1 + 2\ \
l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\)\)\)\ \((Z\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\))\)\^l\_orb, {n\_rad \[Rule] 1, l\_orb \[Rule] 1, 
          m\_azm \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_HydAt[1, 1, 1, Z] = 
      PowerExpand[
        FullSimplify[
          ComplexExpand[\[Psi]\_HydAt[1, 1, 1, Z]*
              Conjugate[\[Psi]\_HydAt[1, 1, 1, Z]\ r\^2]]]]\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(3\ a\
\_0\)\)\ r\ Z\ Sin[\[Theta]]\ \((4 - \(2\ r\ Z\)\/\(3\ a\_0\))\)\ \((Z\/a\_0)\
\)\^\(3/2\)\)\/\(54\ \@\[Pi]\ a\_0\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(3\ a\_0\)\)\)\ r\^4\ Z\^5\ Sin[\
\[Theta]]\^2\ \((r\ Z - 6\ a\_0)\)\^2\)\/\(6561\ \[Pi]\ a\_0\%7\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_HydAt[1, 2, 0, Z] = 
      ReplaceAll[
        2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
            1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
SphericalHarmonicY[l\_orb, 
            m\_azm, \[Theta], \[CurlyPhi]]\ \@\(\(n\_rad!\)\/\(\(\((1 + 2\ \
l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\)\)\)\ \((Z\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\))\)\^l\_orb, {n\_rad \[Rule] 1, l\_orb \[Rule] 2, 
          m\_azm \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_HydAt[1, 2, 0, Z] = 
      PowerExpand[
        FullSimplify[
          ComplexExpand[\[Psi]\_HydAt[1, 2, 0, Z]*
              Conjugate[\[Psi]\_HydAt[1, 2, 0, Z]\ r\^2]]]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(4\ a\_0\)\)\)\ r\^2\ Z\^2\ \
\((\(-1\) + 3\ Cos[\[Theta]]\^2)\)\ \((6 - \(r\ Z\)\/\(2\ a\_0\))\)\ \
\((Z\/a\_0)\)\^\(3/2\)\)\/\(1536\ \@\[Pi]\ a\_0\%2\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\^6\ Z\^7\ \((1 + 3\
\ Cos[2\ \[Theta]])\)\^2\ \((r\ Z - 12\ a\_0)\)\^2\)\/\(37748736\ \[Pi]\ a\_0\
\%9\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_HydAt[1, 2, 1, Z] = 
      ReplaceAll[
        2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
            1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
SphericalHarmonicY[l\_orb, 
            m\_azm, \[Theta], \[CurlyPhi]]\ \@\(\(n\_rad!\)\/\(\(\((1 + 2\ \
l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\)\)\)\ \((Z\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\))\)\^l\_orb, {n\_rad \[Rule] 1, l\_orb \[Rule] 2, 
          m\_azm \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_HydAt[1, 2, 1, Z] = 
      PowerExpand[
        FullSimplify[
          ComplexExpand[\[Psi]\_HydAt[1, 2, 1, Z]*
              Conjugate[\[Psi]\_HydAt[1, 2, 1, Z]\ r\^2]]]]\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(4\ a\
\_0\)\)\ r\^2\ Z\^2\ Cos[\[Theta]]\ Sin[\[Theta]]\ \((6 - \(r\ Z\)\/\(2\ a\_0\
\))\)\ \((Z\/a\_0)\)\^\(3/2\)\)\/\(256\ \@\(6\ \[Pi]\)\ a\_0\%2\)\)\)\)], \
"Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\^6\ Z\^7\ Cos[\
\[Theta]]\^2\ Sin[\[Theta]]\^2\ \((r\ Z - 12\ a\_0)\)\^2\)\/\(1572864\ \[Pi]\ \
a\_0\%9\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 2;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_HydAt[1, 2, 2, Z] = 
      ReplaceAll[
        2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
            1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
SphericalHarmonicY[l\_orb, 
            m\_azm, \[Theta], \[CurlyPhi]]\ \@\(\(n\_rad!\)\/\(\(\((1 + 2\ \
l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\)\)\)\ \((Z\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\))\)\^l\_orb, {n\_rad \[Rule] 1, l\_orb \[Rule] 2, 
          m\_azm \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_HydAt[1, 2, 2, Z] = 
      PowerExpand[
        FullSimplify[
          ComplexExpand[\[Psi]\_HydAt[1, 2, 2, Z]*
              Conjugate[\[Psi]\_HydAt[1, 2, 2, Z]\ r\^2]]]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(2\ \[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(4\ \
a\_0\)\)\ r\^2\ Z\^2\ Sin[\[Theta]]\^2\ \((6 - \(r\ Z\)\/\(2\ a\_0\))\)\ \((Z\
\/a\_0)\)\^\(3/2\)\)\/\(512\ \@\(6\ \[Pi]\)\ a\_0\%2\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\^6\ Z\^7\ Sin[\
\[Theta]]\^4\ \((r\ Z - 12\ a\_0)\)\^2\)\/\(6291456\ \[Pi]\ a\_0\%9\)\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_HydAt[1, 3, 0, Z] = 
      ReplaceAll[
        2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
            1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
SphericalHarmonicY[l\_orb, 
            m\_azm, \[Theta], \[CurlyPhi]]\ \@\(\(n\_rad!\)\/\(\(\((1 + 2\ \
l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\)\)\)\ \((Z\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\))\)\^l\_orb, {n\_rad \[Rule] 1, l\_orb \[Rule] 3, 
          m\_azm \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_HydAt[1, 3, 0, Z] = 
      PowerExpand[
        FullSimplify[
          ComplexExpand[\[Psi]\_HydAt[1, 3, 0, Z]*
              Conjugate[\[Psi]\_HydAt[1, 3, 0, Z]\ r\^2]]]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(5\ a\_0\)\)\)\ r\^3\ Z\^3\ \
\((\(-3\)\ Cos[\[Theta]] + 5\ Cos[\[Theta]]\^3)\)\ \((8 - \(2\ r\ Z\)\/\(5\ a\
\_0\))\)\ \((Z\/a\_0)\)\^\(3/2\)\)\/\(18750\ \@\(10\ \[Pi]\)\ a\_0\%3\)\)], \
"Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(5\ a\_0\)\)\)\ r\^8\ Z\^9\ Cos[\
\[Theta]]\^2\ \((1 - 5\ Cos[2\ \[Theta]])\)\^2\ \((r\ Z - 20\ \
a\_0)\)\^2\)\/\(87890625000\ \[Pi]\ a\_0\%11\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_HydAt[1, 3, 1, Z] = 
      ReplaceAll[
        2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
            1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
SphericalHarmonicY[l\_orb, 
            m\_azm, \[Theta], \[CurlyPhi]]\ \@\(\(n\_rad!\)\/\(\(\((1 + 2\ \
l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\)\)\)\ \((Z\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\))\)\^l\_orb, {n\_rad \[Rule] 1, l\_orb \[Rule] 3, 
          m\_azm \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_HydAt[1, 3, 1, Z] = 
      PowerExpand[
        FullSimplify[
          ComplexExpand[\[Psi]\_HydAt[1, 3, 1, Z]*
              Conjugate[\[Psi]\_HydAt[1, 3, 1, Z]\ r\^2]]]]\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(5\ a\
\_0\)\)\ r\^3\ Z\^3\ \((\(-1\) + 
                5\ Cos[\[Theta]]\^2)\)\ Sin[\[Theta]]\ \((8 - \(2\ r\ \
Z\)\/\(5\ a\_0\))\)\ \((Z\/a\_0)\)\^\(3/2\)\)\/\(12500\ \@\(30\ \[Pi]\)\ a\_0\
\%3\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(5\ a\_0\)\)\)\ r\^8\ Z\^9\ \((3 \
+ 5\ Cos[2\ \[Theta]])\)\^2\ Sin[\[Theta]]\^2\ \((r\ Z - 20\ \
a\_0)\)\^2\)\/\(117187500000\ \[Pi]\ a\_0\%11\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 2;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_HydAt[1, 3, 2, Z] = 
      ReplaceAll[
        2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
            1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
SphericalHarmonicY[l\_orb, 
            m\_azm, \[Theta], \[CurlyPhi]]\ \@\(\(n\_rad!\)\/\(\(\((1 + 2\ \
l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\)\)\)\ \((Z\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\))\)\^l\_orb, {n\_rad \[Rule] 1, l\_orb \[Rule] 3, 
          m\_azm \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_HydAt[1, 3, 2, Z] = 
      PowerExpand[
        FullSimplify[
          ComplexExpand[\[Psi]\_HydAt[1, 3, 2, Z]*
              Conjugate[\[Psi]\_HydAt[1, 3, 2, Z]\ r\^2]]]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(2\ \[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(5\ \
a\_0\)\)\ r\^3\ Z\^3\ Cos[\[Theta]]\ Sin[\[Theta]]\^2\ \((8 - \(2\ r\ \
Z\)\/\(5\ a\_0\))\)\ \((Z\/a\_0)\)\^\(3/2\)\)\/\(12500\ \@\(3\ \[Pi]\)\ \
a\_0\%3\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(5\ a\_0\)\)\)\ r\^8\ Z\^9\ Cos[\
\[Theta]]\^2\ Sin[\[Theta]]\^4\ \((r\ Z - 20\ a\_0)\)\^2\)\/\(2929687500\ \
\[Pi]\ a\_0\%11\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\n", 
    \(\(l\_orb = 3;\)\), "\n", 
    \(\(m\_azm = 3;\)\), "\n", 
    \(\[Psi]\_HydAt[1, 3, 3, Z] = 
      ReplaceAll[
        2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
            1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
SphericalHarmonicY[l\_orb, 
            m\_azm, \[Theta], \[CurlyPhi]]\ \@\(\(n\_rad!\)\/\(\(\((1 + 2\ \
l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\)\)\)\ \((Z\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\))\)\^l\_orb, {n\_rad \[Rule] 1, l\_orb \[Rule] 3, 
          m\_azm \[Rule] 3}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_HydAt[1, 3, 3, Z] = 
      PowerExpand[
        FullSimplify[
          ComplexExpand[\[Psi]\_HydAt[1, 3, 3, Z]*
              Conjugate[\[Psi]\_HydAt[1, 3, 3, Z]\ r\^2]]]]\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(3\ \[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(5\
\ a\_0\)\)\ r\^3\ Z\^3\ Sin[\[Theta]]\^3\ \((8 - \(2\ r\ Z\)\/\(5\ a\_0\))\)\ \
\((Z\/a\_0)\)\^\(3/2\)\)\/\(37500\ \@\(2\ \[Pi]\)\ a\_0\%3\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(5\ a\_0\)\)\)\ r\^8\ Z\^9\ Sin[\
\[Theta]]\^6\ \((r\ Z - 20\ a\_0)\)\^2\)\/\(17578125000\ \[Pi]\ \
a\_0\%11\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "3) ",
  Cell[BoxData[
      \(n\_rad = 2\)],
    FontSlant->"Italic"]
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_HydAt[2, 0, 0, Z] = 
      ReplaceAll[
        2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
            1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
SphericalHarmonicY[l\_orb, 
            m\_azm, \[Theta], \[CurlyPhi]]\ \@\(\(n\_rad!\)\/\(\(\((1 + 2\ \
l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\)\)\)\ \((Z\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\))\)\^l\_orb, {n\_rad \[Rule] 2, l\_orb \[Rule] 0, 
          m\_azm \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_HydAt[2, 0, 0, Z] = 
      PowerExpand[
        FullSimplify[
          ComplexExpand[\[Psi]\_HydAt[2, 0, 0, Z]*
              Conjugate[\[Psi]\_HydAt[2, 0, 0, Z]\ r\^2]]]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ \((Z\/a\_0)\)\^\(3/2\
\)\ \((2\ r\^2\ Z\^2 - 18\ r\ Z\ a\_0 + 27\ a\_0\%2)\)\)\/\(81\ \@\(3\ \
\[Pi]\)\ a\_0\%2\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(3\ a\_0\)\)\)\ r\^2\ Z\^3\ \((2\ \
r\^2\ Z\^2 + 9\ a\_0\ \((\(-2\)\ r\ Z + 3\ a\_0)\))\)\^2\)\/\(19683\ \[Pi]\ a\
\_0\%7\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_HydAt[2, 1, 0, Z] = 
      ReplaceAll[
        2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
            1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
SphericalHarmonicY[l\_orb, 
            m\_azm, \[Theta], \[CurlyPhi]]\ \@\(\(n\_rad!\)\/\(\(\((1 + 2\ \
l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\)\)\)\ \((Z\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\))\)\^l\_orb, {n\_rad \[Rule] 2, l\_orb \[Rule] 1, 
          m\_azm \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_HydAt[2, 1, 0, Z] = 
      PowerExpand[
        FullSimplify[
          ComplexExpand[\[Psi]\_HydAt[2, 1, 0, Z]*
              Conjugate[\[Psi]\_HydAt[2, 1, 0, Z]\ r\^2]]]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(4\ a\_0\)\)\)\ r\ Z\ Cos[\[Theta]]\ \
\((Z\/a\_0)\)\^\(3/2\)\ \((r\^2\ Z\^2 - 20\ r\ Z\ a\_0 + 80\ \
a\_0\%2)\)\)\/\(512\ \@\(5\ \[Pi]\)\ a\_0\%3\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\^4\ Z\^5\ Cos[\
\[Theta]]\^2\ \((r\^2\ Z\^2 - 20\ r\ Z\ a\_0 + 80\ a\_0\%2)\)\^2\)\/\(1310720\
\ \[Pi]\ a\_0\%9\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_HydAt[2, 1, 1, Z] = 
      ReplaceAll[
        2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
            1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
SphericalHarmonicY[l\_orb, 
            m\_azm, \[Theta], \[CurlyPhi]]\ \@\(\(n\_rad!\)\/\(\(\((1 + 2\ \
l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\)\)\)\ \((Z\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\))\)\^l\_orb, {n\_rad \[Rule] 2, l\_orb \[Rule] 1, 
          m\_azm \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_HydAt[2, 1, 1, Z] = 
      PowerExpand[
        FullSimplify[
          ComplexExpand[\[Psi]\_HydAt[2, 1, 1, Z]*
              Conjugate[\[Psi]\_HydAt[2, 1, 1, Z]\ r\^2]]]]\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(4\ a\
\_0\)\)\ r\ Z\ Sin[\[Theta]]\ \((Z\/a\_0)\)\^\(3/2\)\ \((r\^2\ Z\^2 - 
                20\ r\ Z\ a\_0 + 
                80\ a\_0\%2)\)\)\/\(512\ \@\(10\ \[Pi]\)\ a\_0\%3\)\)\)\)], \
"Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\^4\ Z\^5\ Sin[\
\[Theta]]\^2\ \((r\^2\ Z\^2 - 20\ r\ Z\ a\_0 + 80\ a\_0\%2)\)\^2\)\/\(2621440\
\ \[Pi]\ a\_0\%9\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_HydAt[2, 2, 0, Z] = 
      ReplaceAll[
        2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
            1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
SphericalHarmonicY[l\_orb, 
            m\_azm, \[Theta], \[CurlyPhi]]\ \@\(\(n\_rad!\)\/\(\(\((1 + 2\ \
l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\)\)\)\ \((Z\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\))\)\^l\_orb, {n\_rad \[Rule] 2, l\_orb \[Rule] 2, 
          m\_azm \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_HydAt[2, 2, 0, Z] = 
      PowerExpand[
        FullSimplify[
          ComplexExpand[\[Psi]\_HydAt[2, 2, 0, Z]*
              Conjugate[\[Psi]\_HydAt[2, 2, 0, Z]\ r\^2]]]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(5\ a\_0\)\)\)\ r\^2\ Z\^2\ \
\((\(-1\) + 3\ Cos[\[Theta]]\^2)\)\ \((Z\/a\_0)\)\^\(3/2\)\ \((2\ r\^2\ Z\^2 \
- 70\ r\ Z\ a\_0 + 525\ a\_0\%2)\)\)\/\(46875\ \@\(14\ \[Pi]\)\ a\_0\%4\)\)], \
"Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(5\ a\_0\)\)\)\ r\^6\ Z\^7\ \((1 \
+ 3\ Cos[2\ \[Theta]])\)\^2\ \((2\ r\^2\ Z\^2 - 70\ r\ Z\ a\_0 + 525\ \
a\_0\%2)\)\^2\)\/\(123046875000\ \[Pi]\ a\_0\%11\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_HydAt[2, 2, 1, Z] = 
      ReplaceAll[
        2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
            1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
SphericalHarmonicY[l\_orb, 
            m\_azm, \[Theta], \[CurlyPhi]]\ \@\(\(n\_rad!\)\/\(\(\((1 + 2\ \
l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\)\)\)\ \((Z\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\))\)\^l\_orb, {n\_rad \[Rule] 2, l\_orb \[Rule] 2, 
          m\_azm \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_HydAt[2, 2, 1, Z] = 
      PowerExpand[
        FullSimplify[
          ComplexExpand[\[Psi]\_HydAt[2, 2, 1, Z]*
              Conjugate[\[Psi]\_HydAt[2, 2, 1, Z]\ r\^2]]]]\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(5\ a\
\_0\)\)\ r\^2\ Z\^2\ Cos[\[Theta]]\ Sin[\[Theta]]\ \((Z\/a\_0)\)\^\(3/2\)\ \
\((2\ r\^2\ Z\^2 - 70\ r\ Z\ a\_0 + 
                525\ a\_0\%2)\)\)\/\(15625\ \@\(21\ \[Pi]\)\ \
a\_0\%4\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(5\ a\_0\)\)\)\ r\^6\ Z\^7\ Cos[\
\[Theta]]\^2\ Sin[\[Theta]]\^2\ \((2\ r\^2\ Z\^2 - 70\ r\ Z\ a\_0 + 525\ a\_0\
\%2)\)\^2\)\/\(5126953125\ \[Pi]\ a\_0\%11\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 2;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_HydAt[2, 2, 2, Z] = 
      ReplaceAll[
        2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
            1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
SphericalHarmonicY[l\_orb, 
            m\_azm, \[Theta], \[CurlyPhi]]\ \@\(\(n\_rad!\)\/\(\(\((1 + 2\ \
l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\)\)\)\ \((Z\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\))\)\^l\_orb, {n\_rad \[Rule] 2, l\_orb \[Rule] 2, 
          m\_azm \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_HydAt[2, 2, 2, Z] = 
      PowerExpand[
        FullSimplify[
          ComplexExpand[\[Psi]\_HydAt[2, 2, 2, Z]*
              Conjugate[\[Psi]\_HydAt[2, 2, 2, Z]\ r\^2]]]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(2\ \[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(5\ \
a\_0\)\)\ r\^2\ Z\^2\ Sin[\[Theta]]\^2\ \((Z\/a\_0)\)\^\(3/2\)\ \((2\ r\^2\ Z\
\^2 - 70\ r\ Z\ a\_0 + 525\ a\_0\%2)\)\)\/\(31250\ \@\(21\ \[Pi]\)\ a\_0\%4\)\
\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(5\ a\_0\)\)\)\ r\^6\ Z\^7\ Sin[\
\[Theta]]\^4\ \((2\ r\^2\ Z\^2 - 70\ r\ Z\ a\_0 + 525\ \
a\_0\%2)\)\^2\)\/\(20507812500\ \[Pi]\ a\_0\%11\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_HydAt[2, 3, 0, Z] = 
      ReplaceAll[
        2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
            1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
SphericalHarmonicY[l\_orb, 
            m\_azm, \[Theta], \[CurlyPhi]]\ \@\(\(n\_rad!\)\/\(\(\((1 + 2\ \
l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\)\)\)\ \((Z\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\))\)\^l\_orb, {n\_rad \[Rule] 2, l\_orb \[Rule] 3, 
          m\_azm \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_HydAt[2, 3, 0, Z] = 
      PowerExpand[
        FullSimplify[
          ComplexExpand[\[Psi]\_HydAt[2, 3, 0, Z]*
              Conjugate[\[Psi]\_HydAt[2, 3, 0, Z]\ r\^2]]]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(6\ a\_0\)\)\)\ r\^3\ Z\^3\ \
\((\(-3\)\ Cos[\[Theta]] + 5\ Cos[\[Theta]]\^3)\)\ \((Z\/a\_0)\)\^\(3/2\)\ \
\((r\^2\ Z\^2 - 54\ r\ Z\ a\_0 + 648\ a\_0\%2)\)\)\/\(2519424\ \@\(5\ \[Pi]\)\
\ a\_0\%5\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ r\^8\ Z\^9\ Cos[\
\[Theta]]\^2\ \((1 - 5\ Cos[2\ \[Theta]])\)\^2\ \((r\ Z - 36\ a\_0)\)\^2\ \
\((r\ Z - 18\ a\_0)\)\^2\)\/\(126949945835520\ \[Pi]\ a\_0\%13\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_HydAt[2, 3, 1, Z] = 
      ReplaceAll[
        2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
            1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
SphericalHarmonicY[l\_orb, 
            m\_azm, \[Theta], \[CurlyPhi]]\ \@\(\(n\_rad!\)\/\(\(\((1 + 2\ \
l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\)\)\)\ \((Z\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\))\)\^l\_orb, {n\_rad \[Rule] 2, l\_orb \[Rule] 3, 
          m\_azm \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_HydAt[2, 3, 1, Z] = 
      PowerExpand[
        FullSimplify[
          ComplexExpand[\[Psi]\_HydAt[2, 3, 1, Z]*
              Conjugate[\[Psi]\_HydAt[2, 3, 1, Z]\ r\^2]]]]\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(6\ a\
\_0\)\)\ r\^3\ Z\^3\ \((\(-1\) + 
                5\ Cos[\[Theta]]\^2)\)\ Sin[\[Theta]]\ \((Z\/a\_0)\)\^\(3/2\)\
\ \((r\^2\ Z\^2 - 54\ r\ Z\ a\_0 + 
                648\ a\_0\%2)\)\)\/\(1679616\ \@\(15\ \[Pi]\)\ \
a\_0\%5\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ r\^8\ Z\^9\ \((3 + 5\
\ Cos[2\ \[Theta]])\)\^2\ Sin[\[Theta]]\^2\ \((r\ Z - 36\ a\_0)\)\^2\ \((r\ Z \
- 18\ a\_0)\)\^2\)\/\(169266594447360\ \[Pi]\ a\_0\%13\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 2;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_HydAt[2, 3, 2, Z] = 
      ReplaceAll[
        2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
            1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
SphericalHarmonicY[l\_orb, 
            m\_azm, \[Theta], \[CurlyPhi]]\ \@\(\(n\_rad!\)\/\(\(\((1 + 2\ \
l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\)\)\)\ \((Z\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\))\)\^l\_orb, {n\_rad \[Rule] 2, l\_orb \[Rule] 3, 
          m\_azm \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_HydAt[2, 3, 2, Z] = 
      PowerExpand[
        FullSimplify[
          ComplexExpand[\[Psi]\_HydAt[2, 3, 2, Z]*
              Conjugate[\[Psi]\_HydAt[2, 3, 2, Z]\ r\^2]]]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(2\ \[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(6\ \
a\_0\)\)\ r\^3\ Z\^3\ Cos[\[Theta]]\ Sin[\[Theta]]\^2\ \((Z\/a\_0)\)\^\(3/2\)\
\ \((r\^2\ Z\^2 - 54\ r\ Z\ a\_0 + 648\ a\_0\%2)\)\)\/\(839808\ \@\(6\ \
\[Pi]\)\ a\_0\%5\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ r\^8\ Z\^9\ Cos[\
\[Theta]]\^2\ Sin[\[Theta]]\^4\ \((r\ Z - 36\ a\_0)\)\^2\ \((r\ Z - 18\ a\_0)\
\)\^2\)\/\(4231664861184\ \[Pi]\ a\_0\%13\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\n", 
    \(\(l\_orb = 3;\)\), "\n", 
    \(\(m\_azm = 3;\)\), "\n", 
    \(\[Psi]\_HydAt[2, 3, 3, Z] = 
      ReplaceAll[
        2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
            1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
SphericalHarmonicY[l\_orb, 
            m\_azm, \[Theta], \[CurlyPhi]]\ \@\(\(n\_rad!\)\/\(\(\((1 + 2\ \
l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\)\)\)\ \((Z\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\))\)\^l\_orb, {n\_rad \[Rule] 2, l\_orb \[Rule] 3, 
          m\_azm \[Rule] 3}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_HydAt[2, 3, 3, Z] = 
      PowerExpand[
        FullSimplify[
          ComplexExpand[\[Psi]\_HydAt[2, 3, 3, Z]*
              Conjugate[\[Psi]\_HydAt[2, 3, 3, Z]\ r\^2]]]]\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(3\ \[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(6\
\ a\_0\)\)\ r\^3\ Z\^3\ Sin[\[Theta]]\^3\ \((Z\/a\_0)\)\^\(3/2\)\ \((r\^2\ \
Z\^2 - 54\ r\ Z\ a\_0 + 
                648\ a\_0\%2)\)\)\/\(5038848\ \@\[Pi]\ a\_0\%5\)\)\)\)], \
"Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ r\^8\ Z\^9\ Sin[\
\[Theta]]\^6\ \((r\ Z - 36\ a\_0)\)\^2\ \((r\ Z - 18\ \
a\_0)\)\^2\)\/\(25389989167104\ \[Pi]\ a\_0\%13\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "4) ",
  Cell[BoxData[
      \(n\_rad = 3\)],
    FontSlant->"Italic"]
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 0;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_HydAt[3, 0, 0, Z] = 
      ReplaceAll[
        2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
            1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
SphericalHarmonicY[l\_orb, 
            m\_azm, \[Theta], \[CurlyPhi]]\ \@\(\(n\_rad!\)\/\(\(\((1 + 2\ \
l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\)\)\)\ \((Z\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\))\)\^l\_orb, {n\_rad \[Rule] 3, l\_orb \[Rule] 0, 
          m\_azm \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_HydAt[3, 0, 0, Z] = 
      PowerExpand[
        FullSimplify[
          ComplexExpand[\[Psi]\_HydAt[3, 0, 0, Z]*
              Conjugate[\[Psi]\_HydAt[3, 0, 0, Z]\ r\^2]]]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(4\ a\_0\)\)\)\ \((Z\/a\_0)\)\^\(3/2\
\)\ \((\(-r\^3\)\ Z\^3 + 24\ r\^2\ Z\^2\ a\_0 - 144\ r\ Z\ a\_0\%2 + 192\ \
a\_0\%3)\)\)\/\(1536\ \@\[Pi]\ a\_0\%3\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\^2\ Z\^3\ \((r\^3\ \
Z\^3 - 24\ \((r\ Z - 4\ a\_0)\)\ \((r\ Z - 2\ a\_0)\)\ \
a\_0)\)\^2\)\/\(2359296\ \[Pi]\ a\_0\%9\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_HydAt[3, 1, 0, Z] = 
      ReplaceAll[
        2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
            1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
SphericalHarmonicY[l\_orb, 
            m\_azm, \[Theta], \[CurlyPhi]]\ \@\(\(n\_rad!\)\/\(\(\((1 + 2\ \
l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\)\)\)\ \((Z\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\))\)\^l\_orb, {n\_rad \[Rule] 3, l\_orb \[Rule] 1, 
          m\_azm \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_HydAt[3, 1, 0, Z] = 
      PowerExpand[
        FullSimplify[
          ComplexExpand[\[Psi]\_HydAt[3, 1, 0, Z]*
              Conjugate[\[Psi]\_HydAt[3, 1, 0, Z]\ r\^2]]]]\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(5\ a\_0\)\)\)\ \@\(2\/\(5\ \
\[Pi]\)\)\ r\ Z\ Cos[\[Theta]]\ \((Z\/a\_0)\)\^\(3/2\)\ \((2\ r\^3\ Z\^3 - 
                90\ r\^2\ Z\^2\ a\_0 + 1125\ r\ Z\ a\_0\%2 - 
                3750\ a\_0\%3)\)\)\/\(46875\ a\_0\%4\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(2\ \[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(5\ a\_0\)\)\)\ r\^4\ Z\^5\ \
Cos[\[Theta]]\^2\ \((2\ r\^3\ Z\^3 - 15\ a\_0\ \((6\ r\^2\ Z\^2 - 75\ r\ Z\ a\
\_0 + 250\ a\_0\%2)\))\)\^2\)\/\(10986328125\ \[Pi]\ a\_0\%11\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 1;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_HydAt[3, 1, 1, Z] = 
      ReplaceAll[
        2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
            1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
SphericalHarmonicY[l\_orb, 
            m\_azm, \[Theta], \[CurlyPhi]]\ \@\(\(n\_rad!\)\/\(\(\((1 + 2\ \
l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\)\)\)\ \((Z\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\))\)\^l\_orb, {n\_rad \[Rule] 3, l\_orb \[Rule] 1, 
          m\_azm \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_HydAt[3, 1, 1, Z] = 
      PowerExpand[
        FullSimplify[
          ComplexExpand[\[Psi]\_HydAt[3, 1, 1, Z]*
              Conjugate[\[Psi]\_HydAt[3, 1, 1, Z]\ r\^2]]]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(5\ a\_0\)\
\)\ r\ Z\ Sin[\[Theta]]\ \((Z\/a\_0)\)\^\(3/2\)\ \((2\ r\^3\ Z\^3 - 90\ r\^2\ \
Z\^2\ a\_0 + 1125\ r\ Z\ a\_0\%2 - 3750\ a\_0\%3)\)\)\/\(46875\ \@\(5\ \
\[Pi]\)\ a\_0\%4\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(5\ a\_0\)\)\)\ r\^4\ Z\^5\ Sin[\
\[Theta]]\^2\ \((2\ r\^3\ Z\^3 - 15\ a\_0\ \((6\ r\^2\ Z\^2 - 75\ r\ Z\ a\_0 \
+ 250\ a\_0\%2)\))\)\^2\)\/\(10986328125\ \[Pi]\ a\_0\%11\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_HydAt[3, 2, 0, Z] = 
      ReplaceAll[
        2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
            1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
SphericalHarmonicY[l\_orb, 
            m\_azm, \[Theta], \[CurlyPhi]]\ \@\(\(n\_rad!\)\/\(\(\((1 + 2\ \
l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\)\)\)\ \((Z\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\))\)\^l\_orb, {n\_rad \[Rule] 3, l\_orb \[Rule] 2, 
          m\_azm \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_HydAt[3, 2, 0, Z] = 
      PowerExpand[
        FullSimplify[
          ComplexExpand[\[Psi]\_HydAt[3, 2, 0, Z]*
              Conjugate[\[Psi]\_HydAt[3, 2, 0, Z]\ r\^2]]]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(6\ a\_0\)\)\)\ r\^2\ Z\^2\ \
\((\(-1\) + 3\ Cos[\[Theta]]\^2)\)\ \((Z\/a\_0)\)\^\(3/2\)\ \((\(-r\^3\)\ \
Z\^3 + 72\ r\^2\ Z\^2\ a\_0 - 1512\ r\ Z\ a\_0\%2 + 9072\ \
a\_0\%3)\)\)\/\(839808\ \@\(21\ \[Pi]\)\ a\_0\%5\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ r\^6\ Z\^7\ \((1 + 3\
\ Cos[2\ \[Theta]])\)\^2\ \((r\^3\ Z\^3 - 72\ a\_0\ \((r\^2\ Z\^2 + 21\ a\_0\ \
\((\(-r\)\ Z + 6\ a\_0)\))\))\)\^2\)\/\(59243308056576\ \[Pi]\ a\_0\%13\)\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_HydAt[3, 2, 1, Z] = 
      ReplaceAll[
        2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
            1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
SphericalHarmonicY[l\_orb, 
            m\_azm, \[Theta], \[CurlyPhi]]\ \@\(\(n\_rad!\)\/\(\(\((1 + 2\ \
l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\)\)\)\ \((Z\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\))\)\^l\_orb, {n\_rad \[Rule] 3, l\_orb \[Rule] 2, 
          m\_azm \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_HydAt[3, 2, 1, Z] = 
      PowerExpand[
        FullSimplify[
          ComplexExpand[\[Psi]\_HydAt[3, 2, 1, Z]*
              Conjugate[\[Psi]\_HydAt[3, 2, 1, Z]\ r\^2]]]]\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(6\ a\
\_0\)\)\ r\^2\ Z\^2\ Cos[\[Theta]]\ Sin[\[Theta]]\ \((Z\/a\_0)\)\^\(3/2\)\ \
\((\(-r\^3\)\ Z\^3 + 72\ r\^2\ Z\^2\ a\_0 - 1512\ r\ Z\ a\_0\%2 + 
                9072\ a\_0\%3)\)\)\/\(419904\ \@\(14\ \[Pi]\)\ \
a\_0\%5\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ r\^6\ Z\^7\ Cos[\
\[Theta]]\^2\ Sin[\[Theta]]\^2\ \((r\^3\ Z\^3 - 72\ a\_0\ \((r\^2\ Z\^2 + 21\ \
a\_0\ \((\(-r\)\ Z + 6\ a\_0)\))\))\)\^2\)\/\(2468471169024\ \[Pi]\ \
a\_0\%13\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 2;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 2;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_HydAt[3, 2, 2, Z] = 
      ReplaceAll[
        2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
            1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
SphericalHarmonicY[l\_orb, 
            m\_azm, \[Theta], \[CurlyPhi]]\ \@\(\(n\_rad!\)\/\(\(\((1 + 2\ \
l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\)\)\)\ \((Z\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\))\)\^l\_orb, {n\_rad \[Rule] 3, l\_orb \[Rule] 2, 
          m\_azm \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_HydAt[3, 2, 2, Z] = 
      PowerExpand[
        FullSimplify[
          ComplexExpand[\[Psi]\_HydAt[3, 2, 2, Z]*
              Conjugate[\[Psi]\_HydAt[3, 2, 2, Z]\ r\^2]]]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(2\ \[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(6\ \
a\_0\)\)\ r\^2\ Z\^2\ Sin[\[Theta]]\^2\ \((Z\/a\_0)\)\^\(3/2\)\ \((\(-r\^3\)\ \
Z\^3 + 72\ r\^2\ Z\^2\ a\_0 - 1512\ r\ Z\ a\_0\%2 + 9072\ \
a\_0\%3)\)\)\/\(839808\ \@\(14\ \[Pi]\)\ a\_0\%5\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ r\^6\ Z\^7\ Sin[\
\[Theta]]\^4\ \((r\^3\ Z\^3 - 72\ a\_0\ \((r\^2\ Z\^2 + 21\ a\_0\ \((\(-r\)\ \
Z + 6\ a\_0)\))\))\)\^2\)\/\(9873884676096\ \[Pi]\ a\_0\%13\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 0;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_HydAt[3, 3, 0, Z] = 
      ReplaceAll[
        2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
            1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
SphericalHarmonicY[l\_orb, 
            m\_azm, \[Theta], \[CurlyPhi]]\ \@\(\(n\_rad!\)\/\(\(\((1 + 2\ \
l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\)\)\)\ \((Z\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\))\)\^l\_orb, {n\_rad \[Rule] 3, l\_orb \[Rule] 3, 
          m\_azm \[Rule] 0}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_HydAt[3, 3, 0, Z] = 
      PowerExpand[
        FullSimplify[
          ComplexExpand[\[Psi]\_HydAt[3, 3, 0, Z]*
              Conjugate[\[Psi]\_HydAt[3, 3, 0, Z]\ r\^2]]]]\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(1\/\(259416045\ \@\(6\ \[Pi]\)\ \
a\_0\%6\)\)\((\[ExponentialE]\^\(-\(\(r\ Z\)\/\(7\ a\_0\)\)\)\ r\^3\ Z\^3\ \
\((\(-3\)\ Cos[\[Theta]] + 
              5\ Cos[\[Theta]]\^3)\)\ \((Z\/a\_0)\)\^\(3/2\)\ \((2\ r\^3\ \
Z\^3 - 210\ r\^2\ Z\^2\ a\_0 + 6615\ r\ Z\ a\_0\%2 - 
              61740\ a\_0\%3)\))\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(7\ a\_0\)\)\)\ r\^8\ Z\^9\ Cos[\
\[Theta]]\^2\ \((1 - 5\ Cos[2\ \[Theta]])\)\^2\ \((2\ r\^3\ Z\^3 - 105\ a\_0\ \
\((2\ r\^2\ Z\^2 - 63\ r\ Z\ a\_0 + 588\ \
a\_0\%2)\))\)\^2\)\/\(1615120425682608600\ \[Pi]\ a\_0\%15\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 1;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_HydAt[3, 3, 1, Z] = 
      ReplaceAll[
        2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
            1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
SphericalHarmonicY[l\_orb, 
            m\_azm, \[Theta], \[CurlyPhi]]\ \@\(\(n\_rad!\)\/\(\(\((1 + 2\ \
l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\)\)\)\ \((Z\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\))\)\^l\_orb, {n\_rad \[Rule] 3, l\_orb \[Rule] 3, 
          m\_azm \[Rule] 1}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_HydAt[3, 3, 1, Z] = 
      PowerExpand[
        FullSimplify[
          ComplexExpand[\[Psi]\_HydAt[3, 3, 1, Z]*
              Conjugate[\[Psi]\_HydAt[3, 3, 1, Z]\ r\^2]]]]\)}], "Input"],

Cell[BoxData[
    \(\(\(1\/\(518832090\ \@\(2\ \[Pi]\)\ a\_0\%6\)\)\((\[ExponentialE]\^\(\
\[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(7\ a\_0\)\)\ r\^3\ Z\^3\ \((\(-1\) + 
            5\ Cos[\[Theta]]\^2)\)\ Sin[\[Theta]]\ \((Z\/a\_0)\)\^\(3/2\)\ \
\((2\ r\^3\ Z\^3 - 210\ r\^2\ Z\^2\ a\_0 + 6615\ r\ Z\ a\_0\%2 - 
            61740\ a\_0\%3)\))\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(7\ a\_0\)\)\)\ r\^8\ Z\^9\ \((3 \
+ 5\ Cos[2\ \[Theta]])\)\^2\ Sin[\[Theta]]\^2\ \((2\ r\^3\ Z\^3 - 105\ a\_0\ \
\((2\ r\^2\ Z\^2 - 63\ r\ Z\ a\_0 + 588\ \
a\_0\%2)\))\)\^2\)\/\(2153493900910144800\ \[Pi]\ a\_0\%15\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(l\_orb = 3;\)\), "\[IndentingNewLine]", 
    \(\(m\_azm = 2;\)\), "\[IndentingNewLine]", 
    \(\[Psi]\_HydAt[3, 3, 2, Z] = 
      ReplaceAll[
        2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
            1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
SphericalHarmonicY[l\_orb, 
            m\_azm, \[Theta], \[CurlyPhi]]\ \@\(\(n\_rad!\)\/\(\(\((1 + 2\ \
l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\)\)\)\ \((Z\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\))\)\^l\_orb, {n\_rad \[Rule] 3, l\_orb \[Rule] 3, 
          m\_azm \[Rule] 2}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_HydAt[3, 3, 2, Z] = 
      PowerExpand[
        FullSimplify[
          ComplexExpand[\[Psi]\_HydAt[3, 3, 2, Z]*
              Conjugate[\[Psi]\_HydAt[3, 3, 2, Z]\ r\^2]]]]\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(2\ \[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(7\
\ a\_0\)\)\ r\^3\ Z\^3\ Cos[\[Theta]]\ Sin[\[Theta]]\^2\ \((Z\/a\_0)\)\^\(3/2\
\)\ \((2\ r\^3\ Z\^3 - 210\ r\^2\ Z\^2\ a\_0 + 6615\ r\ Z\ a\_0\%2 - 
                61740\ a\_0\%3)\)\)\/\(103766418\ \@\(5\ \[Pi]\)\ a\_0\%6\)\)\
\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(7\ a\_0\)\)\)\ r\^8\ Z\^9\ Cos[\
\[Theta]]\^2\ Sin[\[Theta]]\^4\ \((2\ r\^3\ Z\^3 - 105\ a\_0\ \((2\ r\^2\ \
Z\^2 - 63\ r\ Z\ a\_0 + 588\ a\_0\%2)\))\)\^2\)\/\(53837347522753620\ \[Pi]\ \
a\_0\%15\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\n", 
    \(\(l\_orb = 3;\)\), "\n", 
    \(\(m\_azm = 3;\)\), "\n", 
    \(\[Psi]\_HydAt[3, 3, 3, Z] = 
      ReplaceAll[
        2\^\(1 + l\_orb\)\ \[ExponentialE]\^\(-\(\(r\ Z\)\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\)\)\)\ LaguerreL[n\_rad, 
            1 + 2\ l\_orb, \(2\ r\ Z\)\/\(a\_0\ \((1 + l\_orb + n\_rad)\)\)]\ \
SphericalHarmonicY[l\_orb, 
            m\_azm, \[Theta], \[CurlyPhi]]\ \@\(\(n\_rad!\)\/\(\(\((1 + 2\ \
l\_orb + n\_rad)\)!\)\ \((1 + l\_orb + n\_rad)\)\)\)\ \((Z\/\(a\_0\ \((1 + \
l\_orb + n\_rad)\)\))\)\^\(3/2\)\ \((\(r\ Z\)\/\(a\_0\ \((1 + l\_orb + \
n\_rad)\)\))\)\^l\_orb, {n\_rad \[Rule] 3, l\_orb \[Rule] 3, 
          m\_azm \[Rule] 3}]\), "\[IndentingNewLine]", 
    \(\[Psi]\[Psi]\_HydAt[3, 3, 3, Z] = 
      PowerExpand[
        FullSimplify[
          ComplexExpand[\[Psi]\_HydAt[3, 3, 3, Z]*
              Conjugate[\[Psi]\_HydAt[3, 3, 3, Z]\ r\^2]]]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(3\ \[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(7\ \
a\_0\)\)\ r\^3\ Z\^3\ Sin[\[Theta]]\^3\ \((Z\/a\_0)\)\^\(3/2\)\ \((2\ r\^3\ Z\
\^3 - 210\ r\^2\ Z\^2\ a\_0 + 6615\ r\ Z\ a\_0\%2 - 61740\ \
a\_0\%3)\)\)\/\(103766418\ \@\(30\ \[Pi]\)\ a\_0\%6\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(7\ a\_0\)\)\)\ r\^8\ Z\^9\ Sin[\
\[Theta]]\^6\ \((2\ r\^3\ Z\^3 - 105\ a\_0\ \((2\ r\^2\ Z\^2 - 63\ r\ Z\ a\_0 \
+ 588\ a\_0\%2)\))\)\^2\)\/\(323024085136521720\ \[Pi]\ a\_0\%15\)\)], \
"Output"]
}, Open  ]],

Cell["Thus we have:", "Text"],

Cell["Wave functions", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[0, 0, 0, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[0, 1, 0, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[0, 1, 1, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[0, 2, 0, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[0, 2, 1, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[0, 2, 2, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[0, 3, 0, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[0, 3, 1, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[0, 3, 2, Z]]]\), "\[IndentingNewLine]", 
    \(\(\(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[0, 3, 3, Z]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[1, 0, 0, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[1, 1, 0, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[1, 1, 1, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[1, 2, 0, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[1, 2, 1, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[1, 2, 2, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[1, 3, 0, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[1, 3, 1, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[1, 3, 2, Z]]]\), "\[IndentingNewLine]", 
    \(\(\(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[1, 3, 3, Z]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[2, 0, 0, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[2, 1, 0, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[2, 1, 1, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[2, 2, 0, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[2, 2, 1, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[2, 2, 2, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[2, 3, 0, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[2, 3, 1, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[2, 3, 2, Z]]]\), "\[IndentingNewLine]", 
    \(\(\(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[2, 3, 3, Z]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[3, 0, 0, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[3, 1, 0, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[3, 1, 1, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[3, 2, 0, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[3, 2, 1, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[3, 2, 2, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[3, 3, 0, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[3, 3, 1, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[3, 3, 2, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[FullSimplify[\[Psi]\_HydAt[3, 3, 3, Z]]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/a\_0\)\)\ Z\^\(3/2\)\)\/\(\@\[Pi]\ \
a\_0\%\(3/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\ Z\^\(5/2\)\ Cos[\
\[Theta]]\)\/\(4\ \@\(2\ \[Pi]\)\ a\_0\%\(5/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(2\ a\
\_0\)\)\ r\ Z\^\(5/2\)\ Sin[\[Theta]]\)\/\(8\ \@\[Pi]\ \
a\_0\%\(5/2\)\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ r\^2\ Z\^\(7/2\)\ \
\((1 + 3\ Cos[2\ \[Theta]])\)\)\/\(162\ \@\(6\ \[Pi]\)\ a\_0\%\(7/2\)\)\)], \
"Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(3\ a\
\_0\)\)\ r\^2\ Z\^\(7/2\)\ Cos[\[Theta]]\ Sin[\[Theta]]\)\/\(81\ \@\[Pi]\ \
a\_0\%\(7/2\)\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(2\ \[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(3\ \
a\_0\)\)\ r\^2\ Z\^\(7/2\)\ Sin[\[Theta]]\^2\)\/\(162\ \@\[Pi]\ a\_0\%\(7/2\)\
\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(4\ a\_0\)\)\)\ r\^3\ Z\^\(9/2\)\ \
Cos[\[Theta]]\ \((\(-1\) + 5\ Cos[2\ \[Theta]])\)\)\/\(6144\ \@\(5\ \[Pi]\)\ \
a\_0\%\(9/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(4\ a\
\_0\)\)\ r\^3\ Z\^\(9/2\)\ \((Sin[\[Theta]] + 
                5\ Sin[3\ \[Theta]])\)\)\/\(8192\ \@\(15\ \[Pi]\)\ \
a\_0\%\(9/2\)\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(2\ \[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(4\ \
a\_0\)\)\ r\^3\ Z\^\(9/2\)\ Cos[\[Theta]]\ Sin[\[Theta]]\^2\)\/\(1024\ \@\(6\ \
\[Pi]\)\ a\_0\%\(9/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(3\ \[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(4\
\ a\_0\)\)\ r\^3\ Z\^\(9/2\)\ Sin[\[Theta]]\^3\)\/\(6144\ \@\[Pi]\ \
a\_0\%\(9/2\)\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ Z\^\(3/2\)\ \((2 - \
\(r\ Z\)\/a\_0)\)\)\/\(4\ \@\(2\ \[Pi]\)\ a\_0\%\(3/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ \@\(2\/\[Pi]\)\ \
r\ Z\^\(5/2\)\ Cos[\[Theta]]\ \((r\ Z - 
                6\ a\_0)\)\)\/\(81\ a\_0\%\(7/2\)\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(3\ a\_0\)\
\)\ r\ Z\^\(5/2\)\ Sin[\[Theta]]\ \((r\ Z - 6\ a\_0)\)\)\/\(81\ \@\[Pi]\ a\_0\
\%\(7/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(4\ a\_0\)\)\)\ r\^2\ \
Z\^\(7/2\)\ \((1 + 3\ Cos[2\ \[Theta]])\)\ \((r\ Z - 
                12\ a\_0)\)\)\/\(6144\ \@\[Pi]\ a\_0\%\(9/2\)\)\)\)\)], \
"Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(4\ a\_0\)\
\)\ r\^2\ Z\^\(7/2\)\ Cos[\[Theta]]\ Sin[\[Theta]]\ \((r\ Z - 12\ a\_0)\)\)\/\
\(512\ \@\(6\ \[Pi]\)\ a\_0\%\(9/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(2\ \[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(4\
\ a\_0\)\)\ r\^2\ Z\^\(7/2\)\ Sin[\[Theta]]\^2\ \((r\ Z - 
                12\ a\_0)\)\)\/\(1024\ \@\(6\ \[Pi]\)\ \
a\_0\%\(9/2\)\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(5\ a\_0\)\)\)\ r\^3\ \
Z\^\(9/2\)\ Cos[\[Theta]]\ \((\(-1\) + 5\ Cos[2\ \[Theta]])\)\ \((r\ Z - 
                20\ a\_0)\)\)\/\(93750\ \@\(10\ \[Pi]\)\ a\_0\%\(11/2\)\)\)\)\
\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(5\ a\_0\)\
\)\ r\^3\ Z\^\(9/2\)\ \((3 + 5\ Cos[2\ \[Theta]])\)\ Sin[\[Theta]]\ \((r\ Z - \
20\ a\_0)\)\)\/\(62500\ \@\(30\ \[Pi]\)\ a\_0\%\(11/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(2\ \[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(5\
\ a\_0\)\)\ r\^3\ Z\^\(9/2\)\ Cos[\[Theta]]\ Sin[\[Theta]]\^2\ \((r\ Z - 
                20\ a\_0)\)\)\/\(31250\ \@\(3\ \[Pi]\)\ \
a\_0\%\(11/2\)\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(3\ \[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(5\ \
a\_0\)\)\ r\^3\ Z\^\(9/2\)\ Sin[\[Theta]]\^3\ \((r\ Z - 20\ \
a\_0)\)\)\/\(93750\ \@\(2\ \[Pi]\)\ a\_0\%\(11/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ Z\^\(3/2\)\ \((2\ \
r\^2\ Z\^2 + 9\ a\_0\ \((\(-2\)\ r\ Z + 3\ a\_0)\))\)\)\/\(81\ \@\(3\ \[Pi]\)\
\ a\_0\%\(7/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(4\ a\_0\)\)\)\ r\ Z\^\(5/2\)\ Cos[\
\[Theta]]\ \((r\^2\ Z\^2 - 20\ r\ Z\ a\_0 + 80\ a\_0\%2)\)\)\/\(512\ \@\(5\ \
\[Pi]\)\ a\_0\%\(9/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(4\ a\
\_0\)\)\ r\ Z\^\(5/2\)\ Sin[\[Theta]]\ \((r\^2\ Z\^2 - 20\ r\ Z\ a\_0 + 
                80\ a\_0\%2)\)\)\/\(512\ \@\(10\ \[Pi]\)\ a\_0\%\(9/2\)\)\)\)\
\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(5\ a\_0\)\)\)\ r\^2\ Z\^\(7/2\)\ \
\((1 + 3\ Cos[2\ \[Theta]])\)\ \((2\ r\^2\ Z\^2 - 70\ r\ Z\ a\_0 + 525\ \
a\_0\%2)\)\)\/\(93750\ \@\(14\ \[Pi]\)\ a\_0\%\(11/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(5\ a\
\_0\)\)\ r\^2\ Z\^\(7/2\)\ Sin[
              2\ \[Theta]]\ \((2\ r\^2\ Z\^2 - 70\ r\ Z\ a\_0 + 
                525\ a\_0\%2)\)\)\/\(31250\ \@\(21\ \[Pi]\)\ a\_0\%\(11/2\)\)\
\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(2\ \[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(5\ \
a\_0\)\)\ r\^2\ Z\^\(7/2\)\ Sin[\[Theta]]\^2\ \((2\ r\^2\ Z\^2 - 70\ r\ Z\ \
a\_0 + 525\ a\_0\%2)\)\)\/\(31250\ \@\(21\ \[Pi]\)\ a\_0\%\(11/2\)\)\)], \
"Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(6\ a\_0\)\)\)\ r\^3\ Z\^\(9/2\)\ \
Cos[\[Theta]]\ \((\(-1\) + 5\ Cos[2\ \[Theta]])\)\ \((r\ Z - 36\ a\_0)\)\ \
\((r\ Z - 18\ a\_0)\)\)\/\(5038848\ \@\(5\ \[Pi]\)\ a\_0\%\(13/2\)\)\)], \
"Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(6\ a\
\_0\)\)\ r\^3\ Z\^\(9/2\)\ \((3 + 
                5\ Cos[2\ \[Theta]])\)\ Sin[\[Theta]]\ \((r\ Z - 
                36\ a\_0)\)\ \((r\ Z - 
                18\ a\_0)\)\)\/\(3359232\ \@\(15\ \[Pi]\)\ a\_0\%\(13/2\)\)\)\
\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(2\ \[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(6\ \
a\_0\)\)\ r\^3\ Z\^\(9/2\)\ Cos[\[Theta]]\ Sin[\[Theta]]\^2\ \((r\ Z - 36\ \
a\_0)\)\ \((r\ Z - 18\ a\_0)\)\)\/\(839808\ \@\(6\ \[Pi]\)\ \
a\_0\%\(13/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(3\ \[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(6\
\ a\_0\)\)\ r\^3\ Z\^\(9/2\)\ Sin[\[Theta]]\^3\ \((r\ Z - 
                36\ a\_0)\)\ \((r\ Z - 
                18\ a\_0)\)\)\/\(5038848\ \@\[Pi]\ a\_0\%\(13/2\)\)\)\)\)], \
"Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(4\ a\_0\)\)\)\ Z\^\(3/2\)\ \
\((r\^3\ Z\^3 - 
                24\ \((r\ Z - 4\ a\_0)\)\ \((r\ Z - 
                      2\ a\_0)\)\ a\_0)\)\)\/\(1536\ \@\[Pi]\ a\_0\%\(9/2\)\)\
\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(5\ a\_0\)\)\)\ \@\(2\/\(5\ \
\[Pi]\)\)\ r\ Z\^\(5/2\)\ Cos[\[Theta]]\ \((\(-2\)\ r\^3\ Z\^3 + 15\ a\_0\ \
\((6\ r\^2\ Z\^2 - 75\ r\ Z\ a\_0 + 250\ a\_0\%2)\))\)\)\/\(46875\ \
a\_0\%\(11/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(5\ a\_0\)\
\)\ r\ Z\^\(5/2\)\ Sin[\[Theta]]\ \((2\ r\^3\ Z\^3 - 15\ a\_0\ \((6\ r\^2\ \
Z\^2 - 75\ r\ Z\ a\_0 + 250\ a\_0\%2)\))\)\)\/\(46875\ \@\(5\ \[Pi]\)\ a\_0\%\
\(11/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(6\ a\_0\)\)\)\ r\^2\ \
Z\^\(7/2\)\ \((1 + 3\ Cos[2\ \[Theta]])\)\ \((r\^3\ Z\^3 - 
                72\ a\_0\ \((r\^2\ Z\^2 + 
                      21\ a\_0\ \((\(-r\)\ Z + 
                            6\ a\_0)\))\))\)\)\/\(1679616\ \@\(21\ \[Pi]\)\ a\
\_0\%\(13/2\)\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(6\ a\_0\)\
\)\ r\^2\ Z\^\(7/2\)\ Sin[2\ \[Theta]]\ \((r\^3\ Z\^3 - 72\ a\_0\ \((r\^2\ \
Z\^2 + 21\ a\_0\ \((\(-r\)\ Z + 6\ a\_0)\))\))\)\)\/\(839808\ \@\(14\ \[Pi]\)\
\ a\_0\%\(13/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(2\ \[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(6\
\ a\_0\)\)\ r\^2\ Z\^\(7/2\)\ Sin[\[Theta]]\^2\ \((r\^3\ Z\^3 - 
                72\ a\_0\ \((r\^2\ Z\^2 + 
                      21\ a\_0\ \((\(-r\)\ Z + 
                            6\ a\_0)\))\))\)\)\/\(839808\ \@\(14\ \[Pi]\)\ \
a\_0\%\(13/2\)\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(7\ a\_0\)\)\)\ r\^3\ \
Z\^\(9/2\)\ Cos[\[Theta]]\ \((\(-1\) + 
                5\ Cos[2\ \[Theta]])\)\ \((2\ r\^3\ Z\^3 - 
                105\ a\_0\ \((2\ r\^2\ Z\^2 - 63\ r\ Z\ a\_0 + 
                      588\ a\_0\%2)\))\)\)\/\(518832090\ \@\(6\ \[Pi]\)\ a\_0\
\%\(15/2\)\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(7\ a\_0\)\
\)\ r\^3\ Z\^\(9/2\)\ \((3 + 5\ Cos[2\ \[Theta]])\)\ Sin[\[Theta]]\ \((2\ \
r\^3\ Z\^3 - 105\ a\_0\ \((2\ r\^2\ Z\^2 - 63\ r\ Z\ a\_0 + 588\ \
a\_0\%2)\))\)\)\/\(1037664180\ \@\(2\ \[Pi]\)\ a\_0\%\(15/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(2\ \[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(7\
\ a\_0\)\)\ r\^3\ Z\^\(9/2\)\ Cos[\[Theta]]\ Sin[\[Theta]]\^2\ \((2\ r\^3\ \
Z\^3 - 105\ a\_0\ \((2\ r\^2\ Z\^2 - 63\ r\ Z\ a\_0 + 
                      588\ a\_0\%2)\))\)\)\/\(103766418\ \@\(5\ \[Pi]\)\ a\_0\
\%\(15/2\)\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(3\ \[ImaginaryI]\ \[CurlyPhi] - \(r\ Z\)\/\(7\ \
a\_0\)\)\ r\^3\ Z\^\(9/2\)\ Sin[\[Theta]]\^3\ \((2\ r\^3\ Z\^3 - 105\ a\_0\ \
\((2\ r\^2\ Z\^2 - 63\ r\ Z\ a\_0 + 588\ a\_0\%2)\))\)\)\/\(103766418\ \@\(30\
\ \[Pi]\)\ a\_0\%\(15/2\)\)\)], "Output"]
}, Open  ]],

Cell["Probability densities", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[0, 0, 0, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[0, 1, 0, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[0, 1, 1, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[0, 2, 0, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[0, 2, 1, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[0, 2, 2, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[0, 3, 0, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[0, 3, 1, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[0, 3, 2, 
          Z]]]\), "\[IndentingNewLine]", 
    \(\(\(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[0, 3, 3, Z]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[1, 0, 0, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[1, 1, 0, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[1, 1, 1, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[1, 2, 0, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[1, 2, 1, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[1, 2, 2, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[1, 3, 0, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[1, 3, 1, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[1, 3, 2, 
          Z]]]\), "\[IndentingNewLine]", 
    \(\(\(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[1, 3, 3, Z]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[2, 0, 0, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[2, 1, 0, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[2, 1, 1, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[2, 2, 0, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[2, 2, 1, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[2, 2, 2, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[2, 3, 0, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[2, 3, 1, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[2, 3, 2, 
          Z]]]\), "\[IndentingNewLine]", 
    \(\(\(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[2, 3, 3, Z]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[3, 0, 0, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[3, 1, 0, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[3, 1, 1, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[3, 2, 0, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[3, 2, 1, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[3, 2, 2, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[3, 3, 0, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[3, 3, 1, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[3, 3, 2, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[FullSimplify[\[Psi]\[Psi]\_HydAt[3, 3, 3, Z]]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/a\_0\)\)\ r\^2\ Z\^3\)\/\(\[Pi]\ a\
\_0\%3\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/a\_0\)\)\ r\^4\ Z\^5\ \
Cos[\[Theta]]\^2\)\/\(32\ \[Pi]\ a\_0\%5\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/a\_0\)\)\ r\^4\ Z\^5\ \
Sin[\[Theta]]\^2\)\/\(64\ \[Pi]\ a\_0\%5\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(3\ a\_0\)\)\)\ r\^6\ Z\^7\ \((1 \
+ 3\ Cos[2\ \[Theta]])\)\^2\)\/\(157464\ \[Pi]\ a\_0\%7\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(3\ a\_0\)\)\)\ r\^6\ Z\^7\ Cos[\
\[Theta]]\^2\ Sin[\[Theta]]\^2\)\/\(6561\ \[Pi]\ a\_0\%7\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(3\ a\_0\)\)\)\ r\^6\ Z\^7\ Sin[\
\[Theta]]\^4\)\/\(26244\ \[Pi]\ a\_0\%7\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\^8\ Z\^9\ Cos[\
\[Theta]]\^2\ \((1 - 5\ Cos[2\ \[Theta]])\)\^2\)\/\(188743680\ \[Pi]\ a\_0\%9\
\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\^8\ Z\^9\ \((3 + 5\
\ Cos[2\ \[Theta]])\)\^2\ Sin[\[Theta]]\^2\)\/\(251658240\ \[Pi]\ \
a\_0\%9\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\^8\ Z\^9\ Cos[\
\[Theta]]\^2\ Sin[\[Theta]]\^4\)\/\(6291456\ \[Pi]\ a\_0\%9\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\^8\ Z\^9\ Sin[\
\[Theta]]\^6\)\/\(37748736\ \[Pi]\ a\_0\%9\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/a\_0\)\)\ r\^2\ Z\^3\ \((r\ Z - 2\ \
a\_0)\)\^2\)\/\(32\ \[Pi]\ a\_0\%5\)\)], "Output"],

Cell[BoxData[
    \(\(2\ \[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(3\ a\_0\)\)\)\ r\^4\ Z\^5\ \
Cos[\[Theta]]\^2\ \((r\ Z - 6\ a\_0)\)\^2\)\/\(6561\ \[Pi]\ a\_0\%7\)\)], \
"Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(3\ a\_0\)\)\)\ r\^4\ Z\^5\ Sin[\
\[Theta]]\^2\ \((r\ Z - 6\ a\_0)\)\^2\)\/\(6561\ \[Pi]\ a\_0\%7\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\^6\ Z\^7\ \((1 + 3\
\ Cos[2\ \[Theta]])\)\^2\ \((r\ Z - 12\ a\_0)\)\^2\)\/\(37748736\ \[Pi]\ a\_0\
\%9\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\^6\ Z\^7\ Cos[\
\[Theta]]\^2\ Sin[\[Theta]]\^2\ \((r\ Z - 12\ a\_0)\)\^2\)\/\(1572864\ \[Pi]\ \
a\_0\%9\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\^6\ Z\^7\ Sin[\
\[Theta]]\^4\ \((r\ Z - 12\ a\_0)\)\^2\)\/\(6291456\ \[Pi]\ a\_0\%9\)\)], \
"Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(5\ a\_0\)\)\)\ r\^8\ Z\^9\ Cos[\
\[Theta]]\^2\ \((1 - 5\ Cos[2\ \[Theta]])\)\^2\ \((r\ Z - 20\ \
a\_0)\)\^2\)\/\(87890625000\ \[Pi]\ a\_0\%11\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(5\ a\_0\)\)\)\ r\^8\ Z\^9\ \((3 \
+ 5\ Cos[2\ \[Theta]])\)\^2\ Sin[\[Theta]]\^2\ \((r\ Z - 20\ \
a\_0)\)\^2\)\/\(117187500000\ \[Pi]\ a\_0\%11\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(5\ a\_0\)\)\)\ r\^8\ Z\^9\ Cos[\
\[Theta]]\^2\ Sin[\[Theta]]\^4\ \((r\ Z - 20\ a\_0)\)\^2\)\/\(2929687500\ \
\[Pi]\ a\_0\%11\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(5\ a\_0\)\)\)\ r\^8\ Z\^9\ Sin[\
\[Theta]]\^6\ \((r\ Z - 20\ a\_0)\)\^2\)\/\(17578125000\ \[Pi]\ \
a\_0\%11\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(3\ a\_0\)\)\)\ r\^2\ Z\^3\ \((2\ \
r\^2\ Z\^2 + 9\ a\_0\ \((\(-2\)\ r\ Z + 3\ a\_0)\))\)\^2\)\/\(19683\ \[Pi]\ a\
\_0\%7\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\^4\ Z\^5\ Cos[\
\[Theta]]\^2\ \((r\^2\ Z\^2 - 20\ r\ Z\ a\_0 + 80\ a\_0\%2)\)\^2\)\/\(1310720\
\ \[Pi]\ a\_0\%9\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\^4\ Z\^5\ Sin[\
\[Theta]]\^2\ \((r\^2\ Z\^2 - 20\ r\ Z\ a\_0 + 80\ a\_0\%2)\)\^2\)\/\(2621440\
\ \[Pi]\ a\_0\%9\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(5\ a\_0\)\)\)\ r\^6\ Z\^7\ \((1 \
+ 3\ Cos[2\ \[Theta]])\)\^2\ \((2\ r\^2\ Z\^2 - 70\ r\ Z\ a\_0 + 525\ \
a\_0\%2)\)\^2\)\/\(123046875000\ \[Pi]\ a\_0\%11\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(5\ a\_0\)\)\)\ r\^6\ Z\^7\ Cos[\
\[Theta]]\^2\ Sin[\[Theta]]\^2\ \((2\ r\^2\ Z\^2 - 70\ r\ Z\ a\_0 + 525\ a\_0\
\%2)\)\^2\)\/\(5126953125\ \[Pi]\ a\_0\%11\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(5\ a\_0\)\)\)\ r\^6\ Z\^7\ Sin[\
\[Theta]]\^4\ \((2\ r\^2\ Z\^2 - 70\ r\ Z\ a\_0 + 525\ \
a\_0\%2)\)\^2\)\/\(20507812500\ \[Pi]\ a\_0\%11\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ r\^8\ Z\^9\ Cos[\
\[Theta]]\^2\ \((1 - 5\ Cos[2\ \[Theta]])\)\^2\ \((r\ Z - 36\ a\_0)\)\^2\ \
\((r\ Z - 18\ a\_0)\)\^2\)\/\(126949945835520\ \[Pi]\ a\_0\%13\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ r\^8\ Z\^9\ \((3 + 5\
\ Cos[2\ \[Theta]])\)\^2\ Sin[\[Theta]]\^2\ \((r\ Z - 36\ a\_0)\)\^2\ \((r\ Z \
- 18\ a\_0)\)\^2\)\/\(169266594447360\ \[Pi]\ a\_0\%13\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ r\^8\ Z\^9\ Cos[\
\[Theta]]\^2\ Sin[\[Theta]]\^4\ \((r\ Z - 36\ a\_0)\)\^2\ \((r\ Z - 18\ a\_0)\
\)\^2\)\/\(4231664861184\ \[Pi]\ a\_0\%13\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ r\^8\ Z\^9\ Sin[\
\[Theta]]\^6\ \((r\ Z - 36\ a\_0)\)\^2\ \((r\ Z - 18\ \
a\_0)\)\^2\)\/\(25389989167104\ \[Pi]\ a\_0\%13\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\^2\ Z\^3\ \((r\^3\ \
Z\^3 - 24\ \((r\ Z - 4\ a\_0)\)\ \((r\ Z - 2\ a\_0)\)\ \
a\_0)\)\^2\)\/\(2359296\ \[Pi]\ a\_0\%9\)\)], "Output"],

Cell[BoxData[
    \(\(2\ \[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(5\ a\_0\)\)\)\ r\^4\ Z\^5\ \
Cos[\[Theta]]\^2\ \((2\ r\^3\ Z\^3 - 15\ a\_0\ \((6\ r\^2\ Z\^2 - 75\ r\ Z\ a\
\_0 + 250\ a\_0\%2)\))\)\^2\)\/\(10986328125\ \[Pi]\ a\_0\%11\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(5\ a\_0\)\)\)\ r\^4\ Z\^5\ Sin[\
\[Theta]]\^2\ \((2\ r\^3\ Z\^3 - 15\ a\_0\ \((6\ r\^2\ Z\^2 - 75\ r\ Z\ a\_0 \
+ 250\ a\_0\%2)\))\)\^2\)\/\(10986328125\ \[Pi]\ a\_0\%11\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ r\^6\ Z\^7\ \((1 + 3\
\ Cos[2\ \[Theta]])\)\^2\ \((r\^3\ Z\^3 - 72\ a\_0\ \((r\^2\ Z\^2 + 21\ a\_0\ \
\((\(-r\)\ Z + 6\ a\_0)\))\))\)\^2\)\/\(59243308056576\ \[Pi]\ a\_0\%13\)\)], \
"Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ r\^6\ Z\^7\ Cos[\
\[Theta]]\^2\ Sin[\[Theta]]\^2\ \((r\^3\ Z\^3 - 72\ a\_0\ \((r\^2\ Z\^2 + 21\ \
a\_0\ \((\(-r\)\ Z + 6\ a\_0)\))\))\)\^2\)\/\(2468471169024\ \[Pi]\ \
a\_0\%13\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ r\^6\ Z\^7\ Sin[\
\[Theta]]\^4\ \((r\^3\ Z\^3 - 72\ a\_0\ \((r\^2\ Z\^2 + 21\ a\_0\ \((\(-r\)\ \
Z + 6\ a\_0)\))\))\)\^2\)\/\(9873884676096\ \[Pi]\ a\_0\%13\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(7\ a\_0\)\)\)\ r\^8\ Z\^9\ Cos[\
\[Theta]]\^2\ \((1 - 5\ Cos[2\ \[Theta]])\)\^2\ \((2\ r\^3\ Z\^3 - 105\ a\_0\ \
\((2\ r\^2\ Z\^2 - 63\ r\ Z\ a\_0 + 588\ \
a\_0\%2)\))\)\^2\)\/\(1615120425682608600\ \[Pi]\ a\_0\%15\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(7\ a\_0\)\)\)\ r\^8\ Z\^9\ \((3 \
+ 5\ Cos[2\ \[Theta]])\)\^2\ Sin[\[Theta]]\^2\ \((2\ r\^3\ Z\^3 - 105\ a\_0\ \
\((2\ r\^2\ Z\^2 - 63\ r\ Z\ a\_0 + 588\ \
a\_0\%2)\))\)\^2\)\/\(2153493900910144800\ \[Pi]\ a\_0\%15\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(7\ a\_0\)\)\)\ r\^8\ Z\^9\ Cos[\
\[Theta]]\^2\ Sin[\[Theta]]\^4\ \((2\ r\^3\ Z\^3 - 105\ a\_0\ \((2\ r\^2\ \
Z\^2 - 63\ r\ Z\ a\_0 + 588\ a\_0\%2)\))\)\^2\)\/\(53837347522753620\ \[Pi]\ \
a\_0\%15\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(7\ a\_0\)\)\)\ r\^8\ Z\^9\ Sin[\
\[Theta]]\^6\ \((2\ r\^3\ Z\^3 - 105\ a\_0\ \((2\ r\^2\ Z\^2 - 63\ r\ Z\ a\_0 \
+ 588\ a\_0\%2)\))\)\^2\)\/\(323024085136521720\ \[Pi]\ a\_0\%15\)\)], \
"Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
3. List of wave functions and probability densities of the Hydrogen-like \
atoms for given quantum numbers\
\>", "Section"],

Cell["Wave functions", "Text"],

Cell[BoxData[{
    \(\(\[Psi]\_HydAt[0, 0, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/a\_0\)\)\ Z\^\(3/2\)\)\/\(\@\
\[Pi]\ a\_0\%\(3/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_HydAt[0, 1, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\ Z\^\(5/2\
\)\ Cos[\[Theta]]\)\/\(4\ \@\(2\ \[Pi]\)\ a\_0\%\(5/2\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\_HydAt[0, 1, 1, 
          Z] = \(-\(\(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi] - \(r\ \
Z\)\/\(2\ a\_0\)\)\ r\ Z\^\(5/2\)\ Sin[\[Theta]]\)\/\(8\ \@\[Pi]\ a\_0\%\(5/2\
\)\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_HydAt[0, 2, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ r\^2\ \
Z\^\(7/2\)\ \((1 + 3\ Cos[2\ \[Theta]])\)\)\/\(162\ \@\(6\ \[Pi]\)\ \
a\_0\%\(7/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_HydAt[0, 2, 1, 
          Z] = \(-\(\(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi] - \(r\ \
Z\)\/\(3\ a\_0\)\)\ r\^2\ Z\^\(7/2\)\ Cos[\[Theta]]\ Sin[\[Theta]]\)\/\(81\ \
\@\[Pi]\ a\_0\%\(7/2\)\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_HydAt[0, 2, 2, 
          Z] = \(\[ExponentialE]\^\(2\ \[ImaginaryI]\ \[CurlyPhi] - \(r\ \
Z\)\/\(3\ a\_0\)\)\ r\^2\ Z\^\(7/2\)\ Sin[\[Theta]]\^2\)\/\(162\ \@\[Pi]\ \
a\_0\%\(7/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_HydAt[0, 3, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(4\ a\_0\)\)\)\ r\^3\ \
Z\^\(9/2\)\ Cos[\[Theta]]\ \((\(-1\) + 5\ Cos[2\ \[Theta]])\)\)\/\(6144\ \
\@\(5\ \[Pi]\)\ a\_0\%\(9/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_HydAt[0, 3, 1, 
          Z] = \(-\(\(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi] - \(r\ \
Z\)\/\(4\ a\_0\)\)\ r\^3\ Z\^\(9/2\)\ \((Sin[\[Theta]] + 
                    5\ Sin[3\ \[Theta]])\)\)\/\(8192\ \@\(15\ \[Pi]\)\ a\_0\%\
\(9/2\)\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_HydAt[0, 3, 2, 
          Z] = \(\[ExponentialE]\^\(2\ \[ImaginaryI]\ \[CurlyPhi] - \(r\ \
Z\)\/\(4\ a\_0\)\)\ r\^3\ Z\^\(9/2\)\ Cos[\[Theta]]\ \
Sin[\[Theta]]\^2\)\/\(1024\ \@\(6\ \[Pi]\)\ a\_0\%\(9/2\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\_HydAt[0, 3, 3, 
          Z] = \(-\(\(\[ExponentialE]\^\(3\ \[ImaginaryI]\ \[CurlyPhi] - \(r\ \
Z\)\/\(4\ a\_0\)\)\ r\^3\ Z\^\(9/2\)\ Sin[\[Theta]]\^3\)\/\(6144\ \@\[Pi]\ \
a\_0\%\(9/2\)\)\)\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_HydAt[1, 0, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ Z\^\(3/2\)\ \
\((2 - \(r\ Z\)\/a\_0)\)\)\/\(4\ \@\(2\ \[Pi]\)\ a\_0\%\(3/2\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\_HydAt[1, 1, 0, 
          Z] = \(-\(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ \
\@\(2\/\[Pi]\)\ r\ Z\^\(5/2\)\ Cos[\[Theta]]\ \((r\ Z - 
                    6\ a\_0)\)\)\/\(81\ a\_0\%\(7/2\)\)\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\_HydAt[1, 1, 1, 
          Z] = \(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi] - \(r\ \
Z\)\/\(3\ a\_0\)\)\ r\ Z\^\(5/2\)\ Sin[\[Theta]]\ \((r\ Z - 6\ \
a\_0)\)\)\/\(81\ \@\[Pi]\ a\_0\%\(7/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_HydAt[1, 2, 0, 
          Z] = \(-\(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(4\ a\_0\)\)\)\ r\^2\ \
Z\^\(7/2\)\ \((1 + 3\ Cos[2\ \[Theta]])\)\ \((r\ Z - 
                    12\ a\_0)\)\)\/\(6144\ \@\[Pi]\ a\_0\%\(9/2\)\)\)\);\)\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\_HydAt[1, 2, 1, 
          Z] = \(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi] - \(r\ \
Z\)\/\(4\ a\_0\)\)\ r\^2\ Z\^\(7/2\)\ Cos[\[Theta]]\ Sin[\[Theta]]\ \((r\ Z - \
12\ a\_0)\)\)\/\(512\ \@\(6\ \[Pi]\)\ a\_0\%\(9/2\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\_HydAt[1, 2, 2, 
          Z] = \(-\(\(\[ExponentialE]\^\(2\ \[ImaginaryI]\ \[CurlyPhi] - \(r\ \
Z\)\/\(4\ a\_0\)\)\ r\^2\ Z\^\(7/2\)\ Sin[\[Theta]]\^2\ \((r\ Z - 
                    12\ a\_0)\)\)\/\(1024\ \@\(6\ \[Pi]\)\ \
a\_0\%\(9/2\)\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_HydAt[1, 3, 0, 
          Z] = \(-\(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(5\ a\_0\)\)\)\ r\^3\ \
Z\^\(9/2\)\ Cos[\[Theta]]\ \((\(-1\) + 5\ Cos[2\ \[Theta]])\)\ \((r\ Z - 
                    20\ a\_0)\)\)\/\(93750\ \@\(10\ \[Pi]\)\ a\_0\%\(11/2\)\)\
\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_HydAt[1, 3, 1, 
          Z] = \(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi] - \(r\ \
Z\)\/\(5\ a\_0\)\)\ r\^3\ Z\^\(9/2\)\ \((3 + 5\ Cos[2\ \[Theta]])\)\ Sin[\
\[Theta]]\ \((r\ Z - 20\ a\_0)\)\)\/\(62500\ \@\(30\ \[Pi]\)\ \
a\_0\%\(11/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_HydAt[1, 3, 2, 
          Z] = \(-\(\(\[ExponentialE]\^\(2\ \[ImaginaryI]\ \[CurlyPhi] - \(r\ \
Z\)\/\(5\ a\_0\)\)\ r\^3\ Z\^\(9/2\)\ Cos[\[Theta]]\ Sin[\[Theta]]\^2\ \((r\ \
Z - 20\ a\_0)\)\)\/\(31250\ \@\(3\ \[Pi]\)\ a\_0\%\(11/2\)\)\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\_HydAt[1, 3, 3, 
          Z] = \(\[ExponentialE]\^\(3\ \[ImaginaryI]\ \[CurlyPhi] - \(r\ \
Z\)\/\(5\ a\_0\)\)\ r\^3\ Z\^\(9/2\)\ Sin[\[Theta]]\^3\ \((r\ Z - 20\ a\_0)\)\
\)\/\(93750\ \@\(2\ \[Pi]\)\ a\_0\%\(11/2\)\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_HydAt[2, 0, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ Z\^\(3/2\)\ \
\((2\ r\^2\ Z\^2 + 9\ a\_0\ \((\(-2\)\ r\ Z + 3\ a\_0)\))\)\)\/\(81\ \@\(3\ \
\[Pi]\)\ a\_0\%\(7/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_HydAt[2, 1, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(4\ a\_0\)\)\)\ r\ Z\^\(5/2\
\)\ Cos[\[Theta]]\ \((r\^2\ Z\^2 - 20\ r\ Z\ a\_0 + 80\ a\_0\%2)\)\)\/\(512\ \
\@\(5\ \[Pi]\)\ a\_0\%\(9/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_HydAt[2, 1, 1, 
          Z] = \(-\(\(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi] - \(r\ \
Z\)\/\(4\ a\_0\)\)\ r\ Z\^\(5/2\)\ Sin[\[Theta]]\ \((r\^2\ Z\^2 - 
                    20\ r\ Z\ a\_0 + 
                    80\ a\_0\%2)\)\)\/\(512\ \@\(10\ \[Pi]\)\ a\_0\%\(9/2\)\)\
\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_HydAt[2, 2, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(5\ a\_0\)\)\)\ r\^2\ \
Z\^\(7/2\)\ \((1 + 3\ Cos[2\ \[Theta]])\)\ \((2\ r\^2\ Z\^2 - 70\ r\ Z\ a\_0 \
+ 525\ a\_0\%2)\)\)\/\(93750\ \@\(14\ \[Pi]\)\ a\_0\%\(11/2\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\_HydAt[2, 2, 1, 
          Z] = \(-\(\(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi] - \(r\ \
Z\)\/\(5\ a\_0\)\)\ r\^2\ Z\^\(7/2\)\ Sin[
                  2\ \[Theta]]\ \((2\ r\^2\ Z\^2 - 70\ r\ Z\ a\_0 + 
                    525\ a\_0\%2)\)\)\/\(31250\ \@\(21\ \[Pi]\)\ a\_0\%\(11/2\
\)\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_HydAt[2, 2, 2, 
          Z] = \(\[ExponentialE]\^\(2\ \[ImaginaryI]\ \[CurlyPhi] - \(r\ \
Z\)\/\(5\ a\_0\)\)\ r\^2\ Z\^\(7/2\)\ Sin[\[Theta]]\^2\ \((2\ r\^2\ Z\^2 - 70\
\ r\ Z\ a\_0 + 525\ a\_0\%2)\)\)\/\(31250\ \@\(21\ \[Pi]\)\ a\_0\%\(11/2\)\);\
\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_HydAt[2, 3, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(6\ a\_0\)\)\)\ r\^3\ \
Z\^\(9/2\)\ Cos[\[Theta]]\ \((\(-1\) + 5\ Cos[2\ \[Theta]])\)\ \((r\ Z - 36\ \
a\_0)\)\ \((r\ Z - 18\ a\_0)\)\)\/\(5038848\ \@\(5\ \[Pi]\)\ \
a\_0\%\(13/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_HydAt[2, 3, 1, 
          Z] = \(-\(\(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi] - \(r\ \
Z\)\/\(6\ a\_0\)\)\ r\^3\ Z\^\(9/2\)\ \((3 + 
                    5\ Cos[2\ \[Theta]])\)\ Sin[\[Theta]]\ \((r\ Z - 
                    36\ a\_0)\)\ \((r\ Z - 
                    18\ a\_0)\)\)\/\(3359232\ \@\(15\ \[Pi]\)\ a\_0\%\(13/2\)\
\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_HydAt[2, 3, 2, 
          Z] = \(\[ExponentialE]\^\(2\ \[ImaginaryI]\ \[CurlyPhi] - \(r\ \
Z\)\/\(6\ a\_0\)\)\ r\^3\ Z\^\(9/2\)\ Cos[\[Theta]]\ Sin[\[Theta]]\^2\ \((r\ \
Z - 36\ a\_0)\)\ \((r\ Z - 18\ a\_0)\)\)\/\(839808\ \@\(6\ \[Pi]\)\ \
a\_0\%\(13/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\_HydAt[2, 3, 3, 
          Z] = \(-\(\(\[ExponentialE]\^\(3\ \[ImaginaryI]\ \[CurlyPhi] - \(r\ \
Z\)\/\(6\ a\_0\)\)\ r\^3\ Z\^\(9/2\)\ Sin[\[Theta]]\^3\ \((r\ Z - 
                    36\ a\_0)\)\ \((r\ Z - 
                    18\ a\_0)\)\)\/\(5038848\ \@\[Pi]\ \
a\_0\%\(13/2\)\)\)\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_HydAt[3, 0, 0, 
          Z] = \(-\(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(4\ a\_0\)\)\)\ \
Z\^\(3/2\)\ \((r\^3\ Z\^3 - 
                    24\ \((r\ Z - 4\ a\_0)\)\ \((r\ Z - 
                          
                          2\ a\_0)\)\ a\_0)\)\)\/\(1536\ \@\[Pi]\ a\_0\%\(9/2\
\)\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_HydAt[3, 1, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(5\ a\_0\)\)\)\ \@\(2\/\(5\ \
\[Pi]\)\)\ r\ Z\^\(5/2\)\ Cos[\[Theta]]\ \((\(-2\)\ r\^3\ Z\^3 + 15\ a\_0\ \
\((6\ r\^2\ Z\^2 - 75\ r\ Z\ a\_0 + 250\ a\_0\%2)\))\)\)\/\(46875\ \
a\_0\%\(11/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_HydAt[3, 1, 1, 
          Z] = \(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi] - \(r\ \
Z\)\/\(5\ a\_0\)\)\ r\ Z\^\(5/2\)\ Sin[\[Theta]]\ \((2\ r\^3\ Z\^3 - 15\ a\_0\
\ \((6\ r\^2\ Z\^2 - 75\ r\ Z\ a\_0 + 250\ a\_0\%2)\))\)\)\/\(46875\ \@\(5\ \
\[Pi]\)\ a\_0\%\(11/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_HydAt[3, 2, 0, 
          Z] = \(-\(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(6\ a\_0\)\)\)\ r\^2\ \
Z\^\(7/2\)\ \((1 + 3\ Cos[2\ \[Theta]])\)\ \((r\^3\ Z\^3 - 
                    72\ a\_0\ \((r\^2\ Z\^2 + 
                          21\ a\_0\ \((\(-r\)\ Z + 
                                6\ a\_0)\))\))\)\)\/\(1679616\ \@\(21\ \
\[Pi]\)\ a\_0\%\(13/2\)\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_HydAt[3, 2, 1, 
          Z] = \(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi] - \(r\ \
Z\)\/\(6\ a\_0\)\)\ r\^2\ Z\^\(7/2\)\ Sin[2\ \[Theta]]\ \((r\^3\ Z\^3 - 72\ a\
\_0\ \((r\^2\ Z\^2 + 21\ a\_0\ \((\(-r\)\ Z + 6\ a\_0)\))\))\)\)\/\(839808\ \
\@\(14\ \[Pi]\)\ a\_0\%\(13/2\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_HydAt[3, 2, 2, 
          Z] = \(-\(\(\[ExponentialE]\^\(2\ \[ImaginaryI]\ \[CurlyPhi] - \(r\ \
Z\)\/\(6\ a\_0\)\)\ r\^2\ Z\^\(7/2\)\ Sin[\[Theta]]\^2\ \((r\^3\ Z\^3 - 
                    72\ a\_0\ \((r\^2\ Z\^2 + 
                          21\ a\_0\ \((\(-r\)\ Z + 
                                6\ a\_0)\))\))\)\)\/\(839808\ \@\(14\ \[Pi]\)\
\ a\_0\%\(13/2\)\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_HydAt[3, 3, 0, 
          Z] = \(-\(\(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(7\ a\_0\)\)\)\ r\^3\ \
Z\^\(9/2\)\ Cos[\[Theta]]\ \((\(-1\) + 
                    5\ Cos[2\ \[Theta]])\)\ \((2\ r\^3\ Z\^3 - 
                    105\ a\_0\ \((2\ r\^2\ Z\^2 - 63\ r\ Z\ a\_0 + 
                          588\ a\_0\%2)\))\)\)\/\(518832090\ \@\(6\ \[Pi]\)\ \
a\_0\%\(15/2\)\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_HydAt[3, 3, 1, 
          Z] = \(\[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi] - \(r\ \
Z\)\/\(7\ a\_0\)\)\ r\^3\ Z\^\(9/2\)\ \((3 + 5\ Cos[2\ \[Theta]])\)\ Sin[\
\[Theta]]\ \((2\ r\^3\ Z\^3 - 105\ a\_0\ \((2\ r\^2\ Z\^2 - 63\ r\ Z\ a\_0 + \
588\ a\_0\%2)\))\)\)\/\(1037664180\ \@\(2\ \[Pi]\)\ a\_0\%\(15/2\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\_HydAt[3, 3, 2, 
          Z] = \(-\(\(\[ExponentialE]\^\(2\ \[ImaginaryI]\ \[CurlyPhi] - \(r\ \
Z\)\/\(7\ a\_0\)\)\ r\^3\ Z\^\(9/2\)\ Cos[\[Theta]]\ Sin[\[Theta]]\^2\ \((2\ \
r\^3\ Z\^3 - 105\ a\_0\ \((2\ r\^2\ Z\^2 - 63\ r\ Z\ a\_0 + 
                          588\ a\_0\%2)\))\)\)\/\(103766418\ \@\(5\ \[Pi]\)\ \
a\_0\%\(15/2\)\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\_HydAt[3, 3, 3, 
          Z] = \(\[ExponentialE]\^\(3\ \[ImaginaryI]\ \[CurlyPhi] - \(r\ \
Z\)\/\(7\ a\_0\)\)\ r\^3\ Z\^\(9/2\)\ Sin[\[Theta]]\^3\ \((2\ r\^3\ Z\^3 - \
105\ a\_0\ \((2\ r\^2\ Z\^2 - 63\ r\ Z\ a\_0 + 588\ \
a\_0\%2)\))\)\)\/\(103766418\ \@\(30\ \[Pi]\)\ a\_0\%\(15/2\)\);\)\)}], \
"Input"],

Cell["Probability densities:", "Text"],

Cell[BoxData[{
    \(\(\[Psi]\[Psi]\_HydAt[0, 0, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/a\_0\)\)\ r\^2\ \
Z\^3\)\/\(\[Pi]\ a\_0\%3\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_HydAt[0, 1, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/a\_0\)\)\ r\^4\ Z\^5\ Cos[\
\[Theta]]\^2\)\/\(32\ \[Pi]\ a\_0\%5\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_HydAt[0, 1, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/a\_0\)\)\ r\^4\ Z\^5\ Sin[\
\[Theta]]\^2\)\/\(64\ \[Pi]\ a\_0\%5\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_HydAt[0, 2, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(3\ a\_0\)\)\)\ r\^6\ \
Z\^7\ \((1 + 3\ Cos[2\ \[Theta]])\)\^2\)\/\(157464\ \[Pi]\ a\_0\%7\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_HydAt[0, 2, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(3\ a\_0\)\)\)\ r\^6\ \
Z\^7\ Cos[\[Theta]]\^2\ Sin[\[Theta]]\^2\)\/\(6561\ \[Pi]\ a\_0\%7\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_HydAt[0, 2, 2, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(3\ a\_0\)\)\)\ r\^6\ \
Z\^7\ Sin[\[Theta]]\^4\)\/\(26244\ \[Pi]\ a\_0\%7\);\)\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_HydAt[0, 3, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\^8\ Z\^9\ \
Cos[\[Theta]]\^2\ \((1 - 5\ Cos[2\ \[Theta]])\)\^2\)\/\(188743680\ \[Pi]\ \
a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_HydAt[0, 3, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\^8\ Z\^9\ \
\((3 + 5\ Cos[2\ \[Theta]])\)\^2\ Sin[\[Theta]]\^2\)\/\(251658240\ \[Pi]\ \
a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_HydAt[0, 3, 2, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\^8\ Z\^9\ \
Cos[\[Theta]]\^2\ Sin[\[Theta]]\^4\)\/\(6291456\ \[Pi]\ a\_0\%9\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_HydAt[0, 3, 3, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\^8\ Z\^9\ \
Sin[\[Theta]]\^6\)\/\(37748736\ \[Pi]\ a\_0\%9\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_HydAt[1, 0, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/a\_0\)\)\ r\^2\ Z\^3\ \((r\ \
Z - 2\ a\_0)\)\^2\)\/\(32\ \[Pi]\ a\_0\%5\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_HydAt[1, 1, 0, 
          Z] = \(2\ \[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(3\ a\_0\)\)\)\ r\^4\ \
Z\^5\ Cos[\[Theta]]\^2\ \((r\ Z - 6\ a\_0)\)\^2\)\/\(6561\ \[Pi]\ \
a\_0\%7\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_HydAt[1, 1, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(3\ a\_0\)\)\)\ r\^4\ \
Z\^5\ Sin[\[Theta]]\^2\ \((r\ Z - 6\ a\_0)\)\^2\)\/\(6561\ \[Pi]\ \
a\_0\%7\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_HydAt[1, 2, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\^6\ Z\^7\ \
\((1 + 3\ Cos[2\ \[Theta]])\)\^2\ \((r\ Z - 12\ a\_0)\)\^2\)\/\(37748736\ \
\[Pi]\ a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_HydAt[1, 2, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\^6\ Z\^7\ \
Cos[\[Theta]]\^2\ Sin[\[Theta]]\^2\ \((r\ Z - 12\ a\_0)\)\^2\)\/\(1572864\ \
\[Pi]\ a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_HydAt[1, 2, 2, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\^6\ Z\^7\ \
Sin[\[Theta]]\^4\ \((r\ Z - 12\ a\_0)\)\^2\)\/\(6291456\ \[Pi]\ \
a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_HydAt[1, 3, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(5\ a\_0\)\)\)\ r\^8\ \
Z\^9\ Cos[\[Theta]]\^2\ \((1 - 5\ Cos[2\ \[Theta]])\)\^2\ \((r\ Z - 20\ a\_0)\
\)\^2\)\/\(87890625000\ \[Pi]\ a\_0\%11\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_HydAt[1, 3, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(5\ a\_0\)\)\)\ r\^8\ \
Z\^9\ \((3 + 5\ Cos[2\ \[Theta]])\)\^2\ Sin[\[Theta]]\^2\ \((r\ Z - 20\ a\_0)\
\)\^2\)\/\(117187500000\ \[Pi]\ a\_0\%11\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_HydAt[1, 3, 2, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(5\ a\_0\)\)\)\ r\^8\ \
Z\^9\ Cos[\[Theta]]\^2\ Sin[\[Theta]]\^4\ \((r\ Z - 20\ \
a\_0)\)\^2\)\/\(2929687500\ \[Pi]\ a\_0\%11\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_HydAt[1, 3, 3, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(5\ a\_0\)\)\)\ r\^8\ \
Z\^9\ Sin[\[Theta]]\^6\ \((r\ Z - 20\ a\_0)\)\^2\)\/\(17578125000\ \[Pi]\ \
a\_0\%11\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_HydAt[2, 0, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(3\ a\_0\)\)\)\ r\^2\ \
Z\^3\ \((2\ r\^2\ Z\^2 + 9\ a\_0\ \((\(-2\)\ r\ Z + 3\ \
a\_0)\))\)\^2\)\/\(19683\ \[Pi]\ a\_0\%7\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_HydAt[2, 1, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\^4\ Z\^5\ \
Cos[\[Theta]]\^2\ \((r\^2\ Z\^2 - 20\ r\ Z\ a\_0 + 80\ \
a\_0\%2)\)\^2\)\/\(1310720\ \[Pi]\ a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_HydAt[2, 1, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\^4\ Z\^5\ \
Sin[\[Theta]]\^2\ \((r\^2\ Z\^2 - 20\ r\ Z\ a\_0 + 80\ \
a\_0\%2)\)\^2\)\/\(2621440\ \[Pi]\ a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_HydAt[2, 2, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(5\ a\_0\)\)\)\ r\^6\ \
Z\^7\ \((1 + 3\ Cos[2\ \[Theta]])\)\^2\ \((2\ r\^2\ Z\^2 - 70\ r\ Z\ a\_0 + \
525\ a\_0\%2)\)\^2\)\/\(123046875000\ \[Pi]\ a\_0\%11\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_HydAt[2, 2, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(5\ a\_0\)\)\)\ r\^6\ \
Z\^7\ Cos[\[Theta]]\^2\ Sin[\[Theta]]\^2\ \((2\ r\^2\ Z\^2 - 70\ r\ Z\ a\_0 + \
525\ a\_0\%2)\)\^2\)\/\(5126953125\ \[Pi]\ a\_0\%11\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_HydAt[2, 2, 2, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(5\ a\_0\)\)\)\ r\^6\ \
Z\^7\ Sin[\[Theta]]\^4\ \((2\ r\^2\ Z\^2 - 70\ r\ Z\ a\_0 + 525\ \
a\_0\%2)\)\^2\)\/\(20507812500\ \[Pi]\ a\_0\%11\);\)\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_HydAt[2, 3, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ r\^8\ Z\^9\ \
Cos[\[Theta]]\^2\ \((1 - 5\ Cos[2\ \[Theta]])\)\^2\ \((r\ Z - 36\ a\_0)\)\^2\ \
\((r\ Z - 18\ a\_0)\)\^2\)\/\(126949945835520\ \[Pi]\ a\_0\%13\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_HydAt[2, 3, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ r\^8\ Z\^9\ \
\((3 + 5\ Cos[2\ \[Theta]])\)\^2\ Sin[\[Theta]]\^2\ \((r\ Z - 36\ a\_0)\)\^2\ \
\((r\ Z - 18\ a\_0)\)\^2\)\/\(169266594447360\ \[Pi]\ a\_0\%13\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_HydAt[2, 3, 2, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ r\^8\ Z\^9\ \
Cos[\[Theta]]\^2\ Sin[\[Theta]]\^4\ \((r\ Z - 36\ a\_0)\)\^2\ \((r\ Z - 18\ a\
\_0)\)\^2\)\/\(4231664861184\ \[Pi]\ a\_0\%13\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_HydAt[2, 3, 3, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ r\^8\ Z\^9\ \
Sin[\[Theta]]\^6\ \((r\ Z - 36\ a\_0)\)\^2\ \((r\ Z - 18\ \
a\_0)\)\^2\)\/\(25389989167104\ \[Pi]\ a\_0\%13\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_HydAt[3, 0, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(2\ a\_0\)\)\)\ r\^2\ Z\^3\ \
\((r\^3\ Z\^3 - 24\ \((r\ Z - 4\ a\_0)\)\ \((r\ Z - 2\ a\_0)\)\ \
a\_0)\)\^2\)\/\(2359296\ \[Pi]\ a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_HydAt[3, 1, 0, 
          Z] = \(2\ \[ExponentialE]\^\(\(\(-2\)\ r\)/5\)\ r\^4\ \((\(-3750\) \
+ r\ \((1125 + 2\ \((\(-45\) + r)\)\ r)\))\)\^2\ \
Cos[\[Theta]]\^2\)\/\(10986328125\ \[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_HydAt[3, 1, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(5\ a\_0\)\)\)\ r\^4\ \
Z\^5\ Sin[\[Theta]]\^2\ \((2\ r\^3\ Z\^3 - 15\ a\_0\ \((6\ r\^2\ Z\^2 - 75\ r\
\ Z\ a\_0 + 250\ a\_0\%2)\))\)\^2\)\/\(10986328125\ \[Pi]\ a\_0\%11\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_HydAt[3, 2, 0, 
          
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ r\^6\ Z\^7\ \
\((1 + 3\ Cos[2\ \[Theta]])\)\^2\ \((r\^3\ Z\^3 - 72\ a\_0\ \((r\^2\ Z\^2 + \
21\ a\_0\ \((\(-r\)\ Z + 6\ a\_0)\))\))\)\^2\)\/\(59243308056576\ \[Pi]\ a\_0\
\%13\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_HydAt[3, 2, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ r\^6\ Z\^7\ \
Cos[\[Theta]]\^2\ Sin[\[Theta]]\^2\ \((r\^3\ Z\^3 - 72\ a\_0\ \((r\^2\ Z\^2 + \
21\ a\_0\ \((\(-r\)\ Z + 6\ a\_0)\))\))\)\^2\)\/\(2468471169024\ \[Pi]\ \
a\_0\%13\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_HydAt[3, 2, 2, 
          Z] = \(\[ExponentialE]\^\(-\(\(r\ Z\)\/\(3\ a\_0\)\)\)\ r\^6\ Z\^7\ \
Sin[\[Theta]]\^4\ \((r\^3\ Z\^3 - 72\ a\_0\ \((r\^2\ Z\^2 + 21\ a\_0\ \((\(-r\
\)\ Z + 6\ a\_0)\))\))\)\^2\)\/\(9873884676096\ \[Pi]\ a\_0\%13\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_HydAt[3, 3, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(7\ a\_0\)\)\)\ r\^8\ \
Z\^9\ Cos[\[Theta]]\^2\ \((1 - 5\ Cos[2\ \[Theta]])\)\^2\ \((2\ r\^3\ Z\^3 - \
105\ a\_0\ \((2\ r\^2\ Z\^2 - 63\ r\ Z\ a\_0 + 588\ \
a\_0\%2)\))\)\^2\)\/\(1615120425682608600\ \[Pi]\ a\_0\%15\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_HydAt[3, 3, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(7\ a\_0\)\)\)\ r\^8\ \
Z\^9\ \((3 + 5\ Cos[2\ \[Theta]])\)\^2\ Sin[\[Theta]]\^2\ \((2\ r\^3\ Z\^3 - \
105\ a\_0\ \((2\ r\^2\ Z\^2 - 63\ r\ Z\ a\_0 + 588\ \
a\_0\%2)\))\)\^2\)\/\(2153493900910144800\ \[Pi]\ a\_0\%15\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_HydAt[3, 3, 2, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(7\ a\_0\)\)\)\ r\^8\ \
Z\^9\ Cos[\[Theta]]\^2\ Sin[\[Theta]]\^4\ \((2\ r\^3\ Z\^3 - 105\ a\_0\ \((2\ \
r\^2\ Z\^2 - 63\ r\ Z\ a\_0 + 588\ a\_0\%2)\))\)\^2\)\/\(53837347522753620\ \
\[Pi]\ a\_0\%15\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_HydAt[3, 3, 3, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ r\ Z\)\/\(7\ a\_0\)\)\)\ r\^8\ \
Z\^9\ Sin[\[Theta]]\^6\ \((2\ r\^3\ Z\^3 - 105\ a\_0\ \((2\ r\^2\ Z\^2 - 63\ \
r\ Z\ a\_0 + 588\ a\_0\%2)\))\)\^2\)\/\(323024085136521720\ \[Pi]\ \
a\_0\%15\);\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
4. Wave functions and probability densities of the Hydrogen-like atoms in the \
Cartesian rectangular coordinates\
\>", "Section"],

Cell["\<\
To obtain wave functions and probability densities of the Hydrogen-like atoms \
in the Cartesian rectangular coordinates we will use coordinate \
transformations:\
\>", "Text"],

Cell[BoxData[{
    \(\(\[Theta] = 
        ArcCos[z/\@\(x^2 + y^2 + z^2\)];\)\), "\[IndentingNewLine]", 
    \(\(\[CurlyPhi] = ArcCos[x/\@\(x^2 + y^2\)];\)\), "\[IndentingNewLine]", 
    \(\(r = \@\(x^2 + y^2 + z^2\);\)\)}], "Input"],

Cell["Wave functions", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[0, 0, 0, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[0, 1, 0, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[0, 1, 1, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[0, 2, 0, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[0, 2, 1, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[0, 2, 2, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[0, 3, 0, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[0, 3, 1, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[0, 3, 2, Z]]]\), "\[IndentingNewLine]", 
    \(\(\(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[0, 3, 3, Z]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[1, 0, 0, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[1, 1, 0, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[1, 1, 1, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[1, 2, 0, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[1, 2, 1, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[1, 2, 2, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[1, 3, 0, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[1, 3, 1, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[1, 3, 2, Z]]]\), "\[IndentingNewLine]", 
    \(\(\(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[1, 3, 3, Z]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[2, 0, 0, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[2, 1, 0, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[2, 1, 1, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[2, 2, 0, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[2, 2, 1, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[2, 2, 2, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[2, 3, 0, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[2, 3, 1, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[2, 3, 2, Z]]]\), "\[IndentingNewLine]", 
    \(\(\(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[2, 3, 3, Z]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[3, 0, 0, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[3, 1, 0, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[3, 1, 1, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[3, 2, 0, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[3, 2, 1, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[3, 2, 2, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[3, 3, 0, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[3, 3, 1, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\_HydAt[3, 3, 2, Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[FullSimplify[\[Psi]\_HydAt[3, 3, 3, Z]]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/a\_0\)\)\ \
Z\^\(3/2\)\)\/\(\@\[Pi]\ a\_0\%\(3/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ z\ Z\^\(5/2\)\)\/\(4\ \@\(2\ \[Pi]\)\ a\_0\%\(5/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)] - \
\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ a\_0\)\)\ \@\(x\^2 + y\^2\)\ Z\^\(5/2\)\
\)\/\(8\ \@\[Pi]\ a\_0\%\(5/2\)\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\
\)\)\)\ \((x\^2 + y\^2 - 
                2\ z\^2)\)\ Z\^\(7/2\)\)\/\(81\ \@\(6\ \[Pi]\)\ a\_0\%\(7/2\)\
\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)] - \
\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\)\)\ \@\(x\^2 + y\^2\)\ z\ \
Z\^\(7/2\)\)\/\(81\ \@\[Pi]\ a\_0\%\(7/2\)\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(2\ \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)] - \
\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\)\)\ \((x\^2 + y\^2)\)\ Z\^\(7/2\)\
\)\/\(162\ \@\[Pi]\ a\_0\%\(7/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(4\ \
a\_0\)\)\)\ z\ \((\(-3\)\ \((x\^2 + y\^2)\) + 2\ z\^2)\)\ \
Z\^\(9/2\)\)\/\(3072\ \@\(5\ \[Pi]\)\ a\_0\%\(9/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)] - \(\@\
\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(4\ a\_0\)\)\ \@\(x\^2 + y\^2\)\ \((x\^2 + y\^2 \
- 4\ z\^2)\)\ Z\^\(9/2\)\)\/\(2048\ \@\(15\ \[Pi]\)\ a\_0\%\(9/2\)\)\)], \
"Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(2\ \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)] - \
\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(4\ a\_0\)\)\ \((x\^2 + y\^2)\)\ z\ \
Z\^\(9/2\)\)\/\(1024\ \@\(6\ \[Pi]\)\ a\_0\%\(9/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(3\ \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + \
y\^2\)] - \(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(4\ a\_0\)\)\ \((x\^2 + y\^2)\)\^\
\(3/2\)\ Z\^\(9/2\)\)\/\(6144\ \@\[Pi]\ a\_0\%\(9/2\)\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ a\_0\
\)\)\)\ Z\^\(3/2\)\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 
                2\ a\_0)\)\)\/\(4\ \@\(2\ \[Pi]\)\ a\_0\%\(5/2\)\)\)\)\)], \
"Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\
\)\)\)\ \@\(2\/\[Pi]\)\ z\ Z\^\(5/2\)\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 
                6\ a\_0)\)\)\/\(81\ a\_0\%\(7/2\)\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)] - \(\@\
\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\)\)\ \@\(x\^2 + y\^2\)\ Z\^\(5/2\)\ \
\((\@\(x\^2 + y\^2 + z\^2\)\ Z - 6\ a\_0)\)\)\/\(81\ \@\[Pi]\ a\_0\%\(7/2\)\)\
\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(4\ \
a\_0\)\)\)\ \((x\^2 + y\^2 - 2\ z\^2)\)\ Z\^\(7/2\)\ \((\@\(x\^2 + y\^2 + \
z\^2\)\ Z - 12\ a\_0)\)\)\/\(3072\ \@\[Pi]\ a\_0\%\(9/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)] - \(\@\
\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(4\ a\_0\)\)\ \@\(x\^2 + y\^2\)\ z\ Z\^\(7/2\)\ \
\((\@\(x\^2 + y\^2 + z\^2\)\ Z - 12\ a\_0)\)\)\/\(512\ \@\(6\ \[Pi]\)\ a\_0\%\
\(9/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(2\ \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + \
y\^2\)] - \(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(4\ a\_0\)\)\ \((x\^2 + 
                y\^2)\)\ Z\^\(7/2\)\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 
                12\ a\_0)\)\)\/\(1024\ \@\(6\ \[Pi]\)\ \
a\_0\%\(9/2\)\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ a\_0\
\)\)\)\ z\ \((\(-3\)\ \((x\^2 + y\^2)\) + 
                2\ z\^2)\)\ Z\^\(9/2\)\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 
                20\ a\_0)\)\)\/\(46875\ \@\(10\ \[Pi]\)\ a\_0\%\(11/2\)\)\)\)\
\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)] - \
\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ a\_0\)\)\ \@\(x\^2 + y\^2\)\ \((x\^2 + 
                y\^2 - 4\ z\^2)\)\ Z\^\(9/2\)\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z \
- 20\ a\_0)\)\)\/\(31250\ \@\(30\ \[Pi]\)\ a\_0\%\(11/2\)\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(2\ \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + \
y\^2\)] - \(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ a\_0\)\)\ \((x\^2 + 
                y\^2)\)\ z\ Z\^\(9/2\)\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 
                20\ a\_0)\)\)\/\(31250\ \@\(3\ \[Pi]\)\ \
a\_0\%\(11/2\)\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(3\ \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)] - \
\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ a\_0\)\)\ \((x\^2 + y\^2)\)\^\(3/2\)\ Z\
\^\(9/2\)\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 20\ a\_0)\)\)\/\(93750\ \@\(2\ \
\[Pi]\)\ a\_0\%\(11/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ \
a\_0\)\)\)\ Z\^\(3/2\)\ \((2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 + 9\ a\_0\ \
\((\(-2\)\ \@\(x\^2 + y\^2 + z\^2\)\ Z + 3\ a\_0)\))\)\)\/\(81\ \@\(3\ \
\[Pi]\)\ a\_0\%\(7/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(4\ \
a\_0\)\)\)\ z\ Z\^\(5/2\)\ \((\((x\^2 + y\^2 + z\^2)\)\ Z\^2 - 20\ \@\(x\^2 + \
y\^2 + z\^2\)\ Z\ a\_0 + 80\ a\_0\%2)\)\)\/\(512\ \@\(5\ \[Pi]\)\ a\_0\%\(9/2\
\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(\[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)] - \
\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(4\ a\_0\)\)\ \@\(x\^2 + y\^2\)\ Z\^\(5/2\)\
\ \((\((x\^2 + y\^2 + z\^2)\)\ Z\^2 - 20\ \@\(x\^2 + y\^2 + z\^2\)\ Z\ a\_0 + 
                80\ a\_0\%2)\)\)\/\(512\ \@\(10\ \[Pi]\)\ a\_0\%\(9/2\)\)\)\)\
\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ a\_0\
\)\)\)\ \((x\^2 + y\^2 - 
                2\ z\^2)\)\ Z\^\(7/2\)\ \((2\ \((x\^2 + y\^2 + 
                      z\^2)\)\ Z\^2 - 70\ \@\(x\^2 + y\^2 + z\^2\)\ Z\ a\_0 + 
                525\ a\_0\%2)\)\)\/\(46875\ \@\(14\ \[Pi]\)\ a\_0\%\(11/2\)\)\
\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(1\/\(31250\ \@\(21\ \[Pi]\)\ \
a\_0\%\(11/2\)\)\)\((\[ExponentialE]\^\(\[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\
\^2\)] - \(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ a\_0\)\)\ \((x\^2 + y\^2 + 
              z\^2)\)\ Z\^\(7/2\)\ Sin[
            2\ ArcCos[
                z\/\@\(x\^2 + y\^2 + z\^2\)]]\ \((2\ \((x\^2 + y\^2 + 
                    z\^2)\)\ Z\^2 - 70\ \@\(x\^2 + y\^2 + z\^2\)\ Z\ a\_0 + 
              525\ a\_0\%2)\))\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(2\ \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)] - \
\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ a\_0\)\)\ \((x\^2 + y\^2)\)\ Z\^\(7/2\)\
\ \((2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 - 70\ \@\(x\^2 + y\^2 + z\^2\)\ Z\ \
a\_0 + 525\ a\_0\%2)\)\)\/\(31250\ \@\(21\ \[Pi]\)\ a\_0\%\(11/2\)\)\)], \
"Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(6\ \
a\_0\)\)\)\ z\ \((\(-3\)\ \((x\^2 + y\^2)\) + 2\ z\^2)\)\ Z\^\(9/2\)\ \
\((\@\(x\^2 + y\^2 + z\^2\)\ Z - 36\ a\_0)\)\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z \
- 18\ a\_0)\)\)\/\(2519424\ \@\(5\ \[Pi]\)\ a\_0\%\(13/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)] - \(\@\
\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(6\ a\_0\)\)\ \@\(x\^2 + y\^2\)\ \((x\^2 + y\^2 \
- 4\ z\^2)\)\ Z\^\(9/2\)\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 36\ a\_0)\)\ \((\@\
\(x\^2 + y\^2 + z\^2\)\ Z - 18\ a\_0)\)\)\/\(1679616\ \@\(15\ \[Pi]\)\ a\_0\%\
\(13/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(2\ \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)] - \
\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(6\ a\_0\)\)\ \((x\^2 + y\^2)\)\ z\ \
Z\^\(9/2\)\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 36\ a\_0)\)\ \((\@\(x\^2 + y\^2 \
+ z\^2\)\ Z - 18\ a\_0)\)\)\/\(839808\ \@\(6\ \[Pi]\)\ a\_0\%\(13/2\)\)\)], \
"Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(3\ \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + \
y\^2\)] - \(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(6\ a\_0\)\)\ \((x\^2 + y\^2)\)\^\
\(3/2\)\ Z\^\(9/2\)\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 
                36\ a\_0)\)\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 
                18\ a\_0)\)\)\/\(5038848\ \@\[Pi]\ a\_0\%\(13/2\)\)\)\)\)], \
"Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(4\ \
a\_0\)\)\)\ Z\^\(3/2\)\ \((\(-\((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\)\ Z\^3 + 24\ \
a\_0\ \((\((x\^2 + y\^2 + z\^2)\)\ Z\^2 - 6\ \@\(x\^2 + y\^2 + z\^2\)\ Z\ \
a\_0 + 8\ a\_0\%2)\))\)\)\/\(1536\ \@\[Pi]\ a\_0\%\(9/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ \
a\_0\)\)\)\ \@\(2\/\(5\ \[Pi]\)\)\ z\ Z\^\(5/2\)\ \((\(-2\)\ \((x\^2 + y\^2 + \
z\^2)\)\^\(3/2\)\ Z\^3 + 15\ a\_0\ \((6\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 - 75\ \
\@\(x\^2 + y\^2 + z\^2\)\ Z\ a\_0 + 250\ a\_0\%2)\))\)\)\/\(46875\ \
a\_0\%\(11/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)] - \(\@\
\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ a\_0\)\)\ \@\(x\^2 + y\^2\)\ Z\^\(5/2\)\ \
\((2\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ Z\^3 - 15\ a\_0\ \((6\ \((x\^2 + \
y\^2 + z\^2)\)\ Z\^2 - 75\ \@\(x\^2 + y\^2 + z\^2\)\ Z\ a\_0 + 250\ \
a\_0\%2)\))\)\)\/\(46875\ \@\(5\ \[Pi]\)\ a\_0\%\(11/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(6\ \
a\_0\)\)\)\ \((x\^2 + y\^2 - 2\ z\^2)\)\ Z\^\(7/2\)\ \((\((x\^2 + y\^2 + \
z\^2)\)\^\(3/2\)\ Z\^3 + 72\ a\_0\ \((\(-\((x\^2 + y\^2 + z\^2)\)\)\ Z\^2 + \
21\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 6\ a\_0)\)\ a\_0)\))\)\)\/\(839808\ \
\@\(21\ \[Pi]\)\ a\_0\%\(13/2\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(839808\ \@\(14\ \[Pi]\)\ \
a\_0\%\(13/2\)\)\)\((\[ExponentialE]\^\(\[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\
\^2\)] - \(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(6\ a\_0\)\)\ \((x\^2 + y\^2 + 
            z\^2)\)\ Z\^\(7/2\)\ Sin[
          2\ ArcCos[
              z\/\@\(x\^2 + y\^2 + z\^2\)]]\ \((\((x\^2 + y\^2 + \
z\^2)\)\^\(3/2\)\ Z\^3 - 
            72\ a\_0\ \((\((x\^2 + y\^2 + z\^2)\)\ Z\^2 + 
                  21\ a\_0\ \((\(-\@\(x\^2 + y\^2 + z\^2\)\)\ Z + 
                        6\ a\_0)\))\))\))\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\(-2\)\ \[ImaginaryI]\ ArcSin[x\/\@\(x\^2 + \
y\^2\)] - \(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(6\ a\_0\)\)\ \((x\^2 + y\^2)\)\ \
Z\^\(7/2\)\ \((\((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ Z\^3 + 72\ a\_0\ \((\(-\((x\
\^2 + y\^2 + z\^2)\)\)\ Z\^2 + 21\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 6\ \
a\_0)\)\ a\_0)\))\)\)\/\(839808\ \@\(14\ \[Pi]\)\ a\_0\%\(13/2\)\)\)], \
"Output"],

Cell[BoxData[
    \(\(-\(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(7\ a\_0\
\)\)\)\ z\ \((\(-3\)\ \((x\^2 + y\^2)\) + 
                2\ z\^2)\)\ Z\^\(9/2\)\ \((2\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\
\)\ Z\^3 + 105\ a\_0\ \((\(-2\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 + 
                      63\ \@\(x\^2 + y\^2 + z\^2\)\ Z\ a\_0 - 
                      588\ a\_0\%2)\))\)\)\/\(259416045\ \@\(6\ \[Pi]\)\ a\_0\
\%\(15/2\)\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(1\/\(518832090\ \@\(2\ \[Pi]\)\ a\_0\%\(15/2\)\)\)\((\
\[ExponentialE]\^\(\[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)] - \(\@\(x\^2 + \
y\^2 + z\^2\)\ Z\)\/\(7\ a\_0\)\)\ \@\(x\^2 + y\^2\)\ \((x\^2 + y\^2 - 
              4\ z\^2)\)\ Z\^\(9/2\)\ \((2\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\
\ Z\^3 + 105\ a\_0\ \((\(-2\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 + 
                    63\ \@\(x\^2 + y\^2 + z\^2\)\ Z\ a\_0 - 
                    588\ a\_0\%2)\))\))\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(103766418\ \@\(5\ \[Pi]\)\ \
a\_0\%\(15/2\)\)\)\((\[ExponentialE]\^\(\(-2\)\ \[ImaginaryI]\ \
ArcSin[x\/\@\(x\^2 + y\^2\)] - \(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(7\ a\_0\)\)\
\ \((x\^2 + 
            y\^2)\)\ z\ Z\^\(9/2\)\ \((2\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ \
Z\^3 + 105\ a\_0\ \((\(-2\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 + 
                  63\ \@\(x\^2 + y\^2 + z\^2\)\ Z\ a\_0 - 
                  588\ a\_0\%2)\))\))\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(103766418\ \@\(30\ \[Pi]\)\ a\_0\%\(15/2\)\)\)\((\
\[ExponentialE]\^\(3\ \[ImaginaryI]\ ArcCos[x\/\@\(x\^2 + y\^2\)] - \
\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(7\ a\_0\)\)\ \((x\^2 + y\^2)\)\^\(3/2\)\ Z\
\^\(9/2\)\ \((2\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ Z\^3 - 
            105\ a\_0\ \((2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 - 
                  63\ \@\(x\^2 + y\^2 + z\^2\)\ Z\ a\_0 + 
                  588\ a\_0\%2)\))\))\)\)\)], "Output"]
}, Open  ]],

Cell["Probability densities:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[0, 0, 0, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[0, 1, 0, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[0, 1, 1, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[0, 2, 0, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[0, 2, 1, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[0, 2, 2, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[0, 3, 0, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[0, 3, 1, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[0, 3, 2, 
          Z]]]\), "\[IndentingNewLine]", 
    \(\(\(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[0, 3, 3, Z]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[1, 0, 0, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[1, 1, 0, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[1, 1, 1, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[1, 2, 0, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[1, 2, 1, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[1, 2, 2, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[1, 3, 0, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[1, 3, 1, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[1, 3, 2, 
          Z]]]\), "\[IndentingNewLine]", 
    \(\(\(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[1, 3, 3, Z]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[2, 0, 0, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[2, 1, 0, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[2, 1, 1, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[2, 2, 0, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[2, 2, 1, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[2, 2, 2, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[2, 3, 0, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[2, 3, 1, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[2, 3, 2, 
          Z]]]\), "\[IndentingNewLine]", 
    \(\(\(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[2, 3, 3, Z]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[3, 0, 0, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[3, 1, 0, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[3, 1, 1, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[3, 2, 0, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[3, 2, 1, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[3, 2, 2, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[3, 3, 0, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[3, 3, 1, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[
      FullSimplify[\[Psi]\[Psi]\_HydAt[3, 3, 2, 
          Z]]]\), "\[IndentingNewLine]", 
    \(PowerExpand[FullSimplify[\[Psi]\[Psi]\_HydAt[3, 3, 3, Z]]]\)}], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/a\_0\)\)\ \
\((x\^2 + y\^2 + z\^2)\)\ Z\^3\)\/\(\[Pi]\ a\_0\%3\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/a\_0\)\)\ z\^2\
\ \((x\^2 + y\^2 + z\^2)\)\ Z\^5\)\/\(32\ \[Pi]\ a\_0\%5\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/a\_0\)\)\ \((x\
\^2 + y\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^5\)\/\(64\ \[Pi]\ a\_0\%5\)\)], \
"Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\)\
\)\)\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
Z\^7\)\/\(39366\ \[Pi]\ a\_0\%7\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\)\
\)\)\ \((x\^2 + y\^2)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^7\)\/\(6561\ \
\[Pi]\ a\_0\%7\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\)\
\)\)\ \((x\^2 + y\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^7\)\/\(26244\ \[Pi]\ \
a\_0\%7\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \((3\ \((x\^2 + y\^2)\)\ z - 2\ z\^3)\)\
\^2\ Z\^9\)\/\(47185920\ \[Pi]\ a\_0\%9\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 \
+ z\^2)\)\ Z\^9\)\/\(62914560\ \[Pi]\ a\_0\%9\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
Z\^9\)\/\(6291456\ \[Pi]\ a\_0\%9\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + z\^2)\)\ \
Z\^9\)\/\(37748736\ \[Pi]\ a\_0\%9\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/a\_0\)\)\ \((x\
\^2 + y\^2 + z\^2)\)\ Z\^3\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 2\ \
a\_0)\)\^2\)\/\(32\ \[Pi]\ a\_0\%5\)\)], "Output"],

Cell[BoxData[
    \(\(2\ \[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ \
a\_0\)\)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^5\ \((\@\(x\^2 + y\^2 + z\^2\)\
\ Z - 6\ a\_0)\)\^2\)\/\(6561\ \[Pi]\ a\_0\%7\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\)\
\)\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^5\ \((\@\(x\^2 + y\^2 + \
z\^2\)\ Z - 6\ a\_0)\)\^2\)\/\(6561\ \[Pi]\ a\_0\%7\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^7\ \
\((\@\(x\^2 + y\^2 + z\^2\)\ Z - 12\ a\_0)\)\^2\)\/\(9437184\ \[Pi]\ \
a\_0\%9\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^7\ \((\@\(x\
\^2 + y\^2 + z\^2\)\ Z - 12\ a\_0)\)\^2\)\/\(1572864\ \[Pi]\ a\_0\%9\)\)], \
"Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^7\ \((\@\(x\^2 \
+ y\^2 + z\^2\)\ Z - 12\ a\_0)\)\^2\)\/\(6291456\ \[Pi]\ a\_0\%9\)\)], \
"Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ a\_0\)\
\)\)\ z\^2\ \((3\ \((x\^2 + y\^2)\) - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\
\ Z\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 20\ a\_0)\)\^2\)\/\(21972656250\ \
\[Pi]\ a\_0\%11\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ a\_0\)\
\)\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 + \
z\^2)\)\ Z\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 20\ \
a\_0)\)\^2\)\/\(29296875000\ \[Pi]\ a\_0\%11\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ a\_0\)\
\)\)\ \((x\^2 + y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^9\ \((\@\(x\^2 \
+ y\^2 + z\^2\)\ Z - 20\ a\_0)\)\^2\)\/\(2929687500\ \[Pi]\ a\_0\%11\)\)], \
"Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ a\_0\)\
\)\)\ \((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + z\^2)\)\ Z\^9\ \((\@\(x\^2 + \
y\^2 + z\^2\)\ Z - 20\ a\_0)\)\^2\)\/\(17578125000\ \[Pi]\ a\_0\%11\)\)], \
"Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\)\
\)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^3\ \((2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 + \
9\ a\_0\ \((\(-2\)\ \@\(x\^2 + y\^2 + z\^2\)\ Z + 3\ a\_0)\))\)\^2\)\/\(19683\
\ \[Pi]\ a\_0\%7\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^5\ \((\((x\^2 + y\^2 + z\^2)\)\
\ Z\^2 - 20\ \@\(x\^2 + y\^2 + z\^2\)\ Z\ a\_0 + 80\ \
a\_0\%2)\)\^2\)\/\(1310720\ \[Pi]\ a\_0\%9\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^5\ \((\((x\^2 + y\
\^2 + z\^2)\)\ Z\^2 - 20\ \@\(x\^2 + y\^2 + z\^2\)\ Z\ a\_0 + 80\ \
a\_0\%2)\)\^2\)\/\(2621440\ \[Pi]\ a\_0\%9\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ a\_0\)\
\)\)\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^7\ \((2\ \
\((x\^2 + y\^2 + z\^2)\)\ Z\^2 - 70\ \@\(x\^2 + y\^2 + z\^2\)\ Z\ a\_0 + 525\ \
a\_0\%2)\)\^2\)\/\(30761718750\ \[Pi]\ a\_0\%11\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ a\_0\)\
\)\)\ \((x\^2 + y\^2)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^7\ \((2\ \((x\^2 \
+ y\^2 + z\^2)\)\ Z\^2 - 70\ \@\(x\^2 + y\^2 + z\^2\)\ Z\ a\_0 + 525\ \
a\_0\%2)\)\^2\)\/\(5126953125\ \[Pi]\ a\_0\%11\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ a\_0\)\
\)\)\ \((x\^2 + y\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^7\ \((2\ \((x\^2 + y\
\^2 + z\^2)\)\ Z\^2 - 70\ \@\(x\^2 + y\^2 + z\^2\)\ Z\ a\_0 + 525\ a\_0\%2)\)\
\^2\)\/\(20507812500\ \[Pi]\ a\_0\%11\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ \
a\_0\)\)\)\ z\^2\ \((3\ \((x\^2 + y\^2)\) - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + z\
\^2)\)\ Z\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 36\ a\_0)\)\^2\ \((\@\(x\^2 + \
y\^2 + z\^2\)\ Z - 18\ a\_0)\)\^2\)\/\(31737486458880\ \[Pi]\ a\_0\%13\)\)], \
"Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 \
+ z\^2)\)\ Z\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 36\ a\_0)\)\^2\ \((\@\(x\^2 \
+ y\^2 + z\^2\)\ Z - 18\ a\_0)\)\^2\)\/\(42316648611840\ \[Pi]\ \
a\_0\%13\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^9\ \((\@\
\(x\^2 + y\^2 + z\^2\)\ Z - 36\ a\_0)\)\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - \
18\ a\_0)\)\^2\)\/\(4231664861184\ \[Pi]\ a\_0\%13\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + z\^2)\)\ Z\^9\ \((\@\(x\^2 \
+ y\^2 + z\^2\)\ Z - 36\ a\_0)\)\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 18\ \
a\_0)\)\^2\)\/\(25389989167104\ \[Pi]\ a\_0\%13\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^3\ \((\((x\^2 + y\^2 + \
z\^2)\)\^\(3/2\)\ Z\^3 + 24\ a\_0\ \((\(-\((x\^2 + y\^2 + z\^2)\)\)\ Z\^2 + 6\
\ \@\(x\^2 + y\^2 + z\^2\)\ Z\ a\_0 - 8\ a\_0\%2)\))\)\^2\)\/\(2359296\ \[Pi]\
\ a\_0\%9\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ a\_0\)\
\)\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^5\ \((90\ \((x\^2 + \
y\^2 + z\^2)\)\ Z\^2\ a\_0 + 3750\ a\_0\%3 - \@\(x\^2 + y\^2 + z\^2\)\ \((2\ \
\((x\^2 + y\^2 + z\^2)\)\ Z\^3 + 1125\ Z\ a\_0\%2)\))\)\^2\)\/\(10986328125\ \
\[Pi]\ a\_0\%11\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ a\_0\)\
\)\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^5\ \((90\ \((x\^2 + \
y\^2 + z\^2)\)\ Z\^2\ a\_0 + 3750\ a\_0\%3 - \@\(x\^2 + y\^2 + z\^2\)\ \((2\ \
\((x\^2 + y\^2 + z\^2)\)\ Z\^3 + 1125\ Z\ a\_0\%2)\))\)\^2\)\/\(10986328125\ \
\[Pi]\ a\_0\%11\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ \
a\_0\)\)\)\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^7\ \
\((\((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ Z\^3 + 72\ a\_0\ \((\(-\((x\^2 + y\^2 + \
z\^2)\)\)\ Z\^2 + 21\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 6\ a\_0)\)\ a\_0)\))\)\
\^2\)\/\(14810827014144\ \[Pi]\ a\_0\%13\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^7\ \((z\ \((x\^2 \
+ y\^2 + z\^2)\)\^\(3/2\)\ Z\^3 + 72\ z\ a\_0\ \((\(-\((x\^2 + y\^2 + z\^2)\)\
\)\ Z\^2 + 21\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 6\ a\_0)\)\ a\_0)\))\)\^2\)\/\
\(2468471169024\ \[Pi]\ a\_0\%13\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^7\ \((\((x\^2 \
+ y\^2 + z\^2)\)\^\(3/2\)\ Z\^3 + 72\ a\_0\ \((\(-\((x\^2 + y\^2 + z\^2)\)\)\ \
Z\^2 + 21\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 6\ a\_0)\)\ \
a\_0)\))\)\^2\)\/\(9873884676096\ \[Pi]\ a\_0\%13\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(403780106420652150\ \[Pi]\ a\_0\%15\)\)\((\[ExponentialE]\^\(-\
\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(7\ a\_0\)\)\)\ z\^2\ \((3\ \((x\^2 + \
y\^2)\) - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
            z\^2)\)\ Z\^9\ \((2\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ Z\^3 + \
105\ a\_0\ \((\(-2\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 + 63\ \@\(x\^2 + y\^2 + \
z\^2\)\ Z\ a\_0 - 588\ a\_0\%2)\))\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(538373475227536200\ \[Pi]\ a\_0\%15\)\)\((\[ExponentialE]\^\(-\
\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(7\ a\_0\)\)\)\ \((x\^2 + 
            y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
            z\^2)\)\ Z\^9\ \((2\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ Z\^3 + \
105\ a\_0\ \((\(-2\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 + 63\ \@\(x\^2 + y\^2 + \
z\^2\)\ Z\ a\_0 - 588\ a\_0\%2)\))\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\(1\/\(53837347522753620\ \[Pi]\ \
a\_0\%15\)\)\((\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(7\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + 
            z\^2)\)\ Z\^9\ \((2\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ Z\^3 + \
105\ a\_0\ \((\(-2\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 + 63\ \@\(x\^2 + y\^2 + \
z\^2\)\ Z\ a\_0 - 588\ a\_0\%2)\))\)\^2)\)\)\)], "Output"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(7\ a\_0\)\
\)\)\ \((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + z\^2)\)\ Z\^9\ \((2\ \((x\^2 + y\
\^2 + z\^2)\)\^\(3/2\)\ Z\^3 + 105\ a\_0\ \((\(-2\)\ \((x\^2 + y\^2 + z\^2)\)\
\ Z\^2 + 63\ \@\(x\^2 + y\^2 + z\^2\)\ Z\ a\_0 - 588\ \
a\_0\%2)\))\)\^2\)\/\(323024085136521720\ \[Pi]\ a\_0\%15\)\)], "Output"]
}, Open  ]],

Cell["\<\
Thus probability densities in the Cartesian rectangular coordinates are:\
\>", "Text"],

Cell[BoxData[{
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 0, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/a\_0\)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^3\)\/\(\[Pi]\ a\_0\%3\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 1, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/a\_0\)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^5\)\/\(32\ \[Pi]\ \
a\_0\%5\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 1, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/a\_0\)\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^5\)\/\(64\ \
\[Pi]\ a\_0\%5\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 2, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + \
z\^2)\)\ Z\^7\)\/\(39366\ \[Pi]\ a\_0\%7\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 2, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^7\
\)\/\(6561\ \[Pi]\ a\_0\%7\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 2, 2, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
Z\^7\)\/\(26244\ \[Pi]\ a\_0\%7\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 3, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\ \((3\ \((x\^2 + y\^2)\)\ z - 2\ z\^3)\)\
\^2\ Z\^9\)\/\(47185920\ \[Pi]\ a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 3, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 \
+ z\^2)\)\ Z\^9\)\/\(62914560\ \[Pi]\ a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 3, 2, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ \
Z\^9\)\/\(6291456\ \[Pi]\ a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[0, 3, 3, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + z\^2)\)\ \
Z\^9\)\/\(37748736\ \[Pi]\ a\_0\%9\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 0, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/a\_0\)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^3\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z \
- 2\ a\_0)\)\^2\)\/\(32\ \[Pi]\ a\_0\%5\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 1, 0, 
          Z] = \(2\ \[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(3\ a\_0\)\)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^5\ \((\@\(x\^2 + \
y\^2 + z\^2\)\ Z - 6\ a\_0)\)\^2\)\/\(6561\ \[Pi]\ a\_0\%7\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 1, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^5\ \
\((\@\(x\^2 + y\^2 + z\^2\)\ Z - 6\ a\_0)\)\^2\)\/\(6561\ \[Pi]\ a\_0\%7\);\)\
\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 2, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^7\ \
\((\@\(x\^2 + y\^2 + z\^2\)\ Z - 12\ a\_0)\)\^2\)\/\(9437184\ \[Pi]\ \
a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 2, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^7\ \((\@\(x\
\^2 + y\^2 + z\^2\)\ Z - 12\ a\_0)\)\^2\)\/\(1572864\ \[Pi]\ a\_0\%9\);\)\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 2, 2, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^7\ \((\@\(x\^2 \
+ y\^2 + z\^2\)\ Z - 12\ a\_0)\)\^2\)\/\(6291456\ \[Pi]\ a\_0\%9\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 3, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(5\ a\_0\)\)\)\ z\^2\ \((3\ \((x\^2 + y\^2)\) - 2\ z\^2)\)\^2\ \((x\^2 \
+ y\^2 + z\^2)\)\ Z\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 20\ \
a\_0)\)\^2\)\/\(21972656250\ \[Pi]\ a\_0\%11\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 3, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(5\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\
\^2 + y\^2 + z\^2)\)\ Z\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 20\ a\_0)\)\^2\)\
\/\(29296875000\ \[Pi]\ a\_0\%11\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 3, 2, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(5\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\
\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 20\ a\_0)\)\^2\)\/\(2929687500\ \[Pi]\ \
a\_0\%11\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[1, 3, 3, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(5\ a\_0\)\)\)\ \((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + z\^2)\)\ Z\^9\ \
\((\@\(x\^2 + y\^2 + z\^2\)\ Z - 20\ a\_0)\)\^2\)\/\(17578125000\ \[Pi]\ a\_0\
\%11\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 0, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ \
Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^3\ \((2\ \((x\^2 + y\^2 + \
z\^2)\)\ Z\^2 + 9\ a\_0\ \((\(-2\)\ \@\(x\^2 + y\^2 + z\^2\)\ Z + 3\ a\_0)\))\
\)\^2\)\/\(19683\ \[Pi]\ a\_0\%7\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 1, 0, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ z\^2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^5\ \((\((x\^2 + y\^2 + z\^2)\)\
\ Z\^2 - 20\ \@\(x\^2 + y\^2 + z\^2\)\ Z\ a\_0 + 80\ \
a\_0\%2)\)\^2\)\/\(1310720\ \[Pi]\ a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 1, 1, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^5\ \((\((x\^2 + y\
\^2 + z\^2)\)\ Z\^2 - 20\ \@\(x\^2 + y\^2 + z\^2\)\ Z\ a\_0 + 80\ \
a\_0\%2)\)\^2\)\/\(2621440\ \[Pi]\ a\_0\%9\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 2, 0, 
          Z] = \(\(1\/\(30761718750\ \[Pi]\ \
a\_0\%11\)\)\((\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ \
a\_0\)\)\)\ \((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                z\^2)\)\ Z\^7\ \((2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 - 70\ \
\@\(x\^2 + y\^2 + z\^2\)\ Z\ a\_0 + 525\ a\_0\%2)\)\^2)\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 2, 1, 
          Z] = \(\(1\/\(5126953125\ \[Pi]\ \
a\_0\%11\)\)\((\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\ z\^2\ \((x\^2 + y\^2 + 
                z\^2)\)\ Z\^7\ \((2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 - 70\ \
\@\(x\^2 + y\^2 + z\^2\)\ Z\ a\_0 + 525\ a\_0\%2)\)\^2)\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 2, 2, 
          Z] = \(\(1\/\(20507812500\ \[Pi]\ \
a\_0\%11\)\)\((\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\^2\ \((x\^2 + y\^2 + 
                z\^2)\)\ Z\^7\ \((2\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 - 70\ \
\@\(x\^2 + y\^2 + z\^2\)\ Z\ a\_0 + 525\ a\_0\%2)\)\^2)\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 3, 0, 
          Z] = \(\(1\/\(31737486458880\ \[Pi]\ a\_0\%13\)\)\((\[ExponentialE]\
\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\)\)\)\ z\^2\ \((3\ \((x\^2 \
+ y\^2)\) - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                z\^2)\)\ Z\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 36\ \
a\_0)\)\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 18\ a\_0)\)\^2)\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 3, 1, 
          Z] = \(\(1\/\(42316648611840\ \[Pi]\ a\_0\%13\)\)\((\[ExponentialE]\
\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\)\)\)\ \((x\^2 + 
                y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                z\^2)\)\ Z\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 36\ \
a\_0)\)\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 18\ a\_0)\)\^2)\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 3, 2, 
          Z] = \(\(1\/\(4231664861184\ \[Pi]\ \
a\_0\%13\)\)\((\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + 
                z\^2)\)\ Z\^9\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 36\ \
a\_0)\)\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 18\ a\_0)\)\^2)\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[2, 3, 3, 
          Z] = \(\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + z\^2)\)\ Z\^9\ \((\@\(x\^2 \
+ y\^2 + z\^2\)\ Z - 36\ a\_0)\)\^2\ \((\@\(x\^2 + y\^2 + z\^2\)\ Z - 18\ \
a\_0)\)\^2\)\/\(25389989167104\ \[Pi]\ a\_0\%13\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 0, 0, 
          Z] = \(\(1\/\(2359296\ \[Pi]\ \
a\_0\%9\)\)\((\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(2\ \
a\_0\)\)\)\ \((x\^2 + y\^2 + 
                z\^2)\)\ Z\^3\ \((\((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ Z\^3 + \
24\ a\_0\ \((\(-\((x\^2 + y\^2 + z\^2)\)\)\ Z\^2 + 6\ \@\(x\^2 + y\^2 + \
z\^2\)\ Z\ a\_0 - 8\ a\_0\%2)\))\)\^2)\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 1, 0, 
          Z] = \(1\/\(10986328125\ \[Pi]\ a\_0\%11\)\) \
\((\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ a\_0\)\)\)\ \
z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^5\ \((90\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2\ a\_0 \
+ 3750\ a\_0\%3 - \@\(x\^2 + y\^2 + z\^2\)\ \((2\ \((x\^2 + y\^2 + z\^2)\)\ Z\
\^3 + 1125\ Z\ a\_0\%2)\))\)\^2)\);\)\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 1, 1, 
          Z] = \(\(1\/\(10986328125\ \[Pi]\ \
a\_0\%11\)\)\((\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(5\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + 
                z\^2)\)\ Z\^5\ \((90\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2\ a\_0 + \
3750\ a\_0\%3 - \@\(x\^2 + y\^2 + z\^2\)\ \((2\ \((x\^2 + y\^2 + z\^2)\)\ \
Z\^3 + 1125\ Z\ a\_0\%2)\))\)\^2)\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 2, 0, 
          Z] = \(1\/\(14810827014144\ \[Pi]\ a\_0\%13\)\) \
\((\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ a\_0\)\)\)\ \
\((x\^2 + y\^2 - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^7\ \((\((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ Z\^3 + \
72\ a\_0\ \((\(-\((x\^2 + y\^2 + z\^2)\)\)\ Z\^2 + 21\ \((\@\(x\^2 + y\^2 + z\
\^2\)\ Z - 6\ a\_0)\)\ a\_0)\))\)\^2)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 2, 1, 
          Z] = \(\(1\/\(2468471169024\ \[Pi]\ \
a\_0\%13\)\)\((\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\ \((x\^2 + y\^2 + 
                z\^2)\)\ Z\^7\ \((z\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ Z\^3 \
+ 72\ z\ a\_0\ \((\(-\((x\^2 + y\^2 + z\^2)\)\)\ Z\^2 + 21\ \((\@\(x\^2 + \
y\^2 + z\^2\)\ Z - 6\ a\_0)\)\ a\_0)\))\)\^2)\)\);\)\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 2, 2, 
          Z] = \(\(1\/\(9873884676096\ \[Pi]\ \
a\_0\%13\)\)\((\[ExponentialE]\^\(-\(\(\@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(3\ \
a\_0\)\)\)\ \((x\^2 + y\^2)\)\^2\ \((x\^2 + y\^2 + 
                z\^2)\)\ Z\^7\ \((\((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ Z\^3 + \
72\ a\_0\ \((\(-\((x\^2 + y\^2 + z\^2)\)\)\ Z\^2 + 21\ \((\@\(x\^2 + y\^2 + z\
\^2\)\ Z - 6\ a\_0)\)\ a\_0)\))\)\^2)\)\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 3, 0, 
          Z] = \(1\/\(403780106420652150\ \[Pi]\ a\_0\%15\)\) \((\
\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(7\ a\_0\)\)\)\ \
z\^2\ \((3\ \((x\^2 + y\^2)\) - 2\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^9\ \((2\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ \
Z\^3 + 105\ a\_0\ \((\(-2\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 + 63\ \@\(x\^2 + \
y\^2 + z\^2\)\ Z\ a\_0 - 588\ a\_0\%2)\))\)\^2)\);\)\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 3, 1, 
          Z] = \(1\/\(538373475227536200\ \[Pi]\ a\_0\%15\)\) \((\
\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(7\ a\_0\)\)\)\ \
\((x\^2 + y\^2)\)\ \((x\^2 + y\^2 - 4\ z\^2)\)\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^9\ \((2\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ \
Z\^3 + 105\ a\_0\ \((\(-2\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 + 63\ \@\(x\^2 + \
y\^2 + z\^2\)\ Z\ a\_0 - 588\ a\_0\%2)\))\)\^2)\);\)\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 3, 2, 
          Z] = \(1\/\(53837347522753620\ \[Pi]\ a\_0\%15\)\) \((\
\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(7\ a\_0\)\)\)\ \
\((x\^2 + y\^2)\)\^2\ z\^2\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^9\ \((2\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ \
Z\^3 + 105\ a\_0\ \((\(-2\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 + 63\ \@\(x\^2 + \
y\^2 + z\^2\)\ Z\ a\_0 - 588\ a\_0\%2)\))\)\^2)\);\)\), \
"\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_\(HydAt, Cart\)[3, 3, 3, 
          Z] = \(1\/\(323024085136521720\ \[Pi]\ a\_0\%15\)\) \((\
\[ExponentialE]\^\(-\(\(2\ \@\(x\^2 + y\^2 + z\^2\)\ Z\)\/\(7\ a\_0\)\)\)\ \
\((x\^2 + y\^2)\)\^3\ \((x\^2 + y\^2 + 
                  z\^2)\)\ Z\^9\ \((2\ \((x\^2 + y\^2 + z\^2)\)\^\(3/2\)\ \
Z\^3 + 105\ a\_0\ \((\(-2\)\ \((x\^2 + y\^2 + z\^2)\)\ Z\^2 + 63\ \@\(x\^2 + \
y\^2 + z\^2\)\ Z\ a\_0 - 588\ a\_0\%2)\))\)\^2)\);\)\)}], "Input"],

Cell["", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1016, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.25,
StyleDefinitions -> "Classroom1.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 186, 7, 56, "Subtitle"],
Cell[2459, 81, 195, 5, 124, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2679, 90, 118, 3, 85, "Section"],
Cell[2800, 95, 190, 5, 56, "Text"],

Cell[CellGroupData[{
Cell[3015, 104, 599, 10, 157, "Input"],
Cell[3617, 116, 426, 6, 154, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4080, 127, 112, 2, 64, "Input"],
Cell[4195, 131, 437, 7, 147, "Output"]
}, Open  ]],
Cell[4647, 141, 222, 6, 80, "Text"],

Cell[CellGroupData[{
Cell[4894, 151, 117, 2, 63, "Input"],
Cell[5014, 155, 91, 1, 63, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5142, 161, 281, 7, 138, "Input"],
Cell[5426, 170, 101, 2, 64, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5564, 177, 129, 2, 63, "Input"],
Cell[5696, 181, 496, 8, 212, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6241, 195, 125, 3, 85, "Section"],
Cell[6369, 200, 164, 5, 56, "Text"],
Cell[6536, 207, 159, 3, 53, "NumberedEquation"],
Cell[6698, 212, 342, 12, 56, "Text"],
Cell[7043, 226, 135, 3, 56, "Text"],
Cell[7181, 231, 181, 4, 63, "Input"],

Cell[CellGroupData[{
Cell[7387, 239, 189, 4, 64, "Input"],
Cell[7579, 245, 506, 8, 170, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8122, 258, 106, 5, 89, "Subsection"],

Cell[CellGroupData[{
Cell[8253, 267, 995, 19, 393, "Input"],
Cell[9251, 288, 113, 2, 116, "Output"],
Cell[9367, 292, 115, 2, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9519, 299, 995, 19, 393, "Input"],
Cell[10517, 320, 161, 2, 117, "Output"],
Cell[10681, 324, 134, 2, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10852, 331, 995, 19, 393, "Input"],
Cell[11850, 352, 189, 3, 117, "Output"],
Cell[12042, 357, 134, 2, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12213, 364, 995, 19, 393, "Input"],
Cell[13211, 385, 194, 3, 117, "Output"],
Cell[13408, 390, 164, 2, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13609, 397, 995, 19, 393, "Input"],
Cell[14607, 418, 214, 3, 117, "Output"],
Cell[14824, 423, 164, 2, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15025, 430, 995, 19, 393, "Input"],
Cell[16023, 451, 197, 3, 117, "Output"],
Cell[16223, 456, 147, 2, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16407, 463, 995, 19, 393, "Input"],
Cell[17405, 484, 211, 3, 117, "Output"],
Cell[17619, 489, 184, 3, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17840, 497, 995, 19, 393, "Input"],
Cell[18838, 518, 262, 4, 117, "Output"],
Cell[19103, 524, 184, 3, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19324, 532, 995, 19, 393, "Input"],
Cell[20322, 553, 220, 3, 117, "Output"],
Cell[20545, 558, 164, 2, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20746, 565, 944, 19, 393, "Input"],
Cell[21693, 586, 207, 3, 117, "Output"],
Cell[21903, 591, 147, 2, 102, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[22099, 599, 106, 5, 89, "Subsection"],

Cell[CellGroupData[{
Cell[22230, 608, 995, 19, 393, "Input"],
Cell[23228, 629, 160, 2, 116, "Output"],
Cell[23391, 633, 141, 2, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23569, 640, 995, 19, 393, "Input"],
Cell[24567, 661, 200, 3, 117, "Output"],
Cell[24770, 666, 176, 3, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24983, 674, 995, 19, 393, "Input"],
Cell[25981, 695, 226, 3, 117, "Output"],
Cell[26210, 700, 171, 2, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26418, 707, 995, 19, 393, "Input"],
Cell[27416, 728, 222, 3, 117, "Output"],
Cell[27641, 733, 191, 3, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27869, 741, 995, 19, 393, "Input"],
Cell[28867, 762, 257, 4, 117, "Output"],
Cell[29127, 768, 192, 3, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29356, 776, 995, 19, 393, "Input"],
Cell[30354, 797, 237, 3, 117, "Output"],
Cell[30594, 802, 174, 3, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30805, 810, 995, 19, 393, "Input"],
Cell[31803, 831, 251, 4, 117, "Output"],
Cell[32057, 837, 216, 3, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32310, 845, 995, 19, 393, "Input"],
Cell[33308, 866, 301, 5, 117, "Output"],
Cell[33612, 873, 217, 3, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33866, 881, 995, 19, 393, "Input"],
Cell[34864, 902, 259, 4, 117, "Output"],
Cell[35126, 908, 199, 3, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35362, 916, 944, 19, 393, "Input"],
Cell[36309, 937, 251, 3, 117, "Output"],
Cell[36563, 942, 182, 3, 102, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[36794, 951, 106, 5, 89, "Subsection"],

Cell[CellGroupData[{
Cell[36925, 960, 995, 19, 393, "Input"],
Cell[37923, 981, 198, 3, 117, "Output"],
Cell[38124, 986, 195, 3, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38356, 994, 995, 19, 393, "Input"],
Cell[39354, 1015, 217, 3, 117, "Output"],
Cell[39574, 1020, 200, 3, 103, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[39811, 1028, 995, 19, 393, "Input"],
Cell[40809, 1049, 285, 5, 117, "Output"],
Cell[41097, 1056, 200, 3, 103, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41334, 1064, 995, 19, 393, "Input"],
Cell[42332, 1085, 253, 4, 117, "Output"],
Cell[42588, 1091, 229, 3, 103, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[42854, 1099, 995, 19, 393, "Input"],
Cell[43852, 1120, 297, 5, 117, "Output"],
Cell[44152, 1127, 229, 3, 103, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[44418, 1135, 995, 19, 393, "Input"],
Cell[45416, 1156, 262, 4, 117, "Output"],
Cell[45681, 1162, 212, 3, 103, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[45930, 1170, 995, 19, 393, "Input"],
Cell[46928, 1191, 266, 4, 117, "Output"],
Cell[47197, 1197, 243, 3, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47477, 1205, 995, 19, 393, "Input"],
Cell[48475, 1226, 334, 6, 117, "Output"],
Cell[48812, 1234, 243, 3, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49092, 1242, 995, 19, 393, "Input"],
Cell[50090, 1263, 274, 4, 117, "Output"],
Cell[50367, 1269, 225, 3, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[50629, 1277, 944, 19, 393, "Input"],
Cell[51576, 1298, 279, 5, 117, "Output"],
Cell[51858, 1305, 208, 3, 102, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[52115, 1314, 106, 5, 89, "Subsection"],

Cell[CellGroupData[{
Cell[52246, 1323, 995, 19, 393, "Input"],
Cell[53244, 1344, 223, 3, 117, "Output"],
Cell[53470, 1349, 206, 3, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[53713, 1357, 995, 19, 393, "Input"],
Cell[54711, 1378, 300, 4, 129, "Output"],
Cell[55014, 1384, 247, 3, 103, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[55298, 1392, 995, 19, 393, "Input"],
Cell[56296, 1413, 278, 4, 117, "Output"],
Cell[56577, 1419, 244, 3, 103, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[56858, 1427, 995, 19, 393, "Input"],
Cell[57856, 1448, 285, 4, 117, "Output"],
Cell[58144, 1454, 262, 4, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[58443, 1463, 995, 19, 393, "Input"],
Cell[59441, 1484, 329, 5, 117, "Output"],
Cell[59773, 1491, 263, 4, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[60073, 1500, 995, 19, 393, "Input"],
Cell[61071, 1521, 294, 4, 117, "Output"],
Cell[61368, 1527, 243, 3, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[61648, 1535, 995, 19, 393, "Input"],
Cell[62646, 1556, 348, 6, 154, "Output"],
Cell[62997, 1564, 289, 4, 103, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[63323, 1573, 995, 19, 393, "Input"],
Cell[64321, 1594, 361, 5, 154, "Output"],
Cell[64685, 1601, 289, 4, 103, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[65011, 1610, 995, 19, 393, "Input"],
Cell[66009, 1631, 337, 5, 117, "Output"],
Cell[66349, 1638, 271, 4, 103, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[66657, 1647, 944, 19, 393, "Input"],
Cell[67604, 1668, 297, 4, 117, "Output"],
Cell[67904, 1674, 254, 4, 103, "Output"]
}, Open  ]],
Cell[68173, 1681, 29, 0, 56, "Text"],
Cell[68205, 1683, 30, 0, 56, "Text"],

Cell[CellGroupData[{
Cell[68260, 1687, 3822, 82, 1113, "Input"],
Cell[72085, 1771, 120, 2, 108, "Output"],
Cell[72208, 1775, 155, 2, 108, "Output"],
Cell[72366, 1779, 183, 3, 108, "Output"],
Cell[72552, 1784, 178, 3, 108, "Output"],
Cell[72733, 1789, 202, 3, 108, "Output"],
Cell[72938, 1794, 185, 3, 108, "Output"],
Cell[73126, 1799, 199, 3, 108, "Output"],
Cell[73328, 1804, 242, 4, 108, "Output"],
Cell[73573, 1810, 208, 3, 108, "Output"],
Cell[73784, 1815, 195, 3, 108, "Output"],
Cell[73982, 1820, 163, 2, 117, "Output"],
Cell[74148, 1824, 204, 3, 130, "Output"],
Cell[74355, 1829, 197, 3, 108, "Output"],
Cell[74555, 1834, 221, 4, 108, "Output"],
Cell[74779, 1840, 224, 3, 108, "Output"],
Cell[75006, 1845, 242, 4, 108, "Output"],
Cell[75251, 1851, 251, 4, 108, "Output"],
Cell[75505, 1857, 244, 3, 108, "Output"],
Cell[75752, 1862, 259, 4, 108, "Output"],
Cell[76014, 1868, 218, 3, 108, "Output"],
Cell[76235, 1873, 201, 3, 108, "Output"],
Cell[76439, 1878, 208, 3, 109, "Output"],
Cell[76650, 1883, 259, 4, 109, "Output"],
Cell[76912, 1889, 235, 3, 109, "Output"],
Cell[77150, 1894, 287, 5, 109, "Output"],
Cell[77440, 1901, 251, 4, 109, "Output"],
Cell[77694, 1907, 251, 4, 108, "Output"],
Cell[77948, 1913, 329, 6, 108, "Output"],
Cell[78280, 1921, 259, 4, 108, "Output"],
Cell[78542, 1927, 279, 5, 108, "Output"],
Cell[78824, 1934, 257, 5, 108, "Output"],
Cell[79084, 1941, 261, 4, 130, "Output"],
Cell[79348, 1947, 273, 4, 109, "Output"],
Cell[79624, 1953, 347, 6, 108, "Output"],
Cell[79974, 1961, 281, 4, 108, "Output"],
Cell[80258, 1967, 360, 6, 108, "Output"],
Cell[80621, 1975, 357, 6, 109, "Output"],
Cell[80981, 1983, 313, 4, 109, "Output"],
Cell[81297, 1989, 334, 5, 109, "Output"],
Cell[81634, 1996, 288, 4, 109, "Output"]
}, Open  ]],
Cell[81937, 2003, 37, 0, 56, "Text"],

Cell[CellGroupData[{
Cell[81999, 2007, 4458, 118, 1153, "Input"],
Cell[86460, 2127, 115, 2, 102, "Output"],
Cell[86578, 2131, 134, 2, 102, "Output"],
Cell[86715, 2135, 134, 2, 102, "Output"],
Cell[86852, 2139, 164, 2, 102, "Output"],
Cell[87019, 2143, 164, 2, 102, "Output"],
Cell[87186, 2147, 147, 2, 102, "Output"],
Cell[87336, 2151, 184, 3, 102, "Output"],
Cell[87523, 2156, 184, 3, 102, "Output"],
Cell[87710, 2161, 164, 2, 102, "Output"],
Cell[87877, 2165, 147, 2, 102, "Output"],
Cell[88027, 2169, 141, 2, 102, "Output"],
Cell[88171, 2173, 176, 3, 102, "Output"],
Cell[88350, 2178, 171, 2, 102, "Output"],
Cell[88524, 2182, 191, 3, 102, "Output"],
Cell[88718, 2187, 192, 3, 102, "Output"],
Cell[88913, 2192, 174, 3, 102, "Output"],
Cell[89090, 2197, 216, 3, 102, "Output"],
Cell[89309, 2202, 217, 3, 102, "Output"],
Cell[89529, 2207, 199, 3, 102, "Output"],
Cell[89731, 2212, 182, 3, 102, "Output"],
Cell[89916, 2217, 195, 3, 102, "Output"],
Cell[90114, 2222, 200, 3, 103, "Output"],
Cell[90317, 2227, 200, 3, 103, "Output"],
Cell[90520, 2232, 229, 3, 103, "Output"],
Cell[90752, 2237, 229, 3, 103, "Output"],
Cell[90984, 2242, 212, 3, 103, "Output"],
Cell[91199, 2247, 243, 3, 102, "Output"],
Cell[91445, 2252, 243, 3, 102, "Output"],
Cell[91691, 2257, 225, 3, 102, "Output"],
Cell[91919, 2262, 208, 3, 102, "Output"],
Cell[92130, 2267, 206, 3, 102, "Output"],
Cell[92339, 2272, 247, 3, 103, "Output"],
Cell[92589, 2277, 244, 3, 103, "Output"],
Cell[92836, 2282, 262, 4, 102, "Output"],
Cell[93101, 2288, 263, 4, 102, "Output"],
Cell[93367, 2294, 243, 3, 102, "Output"],
Cell[93613, 2299, 289, 4, 103, "Output"],
Cell[93905, 2305, 289, 4, 103, "Output"],
Cell[94197, 2311, 271, 4, 103, "Output"],
Cell[94471, 2317, 254, 4, 103, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[94786, 2328, 133, 3, 119, "Section"],
Cell[94922, 2333, 30, 0, 56, "Text"],
Cell[94955, 2335, 11728, 205, 3539, "Input"],
Cell[106686, 2542, 38, 0, 56, "Text"],
Cell[106727, 2544, 10228, 174, 3154, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[116992, 2723, 140, 3, 119, "Section"],
Cell[117135, 2728, 186, 4, 80, "Text"],
Cell[117324, 2734, 233, 4, 138, "Input"],
Cell[117560, 2740, 30, 0, 56, "Text"],

Cell[CellGroupData[{
Cell[117615, 2744, 3822, 82, 1113, "Input"],
Cell[121440, 2828, 143, 2, 119, "Output"],
Cell[121586, 2832, 163, 2, 119, "Output"],
Cell[121752, 2836, 224, 3, 128, "Output"],
Cell[121979, 2841, 218, 4, 119, "Output"],
Cell[122200, 2847, 228, 3, 128, "Output"],
Cell[122431, 2852, 220, 3, 128, "Output"],
Cell[122654, 2857, 211, 3, 119, "Output"],
Cell[122868, 2862, 257, 4, 128, "Output"],
Cell[123128, 2868, 231, 3, 128, "Output"],
Cell[123362, 2873, 239, 3, 128, "Output"],
Cell[123604, 2878, 233, 4, 126, "Output"],
Cell[123840, 2884, 235, 3, 130, "Output"],
Cell[124078, 2889, 263, 4, 135, "Output"],
Cell[124344, 2895, 233, 3, 126, "Output"],
Cell[124580, 2900, 275, 4, 135, "Output"],
Cell[124858, 2906, 317, 5, 135, "Output"],
Cell[125178, 2913, 303, 5, 126, "Output"],
Cell[125484, 2920, 329, 4, 135, "Output"],
Cell[125816, 2926, 322, 5, 135, "Output"],
Cell[126141, 2933, 287, 4, 135, "Output"],
Cell[126431, 2939, 269, 4, 126, "Output"],
Cell[126703, 2945, 261, 4, 126, "Output"],
Cell[126967, 2951, 345, 5, 135, "Output"],
Cell[127315, 2958, 359, 6, 126, "Output"],
Cell[127677, 2966, 473, 8, 212, "Output"],
Cell[128153, 2976, 331, 5, 135, "Output"],
Cell[128487, 2983, 309, 4, 126, "Output"],
Cell[128799, 2989, 355, 5, 212, "Output"],
Cell[129157, 2996, 330, 5, 135, "Output"],
Cell[129490, 3003, 371, 6, 212, "Output"],
Cell[129864, 3011, 313, 4, 126, "Output"],
Cell[130180, 3017, 343, 5, 177, "Output"],
Cell[130526, 3024, 388, 5, 212, "Output"],
Cell[130917, 3031, 359, 5, 174, "Output"],
Cell[131279, 3038, 547, 10, 281, "Output"],
Cell[131829, 3050, 400, 6, 212, "Output"],
Cell[132232, 3058, 454, 7, 174, "Output"],
Cell[132689, 3067, 498, 7, 212, "Output"],
Cell[133190, 3076, 471, 8, 212, "Output"],
Cell[133664, 3086, 466, 7, 212, "Output"]
}, Open  ]],
Cell[134145, 3096, 38, 0, 56, "Text"],

Cell[CellGroupData[{
Cell[134208, 3100, 4458, 118, 1153, "Input"],
Cell[138669, 3220, 158, 2, 113, "Output"],
Cell[138830, 3224, 165, 2, 113, "Output"],
Cell[138998, 3228, 180, 3, 113, "Output"],
Cell[139181, 3233, 206, 3, 113, "Output"],
Cell[139390, 3238, 198, 3, 113, "Output"],
Cell[139591, 3243, 196, 3, 113, "Output"],
Cell[139790, 3248, 218, 3, 113, "Output"],
Cell[140011, 3253, 225, 3, 113, "Output"],
Cell[140239, 3258, 201, 3, 113, "Output"],
Cell[140443, 3263, 196, 3, 113, "Output"],
Cell[140642, 3268, 209, 3, 120, "Output"],
Cell[140854, 3273, 230, 3, 120, "Output"],
Cell[141087, 3278, 240, 3, 120, "Output"],
Cell[141330, 3283, 256, 4, 120, "Output"],
Cell[141589, 3289, 249, 4, 120, "Output"],
Cell[141841, 3295, 246, 4, 120, "Output"],
Cell[142090, 3301, 279, 4, 120, "Output"],
Cell[142372, 3307, 283, 4, 120, "Output"],
Cell[142658, 3313, 259, 4, 120, "Output"],
Cell[142920, 3319, 254, 4, 120, "Output"],
Cell[143177, 3325, 283, 4, 120, "Output"],
Cell[143463, 3331, 276, 4, 120, "Output"],
Cell[143742, 3337, 289, 4, 120, "Output"],
Cell[144034, 3343, 314, 4, 171, "Output"],
Cell[144351, 3349, 306, 4, 171, "Output"],
Cell[144660, 3355, 304, 4, 120, "Output"],
Cell[144967, 3361, 330, 5, 171, "Output"],
Cell[145300, 3368, 334, 5, 171, "Output"],
Cell[145637, 3375, 308, 4, 120, "Output"],
Cell[145948, 3381, 303, 4, 120, "Output"],
Cell[146254, 3387, 333, 5, 171, "Output"],
Cell[146590, 3394, 358, 5, 171, "Output"],
Cell[146951, 3401, 358, 5, 171, "Output"],
Cell[147312, 3408, 377, 5, 171, "Output"],
Cell[147692, 3415, 369, 5, 171, "Output"],
Cell[148064, 3422, 366, 5, 171, "Output"],
Cell[148433, 3429, 429, 6, 171, "Output"],
Cell[148865, 3437, 444, 6, 171, "Output"],
Cell[149312, 3445, 409, 6, 171, "Output"],
Cell[149724, 3453, 380, 5, 201, "Output"]
}, Open  ]],
Cell[150119, 3461, 96, 2, 56, "Text"],
Cell[150218, 3465, 14221, 229, 6165, "Input"],
Cell[164442, 3696, 16, 0, 56, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

