(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    245542,       4782]*)
(*NotebookOutlinePosition[    246271,       4807]*)
(*  CellTagsIndexPosition[    246227,       4803]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Part 4. Comparison of Quantum States",
    FontWeight->"Bold"],
  StyleBox[" of the Bound Isotropic Systems",
    FontWeight->"Bold"]
}], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
4.1. Comparison of Quantum States of the Two-Dimensional Isotropic Quantum \
Rotator and Oscillator\
\>", "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["\<\
1. Normalized wave functions and probability densities of the two-dimensional \
quantum rotator and oscillator\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Consider states of the two-dimensional quantum rotator defined by quantum \
numbers:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`n\_rad = \ 1, 2, 3, 4\)]],
  ",\n",
  Cell[BoxData[
      \(TraditionalForm\`m\_azm = \ 0, 1, 2, 3\)]]
}], "NumberedEquation"],

Cell["\<\
and states (corresponding to given states of rotator) of the two-dimensional \
quantum oscillator defined by quantum numbers:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`n\_rad = \ 0, 1, 2, 3\)]],
  ",\n",
  Cell[BoxData[
      \(TraditionalForm\`m\_azm = \ 0, 1, 2, 3\)]]
}], "NumberedEquation"],

Cell[TextData[{
  "We will use \"",
  StyleBox["NumericalMath`BesselZeros`",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  "\" to find radial functions of the three-dimensional quantum rotator."
}], "Text"],

Cell[BoxData[
    \(<< NumericalMath`BesselZeros`\)], "Input"],

Cell[TextData[{
  "We will use \"",
  StyleBox["Graphics`FilledPlot`",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  "\" tool in this part to give vivid presentation of functions."
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(<< Graphics`FilledPlot`\)], "Input"],

Cell[TextData[{
  "Determine parameters ",
  StyleBox["r0",
    FontSlant->"Italic"],
  " of the two-dimensional quantum rotator and \[Lambda] of the \
two-dimensional quantum oscillator:"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(r0 = 5;\)\ \[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(\[Lambda] = 1;\)\ \)}], "Input"],

Cell["\<\
Normalized radial wave functions and radial probability densities of the \
two-dimensional quantum rotator for given quantum numbers (1) are:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(R\_Rotat[1, 0, 
          r0] = \(2.724107444910865`\ BesselJ[0, \(2.4048255576957467`\ \
r\)\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[1, 1, 
          r0] = \(3.7929945592877274`\ BesselJ[\@2, \(4.381447479827306`\ r\)\
\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[1, 2, 
          r0] = \(4.430540052964394`\ BesselJ[\@6, \(5.70058432040823`\ \
r\)\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[1, 3, 
          r0] = \(4.9917511617183115`\ BesselJ[2\ \@3, \(6.944557309670949`\ \
r\)\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[2, 0, 
          r0] = \(4.15621461613164`\ BesselJ[0, \(5.52007811028631`\ r\)\/r0]\
\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[2, 1, 
          r0] = \(4.924605606199757`\ BesselJ[\@2, \(7.604863775917667`\ \
r\)\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[2, 2, 
          r0] = \(5.42167030668399`\ BesselJ[\@6, \(9.027112035039801`\ \
r\)\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[2, 3, 
          r0] = \(5.8724331687105735`\ BesselJ[2\ \@3, \(10.370311238377235`\ \
r\)\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[3, 0, 
          r0] = \(5.209805047808564`\ BesselJ[0, \(8.653727913113732`\ \
r\)\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[3, 1, 
          r0] = \(5.8412881505895395`\ BesselJ[\@2, \(10.779896986906524`\ \
r\)\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[3, 2, 
          r0] = \(6.264432018983282`\ BesselJ[\@6, \(12.252431949142155`\ r\)\
\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[3, 3, 
          r0] = \(6.65486004162976`\ BesselJ[2\ \@3, \(13.649287690577403`\ r\
\)\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[4, 0, 
          r0] = \(6.0836900469025705`\ BesselJ[0, \(11.791534439057065`\ \
r\)\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[4, 1, 
          r0] = \(6.632499631049359`\ BesselJ[\@2, \(13.939757650233451`\ r\)\
\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[4, 2, 
          r0] = \(7.007547679056817`\ BesselJ[\@6, \(15.442468814142474`\ r\)\
\/r0]\)\/r0;\)\), "\[IndentingNewLine]", 
    \(\(R\_Rotat[4, 3, 
          r0] = \(7.357475297013236`\ BesselJ[2\ \@3, \(16.87362244717725`\ r\
\)\/r0]\)\/r0;\)\)}], "Input"],

Cell[BoxData[{
    \(\(RR\_Rotat[1, 0, 
          r0] = \(7.420761371418802`\ r\ BesselJ[0, \(2.4048255576957467`\ \
r\)\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[1, 1, 
          r0] = \(12.32930608758591`\ r\ BesselJ[1, \(3.8317059702075125`\ \
r\)\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[1, 2, 
          r0] = \(17.33479971146061`\ r\ BesselJ[2, \(5.135622301840683`\ r\)\
\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(\(RR\_Rotat[1, 3, 
          r0] = \(22.480251104858397`\ r\ BesselJ[3, \(6.3801618959386`\ \
r\)\/r0]\^2\)\/r0\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(RR\_Rotat[2, 0, 
          r0] = \(17.274119935346278`\ r\ BesselJ[0, \(5.52007811028631`\ r\)\
\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[2, 1, 
          r0] = \(22.205083619652548`\ r\ BesselJ[1, \(7.015586669815615`\ \
r\)\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[2, 2, 
          r0] = \(27.155981240648163`\ r\ BesselJ[2, \(8.417244140695804`\ \
r\)\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[2, 3, 
          r0] = \(32.14982441291802`\ r\ BesselJ[3, \(9.761023130149406`\ r\)\
\/r0]\^2\)\/r0\^2;\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(RR\_Rotat[3, 0, 
          r0] = \(27.14206863617159`\ r\ BesselJ[0, \(8.653727913113732`\ r\)\
\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[3, 1, 
          r0] = \(32.075685466503465`\ r\ BesselJ[1, \(10.173468135156398`\ r\
\)\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[3, 2, 
          r0] = \(37.016603769213035`\ r\ BesselJ[2, \(11.619841172201633`\ r\
\)\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[3, 3, 
          r0] = \(41.97647135298122`\ r\ BesselJ[3, \(13.015200721731633`\ \
r\)\/r0]\^2\)\/r0\^2;\)\[IndentingNewLine]\n\), "\[IndentingNewLine]", 
    \(\(RR\_Rotat[4, 0, 
          r0] = \(37.0112845867814`\ r\ BesselJ[0, \(11.791534439057065`\ r\)\
\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[4, 1, 
          r0] = \(41.94560493951443`\ r\ BesselJ[1, \(13.323691936337989`\ \
r\)\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[4, 2, 
          r0] = \(46.88333516609999`\ r\ BesselJ[2, \(14.795951782366128`\ \
r\)\/r0]\^2\)\/r0\^2;\)\), "\n", 
    \(\(RR\_Rotat[4, 3, 
          r0] = \(51.83115454957805`\ r\ BesselJ[3, \(16.223466160328837`\ \
r\)\/r0]\^2\)\/r0\^2;\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Normalized probability densities of the two-dimensional quantum \
oscillator for given quantum numbers (1) are:",
    ScreenRectangle->{{0, 1024}, {0, 685}},
    WindowToolbars->"EditBar",
    WindowSize->{1011, 654},
    WindowMargins->{{0, Automatic}, {Automatic, 0}},
    FontFamily->"Times New Roman",
    FontSize->14,
    FontColor->GrayLevel[0.996109],
    Background->RGBColor[0, 0.500008, 0]],
  StyleBox["\:f35f",
    ScreenRectangle->{{0, 1024}, {0, 685}},
    WindowToolbars->"EditBar",
    WindowSize->{1011, 654},
    WindowMargins->{{0, Automatic}, {Automatic, 0}},
    FontSize->14,
    FontColor->GrayLevel[0.996109],
    Background->RGBColor[0, 0.500008, 0]],
  StyleBox["",
    ScreenRectangle->{{0, 1024}, {0, 685}},
    WindowToolbars->"EditBar",
    WindowSize->{1011, 654},
    WindowMargins->{{0, Automatic}, {Automatic, 0}},
    Magnification->1.25]
}], "Text",
  ScreenRectangle->{{0, 1024}, {0, 685}},
  WindowToolbars->"EditBar",
  WindowSize->{1011, 654},
  WindowMargins->{{0, Automatic}, {Automatic, 0}},
  Magnification->1.25],

Cell[BoxData[{
    \(\(\[Psi]\[Psi]\_Rotat[1, 0, 
          r0] = \(1.1810508537666946`\ r\ BesselJ[0, \(2.4048255576957467`\ r\
\)\/r0]\^2\)\/r0\^2;\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Rotat[1, 1, 
          r0] = \(1.9622700087322944`\ r\ BesselJ[1, \(3.8317059702075125`\ r\
\)\/r0]\^2\)\/r0\^2;\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Rotat[1, 2, 
          r0] = \(2.7589190615869175`\ r\ BesselJ[2, \(5.135622301840683`\ \
r\)\/r0]\^2\)\/r0\^2;\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_Rotat[1, 3, 
          r0] = \(3.5778430852852554`\ r\ BesselJ[3, \(6.3801618959386`\ \
r\)\/r0]\^2\)\/r0\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Rotat[2, 0, 
          r0] = \(2.7492615752726115`\ r\ BesselJ[0, \(5.52007811028631`\ r\)\
\/r0]\^2\)\/r0\^2;\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Rotat[2, 1, 
          r0] = \(3.534048819836579`\ r\ BesselJ[1, \(7.015586669815615`\ r\)\
\/r0]\^2\)\/r0\^2;\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Rotat[2, 2, 
          r0] = \(4.322008648959936`\ r\ BesselJ[2, \(8.417244140695804`\ r\)\
\/r0]\^2\)\/r0\^2;\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_Rotat[2, 3, 
          r0] = \(5.116803474852396`\ r\ BesselJ[3, \(9.761023130149406`\ r\)\
\/r0]\^2\)\/r0\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Rotat[3, 0, 
          r0] = \(4.319794389186207`\ r\ BesselJ[0, \(8.653727913113732`\ r\)\
\/r0]\^2\)\/r0\^2;\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Rotat[3, 1, 
          r0] = \(5.105003895054893`\ r\ BesselJ[1, \(10.173468135156398`\ \
r\)\/r0]\^2\)\/r0\^2;\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Rotat[3, 2, 
          r0] = \(5.891375466344339`\ r\ BesselJ[2, \(11.619841172201633`\ \
r\)\/r0]\^2\)\/r0\^2;\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_Rotat[3, 3, 
          r0] = \(6.6807629093823016`\ r\ BesselJ[3, \(13.015200721731633`\ r\
\)\/r0]\^2\)\/r0\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Rotat[4, 0, 
          r0] = \(5.890528892167137`\ r\ BesselJ[0, \(11.791534439057065`\ \
r\)\/r0]\^2\)\/r0\^2;\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Rotat[4, 1, 
          r0] = \(6.675850367103544`\ r\ BesselJ[1, \(13.323691936337989`\ \
r\)\/r0]\^2\)\/r0\^2;\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Rotat[4, 2, 
          r0] = \(7.4617145403189`\ r\ BesselJ[2, \(14.795951782366128`\ \
r\)\/r0]\^2\)\/r0\^2;\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Rotat[4, 3, 
          r0] = \(8.249184452725327`\ r\ BesselJ[3, \(16.223466160328837`\ \
r\)\/r0]\^2\)\/r0\^2;\)\)}], "Input"],

Cell["\<\
Normalized radial wave functions and radial probability densities of the \
two-dimensional quantum oscillator for given quantum numbers (1) are:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(R\_Oscl[0, 
          0, \[Lambda]] = \@2\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\
\)\ \@\[Lambda];\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[0, 0, \[Lambda]] = 
        2\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \[Lambda];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[0, 
          1, \[Lambda]] = \@2\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\
\)\ r\ \[Lambda];\)\), "\[IndentingNewLine]", 
    \(\(RR\_Oscl[0, 1, \[Lambda]] = 
        2\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \[Lambda];\)\
\[IndentingNewLine]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[0, 
          2, \[Lambda]] = \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\
\^2\ \[Lambda]\^\(3/2\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[0, 
          2, \[Lambda]] = \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^5\ \
\[Lambda]\^3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[0, 
          3, \[Lambda]] = \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
r\^3\ \[Lambda]\^2\)\/\@3;\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[0, 3, \[Lambda]] = 
        1\/3\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^7\ \
\[Lambda]\^4;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[1, 
          0, \[Lambda]] = \@2\ \[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\
\)\ \@\[Lambda]\ \((1 - r\^2\ \[Lambda])\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[1, 0, \[Lambda]] = 
        2\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \[Lambda]\ \((1 - \
r\^2\ \[Lambda])\)\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[1, 
          1, \[Lambda]] = \(-\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\
\)\ r\ \[Lambda]\ \((\(-2\) + 
              r\^2\ \[Lambda])\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[1, 
          1, \[Lambda]] = \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^3\ \
\[Lambda]\^2\ \((\(-2\) + r\^2\ \[Lambda])\)\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[1, 
          2, \[Lambda]] = \(-\(\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\
\)\)\ r\^2\ \[Lambda]\^\(3/2\)\ \((\(-3\) + 
                    r\^2\ \[Lambda])\)\)\/\@3\)\);\)\), \
"\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[1, 2, \[Lambda]] = 
        1\/3\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^5\ \[Lambda]\^3\ \
\((\(-3\) + r\^2\ \[Lambda])\)\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[1, 
          3, \[Lambda]] = \(-\(\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\
\)\)\ r\^3\ \[Lambda]\^2\ \((\(-4\) + 
                    r\^2\ \[Lambda])\)\)\/\(2\ \@3\)\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[1, 3, \[Lambda]] = 
        1\/12\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^7\ \[Lambda]\^4\ \
\((\(-4\) + r\^2\ \[Lambda])\)\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[2, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
\@\[Lambda]\ \((2 + r\^2\ \[Lambda]\ \((\(-4\) + r\^2\ \
\[Lambda])\))\)\)\/\@2;\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[2, 0, \[Lambda]] = 
        1\/2\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \[Lambda]\ \((2 + \
r\^2\ \[Lambda]\ \((\(-4\) + r\^2\ \[Lambda])\))\)\^2;\)\(\[IndentingNewLine]\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[2, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
r\ \[Lambda]\ \((6 + r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \
\[Lambda])\))\)\)\/\@6;\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[2, 1, \[Lambda]] = 
        1\/6\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^3\ \[Lambda]\^2\ \
\((6 + r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \[Lambda])\))\)\^2;\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[2, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
r\^2\ \[Lambda]\^\(3/2\)\ \((\(-6\) + r\^2\ \[Lambda])\)\ \((\(-2\) + r\^2\ \
\[Lambda])\)\)\/\(2\ \@6\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[2, 2, \[Lambda]] = 
        1\/24\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^5\ \[Lambda]\^3\ \
\((\(-6\) + r\^2\ \[Lambda])\)\^2\ \((\(-2\) + r\^2\ \[Lambda])\)\^2;\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[2, 
          3, \[Lambda]] = \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
r\^3\ \[Lambda]\^2\ \((20 + r\^2\ \[Lambda]\ \((\(-10\) + r\^2\ \[Lambda])\))\
\)\)\/\(2\ \@30\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[2, 3, \[Lambda]] = 
        1\/120\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^7\ \[Lambda]\^4\
\ \((20 + r\^2\ \[Lambda]\ \((\(-10\) + r\^2\ \[Lambda])\))\)\^2;\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[3, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ \
\@\[Lambda]\ \((6 - r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \[Lambda])\)\ \
\((\(-3\) + r\^2\ \[Lambda])\))\)\)\/\(3\ \@2\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[3, 0, \[Lambda]] = 
        1\/18\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \[Lambda]\ \((6 \
- r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \[Lambda])\)\ \((\(-3\) + r\^2\ \
\[Lambda])\))\)\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[3, 
          1, \[Lambda]] = \(-\(\(\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\
\)\)\ r\ \[Lambda]\ \((\(-24\) + 
                    r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \[Lambda])\)\^2)\)\)\/\
\(6\ \@2\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[3, 1, \[Lambda]] = 
        1\/72\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^3\ \[Lambda]\^2\ \
\((\(-24\) + r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \[Lambda])\)\^2)\)\^2;\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[3, 
          2, \[Lambda]] = \@10\ \[ExponentialE]\^\(-\(\(r\^2\ \
\[Lambda]\)\/2\)\)\ r\^2\ \[Lambda]\^\(3/2\)\ \((1 - 
              1\/60\ r\^2\ \[Lambda]\ \((60 + 
                    r\^2\ \[Lambda]\ \((\(-15\) + 
                          r\^2\ \[Lambda])\))\))\);\)\), \
"\[IndentingNewLine]", 
    \(\(\(RR\_Oscl[3, 2, \[Lambda]] = 
        10\ \[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^5\ \[Lambda]\^3\ \
\((1 - 1\/60\ r\^2\ \[Lambda]\ \((60 + r\^2\ \[Lambda]\ \((\(-15\) + r\^2\ \
\[Lambda])\))\))\)\^2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(R\_Oscl[3, 
          3, \[Lambda]] = \(-\(1\/\(12\ \@15\)\)\) \
\((\[ExponentialE]\^\(-\(\(r\^2\ \[Lambda]\)\/2\)\)\ r\^3\ \[Lambda]\^2\ \
\((\(-120\) + r\^2\ \[Lambda]\ \((90 + 
                        r\^2\ \[Lambda]\ \((\(-18\) + 
                              r\^2\ \[Lambda])\))\))\))\);\)\), "\
\[IndentingNewLine]", 
    \(\(RR\_Oscl[3, 
          3, \[Lambda]] = \(1\/2160\) \((\[ExponentialE]\^\(\(-r\^2\)\ \
\[Lambda]\)\ r\^7\ \[Lambda]\^4\ \((\(-120\) + r\^2\ \[Lambda]\ \((90 + r\^2\ \
\[Lambda]\ \((\(-18\) + r\^2\ \[Lambda])\))\))\)\^2)\);\)\)}], "Input"],

Cell[BoxData[{
    \(\(\[Psi]\[Psi]\_Oscl[0, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \
\[Lambda]\)\/\[Pi];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[0, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \
\[Lambda]\)\/\[Pi];\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[0, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^5\ \
\[Lambda]\^3\)\/\(2\ \[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_Oscl[0, 
          3, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^7\ \
\[Lambda]\^4\)\/\(6\ \[Pi]\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[1, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \
\[Lambda]\ \((1 - r\^2\ \[Lambda])\)\^2\)\/\[Pi];\)\), "\[IndentingNewLine]", \

    \(\(\[Psi]\[Psi]\_Oscl[1, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^3\ \
\[Lambda]\^2\ \((\(-2\) + r\^2\ \[Lambda])\)\^2\)\/\(2\ \[Pi]\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[1, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^5\ \
\[Lambda]\^3\ \((\(-3\) + r\^2\ \[Lambda])\)\^2\)\/\(6\ \[Pi]\);\)\), "\
\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_Oscl[1, 
          3, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^7\ \
\[Lambda]\^4\ \((\(-4\) + r\^2\ \[Lambda])\)\^2\)\/\(24\ \[Pi]\);\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[2, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \
\[Lambda]\ \((2 + r\^2\ \[Lambda]\ \((\(-4\) + r\^2\ \
\[Lambda])\))\)\^2\)\/\(4\ \[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[2, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^3\ \
\[Lambda]\^2\ \((6 + r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \
\[Lambda])\))\)\^2\)\/\(12\ \[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[2, 
          2, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^5\ \
\[Lambda]\^3\ \((\(-6\) + r\^2\ \[Lambda])\)\^2\ \((\(-2\) + r\^2\ \[Lambda])\
\)\^2\)\/\(48\ \[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]\_Oscl[2, 
          3, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^7\ \
\[Lambda]\^4\ \((20 + r\^2\ \[Lambda]\ \((\(-10\) + r\^2\ \
\[Lambda])\))\)\^2\)\/\(240\ \[Pi]\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[3, 
          0, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\ \
\[Lambda]\ \((6 - r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \[Lambda])\)\ \((\(-3\) \
+ r\^2\ \[Lambda])\))\)\^2\)\/\(36\ \[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[3, 
          1, \[Lambda]] = \(\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^3\ \
\[Lambda]\^2\ \((\(-24\) + r\^2\ \[Lambda]\ \((\(-6\) + r\^2\ \
\[Lambda])\)\^2)\)\^2\)\/\(144\ \[Pi]\);\)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[3, 
          2, \[Lambda]] = \(1\/\[Pi]\) \((5\ \[ExponentialE]\^\(\(-r\^2\)\ \
\[Lambda]\)\ r\^5\ \[Lambda]\^3\ \((1 - 1\/60\ r\^2\ \[Lambda]\ \((60 + r\^2\ \
\[Lambda]\ \((\(-15\) + r\^2\ \[Lambda])\))\))\)\^2)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]\_Oscl[3, 
          3, \[Lambda]] = \(1\/\(4320\ \[Pi]\)\) \
\((\[ExponentialE]\^\(\(-r\^2\)\ \[Lambda]\)\ r\^7\ \[Lambda]\^4\ \((\(-120\) \
+ r\^2\ \[Lambda]\ \((90 + r\^2\ \[Lambda]\ \((\(-18\) + r\^2\ \
\[Lambda])\))\))\)\^2)\);\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2. Visualization of quantum States of the two-dimensional Isotropic quantum \
rotator and oscillator\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Now we present visualizations of the radial wave functions, radial \
probability densities and probability densities of the two-dimensional \
quantum rotator and oscillator.
We will obtain two-dimensional plots for radial  functions and radial \
probability densities and present density and surface (three-dimensional) \
plots for probability densities of the two-dimensional quantum rotator and \
oscillator.
In this file we will present visualizations in individual scales for states \
defined by given quantum numbers.\
\>", "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox["Parameters of Plots:",
    FontWeight->"Bold"],
  "\n",
  StyleBox["2d Plots",
    FontWeight->"Bold"],
  "\n\t\tVariable Range: {x2dMin, x2dMax}\n\t\tPlot Range for 2d Plots: \
{PR2dMin, PR2dMax}\n\t\tImage Size for 2d Plots: {IS2dHorz, IS2dVert}\n\n",
  StyleBox["3d Plots",
    FontWeight->"Bold"],
  "\n\t\tVariable Range: {x3dMin, x3dMax, y3dMin, y3dMax}\n\t\tPlot Range for \
3d Plots: {PR3dMin, PR3dMax}\n\t\tPlot Points for 3d Plots: {N3d}\n\t\tImage \
Size for 3d Plots: {IS3DHorz, IS3DVert}\n\t\tViewPoint for 3d Plots: {VP1, \
VP2, VP3} or {WP1, WP2, WP3}"
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(IS2dHorz = 325;\)\), "\[IndentingNewLine]", 
    \(\(\(IS2dVert = 325;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(IS3dHorz = 325;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dVert = 325;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(IS3dAllHorz = 600;\)\), "\[IndentingNewLine]", 
    \(\(\(IS3dAllVert = 600;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(VP1 = 0.000;\)\), "\[IndentingNewLine]", 
    \(\(VP2 = \(-1.825\);\)\), "\[IndentingNewLine]", 
    \(\(\(VP3 = 1.25;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(WP1 = 0.000;\)\), "\[IndentingNewLine]", 
    \(\(WP2 = 0.000;\)\), "\[IndentingNewLine]", 
    \(\(\(WP3 = 3.000;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(AR = 3/4;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(N3d = 100;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(PR2dMin = \(-0.02\);\)\), "\n", 
    \(\(PR2dMax = 0.875;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(PR3dMin = 0;\)\), "\n", 
    \(\(PR3dMax = 0.15;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(x2dMin = 0;\)\), "\n", 
    \(\(x2dMax = 5;\)\[IndentingNewLine]\), "\n", 
    \(\(x3dMin = \(-5\);\)\), "\n", 
    \(\(x3dMax = 5;\)\), "\n", 
    \(\(y3dMin = \(-5\);\)\), "\n", 
    \(\(y3dMax = 5;\)\)}], "Input"],

Cell[CellGroupData[{

Cell[TextData[{
  "Two-dimensional quantum rotator\n1) ",
  Cell[BoxData[
      \(n\_rad = 1, m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 1;\), "\[IndentingNewLine]", \(\(m\_azm = 
        0;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(Grph1dRR\_Rotat[n\_rad, m\_azm, r0, x2dMin, x2dMax, 
            PR2dMin, PR2dMax, IS2dHorz, IS2dVert]\), "=", 
          RowBox[{"FilledPlot", "[", 
            
            RowBox[{\(RR\_Rotat[n\_rad, m\_azm, r0]\), ",", 
              "\[IndentingNewLine]", \({r, x2dMin, x2dMax}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR2dMin, PR2dMax}\),
               ",", "\[IndentingNewLine]", \(Frame \[Rule] True\), ",", 
              "\[IndentingNewLine]", \(Curves \[Rule] Front\), ",", 
              "\[IndentingNewLine]", \(Fills \[Rule] {RGBColor[0, 1, 0]}\), 
              ",", "\[IndentingNewLine]", \(GridLines \[Rule] Automatic\), 
              ",", "\[IndentingNewLine]", \(PlotStyle \[Rule] {Thickness[
                    0.01]}\), ",", 
              "\[IndentingNewLine]", \(Background -> 
                RGBColor[1.0, 0.85, 0.85]\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS2dHorz, 
                  IS2dVert*0.65}\), ",", 
              "\[IndentingNewLine]", \(AspectRatio \[Rule] AR\), ",", 
              "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\!\(n\_rad\)=1, \!\(m\_azm\)=0, \!\(InputForm\`Rotator\)\
\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", \(\[Psi]\[Psi]xy\_Rotat[
          n\_rad, m\_azm, r0] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\), "\[IndentingNewLine]", 
  
    RowBox[{\(\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, r0] = 
          If[\@\(x\^2 + y\^2\) < r0, \[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, 
              r0], 0];\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", \(\[Psi]\[Psi]Hf[
          n\_rad, m\_azm, r0] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0]];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(Grph3d\[Psi]\[Psi]xyHf\_Rotat[n\_rad, m\_azm, r0, x3dMin, 
            x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
            VP1, \ VP2, \ VP3, N3d]\), "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({y, y3dMin, y3dMax}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Background -> 
                RGBColor[0.7, 1.0, 0.7]\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {VP1, \ VP2, \ VP3}\), 
              ",", "\[IndentingNewLine]", \(AspectRatio \[Rule] AR\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert*0.65}\), ",", 
              "\[IndentingNewLine]", \(Lighting \[Rule] True\), ",", 
              "\[IndentingNewLine]", \(LightSources \[Rule] {{{1.`, 0.`, 
                      1.`}, RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                    RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                    RGBColor[0, 0, 1]}}\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\!\(n\_rad\)=1, \!\(m\_azm\)=0, \!\(InputForm\`Rotator\)\
\>\""}]}], "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, 
            x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
            VP1, \ VP2, \ VP3, N3d]\), "=", 
          RowBox[{"DensityPlot", "[", 
            
            RowBox[{\(\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, r0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({y, y3dMin, y3dMax}\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(Mesh \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.75]\), 
              ",", "\[IndentingNewLine]", \(ColorOutput \[Rule] GrayLevel\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\)\), ",", 
              "\[IndentingNewLine]", \(AspectRatio \[Rule] 1\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\!\(n\_rad\)=1, \!\(m\_azm\)=0, \!\(InputForm\`Rotator\)\
\>\""}]}], "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, 
            x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
            VP1, \ VP2, \ VP3, N3d]\), "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, r0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({y, y3dMin, y3dMax}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.1, 0.1, 0.5]\), ",", 
              "\[IndentingNewLine]", \(AspectRatio \[Rule] 1\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {WP1, \ WP2, \ WP3}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\!\(n\_rad\)=1, \!\(m\_azm\)=0, \!\(InputForm\`Rotator\)\
\>\""}]}], "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
      RowBox[{\(GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, 
                m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
                IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
                N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, 
                m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
                IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
                N3d]}, \[IndentingNewLine]{Grph1dRR\_Rotat[n\_rad, m\_azm, 
                r0, x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
                IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Rotat[
                n\_rad, m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
                PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, N3d]}}]\), 
        ",", "\[IndentingNewLine]", \(Background \[Rule] 
          RGBColor[0.2, 0.475, 0.2]\), ",", " ", 
        "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dAllHorz, 
            IS3dAllHorz}\), ",", "\[IndentingNewLine]", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
          "\"\<\!\(n\_rad\)=1, \!\(m\_azm\)=0, \
\!\(InputForm\`Rotator\)\>\""}]}], "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Two-dimensional quantum rotator\n2). ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 1"
}], "Subsection"],

Cell[BoxData[{\(n\_rad = 1;\), "\[IndentingNewLine]", \(\(m\_azm = 
        1;\)\(\[IndentingNewLine]\)
    \), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(Grph1dRR\_Rotat[n\_rad, m\_azm, r0, x2dMin, x2dMax, 
            PR2dMin, PR2dMax, IS2dHorz, IS2dVert]\), "=", 
          RowBox[{"FilledPlot", "[", 
            
            RowBox[{\(RR\_Rotat[n\_rad, m\_azm, r0]\), ",", 
              "\[IndentingNewLine]", \({r, x2dMin, x2dMax}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR2dMin, PR2dMax}\),
               ",", "\[IndentingNewLine]", \(Frame \[Rule] True\), ",", 
              "\[IndentingNewLine]", \(Curves \[Rule] Front\), ",", 
              "\[IndentingNewLine]", \(Fills \[Rule] {RGBColor[0, 1, 0]}\), 
              ",", "\[IndentingNewLine]", \(GridLines \[Rule] Automatic\), 
              ",", "\[IndentingNewLine]", \(PlotStyle \[Rule] {Thickness[
                    0.01]}\), ",", 
              "\[IndentingNewLine]", \(Background -> 
                RGBColor[1.0, 0.85, 0.85]\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS2dHorz, 
                  IS2dVert*0.65}\), ",", 
              "\[IndentingNewLine]", \(AspectRatio \[Rule] AR\), ",", 
              "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\!\(n\_rad\)=1, \!\(m\_azm\)=1, \!\(InputForm\`Rotator\)\
\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", \(\[Psi]\[Psi]xy\_Rotat[
          n\_rad, m\_azm, r0] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\), "\[IndentingNewLine]", 
  
    RowBox[{\(\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, r0] = 
          If[\@\(x\^2 + y\^2\) < r0, \[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, 
              r0], 0];\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", \(\[Psi]\[Psi]Hf[
          n\_rad, m\_azm, r0] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0]];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(Grph3d\[Psi]\[Psi]xyHf\_Rotat[n\_rad, m\_azm, r0, x3dMin, 
            x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
            VP1, \ VP2, \ VP3, N3d]\), "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({y, y3dMin, y3dMax}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Background -> 
                RGBColor[0.7, 1.0, 0.7]\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {VP1, \ VP2, \ VP3}\), 
              ",", "\[IndentingNewLine]", \(AspectRatio \[Rule] AR\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert*0.65}\), ",", 
              "\[IndentingNewLine]", \(Lighting \[Rule] True\), ",", 
              "\[IndentingNewLine]", \(LightSources \[Rule] {{{1.`, 0.`, 
                      1.`}, RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                    RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                    RGBColor[0, 0, 1]}}\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\!\(n\_rad\)=1, \!\(m\_azm\)=1, \!\(InputForm\`Rotator\)\
\>\""}]}], "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, 
            x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
            VP1, \ VP2, \ VP3, N3d]\), "=", 
          RowBox[{"DensityPlot", "[", 
            
            RowBox[{\(\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, r0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({y, y3dMin, y3dMax}\), ",", 
              "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(Mesh \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] GrayLevel[0.75]\), 
              ",", "\[IndentingNewLine]", \(ColorOutput \[Rule] GrayLevel\), 
              ",", "\[IndentingNewLine]", \(ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\)\), ",", 
              "\[IndentingNewLine]", \(AspectRatio \[Rule] 1\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\!\(n\_rad\)=1, \!\(m\_azm\)=1, \!\(InputForm\`Rotator\)\
\>\""}]}], "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{\(Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, 
            x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
            VP1, \ VP2, \ VP3, N3d]\), "=", 
          RowBox[{"Plot3D", "[", 
            
            RowBox[{\(\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, r0]\), ",", 
              "\[IndentingNewLine]", \({x, x3dMin, x3dMax}\), 
              ",", \({y, y3dMin, y3dMax}\), ",", 
              "\[IndentingNewLine]", \(PlotRange \[Rule] {PR3dMin, PR3dMax}\),
               ",", "\[IndentingNewLine]", \(PlotPoints \[Rule] N3d\), ",", 
              "\[IndentingNewLine]", \(Mesh -> False\), ",", 
              "\[IndentingNewLine]", \(Axes \[Rule] False\), ",", 
              "\[IndentingNewLine]", \(Background \[Rule] 
                RGBColor[0.1, 0.1, 0.5]\), ",", 
              "\[IndentingNewLine]", \(AspectRatio \[Rule] 1\), ",", 
              "\[IndentingNewLine]", \(ImageSize \[Rule] {IS3dHorz, 
                  IS3dVert}\), ",", 
              "\[IndentingNewLine]", \(ViewPoint -> {WP1, \ WP2, \ WP3}\), 
              ",", "\[IndentingNewLine]", 
              RowBox[{
              "PlotLabel", "\[Rule]", 
                "\"\<\!\(n\_rad\)=1, \!\(m\_azm\)=1, \!\(InputForm\`Rotator\)\
\>\""}]}], "]"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, 
              m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Rotat[n\_rad, m\_azm, r0, 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Rotat[
              n\_rad, m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=1, \!\(m\_azm\)=1, Rotator\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Two-dimensional quantum rotator\n3) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 2"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Rotat[n\_rad, m\_azm, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[
          RR\_Rotat[n\_rad, m\_azm, r0], \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {RGBColor[0, 1, 
                0]}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<\!\(n\_rad\)=1, \
\!\(m\_azm\)=2, Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, \[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0], 
          0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=1, \!\(m\_azm\)=2, \
Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh \[Rule] 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=1, \!\(m\_azm\)=2, \
Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=1, \!\(m\_azm\)=2, \
Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, 
              m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Rotat[n\_rad, m\_azm, r0, 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Rotat[
              n\_rad, m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=1, \!\(m\_azm\)=2, Rotator\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Two-dimensional quantum rotator\n4) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Rotat[n\_rad, m\_azm, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[
          RR\_Rotat[n\_rad, m\_azm, r0], \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {RGBColor[0, 1, 
                0]}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<\!\(n\_rad\)=1, \
\!\(m\_azm\)=3, Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, \[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0], 
          0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=1, \!\(m\_azm\)=3, \
Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh \[Rule] 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=1, \!\(m\_azm\)=3, \
Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=1, \!\(m\_azm\)=3, \
Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, 
              m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Rotat[n\_rad, m\_azm, r0, 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Rotat[
              n\_rad, m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=1, \!\(m\_azm\)=3, Rotator\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Two-dimensional quantum rotator\n5) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 2, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 0"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Rotat[n\_rad, m\_azm, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[
          RR\_Rotat[n\_rad, m\_azm, r0], \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {RGBColor[0, 1, 
                0]}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<\!\(n\_rad\)=2, \
\!\(m\_azm\)=0, Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, \[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0], 
          0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=2, \!\(m\_azm\)=0, \
Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh \[Rule] 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=2, \!\(m\_azm\)=0, \
Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=2, \!\(m\_azm\)=0, \
Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, 
              m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Rotat[n\_rad, m\_azm, r0, 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Rotat[
              n\_rad, m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=2, \!\(m\_azm\)=0, Rotator\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Two-dimensional quantum rotator\n6)",
  Cell[BoxData[
      \(\(\(\ \)\(n\_rad\  = 2, m\_azm\  = 1\)\)\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Rotat[n\_rad, m\_azm, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[
          RR\_Rotat[n\_rad, m\_azm, r0], \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {RGBColor[0, 1, 
                0]}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<\!\(n\_rad\)=2, \
\!\(m\_azm\)=1, Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, \[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0], 
          0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=2, \!\(m\_azm\)=1, \
Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh \[Rule] 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=2, \!\(m\_azm\)=1, \
Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=2, \!\(m\_azm\)=1, \
Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, 
              m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Rotat[n\_rad, m\_azm, r0, 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Rotat[
              n\_rad, m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=2, \!\(m\_azm\)=1, Rotator\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Two-dimensional quantum rotator\n7)",
  Cell[BoxData[
      \(\(\(\ \)\(n\_rad\  = 2, m\_azm\  = 2\)\)\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Rotat[n\_rad, m\_azm, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[
          RR\_Rotat[n\_rad, m\_azm, r0], \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {RGBColor[0, 1, 
                0]}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<\!\(n\_rad\)=2, \
\!\(m\_azm\)=2, Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, \[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0], 
          0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=2, \!\(m\_azm\)=2, \
Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh \[Rule] 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=2, \!\(m\_azm\)=2, \
Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=2, \!\(m\_azm\)=2, \
Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, 
              m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Rotat[n\_rad, m\_azm, r0, 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Rotat[
              n\_rad, m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=2, \!\(m\_azm\)=2, Rotator\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Two-dimensional quantum rotator\n8)",
  Cell[BoxData[
      \(\(\(\ \)\(n\_rad\  = 2, m\_azm\  = 3\)\)\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Rotat[n\_rad, m\_azm, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[
          RR\_Rotat[n\_rad, m\_azm, r0], \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {RGBColor[0, 1, 
                0]}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<\!\(n\_rad\)=2, \
\!\(m\_azm\)=3, Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, \[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0], 
          0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=2, \!\(m\_azm\)=3, \
Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh \[Rule] 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=2, \!\(m\_azm\)=3, \
Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=2, \!\(m\_azm\)=3, \
Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, 
              m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Rotat[n\_rad, m\_azm, r0, 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Rotat[
              n\_rad, m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=2, \!\(m\_azm\)=3, Rotator\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Two-dimensional quantum rotator\n9) ",
  Cell[BoxData[
      \(n\_rad\  = 3, m\_azm\  = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Rotat[n\_rad, m\_azm, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[
          RR\_Rotat[n\_rad, m\_azm, r0], \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {RGBColor[0, 1, 
                0]}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<\!\(n\_rad\)=3, \
\!\(m\_azm\)=0, Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, \[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0], 
          0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=3, \!\(m\_azm\)=0, \
Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh \[Rule] 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=3, \!\(m\_azm\)=0, \
Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=3, \!\(m\_azm\)=0, \
Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, 
              m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Rotat[n\_rad, m\_azm, r0, 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Rotat[
              n\_rad, m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=3, \!\(m\_azm\)=0, Rotator\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Two-dimensional quantum rotator\n10) ",
  Cell[BoxData[
      \(n\_rad\  = 3, m\_azm\  = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Rotat[n\_rad, m\_azm, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[
          RR\_Rotat[n\_rad, m\_azm, r0], \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {RGBColor[0, 1, 
                0]}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<\!\(n\_rad\)=3, \
\!\(m\_azm\)=1, Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, \[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0], 
          0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=3, \!\(m\_azm\)=1, \
Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh \[Rule] 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=3, \!\(m\_azm\)=1, \
Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=3, \!\(m\_azm\)=1, \
Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, 
              m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Rotat[n\_rad, m\_azm, r0, 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Rotat[
              n\_rad, m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=3, \!\(m\_azm\)=1, Rotator\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Two-dimensional quantum rotator\n11) ",
  Cell[BoxData[
      \(\(\(\ \)\(n\_rad\  = 3, m\_azm\  = 2\)\)\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Rotat[n\_rad, m\_azm, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[
          RR\_Rotat[n\_rad, m\_azm, r0], \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {RGBColor[0, 1, 
                0]}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<\!\(n\_rad\)=3, \
\!\(m\_azm\)=2, Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, \[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0], 
          0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=3, \!\(m\_azm\)=2, \
Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh \[Rule] 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=3, \!\(m\_azm\)=2, \
Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=3, \!\(m\_azm\)=2, \
Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, 
              m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Rotat[n\_rad, m\_azm, r0, 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Rotat[
              n\_rad, m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=3, \!\(m\_azm\)=2, Rotator\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Two-dimensional quantum rotator\n12) ",
  Cell[BoxData[
      \(\(\(\ \)\(n\_rad\  = 3, m\_azm\  = 3\)\)\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Rotat[n\_rad, m\_azm, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[
          RR\_Rotat[n\_rad, m\_azm, r0], \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {RGBColor[0, 1, 
                0]}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<\!\(n\_rad\)=3, \
\!\(m\_azm\)=3, Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, \[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0], 
          0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=3, \!\(m\_azm\)=3, \
Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh \[Rule] 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=3, \!\(m\_azm\)=3, \
Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=3, \!\(m\_azm\)=3, \
Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, 
              m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Rotat[n\_rad, m\_azm, r0, 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Rotat[
              n\_rad, m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=3, \!\(m\_azm\)=3, Rotator\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Two-dimensional quantum rotator\n13) ",
  Cell[BoxData[
      \(\(\(\ \)\(n\_rad\  = 4, m\_azm\  = 0\)\)\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 4;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Rotat[n\_rad, m\_azm, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[
          RR\_Rotat[n\_rad, m\_azm, r0], \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {RGBColor[0, 1, 
                0]}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<\!\(n\_rad\)=4, \
\!\(m\_azm\)=0, Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, \[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0], 
          0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=4, \!\(m\_azm\)=0, \
Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh \[Rule] 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=4, \!\(m\_azm\)=0, \
Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=4, \!\(m\_azm\)=0, \
Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, 
              m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Rotat[n\_rad, m\_azm, r0, 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Rotat[
              n\_rad, m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=4, \!\(m\_azm\)=0, Rotator\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Two-dimensional quantum rotator\n14) ",
  Cell[BoxData[
      \(\(\(\ \)\(n\_rad\  = 4, m\_azm\  = 1\)\)\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 4;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Rotat[n\_rad, m\_azm, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[
          RR\_Rotat[n\_rad, m\_azm, r0], \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {RGBColor[0, 1, 
                0]}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<\!\(n\_rad\)=4, \
\!\(m\_azm\)=1, Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, \[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0], 
          0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=4, \!\(m\_azm\)=1, \
Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh \[Rule] 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=4, \!\(m\_azm\)=1, \
Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=4, \!\(m\_azm\)=1, \
Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, 
              m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Rotat[n\_rad, m\_azm, r0, 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Rotat[
              n\_rad, m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=4, \!\(m\_azm\)=1, Rotator\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Two-dimensional quantum rotator\n15) ",
  Cell[BoxData[
      \(\(\(\ \)\(n\_rad\  = 4, m\_azm\  = 2\)\)\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 4;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Rotat[n\_rad, m\_azm, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[
          RR\_Rotat[n\_rad, m\_azm, r0], \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {RGBColor[0, 1, 
                0]}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<\!\(n\_rad\)=4, \
\!\(m\_azm\)=2, Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, \[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0], 
          0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=4, \!\(m\_azm\)=2, \
Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh \[Rule] 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=4, \!\(m\_azm\)=2, \
Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=4, \!\(m\_azm\)=2, \
Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, 
              m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Rotat[n\_rad, m\_azm, r0, 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Rotat[
              n\_rad, m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=4, \!\(m\_azm\)=2, Rotator\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Two-dimensional quantum rotator\n16) ",
  Cell[BoxData[
      \(\(\(\ \)\(n\_rad\  = 4, m\_azm\  = 3\)\)\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 4;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Rotat[n\_rad, m\_azm, r0, x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[
          RR\_Rotat[n\_rad, m\_azm, r0], \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {RGBColor[0, 1, 
                0]}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<\!\(n\_rad\)=4, \
\!\(m\_azm\)=3, Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Rotat[n\_rad, m\_azm, 
              r0], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\), \
"\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, r0] = 
        If[\@\(x\^2 + y\^2\) < r0, \[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0], 
          0];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, m\_azm, r0], \[IndentingNewLine]{x, 
            x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.7], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=4, \!\(m\_azm\)=3, \
Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh \[Rule] 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.75], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=4, \!\(m\_azm\)=3, \
Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, x3dMin, x3dMax, 
          y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ 
          VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xyN\_Rotat[n\_rad, m\_azm, 
            r0], \[IndentingNewLine]{x, x3dMin, x3dMax}, {y, y3dMin, 
            y3dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=4, \!\(m\_azm\)=3, \
Rotator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[n\_rad, m\_azm, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[n\_rad, 
              m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Rotat[n\_rad, m\_azm, r0, 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Rotat[
              n\_rad, m\_azm, r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=4, \!\(m\_azm\)=3, Rotator\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Two-dimensional quantum oscillator\n1) ",
  Cell[BoxData[
      \(n\_rad = 0, m\_azm = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Oscl[n\_rad, m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[
          RR\_Oscl[n\_rad, m\_azm, \[Lambda]], \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {RGBColor[1, 0, 
                0]}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.95], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<\!\(n\_rad\)=0, \
\!\(m\_azm\)=0, Oscillator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, 
              m\_azm, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-2.5\), 
            2.5}, {y, \(-2.5\), 
            2.5}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.8], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=0, \!\(m\_azm\)=0, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-2.5\), 
            2.5}, {y, \(-2.5\), 2.5}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh \[Rule] 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.9], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=0, \!\(m\_azm\)=0, Oscillator\>\""];\)\[IndentingNewLine]\
\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-2.5\), 
            2.5}, {y, \(-2.5\), 
            2.5}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.65], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=0, \!\(m\_azm\)=0, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n\_rad, m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=0, \!\(m\_azm\)=0, Oscillator\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Two-dimensional quantum oscillator\n2) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 0, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 1"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Oscl[n\_rad, m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[
          RR\_Oscl[n\_rad, m\_azm, \[Lambda]], \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {RGBColor[1, 0, 
                0]}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.95], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<\!\(n\_rad\)=0, \
\!\(m\_azm\)=1, Oscillator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, 
              m\_azm, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]]];\)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-2.5\), 
            2.5}, {y, \(-2.5\), 
            2.5}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.8], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=0, \!\(m\_azm\)=1, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-2.5\), 
            2.5}, {y, \(-2.5\), 2.5}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.9], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=0, \!\(m\_azm\)=1, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-2.5\), 
            2.5}, {y, \(-2.5\), 
            2.5}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.65], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=0, \!\(m\_azm\)=1, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n\_rad, m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=0, \!\(m\_azm\)=1, Oscillator\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Two-dimensional quantum oscillator\n3) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 0, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 2"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Oscl[n\_rad, m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[
          RR\_Oscl[n\_rad, m\_azm, \[Lambda]], \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {RGBColor[1, 0, 
                0]}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.95], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<\!\(n\_rad\)=0, \
\!\(m\_azm\)=2, Oscillator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, 
              m\_azm, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-3.25\), 
            3.25}, {y, \(-3.25\), 
            3.25}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.8], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=0, \!\(m\_azm\)=2, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-3.25\), 
            3.25}, {y, \(-3.25\), 
            3.25}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.9], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=0, \!\(m\_azm\)=2, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-3.25\), 
            3.25}, {y, \(-3.25\), 
            3.25}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.65], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=0, \!\(m\_azm\)=2, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n\_rad, m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=0, \!\(m\_azm\)=2, Oscillator\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Two-dimensional quantum oscillator\n4) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 0, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 3"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 0;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Oscl[n\_rad, m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[
          RR\_Oscl[n\_rad, m\_azm, \[Lambda]], \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {RGBColor[1, 0, 
                0]}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.95], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<\!\(n\_rad\)=0, \
\!\(m\_azm\)=3, Oscillator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, 
              m\_azm, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-3.5\), 
            3.5}, {y, \(-3.5\), 
            3.5}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.8], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=0, \!\(m\_azm\)=3, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-3.5\), 
            3.5}, {y, \(-3.5\), 3.5}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.9], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=0, \!\(m\_azm\)=3, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-3.5\), 
            3.5}, {y, \(-3.5\), 
            3.5}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.65], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=0, \!\(m\_azm\)=3, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n\_rad, m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=0, \!\(m\_azm\)=3, Oscillator\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Two-dimensional quantum oscillator\n5) ",
  Cell[BoxData[
      \(n\_rad\)],
    FontSlant->"Italic"],
  " = 1, ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 0"
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad\  = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm\  = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Oscl[n\_rad, m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[
          RR\_Oscl[n\_rad, m\_azm, \[Lambda]], \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {RGBColor[1, 0, 
                0]}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.95], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<\!\(n\_rad\)=1, \
\!\(m\_azm\)=0, Oscillator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, 
              m\_azm, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-3.5\), 
            3.5}, {y, \(-3.5\), 
            3.5}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.8], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=1, \!\(m\_azm\)=0, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-3.5\), 
            3.5}, {y, \(-3.5\), 3.5}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.9], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=1, \!\(m\_azm\)=0, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-3.5\), 
            3.5}, {y, \(-3.5\), 
            3.5}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.65], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=1, \!\(m\_azm\)=0, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n\_rad, m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=1, \!\(m\_azm\)=0, Oscillator\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Two-dimensional quantum oscillator\n6)",
  Cell[BoxData[
      \(\(\(\ \)\(n\_rad\  = 1, m\_azm\  = 1\)\)\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad\  = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm\  = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Oscl[n\_rad, m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[
          RR\_Oscl[n\_rad, m\_azm, \[Lambda]], \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {RGBColor[1, 0, 
                0]}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.95], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<\!\(n\_rad\)=1, \
\!\(m\_azm\)=1, Oscillator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, 
              m\_azm, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-3.75\), 
            3.75}, {y, \(-3.75\), 
            3.75}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.8], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=1, \!\(m\_azm\)=1, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-3.75\), 
            3.75}, {y, \(-3.75\), 
            3.75}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.9], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=1, \!\(m\_azm\)=1, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-3.75\), 
            3.75}, {y, \(-3.75\), 
            3.75}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.65], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=1, \!\(m\_azm\)=1, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n\_rad, m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=1, \!\(m\_azm\)=1, Oscillator\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Two-dimensional quantum oscillator\n7) ",
  Cell[BoxData[
      \(\(\(\ \)\(n\_rad\  = 1, m\_azm\  = 2\)\)\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad\  = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm\  = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Oscl[n\_rad, m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[
          RR\_Oscl[n\_rad, m\_azm, \[Lambda]], \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {RGBColor[1, 0, 
                0]}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.95], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<\!\(n\_rad\)=1, \
\!\(m\_azm\)=2, Oscillator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, 
              m\_azm, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-4\), 
            4}, {y, \(-4\), 
            4}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.8], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=1, \!\(m\_azm\)=2, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-4\), 
            4}, {y, \(-4\), 4}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.9], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=1, \!\(m\_azm\)=2, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-4\), 
            4}, {y, \(-4\), 
            4}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.65], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=1, \!\(m\_azm\)=2, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n\_rad, m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=1, \!\(m\_azm\)=2, Oscillator\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Two-dimensional quantum oscillator\n8) ",
  Cell[BoxData[
      \(\(\(\ \)\(n\_rad\  = 1, m\_azm\  = 3\)\)\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad\  = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm\  = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Oscl[n\_rad, m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[
          RR\_Oscl[n\_rad, m\_azm, \[Lambda]], \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {RGBColor[1, 0, 
                0]}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.95], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<\!\(n\_rad\)=1, \
\!\(m\_azm\)=3, Oscillator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, 
              m\_azm, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-4.25\), 
            4.25}, {y, \(-4.25\), 
            4.25}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.8], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=1, \!\(m\_azm\)=3, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-4.25\), 
            4.25}, {y, \(-4.25\), 
            4.25}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.9], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=1, \!\(m\_azm\)=3, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-4.25\), 
            4.25}, {y, \(-4.25\), 
            4.25}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.65], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=1, \!\(m\_azm\)=3, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n\_rad, m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=1, \!\(m\_azm\)=3, Oscillator\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Two-dimensional quantum oscillator\n9)  ",
  Cell[BoxData[
      \(n\_rad\  = 2, m\_azm\  = 0\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad\  = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm\  = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Oscl[n\_rad, m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[
          RR\_Oscl[n\_rad, m\_azm, \[Lambda]], \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {RGBColor[1, 0, 
                0]}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.95], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<\!\(n\_rad\)=2, \
\!\(m\_azm\)=0, Oscillator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, 
              m\_azm, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-4.25\), 
            4.25}, {y, \(-4.25\), 
            4.25}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.8], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=2, \!\(m\_azm\)=0, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-4.25\), 
            4.25}, {y, \(-4.25\), 
            4.25}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.9], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=2, \!\(m\_azm\)=0, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-4.25\), 
            4.25}, {y, \(-4.25\), 
            4.25}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.65], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=2, \!\(m\_azm\)=0, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n\_rad, m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=2, \!\(m\_azm\)=0, Oscillator\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Two-dimensional quantum oscillator\n10)  ",
  Cell[BoxData[
      \(n\_rad\  = 2, m\_azm\  = 1\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad\  = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm\  = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Oscl[n\_rad, m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[
          RR\_Oscl[n\_rad, m\_azm, \[Lambda]], \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {RGBColor[1, 0, 
                0]}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.95], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<\!\(n\_rad\)=2, \
\!\(m\_azm\)=1, Oscillator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, 
              m\_azm, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-4.25\), 
            4.25}, {y, \(-4.25\), 
            4.25}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.8], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=2, \!\(m\_azm\)=1, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-4.25\), 
            4.25}, {y, \(-4.25\), 
            4.25}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.9], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=2, \!\(m\_azm\)=1, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-4.25\), 
            4.25}, {y, \(-4.25\), 
            4.25}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.65], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=2, \!\(m\_azm\)=1, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n\_rad, m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=2, \!\(m\_azm\)=1, Oscillator\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Two-dimensional quantum oscillator\n11) ",
  Cell[BoxData[
      \(\(\(\ \)\(n\_rad\  = 2, m\_azm\  = 2\)\)\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad\  = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm\  = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Oscl[n\_rad, m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[
          RR\_Oscl[n\_rad, m\_azm, \[Lambda]], \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {RGBColor[1, 0, 
                0]}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.95], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<\!\(n\_rad\)=2, \
\!\(m\_azm\)=2, Oscillator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, 
              m\_azm, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-4.5\), 
            4.5}, {y, \(-4.5\), 
            4.5}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.8], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=2, \!\(m\_azm\)=2, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-4.5\), 
            4.5}, {y, \(-4.5\), 4.5}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.9], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=2, \!\(m\_azm\)=2, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-4.5\), 
            4.5}, {y, \(-4.5\), 
            4.5}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.65], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=2, \!\(m\_azm\)=2, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n\_rad, m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=2, \!\(m\_azm\)=2, Oscillator\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Two-dimensional quantum oscillator\n12) ",
  Cell[BoxData[
      \(\(\(\ \)\(n\_rad\  = 2, m\_azm\  = 3\)\)\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 2;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Oscl[n\_rad, m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[
          RR\_Oscl[n\_rad, m\_azm, \[Lambda]], \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {RGBColor[1, 0, 
                0]}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.95], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<\!\(n\_rad\)=2, \
\!\(m\_azm\)=3, Oscillator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, 
              m\_azm, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-4.5\), 
            4.5}, {y, \(-4.5\), 
            4.5}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.8], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=2, \!\(m\_azm\)=3, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-4.5\), 
            4.5}, {y, \(-4.5\), 4.5}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.9], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=2, \!\(m\_azm\)=3, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-4.5\), 
            4.5}, {y, \(-4.5\), 
            4.5}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.65], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=2, \!\(m\_azm\)=3, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n\_rad, m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=2, \!\(m\_azm\)=3, Oscillator\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Two-dimensional quantum oscillator\n13) ",
  Cell[BoxData[
      \(\(\(\ \)\(n\_rad\  = 3, m\_azm\  = 0\)\)\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 0;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Oscl[n\_rad, m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[
          RR\_Oscl[n\_rad, m\_azm, \[Lambda]], \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {RGBColor[1, 0, 
                0]}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.95], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<\!\(n\_rad\)=3, \
\!\(m\_azm\)=0, Oscillator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, 
              m\_azm, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-4.5\), 
            4.5}, {y, \(-4.5\), 
            4.5}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.8], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=3, \!\(m\_azm\)=0, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-4.5\), 
            4.5}, {y, \(-4.5\), 4.5}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.9], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=3, \!\(m\_azm\)=0, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-4.5\), 
            4.5}, {y, \(-4.5\), 
            4.5}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.65], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=3, \!\(m\_azm\)=0, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n\_rad, m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=3, \!\(m\_azm\)=0, Oscillator\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Two-dimensional quantum oscillator\n14) ",
  Cell[BoxData[
      \(\(\(\ \)\(n\_rad\  = 3, m\_azm\  = 1\)\)\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 1;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Oscl[n\_rad, m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[
          RR\_Oscl[n\_rad, m\_azm, \[Lambda]], \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {RGBColor[1, 0, 
                0]}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.95], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<\!\(n\_rad\)=3, \
\!\(m\_azm\)=1, Oscillator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, 
              m\_azm, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-4.75\), 
            4.75}, {y, \(-4.75\), 
            4.75}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.8], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=3, \!\(m\_azm\)=1, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-4.75\), 
            4.75}, {y, \(-4.75\), 
            4.75}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.9], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=3, \!\(m\_azm\)=1, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-4.75\), 
            4.75}, {y, \(-4.75\), 
            4.75}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.65], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=3, \!\(m\_azm\)=1, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n\_rad, m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=3, \!\(m\_azm\)=1, Oscillator\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Two-dimensional quantum oscillator\n15) ",
  Cell[BoxData[
      \(\(\(\ \)\(n\_rad\  = 3, m\_azm\  = 2\)\)\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 2;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Oscl[n\_rad, m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[
          RR\_Oscl[n\_rad, m\_azm, \[Lambda]], \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {RGBColor[1, 0, 
                0]}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.95], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<\!\(n\_rad\)=3, \
\!\(m\_azm\)=2, Oscillator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, 
              m\_azm, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-5\), 
            5}, {y, \(-5\), 
            5}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.8], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=3, \!\(m\_azm\)=2, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-5\), 
            5}, {y, \(-5\), 5}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.9], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=3, \!\(m\_azm\)=2, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-5\), 
            5}, {y, \(-5\), 
            5}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.65], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=3, \!\(m\_azm\)=2, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n\_rad, m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=3, \!\(m\_azm\)=2, Oscillator\>\""]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Two-dimensional quantum oscillator\n16) ",
  Cell[BoxData[
      \(\(\(\ \)\(n\_rad\  = 3, m\_azm\  = 3\)\)\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(n\_rad = 3;\)\), "\[IndentingNewLine]", 
    \(\(\(m\_azm = 3;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph1dRR\_Oscl[n\_rad, m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, 
          PR2dMax, IS2dHorz, IS2dVert] = 
        FilledPlot[
          RR\_Oscl[n\_rad, m\_azm, \[Lambda]], \[IndentingNewLine]{r, x2dMin, 
            x2dMax}, \[IndentingNewLine]PlotRange \[Rule] {PR2dMin, 
              PR2dMax}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]Curves \[Rule] 
            Front, \[IndentingNewLine]Fills \[Rule] {RGBColor[1, 0, 
                0]}, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.01]}, \[IndentingNewLine]Background -> 
            RGBColor[1.0, 0.85, 
              0.95], \[IndentingNewLine]ImageSize \[Rule] {IS2dHorz, 
              IS2dVert*0.65}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]PlotLabel \[Rule] \*"\"\<\!\(n\_rad\)=3, \
\!\(m\_azm\)=3, Oscillator\>\""];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]] = 
        FullSimplify[
          ReplaceAll[\[Psi]\[Psi]\_Oscl[n\_rad, 
              m\_azm, \[Lambda]], {r \[Rule] \@\(x\^2 + y\^2\)}]];\)\(\
\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\[Psi]\[Psi]Hf[n\_rad, m\_azm, \[Lambda]] = 
        If[y < 0, 
          0, \[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda]]];\)\), "\n", 
    \(\(\(Grph3d\[Psi]\[Psi]xyHf\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]Hf[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-5\), 
            5}, {y, \(-5\), 
            5}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background -> 
            RGBColor[0.7, 1.0, 0.8], \[IndentingNewLine]ViewPoint -> {VP1, \ 
              VP2, \ VP3}, \[IndentingNewLine]AspectRatio \[Rule] 
            AR, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert*0.65}, \[IndentingNewLine]Lighting \[Rule] 
            True, \[IndentingNewLine]LightSources \[Rule] {{{1.`, 0.`, 1.`}, 
                RGBColor[1, 0, 0]}, {{1.`, 1.`, 1.`}, 
                RGBColor[0.1, 0.9, 0]}, {{0.`, 1.`, 1.`}, 
                RGBColor[0, 0, 
                  1]}}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=3, \!\(m\_azm\)=3, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        DensityPlot[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-5\), 
            5}, {y, \(-5\), 5}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            GrayLevel[0.9], \[IndentingNewLine]ColorOutput \[Rule] 
            GrayLevel, \[IndentingNewLine]ColorFunction \[Rule] \
\((GrayLevel[#^0.5] &)\), \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=3, \!\(m\_azm\)=3, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, m\_azm, \[Lambda], x3dMin, 
          x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, 
          VP1, \ VP2, \ VP3, N3d] = 
        Plot3D[\[Psi]\[Psi]xy\_Oscl[n\_rad, 
            m\_azm, \[Lambda]], \[IndentingNewLine]{x, \(-5\), 
            5}, {y, \(-5\), 
            5}, \[IndentingNewLine]PlotRange \[Rule] {PR3dMin, 
              PR3dMax}, \[IndentingNewLine]PlotPoints \[Rule] 
            N3d, \[IndentingNewLine]Mesh -> 
            False, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.65], \[IndentingNewLine]AspectRatio \[Rule] 
            1, \[IndentingNewLine]ImageSize \[Rule] {IS3dHorz, 
              IS3dVert}, \[IndentingNewLine]ViewPoint -> {WP1, \ WP2, \ 
              
              WP3}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=3, \!\(m\_azm\)=3, Oscillator\>\""];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}, \[IndentingNewLine]{Grph1dRR\_Oscl[n\_rad, 
              m\_azm, \[Lambda], x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xyHf\_Oscl[
              n\_rad, m\_azm, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, 
              PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 
          0.2], \ \[IndentingNewLine]ImageSize \[Rule] {IS3dAllHorz, 
          IS3dAllHorz}, \[IndentingNewLine]PlotLabel \[Rule] \
\*"\"\<\!\(n\_rad\)=3, \!\(m\_azm\)=3, Oscillator\>\""]\)}], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
3. Comparison of quantum states of the two-dimensional quantum rotator and \
oscillator\
\>", "Section",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Now we can compare quantum states of the two-dimensional quantum rotator and \
oscillator for given quantum numbers.
We will present quantum states of rotator and oscillator in individual scales \
in order to compare geometrical properties corresponding quantum states.\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(Show[
      GraphicsArray[{\[IndentingNewLine]{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[1, 0, 
              r0, x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[1, 0, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Rotat[1, 0, r0, x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[
              0, 0, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[0, 
              0, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Oscl[0, 0, \[Lambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]\[IndentingNewLine]\
\[IndentingNewLine]{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[1, 1, r0, x3dMin, x3dMax, 
              y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ 
              VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[1, 1, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Rotat[1, 1, r0, x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[
              0, 1, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[0, 
              1, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Oscl[0, 1, \[Lambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]\[IndentingNewLine]\
\[IndentingNewLine]{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[1, 2, r0, x3dMin, x3dMax, 
              y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ 
              VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[1, 2, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Rotat[1, 2, r0, x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[
              0, 2, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[0, 
              2, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Oscl[0, 2, \[Lambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]\[IndentingNewLine]\
\[IndentingNewLine]{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[1, 3, r0, x3dMin, x3dMax, 
              y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ 
              VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[1, 3, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Rotat[1, 3, r0, x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[
              0, 3, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[0, 
              3, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Oscl[0, 3, \[Lambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]\[IndentingNewLine]\
\[IndentingNewLine]{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[2, 0, r0, x3dMin, x3dMax, 
              y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ 
              VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[2, 0, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Rotat[2, 0, r0, x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[
              1, 0, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[1, 
              0, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Oscl[1, 0, \[Lambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]\[IndentingNewLine]\
\[IndentingNewLine]{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[2, 1, r0, x3dMin, x3dMax, 
              y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ 
              VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[2, 1, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Rotat[2, 1, r0, x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[
              1, 1, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[1, 
              1, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Oscl[1, 1, \[Lambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]\[IndentingNewLine]\
\[IndentingNewLine]{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[2, 2, r0, x3dMin, x3dMax, 
              y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ 
              VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[2, 2, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Rotat[2, 2, r0, x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[
              1, 2, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[1, 
              2, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Oscl[1, 2, \[Lambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]\[IndentingNewLine]\
\[IndentingNewLine]{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[2, 3, r0, x3dMin, x3dMax, 
              y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ 
              VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[2, 3, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Rotat[2, 3, r0, x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[
              1, 3, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[1, 
              3, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Oscl[1, 3, \[Lambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]\[IndentingNewLine]\
\[IndentingNewLine]{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[3, 0, r0, x3dMin, x3dMax, 
              y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ 
              VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[3, 0, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Rotat[3, 0, r0, x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[
              2, 0, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[2, 
              0, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Oscl[2, 0, \[Lambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]\[IndentingNewLine]\
\[IndentingNewLine]{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[3, 1, r0, x3dMin, x3dMax, 
              y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ 
              VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[3, 1, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Rotat[3, 1, r0, x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[
              2, 1, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[2, 
              1, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Oscl[2, 1, \[Lambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]\[IndentingNewLine]\
\[IndentingNewLine]{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[3, 2, r0, x3dMin, x3dMax, 
              y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ 
              VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[3, 2, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Rotat[3, 2, r0, x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[
              2, 2, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[2, 
              2, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Oscl[2, 2, \[Lambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]\[IndentingNewLine]\
\[IndentingNewLine]{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[3, 3, r0, x3dMin, x3dMax, 
              y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ 
              VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[3, 3, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Rotat[3, 3, r0, x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[
              2, 3, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[2, 
              3, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Oscl[2, 3, \[Lambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]\[IndentingNewLine]\
\[IndentingNewLine]{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[4, 0, r0, x3dMin, x3dMax, 
              y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ 
              VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[4, 0, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Rotat[4, 0, r0, x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[
              3, 0, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[3, 
              0, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Oscl[3, 0, \[Lambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]\[IndentingNewLine]\
\[IndentingNewLine]{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[4, 1, r0, x3dMin, x3dMax, 
              y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ 
              VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[4, 1, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Rotat[4, 1, r0, x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[
              3, 1, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[3, 
              1, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Oscl[3, 1, \[Lambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]\[IndentingNewLine]\
\[IndentingNewLine]{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[4, 2, r0, x3dMin, x3dMax, 
              y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ 
              VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[4, 2, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Rotat[4, 2, r0, x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[
              3, 2, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[3, 
              2, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Oscl[3, 2, \[Lambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]\[IndentingNewLine]\
\[IndentingNewLine]{Grph3dDEN\[Psi]\[Psi]xy\_Rotat[4, 3, r0, x3dMin, x3dMax, 
              y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, IS3dVert, VP1, \ 
              VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Rotat[4, 3, r0, 
              x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, IS3dHorz, 
              IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Rotat[4, 3, r0, x2dMin, 
              x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}, \[IndentingNewLine]{Grph3dDEN\[Psi]\[Psi]xy\_Oscl[
              3, 3, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, 
              PR3dMax, IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph3d\[Psi]\[Psi]xy\_Oscl[3, 
              3, \[Lambda], x3dMin, x3dMax, y3dMin, y3dMax, PR3dMin, PR3dMax, 
              IS3dHorz, IS3dVert, VP1, \ VP2, \ VP3, 
              N3d], \[IndentingNewLine]Grph1dRR\_Oscl[3, 3, \[Lambda], 
              x2dMin, x2dMax, PR2dMin, PR2dMax, IS2dHorz, 
              IS2dVert]}\[IndentingNewLine]\[IndentingNewLine]}], \
\[IndentingNewLine]\[IndentingNewLine]Background \[Rule] 
        RGBColor[0.2, 0.475, 0.2], \[IndentingNewLine]ImageSize \[Rule] {850, 
          8000}, \[IndentingNewLine]PlotLabel \[Rule] "\<Presentation of wave \
function of the Two-dimentional quantum Rotator and Oscillator\>"]\)], "Input"],

Cell["", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1016, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.25,
StyleDefinitions -> "Classroom1.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 226, 7, 56, "Subtitle"],
Cell[2499, 81, 179, 5, 124, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2703, 90, 184, 5, 119, "Section"],
Cell[2890, 97, 155, 5, 56, "Text"],
Cell[3048, 104, 183, 6, 72, "NumberedEquation"],
Cell[3234, 112, 196, 5, 56, "Text"],
Cell[3433, 119, 183, 6, 72, "NumberedEquation"],
Cell[3619, 127, 260, 7, 57, "Text"],
Cell[3882, 136, 62, 1, 63, "Input"],
Cell[3947, 139, 293, 9, 57, "Text"],
Cell[4243, 150, 56, 1, 63, "Input"],
Cell[4302, 153, 247, 8, 56, "Text"],
Cell[4552, 163, 121, 2, 113, "Input"],
Cell[4676, 167, 212, 5, 80, "Text"],
Cell[4891, 174, 2317, 48, 1142, "Input"],
Cell[7211, 224, 2333, 50, 1255, "Input"],
Cell[9547, 276, 1086, 30, 56, "Text"],
Cell[10636, 308, 2699, 51, 1205, "Input"],
Cell[13338, 361, 215, 5, 80, "Text"],
Cell[13556, 368, 7007, 138, 2179, "Input"],
Cell[20566, 508, 3555, 65, 1059, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24158, 578, 174, 5, 85, "Section"],
Cell[24335, 585, 546, 10, 176, "Text"],
Cell[24884, 597, 666, 17, 452, "Text"],
Cell[25553, 616, 1392, 30, 888, "Input"],

Cell[CellGroupData[{
Cell[26970, 650, 126, 4, 123, "Subsection"],
Cell[27099, 656, 7682, 139, 2083, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[34818, 800, 219, 10, 123, "Subsection"],
Cell[35040, 812, 7538, 136, 2083, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[42615, 953, 218, 10, 123, "Subsection"],
Cell[42836, 965, 5982, 106, 2083, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[48855, 1076, 218, 10, 123, "Subsection"],
Cell[49076, 1088, 5982, 106, 2083, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[55095, 1199, 218, 10, 123, "Subsection"],
Cell[55316, 1211, 5982, 106, 2083, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[61335, 1322, 143, 4, 123, "Subsection"],
Cell[61481, 1328, 5982, 106, 2083, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[67500, 1439, 143, 4, 123, "Subsection"],
Cell[67646, 1445, 5982, 106, 2083, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[73665, 1556, 143, 4, 123, "Subsection"],
Cell[73811, 1562, 5982, 106, 2083, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[79830, 1673, 130, 4, 123, "Subsection"],
Cell[79963, 1679, 5982, 106, 2083, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[85982, 1790, 131, 4, 123, "Subsection"],
Cell[86116, 1796, 5982, 106, 2083, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[92135, 1907, 145, 4, 123, "Subsection"],
Cell[92283, 1913, 5982, 106, 2083, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[98302, 2024, 145, 4, 123, "Subsection"],
Cell[98450, 2030, 5982, 106, 2083, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[104469, 2141, 145, 4, 123, "Subsection"],
Cell[104617, 2147, 5982, 106, 2083, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[110636, 2258, 145, 4, 123, "Subsection"],
Cell[110784, 2264, 5982, 106, 2083, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[116803, 2375, 145, 4, 123, "Subsection"],
Cell[116951, 2381, 5982, 106, 2083, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[122970, 2492, 145, 4, 123, "Subsection"],
Cell[123118, 2498, 5982, 106, 2083, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[129137, 2609, 129, 4, 123, "Subsection"],
Cell[129269, 2615, 5942, 104, 2073, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[135248, 2724, 221, 10, 123, "Subsection"],
Cell[135472, 2736, 5931, 105, 2048, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[141440, 2846, 221, 10, 123, "Subsection"],
Cell[141664, 2858, 5909, 105, 2048, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[147610, 2968, 221, 10, 123, "Subsection"],
Cell[147834, 2980, 5884, 104, 2048, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[153755, 3089, 221, 10, 123, "Subsection"],
Cell[153979, 3101, 5888, 104, 2048, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[159904, 3210, 146, 4, 123, "Subsection"],
Cell[160053, 3216, 5913, 105, 2048, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[166003, 3326, 147, 4, 123, "Subsection"],
Cell[166153, 3332, 5879, 105, 2048, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[172069, 3442, 147, 4, 123, "Subsection"],
Cell[172219, 3448, 5913, 105, 2048, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[178169, 3558, 134, 4, 123, "Subsection"],
Cell[178306, 3564, 5913, 105, 2048, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[184256, 3674, 135, 4, 123, "Subsection"],
Cell[184394, 3680, 5913, 105, 2048, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[190344, 3790, 148, 4, 123, "Subsection"],
Cell[190495, 3796, 5888, 104, 2048, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[196420, 3905, 148, 4, 123, "Subsection"],
Cell[196571, 3911, 5884, 104, 2048, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[202492, 4020, 148, 4, 123, "Subsection"],
Cell[202643, 4026, 5884, 104, 2048, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[208564, 4135, 148, 4, 123, "Subsection"],
Cell[208715, 4141, 5909, 105, 2048, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[214661, 4251, 148, 4, 123, "Subsection"],
Cell[214812, 4257, 5875, 105, 2048, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[220724, 4367, 148, 4, 123, "Subsection"],
Cell[220875, 4373, 5875, 105, 2048, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[226799, 4484, 161, 5, 85, "Section"],
Cell[226963, 4491, 340, 7, 116, "Text"],
Cell[227306, 4500, 18201, 277, 5013, "Input"],
Cell[245510, 4779, 16, 0, 56, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

