(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     96810,       2151]*)
(*NotebookOutlinePosition[     97539,       2176]*)
(*  CellTagsIndexPosition[     97495,       2172]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[StyleBox["Part 5. Spherical Harmonics and Angular Probability \
Densities",
  FontWeight->"Bold"]], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "5.2. Visualization of the ",
  StyleBox["Spherical Harmonics and Angular Probability Densities",
    FontWeight->"Bold"]
}], "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["1. General parameters and tools for plots", "Section"],

Cell[TextData[StyleBox["In this file we will present visualizations in \
individual scales for states defined by given quantum numbers.",
  FontWeight->"Bold"]], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Consider some special values of spherical harmonics defined by quantum \
numbers:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  Cell[BoxData[
      \(l\_orb = 0, 1, 2, 3\)],
    FontSlant->"Italic"],
  ", \n",
  Cell[BoxData[
      \(m\_azm = 0, 1, 2, 3\)],
    FontSlant->"Italic"]
}], "NumberedEquation"],

Cell[TextData[{
  "since positive values of ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " ",
  "suffice",
  " for our purposes."
}], "Text"],

Cell[TextData[{
  "Start \"",
  StyleBox["Graphics",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  "\" tool"
}], "Text"],

Cell[BoxData[
    \(<< Graphics`Graphics`\)], "Input"],

Cell[TextData[{
  "We will ",
  "visualize",
  " spherical harmonics ",
  Cell[BoxData[
      StyleBox[\(Y[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]\),
        FontFamily->"Courier New",
        FontSize->14,
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0.996109, 0.996109, 0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}]],
    FontSlant->"Italic"],
  "and angular probability density ",
  Cell[BoxData[
      StyleBox[
        RowBox[{"|", 
          RowBox[{
            StyleBox["Y",
              FontSlant->"Italic"], 
            StyleBox["[",
              FontSlant->"Italic"], 
            StyleBox[\(l\_orb, m\_azm, \[Theta], \[CurlyPhi]\),
              FontSlant->"Italic"], "]"}], \( | \^2\)}],
        FontFamily->"Courier New",
        FontSize->14,
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0.996109, 0.996109, 0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}]]],
  "."
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox["Plots",
    FontSize->22,
    FontWeight->"Bold"],
  "\n",
  Cell[BoxData[
      StyleBox[\(Y[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]\),
        FontFamily->"Courier New",
        FontSize->14,
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0.996109, 0.996109, 0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}]],
    FontSlant->"Italic"],
  "\n\t\t\t- spherical harmonics with given values of ",
  Cell[BoxData[
      StyleBox[\(l\_orb\),
        FontFamily->"Courier New",
        FontSize->14,
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0.996109, 0.996109, 0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}]],
    FontSlant->"Italic"],
  ", and ",
  Cell[BoxData[
      StyleBox[\(m\_azm\),
        FontFamily->"Courier New",
        FontSize->14,
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0.996109, 0.996109, 0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}]],
    FontSlant->"Italic"],
  ",\n",
  Cell[BoxData[
      StyleBox[\(YY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]\),
        FontFamily->"Courier New",
        FontSize->14,
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0.996109, 0.996109, 0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}]],
    FontSlant->"Italic"],
  "\n\t\t\t- angular density with given values of ",
  Cell[BoxData[
      StyleBox[\(l\_orb\),
        FontFamily->"Courier New",
        FontSize->14,
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0.996109, 0.996109, 0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}]],
    FontSlant->"Italic"],
  ", and ",
  Cell[BoxData[
      StyleBox[\(m\_azm\),
        FontFamily->"Courier New",
        FontSize->14,
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0.996109, 0.996109, 0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}]],
    FontSlant->"Italic"],
  ",\n",
  Cell[BoxData[
      StyleBox[\(PltSphHarm[l\_orb, m\_azm]\),
        FontWeight->"Bold"]],
    FontFamily->"Courier New",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  " \n\t\t\t- polar plot representing two-dimensional profile of spherical \
harmonic ",
  Cell[BoxData[
      StyleBox[\(Y[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]\),
        FontFamily->"Courier New",
        FontSize->14,
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0.996109, 0.996109, 0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}]],
    FontSlant->"Italic"],
  ",\n",
  Cell[BoxData[
      StyleBox[\(PltSphHarmDens[l\_orb, m\_azm]\),
        FontWeight->"Bold"]],
    FontFamily->"Courier New",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  "\n\t\t\t- polar plot representing two-dimensional profile of angular \
density ",
  Cell[BoxData[
      StyleBox[\(YY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]\),
        FontFamily->"Courier New",
        FontSize->14,
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0.996109, 0.996109, 0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}]],
    FontSlant->"Italic"],
  ",\n",
  Cell[BoxData[
      StyleBox[\(SphHarm3d[l\_orb, m\_azm]\),
        FontWeight->"Bold",
        FontSlant->"Italic"]],
    FontFamily->"Courier New",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  "\n\t\t\t- three-dimensional representation of spherical harmonic ",
  Cell[BoxData[
      StyleBox[\(Y[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]\),
        FontFamily->"Courier New",
        FontSize->14,
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0.996109, 0.996109, 0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}]],
    FontSlant->"Italic"],
  ",\n",
  Cell[BoxData[
      StyleBox[\(SphHarm3dSeg[l\_orb, m\_azm]\),
        FontFamily->"Courier New",
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0.996109, 0.996109, 0]]]],
  "\n\t\t\t- segment of three -dimensional representation of spherical \
harmonic ",
  Cell[BoxData[
      StyleBox[\(Y[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]\),
        FontFamily->"Courier New",
        FontSize->14,
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0.996109, 0.996109, 0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}]],
    FontSlant->"Italic"],
  " (0 < \[CurlyPhi] < \[Pi]),\n",
  Cell[BoxData[
      StyleBox[\(SphHarmDens3d[l\_orb, m\_azm]\),
        FontFamily->"Courier New",
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0.996109, 0.996109, 0]]]],
  "\n\t\t\t- three -dimensional representation of angular density",
  Cell[BoxData[
      StyleBox[\(YY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]\),
        FontFamily->"Courier New",
        FontSize->14,
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0.996109, 0.996109, 0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}]],
    FontSlant->"Italic"],
  ",\n",
  Cell[BoxData[
      StyleBox[\(SphHarmDens3dSeg[l\_orb, m\_azm]\),
        FontFamily->"Courier New",
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0.996109, 0.996109, 0]]]],
  "\n\t\t\t- segment of three -dimensional representation of angular density \
",
  Cell[BoxData[
      StyleBox[\(YY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]\),
        FontFamily->"Courier New",
        FontSize->14,
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0.996109, 0.996109, 0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}]],
    FontSlant->"Italic"],
  " (0 < \[CurlyPhi] < \[Pi]) \n\t\t\t(",
  Cell[BoxData[
      RowBox[{
        StyleBox["SphHarmDens3dSm",
          FontFamily->"Courier New",
          FontSize->14,
          FontWeight->"Bold",
          FontSlant->"Italic",
          FontColor->RGBColor[0.996109, 0.996109, 0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[" ",
          FontSlant->"Italic"]}]]],
  "has other quantity of plot points)."
}], "Text"],

Cell[TextData[{
  StyleBox["Note",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.996109]],
  ":\t\t",
  "Plots with mazarine background represent spherical harmonics.\n\t\tPlots \
with cerise background represent spherical harmonics."
}], "Text"],

Cell["Define parameters of review of 3d plots:", "Text"],

Cell[BoxData[{
    \(\(VP1 = 1.400;\)\), "\[IndentingNewLine]", 
    \(\(VP2 = \(-2.584\);\)\), "\[IndentingNewLine]", 
    \(\(VP3 = 1.677;\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2. Plots of the spherical harmonics and angular probability densities\
\>", "Section"],

Cell[CellGroupData[{

Cell[TextData[{
  "1. Spherical Harmonic ",
  Cell[BoxData[
      \(Y[0, 0, \[Theta], \[CurlyPhi]]\)],
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      \(l\_orb = 0\)],
    FontSlant->"Italic"],
  StyleBox[", ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(m\_azm = 0\)],
    FontSlant->"Italic"],
  ")"
}], "Subsection"],

Cell[BoxData[{
    \(l\_orb = 0\), "\[IndentingNewLine]", 
    \(m\_azm = 0\), "\[IndentingNewLine]", 
    \(Y[l\_orb, m\_azm] = 
      SphericalHarmonicY[l\_orb, 
        m\_azm, \[Theta], \[CurlyPhi]]\), "\[IndentingNewLine]", 
    \(\(\(YY[l\_orb, m\_azm] = 
      ComplexExpand[
        SphericalHarmonicY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]*
          Conjugate[
            SphericalHarmonicY[l\_orb, 
              m\_azm, \[Theta], \[CurlyPhi]]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(PltSphHarm[l\_orb, m\_azm] = 
        PolarPlot[
          Abs[SphericalHarmonicY[l\_orb, m\_azm, \[Theta] - Pi/2, 
              0]], {\[Theta], \(-Pi\), 
            Pi}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.45, 0.45, 
              0.75], \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.0115]}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.3\), 
                0.3}, {\(-0.3\), 
                0.3}}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \
Y[0,0,\[Theta],\[CurlyPhi]]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(PltSphHarmDens[l\_orb, m\_azm] = 
        PolarPlot[\((Abs[
                SphericalHarmonicY[l\_orb, m\_azm, \[Theta] - Pi/2, 
                  0]])\)^2, \[IndentingNewLine]{\[Theta], \(-Pi\), 
            Pi}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.0115]}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.3\), 
                0.3}, {\(-0.3\), 0.3}}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \
|Y[0,0,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarm3d[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[Y[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[Y[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[Y[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.29\), 
                0.29}, {\(-0.29\), 0.29}, {\(-0.29\), 
                0.29}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of Y[0,0,\
\[Theta],\[CurlyPhi]]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarm3dSeg[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[Y[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[Y[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[Y[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0, 
            Pi}, {\[CurlyPhi], 0, 
            Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              15}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.29\), 
                0.29}, {\(-0.29\), 0.29}, {\(-0.29\), 
                0.29}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {1.400, \ \(-2.584\), \ 
              1.677}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.6], \[IndentingNewLine]PlotLabel \[Rule] "\<Segment of Y[0,0,\
\[Theta],\[CurlyPhi]]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarmDens3d[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[YY[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[YY[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[YY[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0/2, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.0875\), 
                0.0875}, {\(-0.0875\), 0.0875}, {\(-0.0875\), 
                0.0875}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of |Y[0,0,\
\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarmDens3dSeg[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*YY[l\_orb, m\_azm], 
            Cos[\[Theta]]*YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0, Pi}, {\[CurlyPhi], 0, 
            Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              15}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.0875\), 
                0.0875}, {\(-0.0875\), 0.0875}, {\(-0.0875\), 
                0.0875}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.8, 
              0.8], \[IndentingNewLine]PlotLabel \[Rule] "\<Segment of \
|Y[0,0,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarmDens3dSm[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[YY[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[YY[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[YY[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0/2, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {20, 
              20}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.29\), 
                0.29}, {\(-0.29\), 0.29}, {\(-0.29\), 
                0.29}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of |Y[0,0,\
\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{SphHarm3d[l\_orb, m\_azm], 
            SphHarmDens3d[l\_orb, m\_azm]}, \[IndentingNewLine]{SphHarm3dSeg[
              l\_orb, m\_azm], 
            SphHarmDens3dSeg[l\_orb, m\_azm]}, {PltSphHarm[l\_orb, m\_azm], 
            PltSphHarmDens[l\_orb, 
              m\_azm]}}], \[IndentingNewLine]ImageSize \[Rule] {500, 
          750}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Presentation of Plots \
for Y[0,0,\[Theta],\[CurlyPhi]] and |Y[0,0,\[Theta],\[CurlyPhi]]|^2\>"]\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{SphHarm3d[l\_orb, m\_azm], 
          SphHarmDens3dSm[l\_orb, 
            m\_azm]}], \[IndentingNewLine]ImageSize \[Rule] {650, 
          375}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Comparison of Plots \
for Y[0,0,\[Theta],\[CurlyPhi]] and |Y[0,0,\[Theta],\[CurlyPhi]]|^2\>"]\)}], \
"Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "2. Spherical Harmonic ",
  Cell[BoxData[
      \(Y[1, 0, \[Theta], \[CurlyPhi]]\)],
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  StyleBox[", ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(m\_azm = 0\)],
    FontSlant->"Italic"],
  ")"
}], "Subsection"],

Cell[BoxData[{
    \(l\_orb = 1\), "\[IndentingNewLine]", 
    \(m\_azm = 0\), "\[IndentingNewLine]", 
    \(Y[l\_orb, m\_azm] = 
      SphericalHarmonicY[l\_orb, 
        m\_azm, \[Theta], \[CurlyPhi]]\), "\[IndentingNewLine]", 
    \(\(\(YY[l\_orb, m\_azm] = 
      ComplexExpand[
        SphericalHarmonicY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]*
          Conjugate[
            SphericalHarmonicY[l\_orb, 
              m\_azm, \[Theta], \[CurlyPhi]]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(PltSphHarm[l\_orb, m\_azm] = 
        PolarPlot[
          Abs[SphericalHarmonicY[l\_orb, m\_azm, \[Theta] - Pi/2, 
              0]], {\[Theta], \(-Pi\), 
            Pi}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              350}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.0115]}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.26\), 
                0.26}, {\(-0.5\), 
                0.5}}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.45, 0.45, 
              0.75], \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \
Y[1,0,\[Theta],\[CurlyPhi]]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(PltSphHarmDens[l\_orb, m\_azm] = 
        PolarPlot[\((Abs[
                SphericalHarmonicY[l\_orb, m\_azm, \[Theta] - Pi/2, 
                  0]])\)^2, \[IndentingNewLine]{\[Theta], \(-Pi\), 
            Pi}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              350}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.0115]}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.26\), 
                0.26}, {\(-0.5\), 
                0.5}}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \
|Y[1,0,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarm3d[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[Y[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[Y[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[Y[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {36, 
              36}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.26\), 
                0.26}, {\(-0.26\), 0.26}, {\(-0.5\), 
                0.5}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              350}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of Y[1,0,\
\[Theta],\[CurlyPhi]]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarm3dSeg[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[Y[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[Y[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[Y[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0, 
            Pi}, {\[CurlyPhi], 0, 
            Pi}, \[IndentingNewLine]PlotPoints \[Rule] {36, 
              18}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.26\), 
                0.26}, {\(-0.26\), 0.26}, {\(-0.5\), 
                0.5}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              350}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.6], \[IndentingNewLine]PlotLabel \[Rule] "\<Segment of Y[1,0,\
\[Theta],\[CurlyPhi]]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarmDens3d[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[YY[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[YY[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[YY[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0/2, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {36, 
              36}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.13\), 
                0.13}, {\(-0.13\), 0.13}, {\(-0.25\), 
                0.25}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              350}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of |Y[1,0,\
\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarmDens3dSeg[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*YY[l\_orb, m\_azm], 
            Cos[\[Theta]]*YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0, Pi}, {\[CurlyPhi], 0, 
            Pi}, \[IndentingNewLine]PlotPoints \[Rule] {36, 
              18}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.13\), 
                0.13}, {\(-0.13\), 0.13}, {\(-0.25\), 
                0.25}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              350}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.8, 
              0.8], \[IndentingNewLine]PlotLabel \[Rule] "\<Segment of \
|Y[1,0,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarmDens3dSm[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[YY[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[YY[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[YY[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0/2, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {25, 
              25}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.26\), 
                0.26}, {\(-0.26\), 0.26}, {\(-0.5\), 
                0.5}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              350}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of |Y[1,0,\
\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{SphHarm3d[l\_orb, m\_azm], 
            SphHarmDens3d[l\_orb, m\_azm]}, \[IndentingNewLine]{SphHarm3dSeg[
              l\_orb, m\_azm], 
            SphHarmDens3dSeg[l\_orb, m\_azm]}, {PltSphHarm[l\_orb, m\_azm], 
            PltSphHarmDens[l\_orb, 
              m\_azm]}}], \[IndentingNewLine]ImageSize \[Rule] {500, 
          950}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Presentation of Plots \
for Y[1,0,\[Theta],\[CurlyPhi]] and |Y[1,0,\[Theta],\[CurlyPhi]]|^2\>"]\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{SphHarm3d[l\_orb, m\_azm], 
          SphHarmDens3dSm[l\_orb, 
            m\_azm]}], \[IndentingNewLine]ImageSize \[Rule] {650, 
          450}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Comparison of Plots \
for Y[1,0,\[Theta],\[CurlyPhi]] and |Y[1,0,\[Theta],\[CurlyPhi]]|^2\>"]\)}], \
"Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "3. Spherical Harmonic ",
  Cell[BoxData[
      \(Y[1, 1, \[Theta], \[CurlyPhi]]\)],
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  StyleBox[", ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(m\_azm = 1\)],
    FontSlant->"Italic"],
  ")"
}], "Subsection"],

Cell[BoxData[{
    \(l\_orb = 1\), "\[IndentingNewLine]", 
    \(m\_azm = 1\), "\[IndentingNewLine]", 
    \(Y[l\_orb, m\_azm] = 
      SphericalHarmonicY[l\_orb, 
        m\_azm, \[Theta], \[CurlyPhi]]\), "\[IndentingNewLine]", 
    \(\(\(YY[l\_orb, m\_azm] = 
      ComplexExpand[
        SphericalHarmonicY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]*
          Conjugate[
            SphericalHarmonicY[l\_orb, 
              m\_azm, \[Theta], \[CurlyPhi]]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(PltSphHarm[l\_orb, m\_azm] = 
        PolarPlot[
          Abs[SphericalHarmonicY[l\_orb, m\_azm, \[Theta] - Pi/2, 
              0]], {\[Theta], \(-Pi\), 
            Pi}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.0115]}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.355\), 
                0.355}, {\(-0.355\), 
                0.355}}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.45, 0.45, 
              0.75], \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \
Y[1,1,\[Theta],\[CurlyPhi]]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(PltSphHarmDens[l\_orb, m\_azm] = 
        PolarPlot[\((Abs[
                SphericalHarmonicY[l\_orb, m\_azm, \[Theta] - Pi/2, 
                  0]])\)^2, \[IndentingNewLine]{\[Theta], \(-Pi\), 
            Pi}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.0115]}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.355\), 
                0.355}, {\(-0.355\), 
                0.355}}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \
|Y[1,1,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarm3d[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[Y[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[Y[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[Y[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.355\), 
                0.355}, {\(-0.355\), 0.355}, {\(-0.355\), 
                0.355}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of Y[1,1,\
\[Theta],\[CurlyPhi]]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarm3dSeg[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[Y[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[Y[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[Y[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0, 
            Pi}, {\[CurlyPhi], 0, 
            Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              15}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.355\), 
                0.355}, {\(-0.355\), 0.355}, {\(-0.355\), 
                0.355}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.6], \[IndentingNewLine]PlotLabel \[Rule] "\<Segment of Y[1,1,\
\[Theta],\[CurlyPhi]]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarmDens3d[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[YY[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[YY[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[YY[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0/2, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.125\), 
                0.125}, {\(-0.125\), 0.125}, {\(-0.125\), 
                0.125}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of |Y[1,1,\
\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarmDens3dSeg[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*YY[l\_orb, m\_azm], 
            Cos[\[Theta]]*YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0, Pi}, {\[CurlyPhi], 0, 
            Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              15}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.125\), 
                0.125}, {\(-0.125\), 0.125}, {\(-0.125\), 
                0.125}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.8, 
              0.8], \[IndentingNewLine]PlotLabel \[Rule] "\<Segment of \
|Y[1,1,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarmDens3dSm[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[YY[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[YY[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[YY[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0/2, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {25, 
              25}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.355\), 
                0.355}, {\(-0.355\), 0.355}, {\(-0.355\), 
                0.355}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of |Y[1,1,\
\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{SphHarm3d[l\_orb, m\_azm], 
            SphHarmDens3d[l\_orb, m\_azm]}, \[IndentingNewLine]{SphHarm3dSeg[
              l\_orb, m\_azm], 
            SphHarmDens3dSeg[l\_orb, m\_azm]}, {PltSphHarm[l\_orb, m\_azm], 
            PltSphHarmDens[l\_orb, 
              m\_azm]}}], \[IndentingNewLine]ImageSize \[Rule] {500, 
          750}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Presentation of Plots \
for Y[1,1,\[Theta],\[CurlyPhi]] and |Y[1,1,\[Theta],\[CurlyPhi]]|^2\>"]\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{SphHarm3d[l\_orb, m\_azm], 
          SphHarmDens3dSm[l\_orb, 
            m\_azm]}], \[IndentingNewLine]ImageSize \[Rule] {650, 
          375}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Comparison of Plots \
for Y[1,1,\[Theta],\[CurlyPhi]] and |Y[1,1,\[Theta],\[CurlyPhi]]|^2\>"]\)}], \
"Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "4. Spherical Harmonic ",
  Cell[BoxData[
      \(Y[2, 0, \[Theta], \[CurlyPhi]]\)],
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  StyleBox[", ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(m\_azm = 0\)],
    FontSlant->"Italic"],
  ")"
}], "Subsection"],

Cell[BoxData[{
    \(l\_orb = 2\), "\[IndentingNewLine]", 
    \(m\_azm = 0\), "\[IndentingNewLine]", 
    \(Y[l\_orb, m\_azm] = 
      SphericalHarmonicY[l\_orb, 
        m\_azm, \[Theta], \[CurlyPhi]]\), "\[IndentingNewLine]", 
    \(\(\(YY[l\_orb, m\_azm] = 
      ComplexExpand[
        SphericalHarmonicY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]*
          Conjugate[
            SphericalHarmonicY[l\_orb, 
              m\_azm, \[Theta], \[CurlyPhi]]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(PltSphHarm[l\_orb, m\_azm] = 
        PolarPlot[
          Abs[SphericalHarmonicY[l\_orb, m\_azm, \[Theta] - Pi/2, 
              0]], {\[Theta], \(-Pi\), 
            Pi}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              350}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.0115]}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.325\), 
                0.325}, {\(-0.65\), 
                0.65}}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.45, 0.45, 
              0.75], \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \
Y[2,0,\[Theta],\[CurlyPhi]]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(PltSphHarmDens[l\_orb, m\_azm] = 
        PolarPlot[\((Abs[
                SphericalHarmonicY[l\_orb, m\_azm, \[Theta] - Pi/2, 
                  0]])\)^2, \[IndentingNewLine]{\[Theta], \(-Pi\), 
            Pi}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              350}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.0115]}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.325\), 
                0.325}, {\(-0.65\), 
                0.65}}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \
|Y[2,0,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarm3d[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[Y[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[Y[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[Y[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {36, 
              36}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.325\), 
                0.325}, {\(-0.325\), 0.325}, {\(-0.65\), 
                0.65}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              350}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of Y[2,0,\
\[Theta],\[CurlyPhi]]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarm3dSeg[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[Y[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[Y[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[Y[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0, 
            Pi}, {\[CurlyPhi], 0, 
            Pi}, \[IndentingNewLine]PlotPoints \[Rule] {36, 
              18}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.325\), 
                0.325}, {\(-0.325\), 0.325}, {\(-0.65\), 
                0.65}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              350}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.6], \[IndentingNewLine]PlotLabel \[Rule] "\<Segment of Y[2,0,\
\[Theta],\[CurlyPhi]]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarmDens3d[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[YY[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[YY[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[YY[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0/2, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {36, 
              36}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.2\), 
                0.2}, {\(-0.2\), 0.2}, {\(-0.4\), 
                0.4}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              350}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of |Y[2,0,\
\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarmDens3dSeg[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*YY[l\_orb, m\_azm], 
            Cos[\[Theta]]*YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0, Pi}, {\[CurlyPhi], 0, 
            Pi}, \[IndentingNewLine]PlotPoints \[Rule] {36, 
              18}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.2\), 
                0.2}, {\(-0.2\), 0.2}, {\(-0.4\), 
                0.4}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              350}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.8, 
              0.8], \[IndentingNewLine]PlotLabel \[Rule] "\<Segment of \
|Y[2,0,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarmDens3dSm[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[YY[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[YY[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[YY[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0/2, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {25, 
              25}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.325\), 
                0.325}, {\(-0.325\), 0.325}, {\(-0.65\), 
                0.65}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              350}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of |Y[2,0,\
\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{SphHarm3d[l\_orb, m\_azm], 
            SphHarmDens3d[l\_orb, m\_azm]}, \[IndentingNewLine]{SphHarm3dSeg[
              l\_orb, m\_azm], 
            SphHarmDens3dSeg[l\_orb, m\_azm]}, {PltSphHarm[l\_orb, m\_azm], 
            PltSphHarmDens[l\_orb, 
              m\_azm]}}], \[IndentingNewLine]ImageSize \[Rule] {500, 
          1050}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Presentation of Plots \
for Y[2,0,\[Theta],\[CurlyPhi]] and |Y[2,0,\[Theta],\[CurlyPhi]]|^2\>"]\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{SphHarm3d[l\_orb, m\_azm], 
          SphHarmDens3dSm[l\_orb, 
            m\_azm]}], \[IndentingNewLine]ImageSize \[Rule] {650, 
          450}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Comparison of Plots \
for Y[2,0,\[Theta],\[CurlyPhi]] and |Y[2,0,\[Theta],\[CurlyPhi]]|^2\>"]\)}], \
"Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "5. Spherical Harmonic ",
  Cell[BoxData[
      \(Y[2, 1, \[Theta], \[CurlyPhi]]\)],
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  StyleBox[", ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(m\_azm = 1\)],
    FontSlant->"Italic"],
  ")"
}], "Subsection"],

Cell[BoxData[{
    \(l\_orb = 2\), "\[IndentingNewLine]", 
    \(m\_azm = 1\), "\[IndentingNewLine]", 
    \(Y[l\_orb, m\_azm] = 
      SphericalHarmonicY[l\_orb, 
        m\_azm, \[Theta], \[CurlyPhi]]\), "\[IndentingNewLine]", 
    \(\(\(YY[l\_orb, m\_azm] = 
      ComplexExpand[
        SphericalHarmonicY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]*
          Conjugate[
            SphericalHarmonicY[l\_orb, 
              m\_azm, \[Theta], \[CurlyPhi]]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(PltSphHarm[l\_orb, m\_azm] = 
        PolarPlot[
          Abs[SphericalHarmonicY[l\_orb, m\_azm, \[Theta] - Pi/2, 
              0]], {\[Theta], \(-Pi\), 
            Pi}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.0115]}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.315\), 
                0.315}, {\(-0.315\), 
                0.315}}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.45, 0.45, 
              0.75], \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \
Y[2,1,\[Theta],\[CurlyPhi]]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(PltSphHarmDens[l\_orb, m\_azm] = 
        PolarPlot[\((Abs[
                SphericalHarmonicY[l\_orb, m\_azm, \[Theta] - Pi/2, 
                  0]])\)^2, \[IndentingNewLine]{\[Theta], \(-Pi\), 
            Pi}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.0115]}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.315\), 
                0.315}, {\(-0.315\), 
                0.315}}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \
|Y[2,1,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarm3d[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[Y[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[Y[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[Y[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {40, 
              40}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.315\), 
                0.315}, {\(-0.315\), 0.315}, {\(-0.315\), 
                0.315}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of Y[2,1,\
\[Theta],\[CurlyPhi]]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarm3dSeg[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[Y[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[Y[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[Y[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0, 
            Pi}, {\[CurlyPhi], 0, 
            Pi}, \[IndentingNewLine]PlotPoints \[Rule] {40, 
              20}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.315\), 
                0.315}, {\(-0.315\), 0.315}, {\(-0.315\), 
                0.315}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.6], \[IndentingNewLine]PlotLabel \[Rule] "\<Segment of Y[2,1,\
\[Theta],\[CurlyPhi]]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarmDens3d[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[YY[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[YY[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[YY[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0/2, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {40, 
              40}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.115\), 
                0.115}, {\(-0.115\), 0.115}, {\(-0.115\), 
                0.115}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of |Y[2,1,\
\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarmDens3dSeg[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*YY[l\_orb, m\_azm], 
            Cos[\[Theta]]*YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0, Pi}, {\[CurlyPhi], 0, 
            Pi}, \[IndentingNewLine]PlotPoints \[Rule] {40, 
              20}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.115\), 
                0.115}, {\(-0.115\), 0.115}, {\(-0.115\), 
                0.115}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.8, 
              0.8], \[IndentingNewLine]PlotLabel \[Rule] "\<Segment of \
|Y[2,1,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarmDens3dSm[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[YY[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[YY[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[YY[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0/2, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.315\), 
                0.315}, {\(-0.315\), 0.315}, {\(-0.315\), 
                0.315}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of |Y[2,1,\
\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{SphHarm3d[l\_orb, m\_azm], 
            SphHarmDens3d[l\_orb, m\_azm]}, \[IndentingNewLine]{SphHarm3dSeg[
              l\_orb, m\_azm], 
            SphHarmDens3dSeg[l\_orb, m\_azm]}, {PltSphHarm[l\_orb, m\_azm], 
            PltSphHarmDens[l\_orb, 
              m\_azm]}}], \[IndentingNewLine]ImageSize \[Rule] {500, 
          750}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Presentation of Plots \
for Y[2,0,\[Theta],\[CurlyPhi]] and |Y[2,0,\[Theta],\[CurlyPhi]]|^2\>"]\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{SphHarm3d[l\_orb, m\_azm], 
          SphHarmDens3dSm[l\_orb, 
            m\_azm]}], \[IndentingNewLine]ImageSize \[Rule] {650, 
          375}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Comparison of Plots \
for Y[2,1,\[Theta],\[CurlyPhi]] and |Y[2,1,\[Theta],\[CurlyPhi]]|^2\>"]\)}], \
"Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "6. Spherical Harmonic ",
  Cell[BoxData[
      \(Y[2, 2, \[Theta], \[CurlyPhi]]\)],
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  StyleBox[", ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(m\_azm = 2\)],
    FontSlant->"Italic"],
  ")"
}], "Subsection"],

Cell[BoxData[{
    \(l\_orb = 2\), "\[IndentingNewLine]", 
    \(m\_azm = 2\), "\[IndentingNewLine]", 
    \(Y[l\_orb, m\_azm] = 
      SphericalHarmonicY[l\_orb, 
        m\_azm, \[Theta], \[CurlyPhi]]\), "\[IndentingNewLine]", 
    \(\(\(YY[l\_orb, m\_azm] = 
      ComplexExpand[
        SphericalHarmonicY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]*
          Conjugate[
            SphericalHarmonicY[l\_orb, 
              m\_azm, \[Theta], \[CurlyPhi]]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(PltSphHarm[l\_orb, m\_azm] = 
        PolarPlot[
          Abs[SphericalHarmonicY[l\_orb, m\_azm, \[Theta] - Pi/2, 
              0]], {\[Theta], \(-Pi\), 
            Pi}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.0115]}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.4\), 
                0.4}, {\(-0.4\), 0.4}}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.45, 0.45, 
              0.75], \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \
Y[2,2,\[Theta],\[CurlyPhi]]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(PltSphHarmDens[l\_orb, m\_azm] = 
        PolarPlot[\((Abs[
                SphericalHarmonicY[l\_orb, m\_azm, \[Theta] - Pi/2, 
                  0]])\)^2, \[IndentingNewLine]{\[Theta], \(-Pi\), 
            Pi}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.0115]}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.4\), 
                0.4}, {\(-0.4\), 0.4}}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \
|Y[2,2,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarm3d[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[Y[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[Y[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[Y[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.4\), 
                0.4}, {\(-0.4\), 0.4}, {\(-0.4\), 
                0.4}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of Y[2,2,\
\[Theta],\[CurlyPhi]]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarm3dSeg[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[Y[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[Y[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[Y[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0, 
            Pi}, {\[CurlyPhi], 0, 
            Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              15}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.4\), 
                0.4}, {\(-0.4\), 0.4}, {\(-0.4\), 
                0.4}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.6], \[IndentingNewLine]PlotLabel \[Rule] "\<Segment of Y[2,2,\
\[Theta],\[CurlyPhi]]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarmDens3d[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[YY[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[YY[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[YY[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0/2, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.155\), 
                0.155}, {\(-0.155\), 0.155}, {\(-0.155\), 
                0.155}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of |Y[2,2,\
\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarmDens3dSeg[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*YY[l\_orb, m\_azm], 
            Cos[\[Theta]]*YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0, Pi}, {\[CurlyPhi], 0, 
            Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              15}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.155\), 
                0.155}, {\(-0.155\), 0.155}, {\(-0.155\), 
                0.155}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.8, 
              0.8], \[IndentingNewLine]PlotLabel \[Rule] "\<Segment of \
|Y[2,2,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarmDens3dSm[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[YY[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[YY[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[YY[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0/2, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {25, 
              25}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.4\), 
                0.4}, {\(-0.4\), 0.4}, {\(-0.4\), 
                0.4}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of |Y[2,2,\
\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{SphHarm3d[l\_orb, m\_azm], 
            SphHarmDens3d[l\_orb, m\_azm]}, \[IndentingNewLine]{SphHarm3dSeg[
              l\_orb, m\_azm], 
            SphHarmDens3dSeg[l\_orb, m\_azm]}, {PltSphHarm[l\_orb, m\_azm], 
            PltSphHarmDens[l\_orb, 
              m\_azm]}}], \[IndentingNewLine]ImageSize \[Rule] {500, 
          750}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Presentation of Plots \
for Y[2,0,\[Theta],\[CurlyPhi]] and |Y[2,0,\[Theta],\[CurlyPhi]]|^2\>"]\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{SphHarm3d[l\_orb, m\_azm], 
          SphHarmDens3dSm[l\_orb, 
            m\_azm]}], \[IndentingNewLine]ImageSize \[Rule] {650, 
          375}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Comparison of Plots \
for Y[2,2,\[Theta],\[CurlyPhi]] and |Y[2,2,\[Theta],\[CurlyPhi]]|^2\>"]\)}], \
"Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "7. Spherical Harmonic ",
  Cell[BoxData[
      \(Y[3, 0, \[Theta], \[CurlyPhi]]\)],
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  StyleBox[", ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(m\_azm = 0\)],
    FontSlant->"Italic"],
  ")"
}], "Subsection"],

Cell[BoxData[{
    \(l\_orb = 3\), "\[IndentingNewLine]", 
    \(m\_azm = 0\), "\[IndentingNewLine]", 
    \(Y[l\_orb, m\_azm] = 
      SphericalHarmonicY[l\_orb, 
        m\_azm, \[Theta], \[CurlyPhi]]\), "\[IndentingNewLine]", 
    \(\(\(YY[l\_orb, m\_azm] = 
      ComplexExpand[
        SphericalHarmonicY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]*
          Conjugate[
            SphericalHarmonicY[l\_orb, 
              m\_azm, \[Theta], \[CurlyPhi]]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(PltSphHarm[l\_orb, m\_azm] = 
        PolarPlot[
          Abs[SphericalHarmonicY[l\_orb, m\_azm, \[Theta] - Pi/2, 
              0]], {\[Theta], \(-Pi\), 
            Pi}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              350}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.0115]}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.325\), 
                0.325}, {\(-0.755\), 
                0.755}}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.45, 0.45, 
              0.75], \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \
Y[3,0,\[Theta],\[CurlyPhi]]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(PltSphHarmDens[l\_orb, m\_azm] = 
        PolarPlot[\((Abs[
                SphericalHarmonicY[l\_orb, m\_azm, \[Theta] - Pi/2, 
                  0]])\)^2, \[IndentingNewLine]{\[Theta], \(-Pi\), 
            Pi}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              350}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.0115]}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.325\), 
                0.325}, {\(-0.755\), 
                0.755}}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \
|Y[3,0,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarm3d[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[Y[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[Y[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[Y[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {44, 
              44}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.325\), 
                0.325}, {\(-0.325\), 0.325}, {\(-0.755\), 
                0.755}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              350}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of Y[3,0,\
\[Theta],\[CurlyPhi]]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarm3dSeg[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[Y[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[Y[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[Y[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0, 
            Pi}, {\[CurlyPhi], 0, 
            Pi}, \[IndentingNewLine]PlotPoints \[Rule] {44, 
              22}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.325\), 
                0.325}, {\(-0.325\), 0.325}, {\(-0.755\), 
                0.755}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              350}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.6], \[IndentingNewLine]PlotLabel \[Rule] "\<Segment of Y[3,0,\
\[Theta],\[CurlyPhi]]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarmDens3d[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[YY[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[YY[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[YY[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0/2, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {44, 
              44}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.2\), 
                0.2}, {\(-0.2\), 0.2}, {\(-0.575\), 
                0.575}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              350}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of |Y[3,0,\
\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarmDens3dSeg[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*YY[l\_orb, m\_azm], 
            Cos[\[Theta]]*YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0, Pi}, {\[CurlyPhi], 0, 
            Pi}, \[IndentingNewLine]PlotPoints \[Rule] {44, 
              22}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.2\), 
                0.2}, {\(-0.2\), 0.2}, {\(-0.575\), 
                0.575}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              350}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.8, 
              0.8], \[IndentingNewLine]PlotLabel \[Rule] "\<Segment of \
|Y[3,0,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarmDens3dSm[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[YY[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[YY[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[YY[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0/2, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {36, 
              36}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.325\), 
                0.325}, {\(-0.325\), 0.325}, {\(-0.755\), 
                0.755}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              350}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of |Y[3,0,\
\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{SphHarm3d[l\_orb, m\_azm], 
            SphHarmDens3d[l\_orb, m\_azm]}, \[IndentingNewLine]{SphHarm3dSeg[
              l\_orb, m\_azm], 
            SphHarmDens3dSeg[l\_orb, m\_azm]}, {PltSphHarm[l\_orb, m\_azm], 
            PltSphHarmDens[l\_orb, 
              m\_azm]}}], \[IndentingNewLine]ImageSize \[Rule] {500, 
          1050}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Presentation of Plots \
for Y[3,0,\[Theta],\[CurlyPhi]] and |Y[3,0,\[Theta],\[CurlyPhi]]|^2\>"]\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{SphHarm3d[l\_orb, m\_azm], 
          SphHarmDens3dSm[l\_orb, 
            m\_azm]}], \[IndentingNewLine]ImageSize \[Rule] {650, 
          450}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Comparison of Plots \
for Y[3,0,\[Theta],\[CurlyPhi]] and |Y[3,0,\[Theta],\[CurlyPhi]]|^2\>"]\)}], \
"Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "8. Spherical Harmonic ",
  Cell[BoxData[
      \(Y[3, 1, \[Theta], \[CurlyPhi]]\)],
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  StyleBox[", ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(m\_azm = 1\)],
    FontSlant->"Italic"],
  ")"
}], "Subsection"],

Cell[BoxData[{
    \(l\_orb = 3\), "\[IndentingNewLine]", 
    \(m\_azm = 1\), "\[IndentingNewLine]", 
    \(Y[l\_orb, m\_azm] = 
      SphericalHarmonicY[l\_orb, 
        m\_azm, \[Theta], \[CurlyPhi]]\), "\[IndentingNewLine]", 
    \(\(\(YY[l\_orb, m\_azm] = 
      ComplexExpand[
        SphericalHarmonicY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]*
          Conjugate[
            SphericalHarmonicY[l\_orb, 
              m\_azm, \[Theta], \[CurlyPhi]]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(PltSphHarm[l\_orb, m\_azm] = 
        PolarPlot[
          Abs[SphericalHarmonicY[l\_orb, m\_azm, \[Theta] - Pi/2, 
              0]], {\[Theta], \(-Pi\), 
            Pi}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              300}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.0115]}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.33\), 
                0.33}, {\(-0.4\), 
                0.4}}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.45, 0.45, 
              0.75], \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \
Y[3,1,\[Theta],\[CurlyPhi]]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(PltSphHarmDens[l\_orb, m\_azm] = 
        PolarPlot[\((Abs[
                SphericalHarmonicY[l\_orb, m\_azm, \[Theta] - Pi/2, 
                  0]])\)^2, \[IndentingNewLine]{\[Theta], \(-Pi\), 
            Pi}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              300}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.0115]}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.33\), 
                0.33}, {\(-0.4\), 
                0.4}}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \
|Y[3,1,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarm3d[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[Y[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[Y[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[Y[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {50, 
              50}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.33\), 
                0.33}, {\(-0.33\), 0.33}, {\(-0.4\), 
                0.4}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              300}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of Y[3,1,\
\[Theta],\[CurlyPhi]]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarm3dSeg[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[Y[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[Y[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[Y[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0, 
            Pi}, {\[CurlyPhi], 0, 
            Pi}, \[IndentingNewLine]PlotPoints \[Rule] {50, 
              25}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.33\), 
                0.33}, {\(-0.33\), 0.33}, {\(-0.4\), 
                0.4}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              300}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.6], \[IndentingNewLine]PlotLabel \[Rule] "\<Segment of Y[3,1,\
\[Theta],\[CurlyPhi]]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarmDens3d[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[YY[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[YY[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[YY[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0/2, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {50, 
              50}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.13\), 
                0.13}, {\(-0.13\), 0.13}, {\(-0.185\), 
                0.185}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              300}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of |Y[3,1,\
\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarmDens3dSeg[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*YY[l\_orb, m\_azm], 
            Cos[\[Theta]]*YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0, Pi}, {\[CurlyPhi], 0, 
            Pi}, \[IndentingNewLine]PlotPoints \[Rule] {50, 
              25}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.13\), 
                0.13}, {\(-0.13\), 0.13}, {\(-0.185\), 
                0.185}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              300}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.8, 
              0.8], \[IndentingNewLine]PlotLabel \[Rule] "\<Segment of \
|Y[3,1,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarmDens3dSm[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[YY[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[YY[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[YY[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0/2, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {40, 
              40}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.33\), 
                0.33}, {\(-0.33\), 0.33}, {\(-0.4\), 
                0.4}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              300}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of |Y[3,1,\
\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{SphHarm3d[l\_orb, m\_azm], 
            SphHarmDens3d[l\_orb, m\_azm]}, \[IndentingNewLine]{SphHarm3dSeg[
              l\_orb, m\_azm], 
            SphHarmDens3dSeg[l\_orb, m\_azm]}, {PltSphHarm[l\_orb, m\_azm], 
            PltSphHarmDens[l\_orb, 
              m\_azm]}}], \[IndentingNewLine]ImageSize \[Rule] {500, 
          900}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Presentation of Plots \
for Y[3,1,\[Theta],\[CurlyPhi]] and |Y[3,1,\[Theta],\[CurlyPhi]]|^2\>"]\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{SphHarm3d[l\_orb, m\_azm], 
          SphHarmDens3dSm[l\_orb, 
            m\_azm]}], \[IndentingNewLine]ImageSize \[Rule] {650, 
          400}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Comparison of Plots \
for Y[3,1,\[Theta],\[CurlyPhi]] and |Y[3,1,\[Theta],\[CurlyPhi]]|^2\>"]\)}], \
"Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "9. Spherical Harmonic ",
  Cell[BoxData[
      \(Y[3, 2, \[Theta], \[CurlyPhi]]\)],
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  StyleBox[", ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(m\_azm = 2\)],
    FontSlant->"Italic"],
  ")"
}], "Subsection"],

Cell[BoxData[{
    \(l\_orb = 3\), "\[IndentingNewLine]", 
    \(m\_azm = 2\), "\[IndentingNewLine]", 
    \(Y[l\_orb, m\_azm] = 
      SphericalHarmonicY[l\_orb, 
        m\_azm, \[Theta], \[CurlyPhi]]\), "\[IndentingNewLine]", 
    \(\(\(YY[l\_orb, m\_azm] = 
      ComplexExpand[
        SphericalHarmonicY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]*
          Conjugate[
            SphericalHarmonicY[l\_orb, 
              m\_azm, \[Theta], \[CurlyPhi]]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(PltSphHarm[l\_orb, m\_azm] = 
        PolarPlot[
          Abs[SphericalHarmonicY[l\_orb, m\_azm, \[Theta] - Pi/2, 
              0]], {\[Theta], \(-Pi\), 
            Pi}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.0115]}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.345\), 
                0.345}, {\(-0.345\), 
                0.345}}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.45, 0.45, 
              0.75], \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \
Y[3,2,\[Theta],\[CurlyPhi]]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(PltSphHarmDens[l\_orb, m\_azm] = 
        PolarPlot[\((Abs[
                SphericalHarmonicY[l\_orb, m\_azm, \[Theta] - Pi/2, 
                  0]])\)^2, \[IndentingNewLine]{\[Theta], \(-Pi\), 
            Pi}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.0115]}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.345\), 
                0.345}, {\(-0.345\), 
                0.345}}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \
|Y[3,2,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarm3d[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[Y[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[Y[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[Y[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {40, 
              40}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.345\), 
                0.345}, {\(-0.345\), 0.345}, {\(-0.345\), 
                0.345}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of Y[3,2,\
\[Theta],\[CurlyPhi]]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarm3dSeg[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[Y[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[Y[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[Y[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0, 
            Pi}, {\[CurlyPhi], 0, 
            Pi}, \[IndentingNewLine]PlotPoints \[Rule] {40, 
              20}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.345\), 
                0.345}, {\(-0.345\), 0.345}, {\(-0.345\), 
                0.345}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.6], \[IndentingNewLine]PlotLabel \[Rule] "\<Segment of Y[3,2,\
\[Theta],\[CurlyPhi]]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarmDens3d[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[YY[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[YY[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[YY[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0/2, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {40, 
              40}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.14\), 
                0.14}, {\(-0.14\), 0.14}, {\(-0.14\), 
                0.14}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of |Y[3,2,\
\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarmDens3dSeg[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*YY[l\_orb, m\_azm], 
            Cos[\[Theta]]*YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0, Pi}, {\[CurlyPhi], 0, 
            Pi}, \[IndentingNewLine]PlotPoints \[Rule] {40, 
              20}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.14\), 
                0.14}, {\(-0.14\), 0.14}, {\(-0.14\), 
                0.14}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.8, 
              0.8], \[IndentingNewLine]PlotLabel \[Rule] "\<Segment of \
|Y[3,2,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarmDens3dSm[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[YY[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[YY[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[YY[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0/2, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.345\), 
                0.345}, {\(-0.345\), 0.345}, {\(-0.345\), 
                0.345}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of |Y[3,2,\
\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{SphHarm3d[l\_orb, m\_azm], 
            SphHarmDens3d[l\_orb, m\_azm]}, \[IndentingNewLine]{SphHarm3dSeg[
              l\_orb, m\_azm], 
            SphHarmDens3dSeg[l\_orb, m\_azm]}, {PltSphHarm[l\_orb, m\_azm], 
            PltSphHarmDens[l\_orb, 
              m\_azm]}}], \[IndentingNewLine]ImageSize \[Rule] {500, 
          750}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Presentation of Plots \
for Y[3,2,\[Theta],\[CurlyPhi]] and |Y[3,2,\[Theta],\[CurlyPhi]]|^2\>"]\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{SphHarm3d[l\_orb, m\_azm], 
          SphHarmDens3dSm[l\_orb, 
            m\_azm]}], \[IndentingNewLine]ImageSize \[Rule] {650, 
          375}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Comparison of Plots \
for Y[3,2,\[Theta],\[CurlyPhi]] and |Y[3,2,\[Theta],\[CurlyPhi]]|^2\>"]\)}], \
"Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "10. Spherical Harmonic ",
  Cell[BoxData[
      \(Y[3, 3, \[Theta], \[CurlyPhi]]\)],
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  StyleBox[", ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(m\_azm = 3\)],
    FontSlant->"Italic"],
  ")"
}], "Subsection"],

Cell[BoxData[{
    \(l\_orb = 3\), "\[IndentingNewLine]", 
    \(m\_azm = 3\), "\[IndentingNewLine]", 
    \(Y[l\_orb, m\_azm] = 
      SphericalHarmonicY[l\_orb, 
        m\_azm, \[Theta], \[CurlyPhi]]\), "\[IndentingNewLine]", 
    \(\(\(YY[l\_orb, m\_azm] = 
      ComplexExpand[
        SphericalHarmonicY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]*
          Conjugate[
            SphericalHarmonicY[l\_orb, 
              m\_azm, \[Theta], \[CurlyPhi]]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(PltSphHarm[l\_orb, m\_azm] = 
        PolarPlot[
          Abs[SphericalHarmonicY[l\_orb, m\_azm, \[Theta] - Pi/2, 
              0]], {\[Theta], \(-Pi\), 
            Pi}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.0115]}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.425\), 
                0.425}, {\(-0.425\), 
                0.425}}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.45, 0.45, 
              0.75], \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \
Y[3,3,\[Theta],\[CurlyPhi]]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(PltSphHarmDens[l\_orb, m\_azm] = 
        PolarPlot[\((Abs[
                SphericalHarmonicY[l\_orb, m\_azm, \[Theta] - Pi/2, 
                  0]])\)^2, \[IndentingNewLine]{\[Theta], \(-Pi\), 
            Pi}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]PlotStyle \[Rule] {Thickness[
                0.0115]}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.425\), 
                0.425}, {\(-0.425\), 
                0.425}}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \
|Y[3,3,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarm3d[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[Y[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[Y[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[Y[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {40, 
              40}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.425\), 
                0.425}, {\(-0.425\), 0.425}, {\(-0.425\), 
                0.425}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.5], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of Y[3,3,\
\[Theta],\[CurlyPhi]]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarm3dSeg[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[Y[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[Y[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[Y[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0, 
            Pi}, {\[CurlyPhi], 0, 
            Pi}, \[IndentingNewLine]PlotPoints \[Rule] {40, 
              20}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.425\), 
                0.425}, {\(-0.425\), 0.425}, {\(-0.425\), 
                0.425}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 
              0.6], \[IndentingNewLine]PlotLabel \[Rule] "\<Segment of Y[3,3,\
\[Theta],\[CurlyPhi]]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarmDens3d[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[YY[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[YY[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[YY[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0/2, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {40, 
              40}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.183\), 
                0.183}, {\(-0.183\), 0.183}, {\(-0.183\), 
                0.183}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of |Y[3,3,\
\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarmDens3dSeg[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*YY[l\_orb, m\_azm], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*YY[l\_orb, m\_azm], 
            Cos[\[Theta]]*YY[l\_orb, m\_azm]}, \[IndentingNewLine]{\[Theta], 
            0, Pi}, {\[CurlyPhi], 0, 
            Pi}, \[IndentingNewLine]PlotPoints \[Rule] {40, 
              20}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.183\), 
                0.183}, {\(-0.183\), 0.183}, {\(-0.183\), 
                0.183}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.8, 
              0.8], \[IndentingNewLine]PlotLabel \[Rule] "\<Segment of \
|Y[3,3,\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarmDens3dSm[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[YY[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[YY[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[YY[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0/2, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.425\), 
                0.425}, {\(-0.425\), 0.425}, {\(-0.425\), 
                0.425}}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of |Y[3,3,\
\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Show[
      GraphicsArray[{{SphHarm3d[l\_orb, m\_azm], 
            SphHarmDens3d[l\_orb, m\_azm]}, \[IndentingNewLine]{SphHarm3dSeg[
              l\_orb, m\_azm], 
            SphHarmDens3dSeg[l\_orb, m\_azm]}, {PltSphHarm[l\_orb, m\_azm], 
            PltSphHarmDens[l\_orb, 
              m\_azm]}}], \[IndentingNewLine]ImageSize \[Rule] {500, 
          750}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Presentation of Plots \
for Y[3,3,\[Theta],\[CurlyPhi]] and |Y[3,3,\[Theta],\[CurlyPhi]]|^2\>"]\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Show[
      GraphicsArray[{SphHarm3d[l\_orb, m\_azm], 
          SphHarmDens3dSm[l\_orb, 
            m\_azm]}], \[IndentingNewLine]ImageSize \[Rule] {650, 
          375}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Comparison of Plots \
for Y[3,3,\[Theta],\[CurlyPhi]] and |Y[3,3,\[Theta],\[CurlyPhi]]|^2\>"]\)}], \
"Input"],

Cell["", "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1016, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.25,
StyleDefinitions -> "Classroom1.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 174, 4, 56, "Subtitle"],
Cell[2447, 78, 207, 6, 97, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2679, 88, 60, 0, 85, "Section"],
Cell[2742, 90, 216, 4, 56, "Text"],
Cell[2961, 96, 152, 5, 56, "Text"],
Cell[3116, 103, 196, 8, 72, "NumberedEquation"],
Cell[3315, 113, 162, 8, 56, "Text"],
Cell[3480, 123, 174, 7, 57, "Text"],
Cell[3657, 132, 54, 1, 63, "Input"],
Cell[3714, 135, 1043, 33, 56, "Text"],
Cell[4760, 170, 6578, 197, 649, "Text"],
Cell[11341, 369, 263, 7, 92, "Text"],
Cell[11607, 378, 56, 0, 56, "Text"],
Cell[11666, 380, 156, 3, 113, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11859, 388, 96, 2, 85, "Section"],

Cell[CellGroupData[{
Cell[11980, 394, 374, 17, 89, "Subsection"],
Cell[12357, 413, 8053, 150, 2513, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20447, 568, 374, 17, 89, "Subsection"],
Cell[20824, 587, 8048, 152, 2513, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28909, 744, 374, 17, 89, "Subsection"],
Cell[29286, 763, 8096, 152, 2513, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37419, 920, 374, 17, 89, "Subsection"],
Cell[37796, 939, 8063, 152, 2513, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[45896, 1096, 374, 17, 89, "Subsection"],
Cell[46273, 1115, 8096, 152, 2513, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[54406, 1272, 374, 17, 89, "Subsection"],
Cell[54783, 1291, 8010, 150, 2513, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[62830, 1446, 374, 17, 89, "Subsection"],
Cell[63207, 1465, 8081, 152, 2513, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[71325, 1622, 374, 17, 89, "Subsection"],
Cell[71702, 1641, 8052, 152, 2513, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[79791, 1798, 374, 17, 89, "Subsection"],
Cell[80168, 1817, 8084, 152, 2513, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[88289, 1974, 375, 17, 89, "Subsection"],
Cell[88667, 1993, 8096, 152, 2513, "Input"],
Cell[96766, 2147, 16, 0, 56, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

