(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     64044,       1551]*)
(*NotebookOutlinePosition[     64773,       1576]*)
(*  CellTagsIndexPosition[     64729,       1572]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Quantum Mechanics of the Bound Isotropic Systems with \"",
  StyleBox["MATHEMATICA",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "\":\nAnalysis and Visualization of Quantum States"
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Alexei V. Tikhonenko\n",
  StyleBox["General",
    FontWeight->"Plain"],
  " ",
  StyleBox["Physics Department, Institute of Nuclear Power Engineering, \
Russia\navtikhon@okclub.org",
    FontWeight->"Plain"]
}], "Author",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Part ",
    FontWeight->"Bold"],
  StyleBox["5. Spherical Harmonics and Angular Probability Densities",
    FontWeight->"Bold"]
}], "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "5.3. Comparative Visualization of the ",
  StyleBox["Spherical Harmonics and Angular Probability Densities",
    FontWeight->"Bold"]
}], "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["1. General parameters and tools for plots", "Section"],

Cell[TextData[{
  StyleBox["In this file we will present visualizations in ",
    FontWeight->"Bold"],
  StyleBox["unified",
    FontWeight->"Bold"],
  StyleBox[" scales for states defined by given quantum numbers.",
    FontWeight->"Bold"]
}], "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Consider some special values of spherical harmonics defined by quantum \
numbers:\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  Cell[BoxData[
      \(l\_orb\)],
    FontSlant->"Italic"],
  " = 0, 1, 2, 3\n",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " = 0, 1, 2, 3"
}], "NumberedEquation"],

Cell[TextData[{
  "since positive values of ",
  Cell[BoxData[
      \(m\_azm\)],
    FontSlant->"Italic"],
  " ",
  "suffice",
  " for our purposes."
}], "Text"],

Cell[TextData[{
  "Start \"",
  StyleBox["Graphics",
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  "\" tool"
}], "Text"],

Cell[BoxData[
    \(<< Graphics`Graphics`\)], "Input"],

Cell[TextData[{
  "We will ",
  "visualize",
  " spherical harmonics ",
  Cell[BoxData[
      StyleBox[\(Y[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]\),
        FontFamily->"Courier New",
        FontSize->14,
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0.996109, 0.996109, 0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}]],
    FontSlant->"Italic"],
  "and angular probability density ",
  Cell[BoxData[
      StyleBox[
        RowBox[{"|", 
          RowBox[{
            StyleBox["Y",
              FontSlant->"Italic"], 
            StyleBox["[",
              FontSlant->"Italic"], 
            StyleBox[\(l\_orb, m\_azm, \[Theta], \[CurlyPhi]\),
              FontSlant->"Italic"], "]"}], \( | \^2\)}],
        FontFamily->"Courier New",
        FontSize->14,
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0.996109, 0.996109, 0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}]]],
  "."
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox["Plots",
    FontSize->22,
    FontWeight->"Bold"],
  "\n",
  Cell[BoxData[
      StyleBox[\(Y[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]\),
        FontFamily->"Courier New",
        FontSize->14,
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0.996109, 0.996109, 0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}]],
    FontSlant->"Italic"],
  "\n\t\t\t- spherical harmonics with given values of ",
  Cell[BoxData[
      StyleBox[\(l\_orb\),
        FontFamily->"Courier New",
        FontSize->14,
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0.996109, 0.996109, 0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}]],
    FontSlant->"Italic"],
  ", and ",
  Cell[BoxData[
      StyleBox[\(m\_azm\),
        FontFamily->"Courier New",
        FontSize->14,
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0.996109, 0.996109, 0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}]],
    FontSlant->"Italic"],
  ",\n",
  Cell[BoxData[
      StyleBox[\(YY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]\),
        FontFamily->"Courier New",
        FontSize->14,
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0.996109, 0.996109, 0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}]],
    FontSlant->"Italic"],
  "\n\t\t\t- angular density with given values of ",
  Cell[BoxData[
      StyleBox[\(l\_orb\),
        FontFamily->"Courier New",
        FontSize->14,
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0.996109, 0.996109, 0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}]],
    FontSlant->"Italic"],
  ", and ",
  Cell[BoxData[
      StyleBox[\(m\_azm\),
        FontFamily->"Courier New",
        FontSize->14,
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0.996109, 0.996109, 0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}]],
    FontSlant->"Italic"],
  ",\n",
  Cell[BoxData[
      StyleBox[\(PltSphHarm[l\_orb, m\_azm]\),
        FontWeight->"Bold"]],
    FontFamily->"Courier New",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  " \n\t\t\t- polar plot representing two-dimensional profile of spherical \
harmonic ",
  Cell[BoxData[
      StyleBox[\(Y[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]\),
        FontFamily->"Courier New",
        FontSize->14,
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0.996109, 0.996109, 0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}]],
    FontSlant->"Italic"],
  ",\n",
  Cell[BoxData[
      StyleBox[\(PltSphHarmDens[l\_orb, m\_azm]\),
        FontWeight->"Bold"]],
    FontFamily->"Courier New",
    FontSlant->"Italic",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  "\n\t\t\t- polar plot representing two-dimensional profile of angular \
density ",
  Cell[BoxData[
      StyleBox[\(YY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]\),
        FontFamily->"Courier New",
        FontSize->14,
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0.996109, 0.996109, 0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}]],
    FontSlant->"Italic"],
  ",\n",
  Cell[BoxData[
      StyleBox[\(SphHarm3d[l\_orb, m\_azm]\),
        FontWeight->"Bold",
        FontSlant->"Italic"]],
    FontFamily->"Courier New",
    FontColor->RGBColor[0.996109, 0.996109, 0]],
  "\n\t\t\t- three -dimensional representation of spherical harmonic ",
  Cell[BoxData[
      StyleBox[\(Y[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]\),
        FontFamily->"Courier New",
        FontSize->14,
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0.996109, 0.996109, 0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}]],
    FontSlant->"Italic"],
  ",\n",
  Cell[BoxData[
      StyleBox[\(SphHarm3dSeg[l\_orb, m\_azm]\),
        FontFamily->"Courier New",
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0.996109, 0.996109, 0]]]],
  "\n\t\t\t- segment of three -dimensional representation of spherical \
harmonic ",
  Cell[BoxData[
      StyleBox[\(Y[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]\),
        FontFamily->"Courier New",
        FontSize->14,
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0.996109, 0.996109, 0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}]],
    FontSlant->"Italic"],
  " (0 < \[CurlyPhi] < \[Pi]),\n",
  Cell[BoxData[
      StyleBox[\(SphHarmDens3d[l\_orb, m\_azm]\),
        FontFamily->"Courier New",
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0.996109, 0.996109, 0]]]],
  "\n\t\t\t- three -dimensional representation of angular density",
  Cell[BoxData[
      StyleBox[\(YY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]\),
        FontFamily->"Courier New",
        FontSize->14,
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0.996109, 0.996109, 0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}]],
    FontSlant->"Italic"],
  ",\n",
  Cell[BoxData[
      StyleBox[\(SphHarmDens3dSeg[l\_orb, m\_azm]\),
        FontFamily->"Courier New",
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0.996109, 0.996109, 0]]]],
  "\n\t\t\t- segment of three -dimensional representation of angular density \
",
  Cell[BoxData[
      StyleBox[\(YY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]\),
        FontFamily->"Courier New",
        FontSize->14,
        FontWeight->"Bold",
        FontSlant->"Italic",
        FontColor->RGBColor[0.996109, 0.996109, 0],
        FontVariations->{"Underline"->False,
        "StrikeThrough"->False}]],
    FontSlant->"Italic"],
  " (0 < \[CurlyPhi] < \[Pi]) \n\t\t\t(",
  Cell[BoxData[
      RowBox[{
        StyleBox["SphHarmDens3dSm",
          FontFamily->"Courier New",
          FontSize->14,
          FontWeight->"Bold",
          FontSlant->"Italic",
          FontColor->RGBColor[0.996109, 0.996109, 0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[" ",
          FontSlant->"Italic"]}]]],
  "has other quantity of plot points)."
}], "Text"],

Cell[TextData[{
  StyleBox["Note",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0.996109]],
  ":\t\t",
  "Plots with mazarine background represent spherical harmonics.\n\t\tPlots \
with cerise background represent spherical harmonics."
}], "Text"],

Cell["Define parameters of 3d plots:", "Text"],

Cell[BoxData[{
    \(\(ISHorz = 275;\)\), "\[IndentingNewLine]", 
    \(\(\(ISVert = 350;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x2dMin = \(-0.435\);\)\), "\[IndentingNewLine]", 
    \(\(x2dMax = 0.435;\)\), "\[IndentingNewLine]", 
    \(\(y2dMin = \(-0.755\);\)\), "\[IndentingNewLine]", 
    \(\(\(y2dMax = 0.755;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMin = \(-0.435\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMax = 0.435;\)\), "\[IndentingNewLine]", 
    \(\(y3dMin = \(-0.435\);\)\), "\[IndentingNewLine]", 
    \(\(y3dMax = 0.435;\)\), "\[IndentingNewLine]", 
    \(\(z3dMin = \(-0.755\);\)\), "\[IndentingNewLine]", 
    \(\(\(z3dMax = 0.755;\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(x3dMinD = \(-0.4\);\)\), "\[IndentingNewLine]", 
    \(\(x3dMaxD = 0.4;\)\), "\[IndentingNewLine]", 
    \(\(y3dMinD = \(-0.4\);\)\), "\[IndentingNewLine]", 
    \(\(y3dMaxD = 0.4;\)\), "\[IndentingNewLine]", 
    \(\(z3dMinD = \(-0.585\);\)\), "\[IndentingNewLine]", 
    \(\(z3dMaxD = 
        0.585;\)\[IndentingNewLine]\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(VP1 = 1.400;\)\), "\[IndentingNewLine]", 
    \(\(VP2 = \(-2.584\);\)\), "\[IndentingNewLine]", 
    \(\(VP3 = 1.677;\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2. Plots of the spherical harmonics and angular probability densities\
\>", "Section"],

Cell[CellGroupData[{

Cell[TextData[{
  "1. Spherical Harmonic ",
  Cell[BoxData[
      \(Y[0, 0, \[Theta], \[CurlyPhi]]\)],
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      \(l\_orb = 0\)],
    FontSlant->"Italic"],
  StyleBox[", ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(m\_azm = 0\)],
    FontSlant->"Italic"],
  ")"
}], "Subsection"],

Cell[BoxData[{
    \(l\_orb = 0\), "\[IndentingNewLine]", 
    \(m\_azm = 0\), "\[IndentingNewLine]", 
    \(Y[l\_orb, m\_azm] = 
      SphericalHarmonicY[l\_orb, 
        m\_azm, \[Theta], \[CurlyPhi]]\), "\[IndentingNewLine]", 
    \(\(\(YY[l\_orb, m\_azm] = 
      ComplexExpand[
        SphericalHarmonicY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]*
          Conjugate[
            SphericalHarmonicY[l\_orb, 
              m\_azm, \[Theta], \[CurlyPhi]]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(PltSphHarm[l\_orb, m\_azm] = 
        PolarPlot[{Abs[
              SphericalHarmonicY[l\_orb, m\_azm, \[Theta] - Pi/2, 
                0]], \((Abs[
                  SphericalHarmonicY[l\_orb, m\_azm, \[Theta] - Pi/2, 
                    0]])\)^2}, \[IndentingNewLine]{\[Theta], \(-Pi\), 
            Pi}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.45, 0.45, 
              0.75], \[IndentingNewLine]PlotStyle \[Rule] {{Thickness[
                  0.0115]}, {Thickness[
                  0.0215]}}, \[IndentingNewLine]PlotRange \[Rule] {{x2dMin, 
                x2dMax}, {y2dMin, 
                y2dMax}}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \
Y[0,0] and |Y[0,0]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarm3d[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[Y[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[Y[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[Y[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{x3dMin, 
                x3dMax}, {y3dMin, y3dMax}, {z3dMin, 
                z3dMax}}, \[IndentingNewLine]ImageSize \[Rule] {ISHorz, 
              ISVert}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of Y[0,0,\
\[Theta],\[CurlyPhi]]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarmDens3d[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[YY[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[YY[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[YY[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0/2, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{x3dMinD, 
                x3dMaxD}, {y3dMinD, y3dMaxD}, {z3dMinD, 
                z3dMaxD}}, \[IndentingNewLine]ImageSize \[Rule] {ISHorz, 
              ISVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of |Y[0,0,\
\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(SphHarmDens3dSm[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[YY[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[YY[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[YY[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0/2, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {20, 
              20}, \[IndentingNewLine]PlotRange \[Rule] {{x3dMin, 
                x3dMax}, {y3dMin, y3dMax}, {z3dMin, 
                z3dMax}}, \[IndentingNewLine]ImageSize \[Rule] {ISHorz, 
              ISVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of |Y[0,0,\
\[Theta],\[CurlyPhi]]|^2\>"];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "2. Spherical Harmonic ",
  Cell[BoxData[
      \(Y[1, 0, \[Theta], \[CurlyPhi]]\)],
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  StyleBox[", ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(m\_azm = 0\)],
    FontSlant->"Italic"],
  ")"
}], "Subsection"],

Cell[BoxData[{
    \(l\_orb = 1\), "\[IndentingNewLine]", 
    \(m\_azm = 0\), "\[IndentingNewLine]", 
    \(Y[l\_orb, m\_azm] = 
      SphericalHarmonicY[l\_orb, 
        m\_azm, \[Theta], \[CurlyPhi]]\), "\[IndentingNewLine]", 
    \(\(\(YY[l\_orb, m\_azm] = 
      ComplexExpand[
        SphericalHarmonicY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]*
          Conjugate[
            SphericalHarmonicY[l\_orb, 
              m\_azm, \[Theta], \[CurlyPhi]]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(PltSphHarm[l\_orb, m\_azm] = 
        PolarPlot[{Abs[
              SphericalHarmonicY[l\_orb, m\_azm, \[Theta] - Pi/2, 
                0]], \((Abs[
                  SphericalHarmonicY[l\_orb, m\_azm, \[Theta] - Pi/2, 
                    0]])\)^2}, \[IndentingNewLine]{\[Theta], \(-Pi\), 
            Pi}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.45, 0.45, 
              0.75], \[IndentingNewLine]PlotStyle \[Rule] {{Thickness[
                  0.0115]}, {Thickness[
                  0.0215]}}, \[IndentingNewLine]PlotRange \[Rule] {{x2dMin, 
                x2dMax}, {y2dMin, 
                y2dMax}}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \
Y[1,0] and |Y[1,0]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarm3d[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[Y[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[Y[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[Y[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{x3dMin, 
                x3dMax}, {y3dMin, y3dMax}, {z3dMin, 
                z3dMax}}, \[IndentingNewLine]ImageSize \[Rule] {ISHorz, 
              ISVert}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of Y[1,0,\
\[Theta],\[CurlyPhi]]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarmDens3d[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[YY[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[YY[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[YY[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0/2, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{x3dMinD, 
                x3dMaxD}, {y3dMinD, y3dMaxD}, {z3dMinD, 
                z3dMaxD}}, \[IndentingNewLine]ImageSize \[Rule] {ISHorz, 
              ISVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of |Y[1,0,\
\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(SphHarmDens3dSm[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[YY[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[YY[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[YY[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0/2, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {20, 
              20}, \[IndentingNewLine]PlotRange \[Rule] {{x3dMin, 
                x3dMax}, {y3dMin, y3dMax}, {z3dMin, 
                z3dMax}}, \[IndentingNewLine]ImageSize \[Rule] {ISHorz, 
              ISVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of |Y[1,0,\
\[Theta],\[CurlyPhi]]|^2\>"];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "3. Spherical Harmonic ",
  Cell[BoxData[
      \(Y[1, 1, \[Theta], \[CurlyPhi]]\)],
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      \(l\_orb = 1\)],
    FontSlant->"Italic"],
  StyleBox[", ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(m\_azm = 1\)],
    FontSlant->"Italic"],
  ")"
}], "Subsection"],

Cell[BoxData[{
    \(l\_orb = 1\), "\[IndentingNewLine]", 
    \(m\_azm = 1\), "\[IndentingNewLine]", 
    \(Y[l\_orb, m\_azm] = 
      SphericalHarmonicY[l\_orb, 
        m\_azm, \[Theta], \[CurlyPhi]]\), "\[IndentingNewLine]", 
    \(\(\(YY[l\_orb, m\_azm] = 
      ComplexExpand[
        SphericalHarmonicY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]*
          Conjugate[
            SphericalHarmonicY[l\_orb, 
              m\_azm, \[Theta], \[CurlyPhi]]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(PltSphHarm[l\_orb, m\_azm] = 
        PolarPlot[{Abs[
              SphericalHarmonicY[l\_orb, m\_azm, \[Theta] - Pi/2, 
                0]], \((Abs[
                  SphericalHarmonicY[l\_orb, m\_azm, \[Theta] - Pi/2, 
                    0]])\)^2}, \[IndentingNewLine]{\[Theta], \(-Pi\), 
            Pi}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.45, 0.45, 
              0.75], \[IndentingNewLine]PlotStyle \[Rule] {{Thickness[
                  0.0115]}, {Thickness[
                  0.0215]}}, \[IndentingNewLine]PlotRange \[Rule] {{x2dMin, 
                x2dMax}, {y2dMin, 
                y2dMax}}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \
Y[1,1] and |Y[1,1]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarm3d[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[Y[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[Y[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[Y[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{x3dMin, 
                x3dMax}, {y3dMin, y3dMax}, {z3dMin, 
                z3dMax}}, \[IndentingNewLine]ImageSize \[Rule] {ISHorz, 
              ISVert}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of Y[1,1,\
\[Theta],\[CurlyPhi]]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarmDens3d[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[YY[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[YY[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[YY[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0/2, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{x3dMinD, 
                x3dMaxD}, {y3dMinD, y3dMaxD}, {z3dMinD, 
                z3dMaxD}}, \[IndentingNewLine]ImageSize \[Rule] {ISHorz, 
              ISVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of |Y[1,1,\
\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(SphHarmDens3dSm[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[YY[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[YY[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[YY[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0/2, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {20, 
              20}, \[IndentingNewLine]PlotRange \[Rule] {{x3dMin, 
                x3dMax}, {y3dMin, y3dMax}, {z3dMin, 
                z3dMax}}, \[IndentingNewLine]ImageSize \[Rule] {ISHorz, 
              ISVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of |Y[1,1,\
\[Theta],\[CurlyPhi]]|^2\>"];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "4. Spherical Harmonic ",
  Cell[BoxData[
      \(Y[2, 0, \[Theta], \[CurlyPhi]]\)],
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  StyleBox[", ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(m\_azm = 0\)],
    FontSlant->"Italic"],
  ")"
}], "Subsection"],

Cell[BoxData[{
    \(l\_orb = 2\), "\[IndentingNewLine]", 
    \(m\_azm = 0\), "\[IndentingNewLine]", 
    \(Y[l\_orb, m\_azm] = 
      SphericalHarmonicY[l\_orb, 
        m\_azm, \[Theta], \[CurlyPhi]]\), "\[IndentingNewLine]", 
    \(\(\(YY[l\_orb, m\_azm] = 
      ComplexExpand[
        SphericalHarmonicY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]*
          Conjugate[
            SphericalHarmonicY[l\_orb, 
              m\_azm, \[Theta], \[CurlyPhi]]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(PltSphHarm[l\_orb, m\_azm] = 
        PolarPlot[{Abs[
              SphericalHarmonicY[l\_orb, m\_azm, \[Theta] - Pi/2, 
                0]], \((Abs[
                  SphericalHarmonicY[l\_orb, m\_azm, \[Theta] - Pi/2, 
                    0]])\)^2}, \[IndentingNewLine]{\[Theta], \(-Pi\), 
            Pi}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.45, 0.45, 
              0.75], \[IndentingNewLine]PlotStyle \[Rule] {{Thickness[
                  0.0115]}, {Thickness[
                  0.0215]}}, \[IndentingNewLine]PlotRange \[Rule] {{x2dMin, 
                x2dMax}, {y2dMin, 
                y2dMax}}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \
Y[2,0] and |Y[2,0]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarm3d[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[Y[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[Y[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[Y[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{x3dMin, 
                x3dMax}, {y3dMin, y3dMax}, {z3dMin, 
                z3dMax}}, \[IndentingNewLine]ImageSize \[Rule] {ISHorz, 
              ISVert}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of Y[2,0,\
\[Theta],\[CurlyPhi]]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarmDens3d[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[YY[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[YY[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[YY[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0/2, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{x3dMinD, 
                x3dMaxD}, {y3dMinD, y3dMaxD}, {z3dMinD, 
                z3dMaxD}}, \[IndentingNewLine]ImageSize \[Rule] {ISHorz, 
              ISVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of |Y[2,0,\
\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(SphHarmDens3dSm[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[YY[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[YY[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[YY[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0/2, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {20, 
              20}, \[IndentingNewLine]PlotRange \[Rule] {{x3dMin, 
                x3dMax}, {y3dMin, y3dMax}, {z3dMin, 
                z3dMax}}, \[IndentingNewLine]ImageSize \[Rule] {ISHorz, 
              ISVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of |Y[2,0,\
\[Theta],\[CurlyPhi]]|^2\>"];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "5. Spherical Harmonic ",
  Cell[BoxData[
      \(Y[2, 1, \[Theta], \[CurlyPhi]]\)],
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  StyleBox[", ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(m\_azm = 1\)],
    FontSlant->"Italic"],
  ")"
}], "Subsection"],

Cell[BoxData[{
    \(l\_orb = 2\), "\[IndentingNewLine]", 
    \(m\_azm = 1\), "\[IndentingNewLine]", 
    \(Y[l\_orb, m\_azm] = 
      SphericalHarmonicY[l\_orb, 
        m\_azm, \[Theta], \[CurlyPhi]]\), "\[IndentingNewLine]", 
    \(\(\(YY[l\_orb, m\_azm] = 
      ComplexExpand[
        SphericalHarmonicY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]*
          Conjugate[
            SphericalHarmonicY[l\_orb, 
              m\_azm, \[Theta], \[CurlyPhi]]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(PltSphHarm[l\_orb, m\_azm] = 
        PolarPlot[{Abs[
              SphericalHarmonicY[l\_orb, m\_azm, \[Theta] - Pi/2, 
                0]], \((Abs[
                  SphericalHarmonicY[l\_orb, m\_azm, \[Theta] - Pi/2, 
                    0]])\)^2}, \[IndentingNewLine]{\[Theta], \(-Pi\), 
            Pi}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.45, 0.45, 
              0.75], \[IndentingNewLine]PlotStyle \[Rule] {{Thickness[
                  0.0115]}, {Thickness[
                  0.0215]}}, \[IndentingNewLine]PlotRange \[Rule] {{x2dMin, 
                x2dMax}, {y2dMin, 
                y2dMax}}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \
Y[2,1] and |Y[2,1]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarm3d[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[Y[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[Y[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[Y[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{x3dMin, 
                x3dMax}, {y3dMin, y3dMax}, {z3dMin, 
                z3dMax}}, \[IndentingNewLine]ImageSize \[Rule] {ISHorz, 
              ISVert}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of Y[2,1,\
\[Theta],\[CurlyPhi]]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarmDens3d[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[YY[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[YY[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[YY[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0/2, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{x3dMinD, 
                x3dMaxD}, {y3dMinD, y3dMaxD}, {z3dMinD, 
                z3dMaxD}}, \[IndentingNewLine]ImageSize \[Rule] {ISHorz, 
              ISVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of |Y[2,1,\
\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(SphHarmDens3dSm[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[YY[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[YY[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[YY[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0/2, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {20, 
              20}, \[IndentingNewLine]PlotRange \[Rule] {{x3dMin, 
                x3dMax}, {y3dMin, y3dMax}, {z3dMin, 
                z3dMax}}, \[IndentingNewLine]ImageSize \[Rule] {ISHorz, 
              ISVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of |Y[2,1,\
\[Theta],\[CurlyPhi]]|^2\>"];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "6. Spherical Harmonic ",
  Cell[BoxData[
      \(Y[2, 2, \[Theta], \[CurlyPhi]]\)],
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      \(l\_orb = 2\)],
    FontSlant->"Italic"],
  StyleBox[", ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(m\_azm = 2\)],
    FontSlant->"Italic"],
  ")"
}], "Subsection"],

Cell[BoxData[{
    \(l\_orb = 2\), "\[IndentingNewLine]", 
    \(m\_azm = 2\), "\[IndentingNewLine]", 
    \(Y[l\_orb, m\_azm] = 
      SphericalHarmonicY[l\_orb, 
        m\_azm, \[Theta], \[CurlyPhi]]\), "\[IndentingNewLine]", 
    \(\(\(YY[l\_orb, m\_azm] = 
      ComplexExpand[
        SphericalHarmonicY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]*
          Conjugate[
            SphericalHarmonicY[l\_orb, 
              m\_azm, \[Theta], \[CurlyPhi]]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(PltSphHarm[l\_orb, m\_azm] = 
        PolarPlot[{Abs[
              SphericalHarmonicY[l\_orb, m\_azm, \[Theta] - Pi/2, 
                0]], \((Abs[
                  SphericalHarmonicY[l\_orb, m\_azm, \[Theta] - Pi/2, 
                    0]])\)^2}, \[IndentingNewLine]{\[Theta], \(-Pi\), 
            Pi}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.45, 0.45, 
              0.75], \[IndentingNewLine]PlotStyle \[Rule] {{Thickness[
                  0.0115]}, {Thickness[
                  0.0215]}}, \[IndentingNewLine]PlotRange \[Rule] {{x2dMin, 
                x2dMax}, {y2dMin, 
                y2dMax}}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \
Y[2,2] and |Y[2,2]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarm3d[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[Y[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[Y[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[Y[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{x3dMin, 
                x3dMax}, {y3dMin, y3dMax}, {z3dMin, 
                z3dMax}}, \[IndentingNewLine]ImageSize \[Rule] {ISHorz, 
              ISVert}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of Y[2,2,\
\[Theta],\[CurlyPhi]]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarmDens3d[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[YY[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[YY[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[YY[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0/2, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{x3dMinD, 
                x3dMaxD}, {y3dMinD, y3dMaxD}, {z3dMinD, 
                z3dMaxD}}, \[IndentingNewLine]ImageSize \[Rule] {ISHorz, 
              ISVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of |Y[2,2,\
\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(SphHarmDens3dSm[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[YY[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[YY[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[YY[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0/2, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {20, 
              20}, \[IndentingNewLine]PlotRange \[Rule] {{x3dMin, 
                x3dMax}, {y3dMin, y3dMax}, {z3dMin, 
                z3dMax}}, \[IndentingNewLine]ImageSize \[Rule] {ISHorz, 
              ISVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of |Y[2,2,\
\[Theta],\[CurlyPhi]]|^2\>"];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "7. Spherical Harmonic ",
  Cell[BoxData[
      \(Y[3, 0, \[Theta], \[CurlyPhi]]\)],
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  StyleBox[", ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(m\_azm = 0\)],
    FontSlant->"Italic"],
  ")"
}], "Subsection"],

Cell[BoxData[{
    \(l\_orb = 3\), "\[IndentingNewLine]", 
    \(m\_azm = 0\), "\[IndentingNewLine]", 
    \(Y[l\_orb, m\_azm] = 
      SphericalHarmonicY[l\_orb, 
        m\_azm, \[Theta], \[CurlyPhi]]\), "\[IndentingNewLine]", 
    \(\(\(YY[l\_orb, m\_azm] = 
      ComplexExpand[
        SphericalHarmonicY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]*
          Conjugate[
            SphericalHarmonicY[l\_orb, 
              m\_azm, \[Theta], \[CurlyPhi]]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(PltSphHarm[l\_orb, m\_azm] = 
        PolarPlot[{Abs[
              SphericalHarmonicY[l\_orb, m\_azm, \[Theta] - Pi/2, 
                0]], \((Abs[
                  SphericalHarmonicY[l\_orb, m\_azm, \[Theta] - Pi/2, 
                    0]])\)^2}, \[IndentingNewLine]{\[Theta], \(-Pi\), 
            Pi}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.45, 0.45, 
              0.75], \[IndentingNewLine]PlotStyle \[Rule] {{Thickness[
                  0.0115]}, {Thickness[
                  0.0215]}}, \[IndentingNewLine]PlotRange \[Rule] {{x2dMin, 
                x2dMax}, {y2dMin, 
                y2dMax}}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \
Y[3,0] and |Y[3,0]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarm3d[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[Y[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[Y[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[Y[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{x3dMin, 
                x3dMax}, {y3dMin, y3dMax}, {z3dMin, 
                z3dMax}}, \[IndentingNewLine]ImageSize \[Rule] {ISHorz, 
              ISVert}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of Y[3,0,\
\[Theta],\[CurlyPhi]]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarmDens3d[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[YY[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[YY[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[YY[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0/2, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{x3dMinD, 
                x3dMaxD}, {y3dMinD, y3dMaxD}, {z3dMinD, 
                z3dMaxD}}, \[IndentingNewLine]ImageSize \[Rule] {ISHorz, 
              ISVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of |Y[3,0,\
\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(SphHarmDens3dSm[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[YY[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[YY[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[YY[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0/2, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {20, 
              20}, \[IndentingNewLine]PlotRange \[Rule] {{x3dMin, 
                x3dMax}, {y3dMin, y3dMax}, {z3dMin, 
                z3dMax}}, \[IndentingNewLine]ImageSize \[Rule] {ISHorz, 
              ISVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of |Y[3,0,\
\[Theta],\[CurlyPhi]]|^2\>"];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "8. Spherical Harmonic ",
  Cell[BoxData[
      \(Y[3, 1, \[Theta], \[CurlyPhi]]\)],
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  StyleBox[", ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(m\_azm = 1\)],
    FontSlant->"Italic"],
  ")"
}], "Subsection"],

Cell[BoxData[{
    \(l\_orb = 3\), "\[IndentingNewLine]", 
    \(m\_azm = 1\), "\[IndentingNewLine]", 
    \(Y[l\_orb, m\_azm] = 
      SphericalHarmonicY[l\_orb, 
        m\_azm, \[Theta], \[CurlyPhi]]\), "\[IndentingNewLine]", 
    \(YY[l\_orb, m\_azm] = 
      ComplexExpand[
        SphericalHarmonicY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]*
          Conjugate[
            SphericalHarmonicY[l\_orb, 
              m\_azm, \[Theta], \[CurlyPhi]]]]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(PltSphHarm[l\_orb, m\_azm] = 
        PolarPlot[{Abs[
              SphericalHarmonicY[l\_orb, m\_azm, \[Theta] - Pi/2, 
                0]], \((Abs[
                  SphericalHarmonicY[l\_orb, m\_azm, \[Theta] - Pi/2, 
                    0]])\)^2}, \[IndentingNewLine]{\[Theta], \(-Pi\), 
            Pi}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.45, 0.45, 
              0.75], \[IndentingNewLine]PlotStyle \[Rule] {{Thickness[
                  0.0115]}, {Thickness[
                  0.0215]}}, \[IndentingNewLine]PlotRange \[Rule] {{x2dMin, 
                x2dMax}, {y2dMin, 
                y2dMax}}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \
Y[3,1] and |Y[3,1]|^2\>"];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(SphHarm3d[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[Y[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[Y[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[Y[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{x3dMin, 
                x3dMax}, {y3dMin, y3dMax}, {z3dMin, 
                z3dMax}}, \[IndentingNewLine]ImageSize \[Rule] {ISHorz, 
              ISVert}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of Y[3,1,\
\[Theta],\[CurlyPhi]]\>"];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(SphHarmDens3d[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[YY[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[YY[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[YY[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0/2, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{x3dMinD, 
                x3dMaxD}, {y3dMinD, y3dMaxD}, {z3dMinD, 
                z3dMaxD}}, \[IndentingNewLine]ImageSize \[Rule] {ISHorz, 
              ISVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of |Y[3,1,\
\[Theta],\[CurlyPhi]]|^2\>"];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(SphHarmDens3dSm[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[YY[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[YY[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[YY[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0/2, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {20, 
              20}, \[IndentingNewLine]PlotRange \[Rule] {{x3dMin, 
                x3dMax}, {y3dMin, y3dMax}, {z3dMin, 
                z3dMax}}, \[IndentingNewLine]ImageSize \[Rule] {ISHorz, 
              ISVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of |Y[3,1,\
\[Theta],\[CurlyPhi]]|^2\>"];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "9. Spherical Harmonic ",
  Cell[BoxData[
      \(Y[3, 2, \[Theta], \[CurlyPhi]]\)],
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  StyleBox[", ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(m\_azm = 2\)],
    FontSlant->"Italic"],
  ")"
}], "Subsection"],

Cell[BoxData[{
    \(l\_orb = 3\), "\[IndentingNewLine]", 
    \(m\_azm = 2\), "\[IndentingNewLine]", 
    \(Y[l\_orb, m\_azm] = 
      SphericalHarmonicY[l\_orb, 
        m\_azm, \[Theta], \[CurlyPhi]]\), "\[IndentingNewLine]", 
    \(\(\(YY[l\_orb, m\_azm] = 
      ComplexExpand[
        SphericalHarmonicY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]*
          Conjugate[
            SphericalHarmonicY[l\_orb, 
              m\_azm, \[Theta], \[CurlyPhi]]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(PltSphHarm[l\_orb, m\_azm] = 
        PolarPlot[{Abs[
              SphericalHarmonicY[l\_orb, m\_azm, \[Theta] - Pi/2, 
                0]], \((Abs[
                  SphericalHarmonicY[l\_orb, m\_azm, \[Theta] - Pi/2, 
                    0]])\)^2}, \[IndentingNewLine]{\[Theta], \(-Pi\), 
            Pi}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.45, 0.45, 
              0.75], \[IndentingNewLine]PlotStyle \[Rule] {{Thickness[
                  0.0115]}, {Thickness[
                  0.0215]}}, \[IndentingNewLine]PlotRange \[Rule] {{x2dMin, 
                x2dMax}, {y2dMin, 
                y2dMax}}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \
Y[3,2] and |Y[3,2]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarm3d[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[Y[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[Y[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[Y[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{x3dMin, 
                x3dMax}, {y3dMin, y3dMax}, {z3dMin, 
                z3dMax}}, \[IndentingNewLine]ImageSize \[Rule] {ISHorz, 
              ISVert}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of Y[3,2,\
\[Theta],\[CurlyPhi]]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarmDens3d[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[YY[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[YY[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[YY[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0/2, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{x3dMinD, 
                x3dMaxD}, {y3dMinD, y3dMaxD}, {z3dMinD, 
                z3dMaxD}}, \[IndentingNewLine]ImageSize \[Rule] {ISHorz, 
              ISVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of |Y[3,2,\
\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(SphHarmDens3dSm[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[YY[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[YY[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[YY[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0/2, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {20, 
              20}, \[IndentingNewLine]PlotRange \[Rule] {{x3dMin, 
                x3dMax}, {y3dMin, y3dMax}, {z3dMin, 
                z3dMax}}, \[IndentingNewLine]ImageSize \[Rule] {ISHorz, 
              ISVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of |Y[3,2,\
\[Theta],\[CurlyPhi]]|^2\>"];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "10. Spherical Harmonic ",
  Cell[BoxData[
      \(Y[3, 3, \[Theta], \[CurlyPhi]]\)],
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "(",
  Cell[BoxData[
      \(l\_orb = 3\)],
    FontSlant->"Italic"],
  StyleBox[", ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(m\_azm = 3\)],
    FontSlant->"Italic"],
  ")"
}], "Subsection"],

Cell[BoxData[{
    \(l\_orb = 3\), "\[IndentingNewLine]", 
    \(m\_azm = 3\), "\[IndentingNewLine]", 
    \(Y[l\_orb, m\_azm] = 
      SphericalHarmonicY[l\_orb, 
        m\_azm, \[Theta], \[CurlyPhi]]\), "\[IndentingNewLine]", 
    \(\(\(YY[l\_orb, m\_azm] = 
      ComplexExpand[
        SphericalHarmonicY[l\_orb, m\_azm, \[Theta], \[CurlyPhi]]*
          Conjugate[
            SphericalHarmonicY[l\_orb, 
              m\_azm, \[Theta], \[CurlyPhi]]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(PltSphHarm[l\_orb, m\_azm] = 
        PolarPlot[{Abs[
              SphericalHarmonicY[l\_orb, m\_azm, \[Theta] - Pi/2, 
                0]], \((Abs[
                  SphericalHarmonicY[l\_orb, m\_azm, \[Theta] - Pi/2, 
                    0]])\)^2}, \[IndentingNewLine]{\[Theta], \(-Pi\), 
            Pi}, \[IndentingNewLine]ImageSize \[Rule] {275, 
              275}, \[IndentingNewLine]Frame \[Rule] 
            True, \[IndentingNewLine]GridLines \[Rule] 
            Automatic, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.45, 0.45, 
              0.75], \[IndentingNewLine]PlotStyle \[Rule] {{Thickness[
                  0.0115]}, {Thickness[
                  0.0215]}}, \[IndentingNewLine]PlotRange \[Rule] {{x2dMin, 
                x2dMax}, {y2dMin, 
                y2dMax}}, \[IndentingNewLine]PlotLabel \[Rule] "\<Profile of \
Y[3,3] and |Y[3,3]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarm3d[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[Y[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[Y[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[Y[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{x3dMin, 
                x3dMax}, {y3dMin, y3dMax}, {z3dMin, 
                z3dMax}}, \[IndentingNewLine]ImageSize \[Rule] {ISHorz, 
              ISVert}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[0.1, 0.1, 0.5], \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of Y[3,3,\
\[Theta],\[CurlyPhi]]\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(SphHarmDens3d[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[YY[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[YY[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[YY[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0/2, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {30, 
              30}, \[IndentingNewLine]PlotRange \[Rule] {{x3dMinD, 
                x3dMaxD}, {y3dMinD, y3dMaxD}, {z3dMinD, 
                z3dMaxD}}, \[IndentingNewLine]ImageSize \[Rule] {ISHorz, 
              ISVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of |Y[3,3,\
\[Theta],\[CurlyPhi]]|^2\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(SphHarmDens3dSm[l\_orb, m\_azm] = 
        ParametricPlot3D[{Sin[\[Theta]]\ Cos[\[CurlyPhi]]*
              Abs[YY[l\_orb, m\_azm]], 
            Sin[\[Theta]]\ Sin[\[CurlyPhi]]*Abs[YY[l\_orb, m\_azm]], 
            Cos[\[Theta]]*
              Abs[YY[l\_orb, m\_azm]]}, \[IndentingNewLine]{\[Theta], 0/2, 
            Pi}, {\[CurlyPhi], 0, 
            2  Pi}, \[IndentingNewLine]PlotPoints \[Rule] {20, 
              20}, \[IndentingNewLine]PlotRange \[Rule] {{x3dMin, 
                x3dMax}, {y3dMin, y3dMax}, {z3dMin, 
                z3dMax}}, \[IndentingNewLine]ImageSize \[Rule] {ISHorz, 
              ISVert}, \[IndentingNewLine]Axes \[Rule] 
            False, \[IndentingNewLine]ViewPoint -> {VP1, \ VP2, \ 
              VP3}, \[IndentingNewLine]Background \[Rule] 
            RGBColor[1.0, 0.85, 
              0.85], \[IndentingNewLine]PlotLabel \[Rule] "\<Plot of |Y[3,3,\
\[Theta],\[CurlyPhi]]|^2\>"];\)\)}], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "3. Comparative Visualization of the ",
  StyleBox["Spherical Harmonics and Angular Probability Densities",
    FontWeight->"Bold"]
}], "Section"],

Cell["\<\
Now we will present visualizations in unified scale for states defined by \
given quantum numbers.\
\>", "Text",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(Show[
      GraphicsArray[{{PltSphHarm[0, 0]}, {PltSphHarm[1, 0], 
            PltSphHarm[1, 1]}, {PltSphHarm[2, 0], PltSphHarm[2, 1], 
            PltSphHarm[2, 2]}, {PltSphHarm[3, 0], PltSphHarm[3, 1], 
            PltSphHarm[3, 2], 
            PltSphHarm[3, 3]}}], \[IndentingNewLine]ImageSize \[Rule] {650, 
          1150}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Comparison of Y[l,m,\
\[Theta],\[CurlyPhi]] and |Y[l,m,\[Theta],\[CurlyPhi]]|^2 Profiles\>"]\)], \
"Input"],

Cell[BoxData[
    \(Show[
      GraphicsArray[{{SphHarm3d[0, 0]}, {SphHarm3d[1, 0], 
            SphHarm3d[1, 1]}, {SphHarm3d[2, 0], SphHarm3d[2, 1], 
            SphHarm3d[2, 2]}, {SphHarm3d[3, 0], SphHarm3d[3, 1], 
            SphHarm3d[3, 2], 
            SphHarm3d[3, 3]}}], \[IndentingNewLine]ImageSize \[Rule] {750, 
          1150}, \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 
          0.0], \[IndentingNewLine]PlotLabel \[Rule] "\<Comparison of Y[l,m,\
\[Theta],\[CurlyPhi]] functions\>"]\)], "Input"],

Cell[BoxData[
    \(Show[
      GraphicsArray[{{SphHarmDens3d[0, 0]}, {SphHarmDens3d[1, 0], 
            SphHarmDens3d[1, 1]}, {SphHarmDens3d[2, 0], SphHarmDens3d[2, 1], 
            SphHarmDens3d[2, 2]}, {SphHarmDens3d[3, 0], SphHarmDens3d[3, 1], 
            SphHarmDens3d[3, 2], \[IndentingNewLine]SphHarmDens3d[3, 
              3]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 0.0], \[IndentingNewLine]ImageSize \[Rule] {850, 
          1150}, \[IndentingNewLine]PlotLabel \[Rule] "\<Comparison of \
|Y[l,m,\[Theta],\[CurlyPhi]]|^2 Densities\>"]\)], "Input"],

Cell[BoxData[
    \(Show[
      GraphicsArray[{{SphHarm3d[0, 0], 
            SphHarmDens3d[0, 0]}, {SphHarm3d[1, 0], SphHarmDens3d[1, 0], 
            SphHarm3d[1, 1], 
            SphHarmDens3d[1, 1]}, \[IndentingNewLine]{SphHarm3d[2, 0], 
            SphHarmDens3d[2, 0], SphHarm3d[2, 1], SphHarmDens3d[2, 1], 
            SphHarm3d[2, 2], SphHarmDens3d[2, 2]}, {SphHarm3d[3, 0], 
            SphHarmDens3d[3, 0], SphHarm3d[3, 1], SphHarmDens3d[3, 1], 
            SphHarm3d[3, 2], 
            SphHarmDens3d[3, 2], \[IndentingNewLine]SphHarm3d[3, 
              3], \[IndentingNewLine]SphHarmDens3d[3, 
              3]}}], \[IndentingNewLine]Background \[Rule] 
        RGBColor[0.0, 0.75, 0.0], \[IndentingNewLine]ImageSize \[Rule] {1250, 
          1050}, \[IndentingNewLine]PlotLabel \[Rule] "\<Comparison of Y[l,m,\
\[Theta],\[CurlyPhi]] and |Y[l,m,\[Theta],\[CurlyPhi]]|^2\>"]\)], "Input"]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->"EditBar",
WindowSize->{1016, 654},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.25,
StyleDefinitions -> "Classroom1.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 269, 8, 117, "Title"],
Cell[1977, 60, 290, 10, 105, "Author"],
Cell[2270, 72, 220, 7, 56, "Subtitle"],
Cell[2493, 81, 219, 6, 97, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2737, 91, 60, 0, 85, "Section"],
Cell[2800, 93, 299, 9, 56, "Text"],
Cell[3102, 104, 152, 5, 56, "Text"],
Cell[3257, 111, 200, 9, 74, "NumberedEquation"],
Cell[3460, 122, 162, 8, 56, "Text"],
Cell[3625, 132, 174, 7, 57, "Text"],
Cell[3802, 141, 54, 1, 63, "Input"],
Cell[3859, 144, 1043, 33, 56, "Text"],
Cell[4905, 179, 6579, 197, 649, "Text"],
Cell[11487, 378, 263, 7, 92, "Text"],
Cell[11753, 387, 46, 0, 56, "Text"],
Cell[11802, 389, 1289, 26, 688, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13128, 420, 96, 2, 85, "Section"],

Cell[CellGroupData[{
Cell[13249, 426, 374, 17, 89, "Subsection"],
Cell[13626, 445, 4373, 82, 1388, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18036, 532, 374, 17, 89, "Subsection"],
Cell[18413, 551, 4373, 82, 1388, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22823, 638, 374, 17, 89, "Subsection"],
Cell[23200, 657, 4373, 82, 1388, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27610, 744, 374, 17, 89, "Subsection"],
Cell[27987, 763, 4373, 82, 1388, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32397, 850, 374, 17, 89, "Subsection"],
Cell[32774, 869, 4373, 82, 1388, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37184, 956, 374, 17, 89, "Subsection"],
Cell[37561, 975, 4373, 82, 1388, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41971, 1062, 374, 17, 89, "Subsection"],
Cell[42348, 1081, 4373, 82, 1388, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[46758, 1168, 374, 17, 89, "Subsection"],
Cell[47135, 1187, 4319, 79, 1388, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[51491, 1271, 374, 17, 89, "Subsection"],
Cell[51868, 1290, 4373, 82, 1388, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[56278, 1377, 375, 17, 89, "Subsection"],
Cell[56656, 1396, 4373, 82, 1388, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[61078, 1484, 164, 4, 85, "Section"],
Cell[61245, 1490, 169, 5, 56, "Text"],
Cell[61417, 1497, 581, 11, 188, "Input"],
Cell[62001, 1510, 534, 10, 188, "Input"],
Cell[62538, 1522, 588, 9, 263, "Input"],
Cell[63129, 1533, 899, 15, 313, "Input"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

